#line 1 "ad_aarch64.cpp"
//
// Copyright (c) 2003, 2022, Oracle and/or its affiliates. All rights reserved.
// Copyright (c) 2014, 2021, Red Hat, Inc. All rights reserved.
// DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
//
// This code is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License version 2 only, as
// published by the Free Software Foundation.
//
// This code is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// version 2 for more details (a copy is included in the LICENSE file that
// accompanied this code).
//
// You should have received a copy of the GNU General Public License version
// 2 along with this work; if not, write to the Free Software Foundation,
// Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
// or visit www.oracle.com if you need additional information or have any
// questions.
//
//

// Machine Generated File.  Do Not Edit!

#include "precompiled.hpp"
#include "adfiles/adGlobals_aarch64.hpp"
#include "adfiles/ad_aarch64.hpp"
#include "memory/allocation.inline.hpp"
#include "code/codeCache.hpp"
#include "code/compiledIC.hpp"
#include "code/nativeInst.hpp"
#include "code/vmreg.inline.hpp"
#include "gc/shared/collectedHeap.inline.hpp"
#include "oops/compiledICHolder.hpp"
#include "oops/compressedOops.hpp"
#include "oops/markWord.hpp"
#include "oops/method.hpp"
#include "oops/oop.inline.hpp"
#include "opto/c2_MacroAssembler.hpp"
#include "opto/cfgnode.hpp"
#include "opto/intrinsicnode.hpp"
#include "opto/locknode.hpp"
#include "opto/opcodes.hpp"
#include "opto/regalloc.hpp"
#include "opto/regmask.hpp"
#include "opto/runtime.hpp"
#include "runtime/safepointMechanism.hpp"
#include "runtime/sharedRuntime.hpp"
#include "runtime/stubRoutines.hpp"
#include "utilities/growableArray.hpp"
#include "utilities/powerOfTwo.hpp"

//SourceForm

#line 1196 "src/hotspot/cpu/aarch64/aarch64.ad"


  // Derived RegMask with conditionally allocatable registers

  void PhaseOutput::pd_perform_mach_node_analysis() {
  }

  int MachNode::pd_alignment_required() const {
    return 1;
  }

  int MachNode::compute_padding(int current_offset) const {
    return 0;
  }

  RegMask _ANY_REG32_mask;
  RegMask _ANY_REG_mask;
  RegMask _PTR_REG_mask;
  RegMask _NO_SPECIAL_REG32_mask;
  RegMask _NO_SPECIAL_REG_mask;
  RegMask _NO_SPECIAL_PTR_REG_mask;

  void reg_mask_init() {
    // We derive below RegMask(s) from the ones which are auto-generated from
    // adlc register classes to make AArch64 rheapbase (r27) and rfp (r29)
    // registers conditionally reserved.

    _ANY_REG32_mask = _ALL_REG32_mask;
    _ANY_REG32_mask.Remove(OptoReg::as_OptoReg(r31_sp->as_VMReg()));

    _ANY_REG_mask = _ALL_REG_mask;

    _PTR_REG_mask = _ALL_REG_mask;

    _NO_SPECIAL_REG32_mask = _ALL_REG32_mask;
    _NO_SPECIAL_REG32_mask.SUBTRACT(_NON_ALLOCATABLE_REG32_mask);

    _NO_SPECIAL_REG_mask = _ALL_REG_mask;
    _NO_SPECIAL_REG_mask.SUBTRACT(_NON_ALLOCATABLE_REG_mask);

    _NO_SPECIAL_PTR_REG_mask = _ALL_REG_mask;
    _NO_SPECIAL_PTR_REG_mask.SUBTRACT(_NON_ALLOCATABLE_REG_mask);

    // r27 is not allocatable when compressed oops is on and heapbase is not
    // zero, compressed klass pointers doesn't use r27 after JDK-8234794
    if (UseCompressedOops && (CompressedOops::ptrs_base() != NULL)) {
      _NO_SPECIAL_REG32_mask.Remove(OptoReg::as_OptoReg(r27->as_VMReg()));
      _NO_SPECIAL_REG_mask.SUBTRACT(_HEAPBASE_REG_mask);
      _NO_SPECIAL_PTR_REG_mask.SUBTRACT(_HEAPBASE_REG_mask);
    }

    // r29 is not allocatable when PreserveFramePointer is on
    if (PreserveFramePointer) {
      _NO_SPECIAL_REG32_mask.Remove(OptoReg::as_OptoReg(r29->as_VMReg()));
      _NO_SPECIAL_REG_mask.SUBTRACT(_FP_REG_mask);
      _NO_SPECIAL_PTR_REG_mask.SUBTRACT(_FP_REG_mask);
    }
  }

  // Optimizaton of volatile gets and puts
  // -------------------------------------
  //
  // AArch64 has ldar<x> and stlr<x> instructions which we can safely
  // use to implement volatile reads and writes. For a volatile read
  // we simply need
  //
  //   ldar<x>
  //
  // and for a volatile write we need
  //
  //   stlr<x>
  //
  // Alternatively, we can implement them by pairing a normal
  // load/store with a memory barrier. For a volatile read we need
  //
  //   ldr<x>
  //   dmb ishld
  //
  // for a volatile write
  //
  //   dmb ish
  //   str<x>
  //   dmb ish
  //
  // We can also use ldaxr and stlxr to implement compare and swap CAS
  // sequences. These are normally translated to an instruction
  // sequence like the following
  //
  //   dmb      ish
  // retry:
  //   ldxr<x>   rval raddr
  //   cmp       rval rold
  //   b.ne done
  //   stlxr<x>  rval, rnew, rold
  //   cbnz      rval retry
  // done:
  //   cset      r0, eq
  //   dmb ishld
  //
  // Note that the exclusive store is already using an stlxr
  // instruction. That is required to ensure visibility to other
  // threads of the exclusive write (assuming it succeeds) before that
  // of any subsequent writes.
  //
  // The following instruction sequence is an improvement on the above
  //
  // retry:
  //   ldaxr<x>  rval raddr
  //   cmp       rval rold
  //   b.ne done
  //   stlxr<x>  rval, rnew, rold
  //   cbnz      rval retry
  // done:
  //   cset      r0, eq
  //
  // We don't need the leading dmb ish since the stlxr guarantees
  // visibility of prior writes in the case that the swap is
  // successful. Crucially we don't have to worry about the case where
  // the swap is not successful since no valid program should be
  // relying on visibility of prior changes by the attempting thread
  // in the case where the CAS fails.
  //
  // Similarly, we don't need the trailing dmb ishld if we substitute
  // an ldaxr instruction since that will provide all the guarantees we
  // require regarding observation of changes made by other threads
  // before any change to the CAS address observed by the load.
  //
  // In order to generate the desired instruction sequence we need to
  // be able to identify specific 'signature' ideal graph node
  // sequences which i) occur as a translation of a volatile reads or
  // writes or CAS operations and ii) do not occur through any other
  // translation or graph transformation. We can then provide
  // alternative aldc matching rules which translate these node
  // sequences to the desired machine code sequences. Selection of the
  // alternative rules can be implemented by predicates which identify
  // the relevant node sequences.
  //
  // The ideal graph generator translates a volatile read to the node
  // sequence
  //
  //   LoadX[mo_acquire]
  //   MemBarAcquire
  //
  // As a special case when using the compressed oops optimization we
  // may also see this variant
  //
  //   LoadN[mo_acquire]
  //   DecodeN
  //   MemBarAcquire
  //
  // A volatile write is translated to the node sequence
  //
  //   MemBarRelease
  //   StoreX[mo_release] {CardMark}-optional
  //   MemBarVolatile
  //
  // n.b. the above node patterns are generated with a strict
  // 'signature' configuration of input and output dependencies (see
  // the predicates below for exact details). The card mark may be as
  // simple as a few extra nodes or, in a few GC configurations, may
  // include more complex control flow between the leading and
  // trailing memory barriers. However, whatever the card mark
  // configuration these signatures are unique to translated volatile
  // reads/stores -- they will not appear as a result of any other
  // bytecode translation or inlining nor as a consequence of
  // optimizing transforms.
  //
  // We also want to catch inlined unsafe volatile gets and puts and
  // be able to implement them using either ldar<x>/stlr<x> or some
  // combination of ldr<x>/stlr<x> and dmb instructions.
  //
  // Inlined unsafe volatiles puts manifest as a minor variant of the
  // normal volatile put node sequence containing an extra cpuorder
  // membar
  //
  //   MemBarRelease
  //   MemBarCPUOrder
  //   StoreX[mo_release] {CardMark}-optional
  //   MemBarCPUOrder
  //   MemBarVolatile
  //
  // n.b. as an aside, a cpuorder membar is not itself subject to
  // matching and translation by adlc rules.  However, the rule
  // predicates need to detect its presence in order to correctly
  // select the desired adlc rules.
  //
  // Inlined unsafe volatile gets manifest as a slightly different
  // node sequence to a normal volatile get because of the
  // introduction of some CPUOrder memory barriers to bracket the
  // Load. However, but the same basic skeleton of a LoadX feeding a
  // MemBarAcquire, possibly through an optional DecodeN, is still
  // present
  //
  //   MemBarCPUOrder
  //        ||       \\
  //   MemBarCPUOrder LoadX[mo_acquire]
  //        ||            |
  //        ||       {DecodeN} optional
  //        ||       /
  //     MemBarAcquire
  //
  // In this case the acquire membar does not directly depend on the
  // load. However, we can be sure that the load is generated from an
  // inlined unsafe volatile get if we see it dependent on this unique
  // sequence of membar nodes. Similarly, given an acquire membar we
  // can know that it was added because of an inlined unsafe volatile
  // get if it is fed and feeds a cpuorder membar and if its feed
  // membar also feeds an acquiring load.
  //
  // Finally an inlined (Unsafe) CAS operation is translated to the
  // following ideal graph
  //
  //   MemBarRelease
  //   MemBarCPUOrder
  //   CompareAndSwapX {CardMark}-optional
  //   MemBarCPUOrder
  //   MemBarAcquire
  //
  // So, where we can identify these volatile read and write
  // signatures we can choose to plant either of the above two code
  // sequences. For a volatile read we can simply plant a normal
  // ldr<x> and translate the MemBarAcquire to a dmb. However, we can
  // also choose to inhibit translation of the MemBarAcquire and
  // inhibit planting of the ldr<x>, instead planting an ldar<x>.
  //
  // When we recognise a volatile store signature we can choose to
  // plant at a dmb ish as a translation for the MemBarRelease, a
  // normal str<x> and then a dmb ish for the MemBarVolatile.
  // Alternatively, we can inhibit translation of the MemBarRelease
  // and MemBarVolatile and instead plant a simple stlr<x>
  // instruction.
  //
  // when we recognise a CAS signature we can choose to plant a dmb
  // ish as a translation for the MemBarRelease, the conventional
  // macro-instruction sequence for the CompareAndSwap node (which
  // uses ldxr<x>) and then a dmb ishld for the MemBarAcquire.
  // Alternatively, we can elide generation of the dmb instructions
  // and plant the alternative CompareAndSwap macro-instruction
  // sequence (which uses ldaxr<x>).
  //
  // Of course, the above only applies when we see these signature
  // configurations. We still want to plant dmb instructions in any
  // other cases where we may see a MemBarAcquire, MemBarRelease or
  // MemBarVolatile. For example, at the end of a constructor which
  // writes final/volatile fields we will see a MemBarRelease
  // instruction and this needs a 'dmb ish' lest we risk the
  // constructed object being visible without making the
  // final/volatile field writes visible.
  //
  // n.b. the translation rules below which rely on detection of the
  // volatile signatures and insert ldar<x> or stlr<x> are failsafe.
  // If we see anything other than the signature configurations we
  // always just translate the loads and stores to ldr<x> and str<x>
  // and translate acquire, release and volatile membars to the
  // relevant dmb instructions.
  //

  // is_CAS(int opcode, bool maybe_volatile)
  //
  // return true if opcode is one of the possible CompareAndSwapX
  // values otherwise false.

  bool is_CAS(int opcode, bool maybe_volatile)
  {
    switch(opcode) {
      // We handle these
    case Op_CompareAndSwapI:
    case Op_CompareAndSwapL:
    case Op_CompareAndSwapP:
    case Op_CompareAndSwapN:
    case Op_ShenandoahCompareAndSwapP:
    case Op_ShenandoahCompareAndSwapN:
    case Op_CompareAndSwapB:
    case Op_CompareAndSwapS:
    case Op_GetAndSetI:
    case Op_GetAndSetL:
    case Op_GetAndSetP:
    case Op_GetAndSetN:
    case Op_GetAndAddI:
    case Op_GetAndAddL:
      return true;
    case Op_CompareAndExchangeI:
    case Op_CompareAndExchangeN:
    case Op_CompareAndExchangeB:
    case Op_CompareAndExchangeS:
    case Op_CompareAndExchangeL:
    case Op_CompareAndExchangeP:
    case Op_WeakCompareAndSwapB:
    case Op_WeakCompareAndSwapS:
    case Op_WeakCompareAndSwapI:
    case Op_WeakCompareAndSwapL:
    case Op_WeakCompareAndSwapP:
    case Op_WeakCompareAndSwapN:
    case Op_ShenandoahWeakCompareAndSwapP:
    case Op_ShenandoahWeakCompareAndSwapN:
    case Op_ShenandoahCompareAndExchangeP:
    case Op_ShenandoahCompareAndExchangeN:
      return maybe_volatile;
    default:
      return false;
    }
  }

  // helper to determine the maximum number of Phi nodes we may need to
  // traverse when searching from a card mark membar for the merge mem
  // feeding a trailing membar or vice versa

// predicates controlling emit of ldr<x>/ldar<x>

bool unnecessary_acquire(const Node *barrier)
{
  assert(barrier->is_MemBar(), "expecting a membar");

  MemBarNode* mb = barrier->as_MemBar();

  if (mb->trailing_load()) {
    return true;
  }

  if (mb->trailing_load_store()) {
    Node* load_store = mb->in(MemBarNode::Precedent);
    assert(load_store->is_LoadStore(), "unexpected graph shape");
    return is_CAS(load_store->Opcode(), true);
  }

  return false;
}

bool needs_acquiring_load(const Node *n)
{
  assert(n->is_Load(), "expecting a load");
  LoadNode *ld = n->as_Load();
  return ld->is_acquire();
}

bool unnecessary_release(const Node *n)
{
  assert((n->is_MemBar() &&
          n->Opcode() == Op_MemBarRelease),
         "expecting a release membar");

  MemBarNode *barrier = n->as_MemBar();
  if (!barrier->leading()) {
    return false;
  } else {
    Node* trailing = barrier->trailing_membar();
    MemBarNode* trailing_mb = trailing->as_MemBar();
    assert(trailing_mb->trailing(), "Not a trailing membar?");
    assert(trailing_mb->leading_membar() == n, "inconsistent leading/trailing membars");

    Node* mem = trailing_mb->in(MemBarNode::Precedent);
    if (mem->is_Store()) {
      assert(mem->as_Store()->is_release(), "");
      assert(trailing_mb->Opcode() == Op_MemBarVolatile, "");
      return true;
    } else {
      assert(mem->is_LoadStore(), "");
      assert(trailing_mb->Opcode() == Op_MemBarAcquire, "");
      return is_CAS(mem->Opcode(), true);
    }
  }
  return false;
}

bool unnecessary_volatile(const Node *n)
{
  // assert n->is_MemBar();
  MemBarNode *mbvol = n->as_MemBar();

  bool release = mbvol->trailing_store();
  assert(!release || (mbvol->in(MemBarNode::Precedent)->is_Store() && mbvol->in(MemBarNode::Precedent)->as_Store()->is_release()), "");
#ifdef ASSERT
  if (release) {
    Node* leading = mbvol->leading_membar();
    assert(leading->Opcode() == Op_MemBarRelease, "");
    assert(leading->as_MemBar()->leading_store(), "");
    assert(leading->as_MemBar()->trailing_membar() == mbvol, "");
  }
#endif

  return release;
}

// predicates controlling emit of str<x>/stlr<x>

bool needs_releasing_store(const Node *n)
{
  // assert n->is_Store();
  StoreNode *st = n->as_Store();
  return st->trailing_membar() != NULL;
}

// predicate controlling translation of CAS
//
// returns true if CAS needs to use an acquiring load otherwise false

bool needs_acquiring_load_exclusive(const Node *n)
{
  assert(is_CAS(n->Opcode(), true), "expecting a compare and swap");
  LoadStoreNode* ldst = n->as_LoadStore();
  if (is_CAS(n->Opcode(), false)) {
    assert(ldst->trailing_membar() != NULL, "expected trailing membar");
  } else {
    return ldst->trailing_membar() != NULL;
  }

  // so we can just return true here
  return true;
}

#define __ _masm.

// advance declarations for helper functions to convert register
// indices to register objects

// the ad file has to provide implementations of certain methods
// expected by the generic code
//
// REQUIRED FUNCTIONALITY

//=============================================================================

// !!!!! Special hack to get all types of calls to specify the byte offset
//       from the start of the call to the point where the return address
//       will point.

int MachCallStaticJavaNode::ret_addr_offset()
{
  // call should be a simple bl
  int off = 4;
  return off;
}

int MachCallDynamicJavaNode::ret_addr_offset()
{
  return 16; // movz, movk, movk, bl
}

int MachCallRuntimeNode::ret_addr_offset() {
  // for generated stubs the call will be
  //   bl(addr)
  // or with far branches
  //   bl(trampoline_stub)
  // for real runtime callouts it will be six instructions
  // see aarch64_enc_java_to_runtime
  //   adr(rscratch2, retaddr)
  //   lea(rscratch1, RuntimeAddress(addr)
  //   stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)))
  //   blr(rscratch1)
  CodeBlob *cb = CodeCache::find_blob(_entry_point);
  if (cb) {
    return 1 * NativeInstruction::instruction_size;
  } else {
    return 6 * NativeInstruction::instruction_size;
  }
}

//=============================================================================

#ifndef PRODUCT
void MachBreakpointNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  st->print("BREAKPOINT");
}
#endif

void MachBreakpointNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  C2_MacroAssembler _masm(&cbuf);
  __ brk(0);
}

uint MachBreakpointNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_);
}

//=============================================================================

#ifndef PRODUCT
  void MachNopNode::format(PhaseRegAlloc*, outputStream* st) const {
    st->print("nop \t# %d bytes pad for loops and calls", _count);
  }
#endif

  void MachNopNode::emit(CodeBuffer &cbuf, PhaseRegAlloc*) const {
    C2_MacroAssembler _masm(&cbuf);
    for (int i = 0; i < _count; i++) {
      __ nop();
    }
  }

  uint MachNopNode::size(PhaseRegAlloc*) const {
    return _count * NativeInstruction::instruction_size;
  }

//=============================================================================
const RegMask& MachConstantBaseNode::_out_RegMask = RegMask::Empty;

int ConstantTable::calculate_table_base_offset() const {
  return 0;  // absolute addressing, no offset
}

bool MachConstantBaseNode::requires_postalloc_expand() const { return false; }
void MachConstantBaseNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  ShouldNotReachHere();
}

void MachConstantBaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  // Empty encoding
}

uint MachConstantBaseNode::size(PhaseRegAlloc* ra_) const {
  return 0;
}

#ifndef PRODUCT
void MachConstantBaseNode::format(PhaseRegAlloc* ra_, outputStream* st) const {
  st->print("-- \t// MachConstantBaseNode (empty encoding)");
}
#endif

#ifndef PRODUCT
void MachPrologNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  Compile* C = ra_->C;

  int framesize = C->output()->frame_slots() << LogBytesPerInt;

  if (C->output()->need_stack_bang(framesize))
    st->print("# stack bang size=%d\n\t", framesize);

  if (VM_Version::use_rop_protection()) {
    st->print("ldr zr, [lr]\n\t");
    st->print("pacia  lr, rfp\n\t");
  }
  if (framesize < ((1 << 9) + 2 * wordSize)) {
    st->print("sub  sp, sp, #%d\n\t", framesize);
    st->print("stp  rfp, lr, [sp, #%d]", framesize - 2 * wordSize);
    if (PreserveFramePointer) st->print("\n\tadd  rfp, sp, #%d", framesize - 2 * wordSize);
  } else {
    st->print("stp  lr, rfp, [sp, #%d]!\n\t", -(2 * wordSize));
    if (PreserveFramePointer) st->print("mov  rfp, sp\n\t");
    st->print("mov  rscratch1, #%d\n\t", framesize - 2 * wordSize);
    st->print("sub  sp, sp, rscratch1");
  }
  if (C->stub_function() == NULL && BarrierSet::barrier_set()->barrier_set_nmethod() != NULL) {
    st->print("\n\t");
    st->print("ldr  rscratch1, [guard]\n\t");
    st->print("dmb ishld\n\t");
    st->print("ldr  rscratch2, [rthread, #thread_disarmed_offset]\n\t");
    st->print("cmp  rscratch1, rscratch2\n\t");
    st->print("b.eq skip");
    st->print("\n\t");
    st->print("blr #nmethod_entry_barrier_stub\n\t");
    st->print("b skip\n\t");
    st->print("guard: int\n\t");
    st->print("\n\t");
    st->print("skip:\n\t");
  }
}
#endif

void MachPrologNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile* C = ra_->C;
  C2_MacroAssembler _masm(&cbuf);

  // n.b. frame size includes space for return pc and rfp
  const int framesize = C->output()->frame_size_in_bytes();

  // insert a nop at the start of the prolog so we can patch in a
  // branch if we need to invalidate the method later
  __ nop();

  if (C->clinit_barrier_on_entry()) {
    assert(!C->method()->holder()->is_not_initialized(), "initialization should have been started");

    Label L_skip_barrier;

    __ mov_metadata(rscratch2, C->method()->holder()->constant_encoding());
    __ clinit_barrier(rscratch2, rscratch1, &L_skip_barrier);
    __ far_jump(RuntimeAddress(SharedRuntime::get_handle_wrong_method_stub()));
    __ bind(L_skip_barrier);
  }

  if (C->max_vector_size() > 0) {
    __ reinitialize_ptrue();
  }

  int bangsize = C->output()->bang_size_in_bytes();
  if (C->output()->need_stack_bang(bangsize))
    __ generate_stack_overflow_check(bangsize);

  __ build_frame(framesize);

  if (C->stub_function() == NULL) {
    BarrierSetAssembler* bs = BarrierSet::barrier_set()->barrier_set_assembler();
    if (BarrierSet::barrier_set()->barrier_set_nmethod() != NULL) {
      // Dummy labels for just measuring the code size
      Label dummy_slow_path;
      Label dummy_continuation;
      Label dummy_guard;
      Label* slow_path = &dummy_slow_path;
      Label* continuation = &dummy_continuation;
      Label* guard = &dummy_guard;
      if (!Compile::current()->output()->in_scratch_emit_size()) {
        // Use real labels from actual stub when not emitting code for the purpose of measuring its size
        C2EntryBarrierStub* stub = Compile::current()->output()->entry_barrier_table()->add_entry_barrier();
        slow_path = &stub->slow_path();
        continuation = &stub->continuation();
        guard = &stub->guard();
      }
      // In the C2 code, we move the non-hot part of nmethod entry barriers out-of-line to a stub.
      bs->nmethod_entry_barrier(&_masm, slow_path, continuation, guard);
    }
  }

  if (VerifyStackAtCalls) {
    Unimplemented();
  }

  C->output()->set_frame_complete(cbuf.insts_size());

  if (C->has_mach_constant_base_node()) {
    // NOTE: We set the table base offset here because users might be
    // emitted before MachConstantBaseNode.
    ConstantTable& constant_table = C->output()->constant_table();
    constant_table.set_table_base_offset(constant_table.calculate_table_base_offset());
  }
}

uint MachPrologNode::size(PhaseRegAlloc* ra_) const
{
  return MachNode::size(ra_); // too many variables; just compute it
                              // the hard way
}

int MachPrologNode::reloc() const
{
  return 0;
}

//=============================================================================

#ifndef PRODUCT
void MachEpilogNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  Compile* C = ra_->C;
  int framesize = C->output()->frame_slots() << LogBytesPerInt;

  st->print("# pop frame %d\n\t",framesize);

  if (framesize == 0) {
    st->print("ldp  lr, rfp, [sp],#%d\n\t", (2 * wordSize));
  } else if (framesize < ((1 << 9) + 2 * wordSize)) {
    st->print("ldp  lr, rfp, [sp,#%d]\n\t", framesize - 2 * wordSize);
    st->print("add  sp, sp, #%d\n\t", framesize);
  } else {
    st->print("mov  rscratch1, #%d\n\t", framesize - 2 * wordSize);
    st->print("add  sp, sp, rscratch1\n\t");
    st->print("ldp  lr, rfp, [sp],#%d\n\t", (2 * wordSize));
  }
  if (VM_Version::use_rop_protection()) {
    st->print("autia lr, rfp\n\t");
    st->print("ldr zr, [lr]\n\t");
  }

  if (do_polling() && C->is_method_compilation()) {
    st->print("# test polling word\n\t");
    st->print("ldr  rscratch1, [rthread],#%d\n\t", in_bytes(JavaThread::polling_word_offset()));
    st->print("cmp  sp, rscratch1\n\t");
    st->print("bhi #slow_path");
  }
}
#endif

void MachEpilogNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile* C = ra_->C;
  C2_MacroAssembler _masm(&cbuf);
  int framesize = C->output()->frame_slots() << LogBytesPerInt;

  __ remove_frame(framesize);

  if (StackReservedPages > 0 && C->has_reserved_stack_access()) {
    __ reserved_stack_check();
  }

  if (do_polling() && C->is_method_compilation()) {
    Label dummy_label;
    Label* code_stub = &dummy_label;
    if (!C->output()->in_scratch_emit_size()) {
      code_stub = &C->output()->safepoint_poll_table()->add_safepoint(__ offset());
    }
    __ relocate(relocInfo::poll_return_type);
    __ safepoint_poll(*code_stub, true /* at_return */, false /* acquire */, true /* in_nmethod */);
  }
}

uint MachEpilogNode::size(PhaseRegAlloc *ra_) const {
  // Variable size. Determine dynamically.
  return MachNode::size(ra_);
}

int MachEpilogNode::reloc() const {
  // Return number of relocatable values contained in this instruction.
  return 1; // 1 for polling page.
}

const Pipeline * MachEpilogNode::pipeline() const {
  return MachNode::pipeline_class();
}

//=============================================================================

// Figure out which register class each belongs in: rc_int, rc_float or
// rc_stack.
enum RC { rc_bad, rc_int, rc_float, rc_predicate, rc_stack };

static enum RC rc_class(OptoReg::Name reg) {

  if (reg == OptoReg::Bad) {
    return rc_bad;
  }

  // we have 32 int registers * 2 halves
  int slots_of_int_registers = Register::number_of_registers * Register::max_slots_per_register;

  if (reg < slots_of_int_registers) {
    return rc_int;
  }

  // we have 32 float register * 8 halves
  int slots_of_float_registers = FloatRegister::number_of_registers * FloatRegister::max_slots_per_register;
  if (reg < slots_of_int_registers + slots_of_float_registers) {
    return rc_float;
  }

  int slots_of_predicate_registers = PRegister::number_of_registers * PRegister::max_slots_per_register;
  if (reg < slots_of_int_registers + slots_of_float_registers + slots_of_predicate_registers) {
    return rc_predicate;
  }

  // Between predicate regs & stack is the flags.
  assert(OptoReg::is_stack(reg), "blow up if spilling flags");

  return rc_stack;
}

uint MachSpillCopyNode::implementation(CodeBuffer *cbuf, PhaseRegAlloc *ra_, bool do_size, outputStream *st) const {
  Compile* C = ra_->C;

  // Get registers to move.
  OptoReg::Name src_hi = ra_->get_reg_second(in(1));
  OptoReg::Name src_lo = ra_->get_reg_first(in(1));
  OptoReg::Name dst_hi = ra_->get_reg_second(this);
  OptoReg::Name dst_lo = ra_->get_reg_first(this);

  enum RC src_hi_rc = rc_class(src_hi);
  enum RC src_lo_rc = rc_class(src_lo);
  enum RC dst_hi_rc = rc_class(dst_hi);
  enum RC dst_lo_rc = rc_class(dst_lo);

  assert(src_lo != OptoReg::Bad && dst_lo != OptoReg::Bad, "must move at least 1 register");

  if (src_hi != OptoReg::Bad && !bottom_type()->isa_vectmask()) {
    assert((src_lo&1)==0 && src_lo+1==src_hi &&
           (dst_lo&1)==0 && dst_lo+1==dst_hi,
           "expected aligned-adjacent pairs");
  }

  if (src_lo == dst_lo && src_hi == dst_hi) {
    return 0;            // Self copy, no move.
  }

  bool is64 = (src_lo & 1) == 0 && src_lo + 1 == src_hi &&
              (dst_lo & 1) == 0 && dst_lo + 1 == dst_hi;
  int src_offset = ra_->reg2offset(src_lo);
  int dst_offset = ra_->reg2offset(dst_lo);

  if (bottom_type()->isa_vect() && !bottom_type()->isa_vectmask()) {
    uint ireg = ideal_reg();
    if (ireg == Op_VecA && cbuf) {
      C2_MacroAssembler _masm(cbuf);
      int sve_vector_reg_size_in_bytes = Matcher::scalable_vector_reg_size(T_BYTE);
      if (src_lo_rc == rc_stack && dst_lo_rc == rc_stack) {
        // stack->stack
        __ spill_copy_sve_vector_stack_to_stack(src_offset, dst_offset,
                                                sve_vector_reg_size_in_bytes);
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_stack) {
        __ spill_sve_vector(as_FloatRegister(Matcher::_regEncode[src_lo]), ra_->reg2offset(dst_lo),
                            sve_vector_reg_size_in_bytes);
      } else if (src_lo_rc == rc_stack && dst_lo_rc == rc_float) {
        __ unspill_sve_vector(as_FloatRegister(Matcher::_regEncode[dst_lo]), ra_->reg2offset(src_lo),
                              sve_vector_reg_size_in_bytes);
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_float) {
        __ sve_orr(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                   as_FloatRegister(Matcher::_regEncode[src_lo]),
                   as_FloatRegister(Matcher::_regEncode[src_lo]));
      } else {
        ShouldNotReachHere();
      }
    } else if (cbuf) {
      assert(ireg == Op_VecD || ireg == Op_VecX, "must be 64 bit or 128 bit vector");
      C2_MacroAssembler _masm(cbuf);
      assert((src_lo_rc != rc_int && dst_lo_rc != rc_int), "sanity");
      if (src_lo_rc == rc_stack && dst_lo_rc == rc_stack) {
        // stack->stack
        assert((src_offset & 7) == 0 && (dst_offset & 7) == 0, "unaligned stack offset");
        if (ireg == Op_VecD) {
          __ unspill(rscratch1, true, src_offset);
          __ spill(rscratch1, true, dst_offset);
        } else {
          __ spill_copy128(src_offset, dst_offset);
        }
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_float) {
        __ mov(as_FloatRegister(Matcher::_regEncode[dst_lo]),
               ireg == Op_VecD ? __ T8B : __ T16B,
               as_FloatRegister(Matcher::_regEncode[src_lo]));
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_stack) {
        __ spill(as_FloatRegister(Matcher::_regEncode[src_lo]),
                 ireg == Op_VecD ? __ D : __ Q,
                 ra_->reg2offset(dst_lo));
      } else if (src_lo_rc == rc_stack && dst_lo_rc == rc_float) {
        __ unspill(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                   ireg == Op_VecD ? __ D : __ Q,
                   ra_->reg2offset(src_lo));
      } else {
        ShouldNotReachHere();
      }
    }
  } else if (cbuf) {
    C2_MacroAssembler _masm(cbuf);
    switch (src_lo_rc) {
    case rc_int:
      if (dst_lo_rc == rc_int) {  // gpr --> gpr copy
        if (is64) {
            __ mov(as_Register(Matcher::_regEncode[dst_lo]),
                   as_Register(Matcher::_regEncode[src_lo]));
        } else {
            C2_MacroAssembler _masm(cbuf);
            __ movw(as_Register(Matcher::_regEncode[dst_lo]),
                    as_Register(Matcher::_regEncode[src_lo]));
        }
      } else if (dst_lo_rc == rc_float) { // gpr --> fpr copy
        if (is64) {
            __ fmovd(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_Register(Matcher::_regEncode[src_lo]));
        } else {
            __ fmovs(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_Register(Matcher::_regEncode[src_lo]));
        }
      } else {                    // gpr --> stack spill
        assert(dst_lo_rc == rc_stack, "spill to bad register class");
        __ spill(as_Register(Matcher::_regEncode[src_lo]), is64, dst_offset);
      }
      break;
    case rc_float:
      if (dst_lo_rc == rc_int) {  // fpr --> gpr copy
        if (is64) {
            __ fmovd(as_Register(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        } else {
            __ fmovs(as_Register(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        }
      } else if (dst_lo_rc == rc_float) { // fpr --> fpr copy
        if (is64) {
            __ fmovd(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        } else {
            __ fmovs(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        }
      } else {                    // fpr --> stack spill
        assert(dst_lo_rc == rc_stack, "spill to bad register class");
        __ spill(as_FloatRegister(Matcher::_regEncode[src_lo]),
                 is64 ? __ D : __ S, dst_offset);
      }
      break;
    case rc_stack:
      if (dst_lo_rc == rc_int) {  // stack --> gpr load
        __ unspill(as_Register(Matcher::_regEncode[dst_lo]), is64, src_offset);
      } else if (dst_lo_rc == rc_float) { // stack --> fpr load
        __ unspill(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                   is64 ? __ D : __ S, src_offset);
      } else if (dst_lo_rc == rc_predicate) {
        __ unspill_sve_predicate(as_PRegister(Matcher::_regEncode[dst_lo]), ra_->reg2offset(src_lo),
                                 Matcher::scalable_vector_reg_size(T_BYTE) >> 3);
      } else {                    // stack --> stack copy
        assert(dst_lo_rc == rc_stack, "spill to bad register class");
        if (ideal_reg() == Op_RegVectMask) {
          __ spill_copy_sve_predicate_stack_to_stack(src_offset, dst_offset,
                                                     Matcher::scalable_vector_reg_size(T_BYTE) >> 3);
        } else {
          __ unspill(rscratch1, is64, src_offset);
          __ spill(rscratch1, is64, dst_offset);
        }
      }
      break;
    case rc_predicate:
      if (dst_lo_rc == rc_predicate) {
        __ sve_mov(as_PRegister(Matcher::_regEncode[dst_lo]), as_PRegister(Matcher::_regEncode[src_lo]));
      } else if (dst_lo_rc == rc_stack) {
        __ spill_sve_predicate(as_PRegister(Matcher::_regEncode[src_lo]), ra_->reg2offset(dst_lo),
                               Matcher::scalable_vector_reg_size(T_BYTE) >> 3);
      } else {
        assert(false, "bad src and dst rc_class combination.");
        ShouldNotReachHere();
      }
      break;
    default:
      assert(false, "bad rc_class for spill");
      ShouldNotReachHere();
    }
  }

  if (st) {
    st->print("spill ");
    if (src_lo_rc == rc_stack) {
      st->print("[sp, #%d] -> ", ra_->reg2offset(src_lo));
    } else {
      st->print("%s -> ", Matcher::regName[src_lo]);
    }
    if (dst_lo_rc == rc_stack) {
      st->print("[sp, #%d]", ra_->reg2offset(dst_lo));
    } else {
      st->print("%s", Matcher::regName[dst_lo]);
    }
    if (bottom_type()->isa_vect() && !bottom_type()->isa_vectmask()) {
      int vsize = 0;
      switch (ideal_reg()) {
      case Op_VecD:
        vsize = 64;
        break;
      case Op_VecX:
        vsize = 128;
        break;
      case Op_VecA:
        vsize = Matcher::scalable_vector_reg_size(T_BYTE) * 8;
        break;
      default:
        assert(false, "bad register type for spill");
        ShouldNotReachHere();
      }
      st->print("\t# vector spill size = %d", vsize);
    } else if (ideal_reg() == Op_RegVectMask) {
      assert(Matcher::supports_scalable_vector(), "bad register type for spill");
      int vsize = Matcher::scalable_predicate_reg_slots() * 32;
      st->print("\t# predicate spill size = %d", vsize);
    } else {
      st->print("\t# spill size = %d", is64 ? 64 : 32);
    }
  }

  return 0;

}

#ifndef PRODUCT
void MachSpillCopyNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  if (!ra_)
    st->print("N%d = SpillCopy(N%d)", _idx, in(1)->_idx);
  else
    implementation(NULL, ra_, false, st);
}
#endif

void MachSpillCopyNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  implementation(&cbuf, ra_, false, NULL);
}

uint MachSpillCopyNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_);
}

//=============================================================================

#ifndef PRODUCT
void BoxLockNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg = ra_->get_reg_first(this);
  st->print("add %s, rsp, #%d]\t# box lock",
            Matcher::regName[reg], offset);
}
#endif

void BoxLockNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  C2_MacroAssembler _masm(&cbuf);

  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg    = ra_->get_encode(this);

  // This add will handle any 24-bit signed offset. 24 bits allows an
  // 8 megabyte stack frame.
  __ add(as_Register(reg), sp, offset);
}

uint BoxLockNode::size(PhaseRegAlloc *ra_) const {
  // BoxLockNode is not a MachNode, so we can't just call MachNode::size(ra_).
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());

  if (Assembler::operand_valid_for_add_sub_immediate(offset)) {
    return NativeInstruction::instruction_size;
  } else {
    return 2 * NativeInstruction::instruction_size;
  }
}

//=============================================================================

#ifndef PRODUCT
void MachUEPNode::format(PhaseRegAlloc* ra_, outputStream* st) const
{
  st->print_cr("# MachUEPNode");
  if (UseCompressedClassPointers) {
    st->print_cr("\tldrw rscratch1, j_rarg0 + oopDesc::klass_offset_in_bytes()]\t# compressed klass");
    if (CompressedKlassPointers::shift() != 0) {
      st->print_cr("\tdecode_klass_not_null rscratch1, rscratch1");
    }
  } else {
   st->print_cr("\tldr rscratch1, j_rarg0 + oopDesc::klass_offset_in_bytes()]\t# compressed klass");
  }
  st->print_cr("\tcmp r0, rscratch1\t # Inline cache check");
  st->print_cr("\tbne, SharedRuntime::_ic_miss_stub");
}
#endif

void MachUEPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const
{
  // This is the unverified entry point.
  C2_MacroAssembler _masm(&cbuf);

  __ cmp_klass(j_rarg0, rscratch2, rscratch1);
  Label skip;
  // TODO
  // can we avoid this skip and still use a reloc?
  __ br(Assembler::EQ, skip);
  __ far_jump(RuntimeAddress(SharedRuntime::get_ic_miss_stub()));
  __ bind(skip);
}

uint MachUEPNode::size(PhaseRegAlloc* ra_) const
{
  return MachNode::size(ra_);
}

// REQUIRED EMIT CODE

//=============================================================================

// Emit exception handler code.
int HandlerImpl::emit_exception_handler(CodeBuffer& cbuf)
{
  // mov rscratch1 #exception_blob_entry_point
  // br rscratch1
  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a handler.
  C2_MacroAssembler _masm(&cbuf);
  address base = __ start_a_stub(size_exception_handler());
  if (base == NULL) {
    ciEnv::current()->record_failure("CodeCache is full");
    return 0;  // CodeBuffer::expand failed
  }
  int offset = __ offset();
  __ far_jump(RuntimeAddress(OptoRuntime::exception_blob()->entry_point()));
  assert(__ offset() - offset <= (int) size_exception_handler(), "overflow");
  __ end_a_stub();
  return offset;
}

// Emit deopt handler code.
int HandlerImpl::emit_deopt_handler(CodeBuffer& cbuf)
{
  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a handler.
  C2_MacroAssembler _masm(&cbuf);
  address base = __ start_a_stub(size_deopt_handler());
  if (base == NULL) {
    ciEnv::current()->record_failure("CodeCache is full");
    return 0;  // CodeBuffer::expand failed
  }
  int offset = __ offset();

  __ adr(lr, __ pc());
  __ far_jump(RuntimeAddress(SharedRuntime::deopt_blob()->unpack()));

  assert(__ offset() - offset == (int) size_deopt_handler(), "overflow");
  __ end_a_stub();
  return offset;
}

// REQUIRED MATCHER CODE

//=============================================================================

const bool Matcher::match_rule_supported(int opcode) {
  if (!has_match_rule(opcode))
    return false;

  bool ret_value = true;
  switch (opcode) {
    case Op_OnSpinWait:
      return VM_Version::supports_on_spin_wait();
    case Op_CacheWB:
    case Op_CacheWBPreSync:
    case Op_CacheWBPostSync:
      if (!VM_Version::supports_data_cache_line_flush()) {
        ret_value = false;
      }
      break;
  }

  return ret_value; // Per default match rules are supported.
}

const RegMask* Matcher::predicate_reg_mask(void) {
  return &_PR_REG_mask;
}

const TypeVectMask* Matcher::predicate_reg_type(const Type* elemTy, int length) {
  return new TypeVectMask(elemTy, length);
}

// Vector calling convention not yet implemented.
const bool Matcher::supports_vector_calling_convention(void) {
  return false;
}

OptoRegPair Matcher::vector_return_value(uint ideal_reg) {
  Unimplemented();
  return OptoRegPair(0, 0);
}

// Is this branch offset short enough that a short branch can be used?
//
// NOTE: If the platform does not provide any short branch variants, then
//       this method should return false for offset 0.
bool Matcher::is_short_branch_offset(int rule, int br_size, int offset) {
  // The passed offset is relative to address of the branch.

  return (-32768 <= offset && offset < 32768);
}

// Vector width in bytes.
const int Matcher::vector_width_in_bytes(BasicType bt) {
  // The MaxVectorSize should have been set by detecting SVE max vector register size.
  int size = MIN2((UseSVE > 0) ? 256 : 16, (int)MaxVectorSize);
  // Minimum 2 values in vector
  if (size < 2*type2aelembytes(bt)) size = 0;
  // But never < 4
  if (size < 4) size = 0;
  return size;
}

// Limits on vector size (number of elements) loaded into vector.
const int Matcher::max_vector_size(const BasicType bt) {
  return vector_width_in_bytes(bt)/type2aelembytes(bt);
}

const int Matcher::min_vector_size(const BasicType bt) {
  int max_size = max_vector_size(bt);
  // Limit the min vector size to 8 bytes.
  int size = 8 / type2aelembytes(bt);
  if (bt == T_BYTE) {
    // To support vector api shuffle/rearrange.
    size = 4;
  } else if (bt == T_BOOLEAN) {
    // To support vector api load/store mask.
    size = 2;
  }
  if (size < 2) size = 2;
  return MIN2(size, max_size);
}

// Actual max scalable vector register length.
const int Matcher::scalable_vector_reg_size(const BasicType bt) {
  return Matcher::max_vector_size(bt);
}

// Vector ideal reg.
const uint Matcher::vector_ideal_reg(int len) {
  if (UseSVE > 0 && 16 < len && len <= 256) {
    return Op_VecA;
  }
  switch(len) {
    // For 16-bit/32-bit mask vector, reuse VecD.
    case  2:
    case  4:
    case  8: return Op_VecD;
    case 16: return Op_VecX;
  }
  ShouldNotReachHere();
  return 0;
}

MachOper* Matcher::pd_specialize_generic_vector_operand(MachOper* generic_opnd, uint ideal_reg, bool is_temp) {
  assert(Matcher::is_generic_vector(generic_opnd), "not generic");
  switch (ideal_reg) {
    case Op_VecA: return new vecAOper();
    case Op_VecD: return new vecDOper();
    case Op_VecX: return new vecXOper();
  }
  ShouldNotReachHere();
  return NULL;
}

bool Matcher::is_reg2reg_move(MachNode* m) {
  return false;
}

bool Matcher::is_generic_vector(MachOper* opnd)  {
  return opnd->opcode() == VREG;
}

// Return whether or not this register is ever used as an argument.
// This function is used on startup to build the trampoline stubs in
// generateOptoStub.  Registers not mentioned will be killed by the VM
// call in the trampoline, and arguments in those registers not be
// available to the callee.
bool Matcher::can_be_java_arg(int reg)
{
  return
    reg ==  R0_num || reg == R0_H_num ||
    reg ==  R1_num || reg == R1_H_num ||
    reg ==  R2_num || reg == R2_H_num ||
    reg ==  R3_num || reg == R3_H_num ||
    reg ==  R4_num || reg == R4_H_num ||
    reg ==  R5_num || reg == R5_H_num ||
    reg ==  R6_num || reg == R6_H_num ||
    reg ==  R7_num || reg == R7_H_num ||
    reg ==  V0_num || reg == V0_H_num ||
    reg ==  V1_num || reg == V1_H_num ||
    reg ==  V2_num || reg == V2_H_num ||
    reg ==  V3_num || reg == V3_H_num ||
    reg ==  V4_num || reg == V4_H_num ||
    reg ==  V5_num || reg == V5_H_num ||
    reg ==  V6_num || reg == V6_H_num ||
    reg ==  V7_num || reg == V7_H_num;
}

bool Matcher::is_spillable_arg(int reg)
{
  return can_be_java_arg(reg);
}

uint Matcher::int_pressure_limit()
{
  // JDK-8183543: When taking the number of available registers as int
  // register pressure threshold, the jtreg test:
  // test/hotspot/jtreg/compiler/regalloc/TestC2IntPressure.java
  // failed due to C2 compilation failure with
  // "COMPILE SKIPPED: failed spill-split-recycle sanity check".
  //
  // A derived pointer is live at CallNode and then is flagged by RA
  // as a spilled LRG. Spilling heuristics(Spill-USE) explicitly skip
  // derived pointers and lastly fail to spill after reaching maximum
  // number of iterations. Lowering the default pressure threshold to
  // (_NO_SPECIAL_REG32_mask.Size() minus 1) forces CallNode to become
  // a high register pressure area of the code so that split_DEF can
  // generate DefinitionSpillCopy for the derived pointer.
  uint default_int_pressure_threshold = _NO_SPECIAL_REG32_mask.Size() - 1;
  if (!PreserveFramePointer) {
    // When PreserveFramePointer is off, frame pointer is allocatable,
    // but different from other SOC registers, it is excluded from
    // fatproj's mask because its save type is No-Save. Decrease 1 to
    // ensure high pressure at fatproj when PreserveFramePointer is off.
    // See check_pressure_at_fatproj().
    default_int_pressure_threshold--;
  }
  return (INTPRESSURE == -1) ? default_int_pressure_threshold : INTPRESSURE;
}

uint Matcher::float_pressure_limit()
{
  // _FLOAT_REG_mask is generated by adlc from the float_reg register class.
  return (FLOATPRESSURE == -1) ? _FLOAT_REG_mask.Size() : FLOATPRESSURE;
}

bool Matcher::use_asm_for_ldiv_by_con(jlong divisor) {
  return false;
}

RegMask Matcher::divI_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for MODI projection of divmodI.
RegMask Matcher::modI_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for DIVL projection of divmodL.
RegMask Matcher::divL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for MODL projection of divmodL.
RegMask Matcher::modL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

const RegMask Matcher::method_handle_invoke_SP_save_mask() {
  return FP_REG_mask();
}

bool size_fits_all_mem_uses(AddPNode* addp, int shift) {
  for (DUIterator_Fast imax, i = addp->fast_outs(imax); i < imax; i++) {
    Node* u = addp->fast_out(i);
    if (u->is_LoadStore()) {
      // On AArch64, LoadStoreNodes (i.e. compare and swap
      // instructions) only take register indirect as an operand, so
      // any attempt to use an AddPNode as an input to a LoadStoreNode
      // must fail.
      return false;
    }
    if (u->is_Mem()) {
      int opsize = u->as_Mem()->memory_size();
      assert(opsize > 0, "unexpected memory operand size");
      if (u->as_Mem()->memory_size() != (1<<shift)) {
        return false;
      }
    }
  }
  return true;
}

// Binary src (Replicate con)
bool is_valid_sve_arith_imm_pattern(Node* n, Node* m) {
  if (n == NULL || m == NULL) {
    return false;
  }

  if (UseSVE == 0 || !VectorNode::is_invariant_vector(m)) {
    return false;
  }

  Node* imm_node = m->in(1);
  if (!imm_node->is_Con()) {
    return false;
  }

  const Type* t = imm_node->bottom_type();
  if (!(t->isa_int() || t->isa_long())) {
    return false;
  }

  switch (n->Opcode()) {
  case Op_AndV:
  case Op_OrV:
  case Op_XorV: {
    Assembler::SIMD_RegVariant T = Assembler::elemType_to_regVariant(Matcher::vector_element_basic_type(n));
    uint64_t value = t->isa_long() ? (uint64_t)imm_node->get_long() : (uint64_t)imm_node->get_int();
    return Assembler::operand_valid_for_sve_logical_immediate(Assembler::regVariant_to_elemBits(T), value);
  }
  case Op_AddVB:
    return (imm_node->get_int() <= 255 && imm_node->get_int() >= -255);
  case Op_AddVS:
  case Op_AddVI:
    return Assembler::operand_valid_for_sve_add_sub_immediate((int64_t)imm_node->get_int());
  case Op_AddVL:
    return Assembler::operand_valid_for_sve_add_sub_immediate(imm_node->get_long());
  default:
    return false;
  }
}

// (XorV src (Replicate m1))
// (XorVMask src (MaskAll m1))
bool is_vector_bitwise_not_pattern(Node* n, Node* m) {
  if (n != NULL && m != NULL) {
    return (n->Opcode() == Op_XorV || n->Opcode() == Op_XorVMask) &&
           VectorNode::is_all_ones_vector(m);
  }
  return false;
}

// Should the matcher clone input 'm' of node 'n'?
bool Matcher::pd_clone_node(Node* n, Node* m, Matcher::MStack& mstack) {
  if (is_vshift_con_pattern(n, m) ||
      is_vector_bitwise_not_pattern(n, m) ||
      is_valid_sve_arith_imm_pattern(n, m)) {
    mstack.push(m, Visit);
    return true;
  }
  return false;
}

// Should the Matcher clone shifts on addressing modes, expecting them
// to be subsumed into complex addressing expressions or compute them
// into registers?
bool Matcher::pd_clone_address_expressions(AddPNode* m, Matcher::MStack& mstack, VectorSet& address_visited) {
  if (clone_base_plus_offset_address(m, mstack, address_visited)) {
    return true;
  }

  Node *off = m->in(AddPNode::Offset);
  if (off->Opcode() == Op_LShiftL && off->in(2)->is_Con() &&
      size_fits_all_mem_uses(m, off->in(2)->get_int()) &&
      // Are there other uses besides address expressions?
      !is_visited(off)) {
    address_visited.set(off->_idx); // Flag as address_visited
    mstack.push(off->in(2), Visit);
    Node *conv = off->in(1);
    if (conv->Opcode() == Op_ConvI2L &&
        // Are there other uses besides address expressions?
        !is_visited(conv)) {
      address_visited.set(conv->_idx); // Flag as address_visited
      mstack.push(conv->in(1), Pre_Visit);
    } else {
      mstack.push(conv, Pre_Visit);
    }
    address_visited.test_set(m->_idx); // Flag as address_visited
    mstack.push(m->in(AddPNode::Address), Pre_Visit);
    mstack.push(m->in(AddPNode::Base), Pre_Visit);
    return true;
  } else if (off->Opcode() == Op_ConvI2L &&
             // Are there other uses besides address expressions?
             !is_visited(off)) {
    address_visited.test_set(m->_idx); // Flag as address_visited
    address_visited.set(off->_idx); // Flag as address_visited
    mstack.push(off->in(1), Pre_Visit);
    mstack.push(m->in(AddPNode::Address), Pre_Visit);
    mstack.push(m->in(AddPNode::Base), Pre_Visit);
    return true;
  }
  return false;
}

#define MOV_VOLATILE(REG, BASE, INDEX, SCALE, DISP, SCRATCH, INSN)      \
  C2_MacroAssembler _masm(&cbuf);                                       \
  {                                                                     \
    guarantee(INDEX == -1, "mode not permitted for volatile");          \
    guarantee(DISP == 0, "mode not permitted for volatile");            \
    guarantee(SCALE == 0, "mode not permitted for volatile");           \
    __ INSN(REG, as_Register(BASE));                                    \
  }


static Address mem2address(int opcode, Register base, int index, int size, int disp)
  {
    Address::extend scale;

    // Hooboy, this is fugly.  We need a way to communicate to the
    // encoder that the index needs to be sign extended, so we have to
    // enumerate all the cases.
    switch (opcode) {
    case INDINDEXSCALEDI2L:
    case INDINDEXSCALEDI2LN:
    case INDINDEXI2L:
    case INDINDEXI2LN:
      scale = Address::sxtw(size);
      break;
    default:
      scale = Address::lsl(size);
    }

    if (index == -1) {
      return Address(base, disp);
    } else {
      assert(disp == 0, "unsupported address mode: disp = %d", disp);
      return Address(base, as_Register(index), scale);
    }
  }


typedef void (MacroAssembler::* mem_insn)(Register Rt, const Address &adr);
typedef void (MacroAssembler::* mem_insn2)(Register Rt, Register adr);
typedef void (MacroAssembler::* mem_float_insn)(FloatRegister Rt, const Address &adr);
typedef void (MacroAssembler::* mem_vector_insn)(FloatRegister Rt,
                                  MacroAssembler::SIMD_RegVariant T, const Address &adr);

  // Used for all non-volatile memory accesses.  The use of
  // $mem->opcode() to discover whether this pattern uses sign-extended
  // offsets is something of a kludge.
  static void loadStore(C2_MacroAssembler masm, mem_insn insn,
                        Register reg, int opcode,
                        Register base, int index, int scale, int disp,
                        int size_in_memory)
  {
    Address addr = mem2address(opcode, base, index, scale, disp);
    if (addr.getMode() == Address::base_plus_offset) {
      /* If we get an out-of-range offset it is a bug in the compiler,
         so we assert here. */
      assert(Address::offset_ok_for_immed(addr.offset(), exact_log2(size_in_memory)),
             "c2 compiler bug");
      /* Fix up any out-of-range offsets. */
      assert_different_registers(rscratch1, base);
      assert_different_registers(rscratch1, reg);
      addr = masm.legitimize_address(addr, size_in_memory, rscratch1);
    }
    (masm.*insn)(reg, addr);
  }

  static void loadStore(C2_MacroAssembler masm, mem_float_insn insn,
                        FloatRegister reg, int opcode,
                        Register base, int index, int size, int disp,
                        int size_in_memory)
  {
    Address::extend scale;

    switch (opcode) {
    case INDINDEXSCALEDI2L:
    case INDINDEXSCALEDI2LN:
      scale = Address::sxtw(size);
      break;
    default:
      scale = Address::lsl(size);
    }

    if (index == -1) {
      /* If we get an out-of-range offset it is a bug in the compiler,
         so we assert here. */
      assert(Address::offset_ok_for_immed(disp, exact_log2(size_in_memory)), "c2 compiler bug");
      /* Fix up any out-of-range offsets. */
      assert_different_registers(rscratch1, base);
      Address addr = Address(base, disp);
      addr = masm.legitimize_address(addr, size_in_memory, rscratch1);
      (masm.*insn)(reg, addr);
    } else {
      assert(disp == 0, "unsupported address mode: disp = %d", disp);
      (masm.*insn)(reg, Address(base, as_Register(index), scale));
    }
  }

  static void loadStore(C2_MacroAssembler masm, mem_vector_insn insn,
                        FloatRegister reg, MacroAssembler::SIMD_RegVariant T,
                        int opcode, Register base, int index, int size, int disp)
  {
    if (index == -1) {
      (masm.*insn)(reg, T, Address(base, disp));
    } else {
      assert(disp == 0, "unsupported address mode");
      (masm.*insn)(reg, T, Address(base, as_Register(index), Address::lsl(size)));
    }
  }


#line 1596 "ad_aarch64.cpp"


//SourceForm

#line 90 "src/hotspot/cpu/aarch64/aarch64_vector.ad"


  typedef void (C2_MacroAssembler::* sve_mem_insn_predicate)(FloatRegister Rt, Assembler::SIMD_RegVariant T,
                                                             PRegister Pg, const Address &adr);

  // Predicated load/store, with optional ptrue to all elements of given predicate register.
  static void loadStoreA_predicated(C2_MacroAssembler masm, bool is_store, FloatRegister reg,
                                    PRegister pg, BasicType mem_elem_bt, BasicType vector_elem_bt,
                                    int opcode, Register base, int index, int size, int disp) {
    sve_mem_insn_predicate insn;
    int mesize = type2aelembytes(mem_elem_bt);
    if (index == -1) {
      assert(size == 0, "unsupported address mode: scale size = %d", size);
      switch(mesize) {
      case 1:
        insn = is_store ? &C2_MacroAssembler::sve_st1b : &C2_MacroAssembler::sve_ld1b;
        break;
      case 2:
        insn = is_store ? &C2_MacroAssembler::sve_st1h : &C2_MacroAssembler::sve_ld1h;
        break;
      case 4:
        insn = is_store ? &C2_MacroAssembler::sve_st1w : &C2_MacroAssembler::sve_ld1w;
        break;
      case 8:
        insn = is_store ? &C2_MacroAssembler::sve_st1d : &C2_MacroAssembler::sve_ld1d;
        break;
      default:
        assert(false, "unsupported");
        ShouldNotReachHere();
      }
      int imm4 = disp / mesize / Matcher::scalable_vector_reg_size(vector_elem_bt);
      (masm.*insn)(reg, Assembler::elemType_to_regVariant(vector_elem_bt), pg, Address(base, imm4));
    } else {
      assert(false, "unimplemented");
      ShouldNotReachHere();
    }
  }

  const bool Matcher::match_rule_supported_superword(int opcode, int vlen, BasicType bt) {
    if (UseSVE == 0) {
      // These operations are not profitable to be vectorized on NEON, because no direct
      // NEON instructions support them. But the match rule support for them is profitable for
      // Vector API intrinsics.
      if ((opcode == Op_VectorCastD2X && bt == T_INT) ||
          (opcode == Op_VectorCastL2X && bt == T_FLOAT) ||
          (opcode == Op_CountLeadingZerosV && bt == T_LONG) ||
          (opcode == Op_CountTrailingZerosV && bt == T_LONG) ||
          opcode == Op_AddReductionVD || opcode == Op_AddReductionVF ||
          opcode == Op_MulReductionVD || opcode == Op_MulReductionVF ||
          opcode == Op_MulVL) {
        return false;
      }
    }
    return match_rule_supported_vector(opcode, vlen, bt);
  }

  // Identify extra cases that we might want to provide match rules for vector nodes and
  // other intrinsics guarded with vector length (vlen) and element type (bt).
  const bool Matcher::match_rule_supported_vector(int opcode, int vlen, BasicType bt) {
    if (!match_rule_supported(opcode)) {
      return false;
    }

    int length_in_bytes = vlen * type2aelembytes(bt);
    if (UseSVE == 0 && length_in_bytes > 16) {
      return false;
    }

    // Check whether specific Op is supported.
    // Fail fast, otherwise fall through to common vector_size_supported() check.
    switch (opcode) {
      case Op_AndVMask:
      case Op_OrVMask:
      case Op_XorVMask:
      case Op_MaskAll:
      case Op_VectorMaskGen:
      case Op_LoadVectorMasked:
      case Op_StoreVectorMasked:
      case Op_LoadVectorGather:
      case Op_StoreVectorScatter:
      case Op_LoadVectorGatherMasked:
      case Op_StoreVectorScatterMasked:
      case Op_PopulateIndex:
      case Op_CompressM:
      case Op_CompressV:
        if (UseSVE == 0) {
          return false;
        }
        break;
      case Op_MulAddVS2VI:
        if (length_in_bytes != 16) {
          return false;
        }
        break;
      case Op_MulReductionVD:
      case Op_MulReductionVF:
      case Op_MulReductionVI:
      case Op_MulReductionVL:
        // No vector multiply reduction instructions, but we do
        // emit scalar instructions for 64/128-bit vectors.
        if (length_in_bytes != 8 && length_in_bytes != 16) {
          return false;
        }
        break;
      case Op_VectorMaskCmp:
        if (length_in_bytes < 8) {
          return false;
        }
        break;
      case Op_VectorLoadShuffle:
      case Op_VectorRearrange:
        if (vlen < 4) {
          return false;
        }
        break;
      case Op_ExpandV:
        if (UseSVE < 2 || is_subword_type(bt)) {
          return false;
        }
        break;
      case Op_VectorMaskToLong:
        if (UseSVE > 0 && vlen > 64) {
          return false;
        }
        break;
      case Op_VectorLongToMask:
        if (UseSVE < 2 || vlen > 64 || !VM_Version::supports_svebitperm()) {
          return false;
        }
        break;
      default:
        break;
    }
    return vector_size_supported(bt, vlen);
  }

  const bool Matcher::match_rule_supported_vector_masked(int opcode, int vlen, BasicType bt) {
    // Only SVE supports masked operations.
    if (UseSVE == 0) {
      return false;
    }

    // If an opcode does not support the masked version,
    // unpredicated node with VectorBlend node will be used instead.
    switch(opcode) {
      case Op_VectorRearrange:
      case Op_MulReductionVD:
      case Op_MulReductionVF:
      case Op_MulReductionVI:
      case Op_MulReductionVL:
        return false;
      // We use Op_LoadVectorMasked to implement the predicated Op_LoadVector.
      // Hence we turn to check whether Op_LoadVectorMasked is supported. The
      // same as vector store/gather/scatter.
      case Op_LoadVector:
        opcode = Op_LoadVectorMasked;
        break;
      case Op_StoreVector:
        opcode = Op_StoreVectorMasked;
        break;
      case Op_LoadVectorGather:
        opcode = Op_LoadVectorGatherMasked;
        break;
      case Op_StoreVectorScatter:
        opcode = Op_StoreVectorScatterMasked;
        break;
      default:
        break;
    }

    return match_rule_supported_vector(opcode, vlen, bt);
  }

  const bool Matcher::vector_needs_partial_operations(Node* node, const TypeVect* vt) {
    // Only SVE has partial vector operations
    if (UseSVE == 0) {
      return false;
    }

    switch(node->Opcode()) {
      case Op_VectorLoadMask:
      case Op_VectorMaskCmp:
      case Op_LoadVectorGather:
      case Op_StoreVectorScatter:
      case Op_AddReductionVF:
      case Op_AddReductionVD:
      case Op_AndReductionV:
      case Op_OrReductionV:
      case Op_XorReductionV:
      // Mask is needed for partial Op_VectorMaskFirstTrue, because when the
      // input predicate is all-false, the result should be the vector length
      // instead of the vector register size.
      case Op_VectorMaskFirstTrue:
        return true;
      case Op_MaskAll:
        return !node->in(1)->is_Con();
      case Op_LoadVector:
      case Op_StoreVector:
        // We use NEON load/store instructions if the vector length is <= 128 bits.
        return vt->length_in_bytes() > 16;
      case Op_AddReductionVI:
      case Op_AddReductionVL:
        // We may prefer using NEON instructions rather than SVE partial operations.
        return !VM_Version::use_neon_for_vector(vt->length_in_bytes());
      case Op_MinReductionV:
      case Op_MaxReductionV:
        // For BYTE/SHORT/INT/FLOAT/DOUBLE types, we may prefer using NEON
        // instructions rather than SVE partial operations.
        return vt->element_basic_type() == T_LONG ||
               !VM_Version::use_neon_for_vector(vt->length_in_bytes());
      default:
        // For other ops whose vector size is smaller than the max vector size, a
        // full-sized unpredicated operation does not impact the final vector result.
        return false;
    }
  }

  // Assert that the given node is not a variable shift.
  bool assert_not_var_shift(const Node* n) {
    assert(!n->as_ShiftV()->is_var_shift(), "illegal variable shift");
    return true;
  }

  Assembler::SIMD_Arrangement get_arrangement(const Node* n) {
    BasicType bt = Matcher::vector_element_basic_type(n);
    uint length_in_bytes = Matcher::vector_length_in_bytes(n);
    return Assembler::esize2arrangement((uint)type2aelembytes(bt),
                                        /* isQ */ length_in_bytes == 16);
  }

#line 1832 "ad_aarch64.cpp"


//SourceForm

#line 32 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"


static void z_load_barrier(MacroAssembler& _masm, const MachNode* node, Address ref_addr, Register ref, Register tmp, uint8_t barrier_data) {
  if (barrier_data == ZLoadBarrierElided) {
    return;
  }
  ZLoadBarrierStubC2* const stub = ZLoadBarrierStubC2::create(node, ref_addr, ref, tmp, barrier_data);
  __ ldr(tmp, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
  __ andr(tmp, tmp, ref);
  __ cbnz(tmp, *stub->entry());
  __ bind(*stub->continuation());
}

static void z_load_barrier_slow_path(MacroAssembler& _masm, const MachNode* node, Address ref_addr, Register ref, Register tmp) {
  ZLoadBarrierStubC2* const stub = ZLoadBarrierStubC2::create(node, ref_addr, ref, tmp, ZLoadBarrierStrong);
  __ b(*stub->entry());
  __ bind(*stub->continuation());
}


#line 1858 "ad_aarch64.cpp"


#ifndef PRODUCT
void Compile::adlc_verification() {

  // Following assertions generated from definition section
  assert( INSN_COST == 100, "Expect (100) to equal 100");
  assert( BRANCH_COST == 200, "Expect (2 * INSN_COST) to equal 200");
  assert( CALL_COST == 200, "Expect (2 * INSN_COST) to equal 200");
  assert( VOLATILE_REF_COST == 1000, "Expect (10 * INSN_COST) to equal 1000");
}
#endif

// Map from machine-independent register number to register_save_policy
const        char register_save_policy[] = {
  'C', // R10
  'C', // R10_H
  'C', // R11
  'C', // R11_H
  'C', // R12
  'C', // R12_H
  'C', // R13
  'C', // R13_H
  'C', // R14
  'C', // R14_H
  'C', // R15
  'C', // R15_H
  'C', // R16
  'C', // R16_H
  'C', // R17
  'C', // R17_H
  'C', // R18
  'C', // R18_H
  'C', // R0
  'C', // R0_H
  'C', // R1
  'C', // R1_H
  'C', // R2
  'C', // R2_H
  'C', // R3
  'C', // R3_H
  'C', // R4
  'C', // R4_H
  'C', // R5
  'C', // R5_H
  'C', // R6
  'C', // R6_H
  'C', // R7
  'C', // R7_H
  'C', // R19
  'C', // R19_H
  'C', // R20
  'C', // R20_H
  'C', // R21
  'C', // R21_H
  'C', // R22
  'C', // R22_H
  'C', // R23
  'C', // R23_H
  'C', // R24
  'C', // R24_H
  'C', // R25
  'C', // R25_H
  'C', // R26
  'C', // R26_H
  'C', // R27
  'C', // R27_H
  'N', // R28
  'N', // R28_H
  'N', // R29
  'N', // R29_H
  'N', // R30
  'N', // R30_H
  'N', // R31
  'N', // R31_H
  'N', // R8
  'N', // R8_H
  'N', // R9
  'N', // R9_H
  'C', // V16
  'C', // V16_H
  'C', // V16_J
  'C', // V16_K
  'C', // V17
  'C', // V17_H
  'C', // V17_J
  'C', // V17_K
  'C', // V18
  'C', // V18_H
  'C', // V18_J
  'C', // V18_K
  'C', // V19
  'C', // V19_H
  'C', // V19_J
  'C', // V19_K
  'C', // V20
  'C', // V20_H
  'C', // V20_J
  'C', // V20_K
  'C', // V21
  'C', // V21_H
  'C', // V21_J
  'C', // V21_K
  'C', // V22
  'C', // V22_H
  'C', // V22_J
  'C', // V22_K
  'C', // V23
  'C', // V23_H
  'C', // V23_J
  'C', // V23_K
  'C', // V24
  'C', // V24_H
  'C', // V24_J
  'C', // V24_K
  'C', // V25
  'C', // V25_H
  'C', // V25_J
  'C', // V25_K
  'C', // V26
  'C', // V26_H
  'C', // V26_J
  'C', // V26_K
  'C', // V27
  'C', // V27_H
  'C', // V27_J
  'C', // V27_K
  'C', // V28
  'C', // V28_H
  'C', // V28_J
  'C', // V28_K
  'C', // V29
  'C', // V29_H
  'C', // V29_J
  'C', // V29_K
  'C', // V30
  'C', // V30_H
  'C', // V30_J
  'C', // V30_K
  'C', // V31
  'C', // V31_H
  'C', // V31_J
  'C', // V31_K
  'C', // V0
  'C', // V0_H
  'C', // V0_J
  'C', // V0_K
  'C', // V1
  'C', // V1_H
  'C', // V1_J
  'C', // V1_K
  'C', // V2
  'C', // V2_H
  'C', // V2_J
  'C', // V2_K
  'C', // V3
  'C', // V3_H
  'C', // V3_J
  'C', // V3_K
  'C', // V4
  'C', // V4_H
  'C', // V4_J
  'C', // V4_K
  'C', // V5
  'C', // V5_H
  'C', // V5_J
  'C', // V5_K
  'C', // V6
  'C', // V6_H
  'C', // V6_J
  'C', // V6_K
  'C', // V7
  'C', // V7_H
  'C', // V7_J
  'C', // V7_K
  'C', // V8
  'C', // V8_H
  'C', // V8_J
  'C', // V8_K
  'C', // V9
  'C', // V9_H
  'C', // V9_J
  'C', // V9_K
  'C', // V10
  'C', // V10_H
  'C', // V10_J
  'C', // V10_K
  'C', // V11
  'C', // V11_H
  'C', // V11_J
  'C', // V11_K
  'C', // V12
  'C', // V12_H
  'C', // V12_J
  'C', // V12_K
  'C', // V13
  'C', // V13_H
  'C', // V13_J
  'C', // V13_K
  'C', // V14
  'C', // V14_H
  'C', // V14_J
  'C', // V14_K
  'C', // V15
  'C', // V15_H
  'C', // V15_J
  'C', // V15_K
  'C', // P0
  'C', // P1
  'C', // P2
  'C', // P3
  'C', // P4
  'C', // P5
  'C', // P6
  'C', // P8
  'C', // P9
  'C', // P10
  'C', // P11
  'C', // P12
  'C', // P13
  'C', // P14
  'C', // P15
  'C', // P7
  'C' // no trailing comma // RFLAGS
};

// Map from machine-independent register number to c_reg_save_policy
const        char c_reg_save_policy[] = {
  'C', // R10
  'C', // R10_H
  'C', // R11
  'C', // R11_H
  'C', // R12
  'C', // R12_H
  'C', // R13
  'C', // R13_H
  'C', // R14
  'C', // R14_H
  'C', // R15
  'C', // R15_H
  'C', // R16
  'C', // R16_H
  'C', // R17
  'C', // R17_H
  'C', // R18
  'C', // R18_H
  'C', // R0
  'C', // R0_H
  'C', // R1
  'C', // R1_H
  'C', // R2
  'C', // R2_H
  'C', // R3
  'C', // R3_H
  'C', // R4
  'C', // R4_H
  'C', // R5
  'C', // R5_H
  'C', // R6
  'C', // R6_H
  'C', // R7
  'C', // R7_H
  'E', // R19
  'E', // R19_H
  'E', // R20
  'E', // R20_H
  'E', // R21
  'E', // R21_H
  'E', // R22
  'E', // R22_H
  'E', // R23
  'E', // R23_H
  'E', // R24
  'E', // R24_H
  'E', // R25
  'E', // R25_H
  'E', // R26
  'E', // R26_H
  'E', // R27
  'E', // R27_H
  'E', // R28
  'E', // R28_H
  'N', // R29
  'N', // R29_H
  'N', // R30
  'N', // R30_H
  'N', // R31
  'N', // R31_H
  'C', // R8
  'C', // R8_H
  'C', // R9
  'C', // R9_H
  'C', // V16
  'C', // V16_H
  'C', // V16_J
  'C', // V16_K
  'C', // V17
  'C', // V17_H
  'C', // V17_J
  'C', // V17_K
  'C', // V18
  'C', // V18_H
  'C', // V18_J
  'C', // V18_K
  'C', // V19
  'C', // V19_H
  'C', // V19_J
  'C', // V19_K
  'C', // V20
  'C', // V20_H
  'C', // V20_J
  'C', // V20_K
  'C', // V21
  'C', // V21_H
  'C', // V21_J
  'C', // V21_K
  'C', // V22
  'C', // V22_H
  'C', // V22_J
  'C', // V22_K
  'C', // V23
  'C', // V23_H
  'C', // V23_J
  'C', // V23_K
  'C', // V24
  'C', // V24_H
  'C', // V24_J
  'C', // V24_K
  'C', // V25
  'C', // V25_H
  'C', // V25_J
  'C', // V25_K
  'C', // V26
  'C', // V26_H
  'C', // V26_J
  'C', // V26_K
  'C', // V27
  'C', // V27_H
  'C', // V27_J
  'C', // V27_K
  'C', // V28
  'C', // V28_H
  'C', // V28_J
  'C', // V28_K
  'C', // V29
  'C', // V29_H
  'C', // V29_J
  'C', // V29_K
  'C', // V30
  'C', // V30_H
  'C', // V30_J
  'C', // V30_K
  'C', // V31
  'C', // V31_H
  'C', // V31_J
  'C', // V31_K
  'C', // V0
  'C', // V0_H
  'C', // V0_J
  'C', // V0_K
  'C', // V1
  'C', // V1_H
  'C', // V1_J
  'C', // V1_K
  'C', // V2
  'C', // V2_H
  'C', // V2_J
  'C', // V2_K
  'C', // V3
  'C', // V3_H
  'C', // V3_J
  'C', // V3_K
  'C', // V4
  'C', // V4_H
  'C', // V4_J
  'C', // V4_K
  'C', // V5
  'C', // V5_H
  'C', // V5_J
  'C', // V5_K
  'C', // V6
  'C', // V6_H
  'C', // V6_J
  'C', // V6_K
  'C', // V7
  'C', // V7_H
  'C', // V7_J
  'C', // V7_K
  'E', // V8
  'E', // V8_H
  'C', // V8_J
  'C', // V8_K
  'E', // V9
  'E', // V9_H
  'C', // V9_J
  'C', // V9_K
  'E', // V10
  'E', // V10_H
  'C', // V10_J
  'C', // V10_K
  'E', // V11
  'E', // V11_H
  'C', // V11_J
  'C', // V11_K
  'E', // V12
  'E', // V12_H
  'C', // V12_J
  'C', // V12_K
  'E', // V13
  'E', // V13_H
  'C', // V13_J
  'C', // V13_K
  'E', // V14
  'E', // V14_H
  'C', // V14_J
  'C', // V14_K
  'E', // V15
  'E', // V15_H
  'C', // V15_J
  'C', // V15_K
  'C', // P0
  'C', // P1
  'C', // P2
  'C', // P3
  'C', // P4
  'C', // P5
  'C', // P6
  'C', // P8
  'C', // P9
  'C', // P10
  'C', // P11
  'C', // P12
  'C', // P13
  'C', // P14
  'C', // P15
  'C', // P7
  'C' // no trailing comma // RFLAGS
};

// Map from machine-independent register number to register_save_type
const        int register_save_type[] = {
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  0 // no trailing comma
};


const        int   reduceOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  immI_rule,
  /*    9 */  immI0_rule,
  /*   10 */  immI_1_rule,
  /*   11 */  immI_M1_rule,
  /*   12 */  immIExt_rule,
  /*   13 */  immI_gt_1_rule,
  /*   14 */  immI_le_4_rule,
  /*   15 */  immI_16_rule,
  /*   16 */  immI_24_rule,
  /*   17 */  immI_32_rule,
  /*   18 */  immI_48_rule,
  /*   19 */  immI_56_rule,
  /*   20 */  immI_63_rule,
  /*   21 */  immI_64_rule,
  /*   22 */  immI_255_rule,
  /*   23 */  immI_65535_rule,
  /*   24 */  immI_positive_rule,
  /*   25 */  immL_255_rule,
  /*   26 */  immL_65535_rule,
  /*   27 */  immL_4294967295_rule,
  /*   28 */  immL_bitmask_rule,
  /*   29 */  immI_bitmask_rule,
  /*   30 */  immL_positive_bitmaskI_rule,
  /*   31 */  immIScale_rule,
  /*   32 */  immI26_rule,
  /*   33 */  immI19_rule,
  /*   34 */  immIU12_rule,
  /*   35 */  immLU12_rule,
  /*   36 */  immIOffset_rule,
  /*   37 */  immIOffset1_rule,
  /*   38 */  immIOffset2_rule,
  /*   39 */  immIOffset4_rule,
  /*   40 */  immIOffset8_rule,
  /*   41 */  immIOffset16_rule,
  /*   42 */  immLoffset_rule,
  /*   43 */  immLoffset1_rule,
  /*   44 */  immLoffset2_rule,
  /*   45 */  immLoffset4_rule,
  /*   46 */  immLoffset8_rule,
  /*   47 */  immLoffset16_rule,
  /*   48 */  immI8_rule,
  /*   49 */  immI8_shift8_rule,
  /*   50 */  immL8_shift8_rule,
  /*   51 */  immBAddSubV_rule,
  /*   52 */  immIAddSub_rule,
  /*   53 */  immIAddSubV_rule,
  /*   54 */  immBLog_rule,
  /*   55 */  immSLog_rule,
  /*   56 */  immILog_rule,
  /*   57 */  immL_rule,
  /*   58 */  immL0_rule,
  /*   59 */  immL_1_rule,
  /*   60 */  immL_M1_rule,
  /*   61 */  immL_pc_off_rule,
  /*   62 */  immLAddSub_rule,
  /*   63 */  immLAddSubV_rule,
  /*   64 */  immLLog_rule,
  /*   65 */  immL_32bits_rule,
  /*   66 */  immP_rule,
  /*   67 */  immP0_rule,
  /*   68 */  immP_1_rule,
  /*   69 */  immByteMapBase_rule,
  /*   70 */  immP_M1_rule,
  /*   71 */  immP_M2_rule,
  /*   72 */  immD_rule,
  /*   73 */  immD0_rule,
  /*   74 */  immDPacked_rule,
  /*   75 */  immF_rule,
  /*   76 */  immF0_rule,
  /*   77 */  immFPacked_rule,
  /*   78 */  immN_rule,
  /*   79 */  immN0_rule,
  /*   80 */  immNKlass_rule,
  /*   81 */  iRegI_rule,
  /*   82 */  iRegINoSp_rule,
  /*   83 */  iRegL_rule,
  /*   84 */  iRegLNoSp_rule,
  /*   85 */  iRegP_rule,
  /*   86 */  iRegPNoSp_rule,
  /*   87 */  iRegP_R0_rule,
  /*   88 */  iRegP_R1_rule,
  /*   89 */  iRegP_R2_rule,
  /*   90 */  iRegP_R3_rule,
  /*   91 */  iRegP_R4_rule,
  /*   92 */  iRegP_R5_rule,
  /*   93 */  iRegP_R10_rule,
  /*   94 */  iRegL_R0_rule,
  /*   95 */  iRegL_R2_rule,
  /*   96 */  iRegL_R3_rule,
  /*   97 */  iRegL_R11_rule,
  /*   98 */  iRegP_FP_rule,
  /*   99 */  iRegI_R0_rule,
  /*  100 */  iRegI_R2_rule,
  /*  101 */  iRegI_R3_rule,
  /*  102 */  iRegI_R4_rule,
  /*  103 */  iRegN_rule,
  /*  104 */  iRegN_R0_rule,
  /*  105 */  iRegN_R2_rule,
  /*  106 */  iRegN_R3_rule,
  /*  107 */  iRegNNoSp_rule,
  /*  108 */  iRegIHeapbase_rule,
  /*  109 */  vRegF_rule,
  /*  110 */  vRegD_rule,
  /*  111 */  vReg_rule,
  /*  112 */  vecA_rule,
  /*  113 */  vecD_rule,
  /*  114 */  vecX_rule,
  /*  115 */  vRegD_V0_rule,
  /*  116 */  vRegD_V1_rule,
  /*  117 */  vRegD_V2_rule,
  /*  118 */  vRegD_V3_rule,
  /*  119 */  vRegD_V4_rule,
  /*  120 */  vRegD_V5_rule,
  /*  121 */  vRegD_V6_rule,
  /*  122 */  vRegD_V7_rule,
  /*  123 */  vRegD_V8_rule,
  /*  124 */  vRegD_V9_rule,
  /*  125 */  vRegD_V10_rule,
  /*  126 */  vRegD_V11_rule,
  /*  127 */  vRegD_V12_rule,
  /*  128 */  vRegD_V13_rule,
  /*  129 */  vRegD_V14_rule,
  /*  130 */  vRegD_V15_rule,
  /*  131 */  vRegD_V16_rule,
  /*  132 */  vRegD_V17_rule,
  /*  133 */  vRegD_V18_rule,
  /*  134 */  vRegD_V19_rule,
  /*  135 */  vRegD_V20_rule,
  /*  136 */  vRegD_V21_rule,
  /*  137 */  vRegD_V22_rule,
  /*  138 */  vRegD_V23_rule,
  /*  139 */  vRegD_V24_rule,
  /*  140 */  vRegD_V25_rule,
  /*  141 */  vRegD_V26_rule,
  /*  142 */  vRegD_V27_rule,
  /*  143 */  vRegD_V28_rule,
  /*  144 */  vRegD_V29_rule,
  /*  145 */  vRegD_V30_rule,
  /*  146 */  vRegD_V31_rule,
  /*  147 */  pReg_rule,
  /*  148 */  pRegGov_rule,
  /*  149 */  pRegGov_P0_rule,
  /*  150 */  pRegGov_P1_rule,
  /*  151 */  rFlagsReg_rule,
  /*  152 */  rFlagsRegU_rule,
  /*  153 */  inline_cache_RegP_rule,
  /*  154 */  thread_RegP_rule,
  /*  155 */  lr_RegP_rule,
  /*  156 */  indirect_rule,
  /*  157 */  indIndexScaledI2L_rule,
  /*  158 */  indIndexScaled_rule,
  /*  159 */  indIndexI2L_rule,
  /*  160 */  indIndex_rule,
  /*  161 */  indOffI_rule,
  /*  162 */  indOffI1_rule,
  /*  163 */  indOffI2_rule,
  /*  164 */  indOffI4_rule,
  /*  165 */  indOffI8_rule,
  /*  166 */  indOffI16_rule,
  /*  167 */  indOffL_rule,
  /*  168 */  indOffL1_rule,
  /*  169 */  indOffL2_rule,
  /*  170 */  indOffL4_rule,
  /*  171 */  indOffL8_rule,
  /*  172 */  indOffL16_rule,
  /*  173 */  indirectN_rule,
  /*  174 */  indIndexScaledI2LN_rule,
  /*  175 */  indIndexScaledN_rule,
  /*  176 */  indIndexI2LN_rule,
  /*  177 */  indIndexN_rule,
  /*  178 */  indOffIN_rule,
  /*  179 */  indOffLN_rule,
  /*  180 */  thread_anchor_pc_rule,
  /*  181 */  stackSlotP_rule,
  /*  182 */  stackSlotI_rule,
  /*  183 */  stackSlotF_rule,
  /*  184 */  stackSlotD_rule,
  /*  185 */  stackSlotL_rule,
  /*  186 */  cmpOp_rule,
  /*  187 */  cmpOpU_rule,
  /*  188 */  cmpOpEqNe_rule,
  /*  189 */  cmpOpLtGe_rule,
  /*  190 */  cmpOpUEqNeLtGe_rule,
  /*  191 */  iRegL2I_rule,
  /*  192 */  vmemA_immIOffset4_rule,
  /*  193 */  vmemA_immLOffset4_rule,
  /*  194 */  vmemA_indOffI4_rule,
  /*  195 */  vmemA_indOffL4_rule,
  // last operand
  /*  196 */  vmem2_rule,
  /*  197 */  vmem4_rule,
  /*  198 */  vmem8_rule,
  /*  199 */  vmem16_rule,
  /*  200 */  memory1_rule,
  /*  201 */  memory2_rule,
  /*  202 */  memory4_rule,
  /*  203 */  memory8_rule,
  /*  204 */  memory_rule,
  /*  205 */  iRegIorL2I_rule,
  /*  206 */  vmemA_rule,
  // last operand class
  /*  207 */  _ConvI2L_iRegI__rule,
  /*  208 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  209 */  _LShiftL_iRegL_immIScale_rule,
  /*  210 */  _DecodeN_iRegN__rule,
  /*  211 */  _LoadB_memory1__rule,
  /*  212 */  _LoadUB_memory1__rule,
  /*  213 */  _LoadS_memory2__rule,
  /*  214 */  _LoadUS_memory2__rule,
  /*  215 */  _LoadI_memory4__rule,
  /*  216 */  _ConvI2L__LoadI_memory4___rule,
  /*  217 */  _LoadB_indirect__rule,
  /*  218 */  _LoadUB_indirect__rule,
  /*  219 */  _LoadUS_indirect__rule,
  /*  220 */  _LoadS_indirect__rule,
  /*  221 */  _LoadI_indirect__rule,
  /*  222 */  _ConvI2L__LoadI_indirect___rule,
  /*  223 */  _LoadL_memory8__rule,
  /*  224 */  _CastP2X_iRegP__rule,
  /*  225 */  _CastP2X__DecodeN_iRegN___rule,
  /*  226 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  227 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  228 */  _Binary_iRegP_iRegP_rule,
  /*  229 */  _Binary_iRegNNoSp_iRegNNoSp_rule,
  /*  230 */  _Binary_iRegI_iRegI_rule,
  /*  231 */  _Binary_iRegL_iRegL_rule,
  /*  232 */  _Binary_iRegN_iRegN_rule,
  /*  233 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  234 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  235 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  236 */  _Binary_immI0_iRegIorL2I_rule,
  /*  237 */  _Binary_iRegIorL2I_immI0_rule,
  /*  238 */  _Binary_immI_1_immI0_rule,
  /*  239 */  _Binary_iRegL_immL0_rule,
  /*  240 */  _Binary_immL0_iRegL_rule,
  /*  241 */  _Binary_iRegP_immP0_rule,
  /*  242 */  _Binary_immP0_iRegP_rule,
  /*  243 */  _Binary_iRegN_immN0_rule,
  /*  244 */  _Binary_immN0_iRegN_rule,
  /*  245 */  _Binary_vRegF_vRegF_rule,
  /*  246 */  _Binary_vRegD_vRegD_rule,
  /*  247 */  _ConvL2I_iRegL__rule,
  /*  248 */  _ConvI2L_iRegIorL2I__rule,
  /*  249 */  _LShiftL__ConvI2L_iRegIorL2I__immIScale_rule,
  /*  250 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  251 */  _SubI_immI0_iRegIorL2I_rule,
  /*  252 */  _MulL_iRegL_iRegL_rule,
  /*  253 */  _SubL_immL0_iRegL_rule,
  /*  254 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  255 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  256 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  257 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  258 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  259 */  _URShiftL_iRegL_immI_rule,
  /*  260 */  _RShiftL_iRegL_immI_rule,
  /*  261 */  _LShiftL_iRegL_immI_rule,
  /*  262 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  263 */  _XorL_iRegL_immL_M1_rule,
  /*  264 */  _XorI_iRegIorL2I_iRegIorL2I_rule,
  /*  265 */  _XorL_iRegL_iRegL_rule,
  /*  266 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  267 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  268 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  269 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  270 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  271 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /*  272 */  _RotateRight_iRegL_immI_rule,
  /*  273 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /*  274 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  275 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  276 */  _XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  277 */  _XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI_rule,
  /*  278 */  _XorL__URShiftL_iRegL_immI_iRegL_rule,
  /*  279 */  _XorL_iRegL__URShiftL_iRegL_immI_rule,
  /*  280 */  _XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  281 */  _XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI_rule,
  /*  282 */  _XorL__RShiftL_iRegL_immI_iRegL_rule,
  /*  283 */  _XorL_iRegL__RShiftL_iRegL_immI_rule,
  /*  284 */  _XorI__RotateRight_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  285 */  _XorI_iRegIorL2I__RotateRight_iRegIorL2I_immI_rule,
  /*  286 */  _XorL__RotateRight_iRegL_immI_iRegL_rule,
  /*  287 */  _XorL_iRegL__RotateRight_iRegL_immI_rule,
  /*  288 */  _XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  289 */  _XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI_rule,
  /*  290 */  _XorL__LShiftL_iRegL_immI_iRegL_rule,
  /*  291 */  _XorL_iRegL__LShiftL_iRegL_immI_rule,
  /*  292 */  _AndI__URShiftI_iRegIorL2I_immI_immI_bitmask_rule,
  /*  293 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /*  294 */  _AndL_iRegL_immL_bitmask_rule,
  /*  295 */  _LShiftI__AndI_iRegIorL2I_immI_bitmask_immI_rule,
  /*  296 */  _AndL_iRegL_immL_positive_bitmaskI_rule,
  /*  297 */  _LShiftL__AndL_iRegL_immL_positive_bitmaskI_immI_rule,
  /*  298 */  _ConvI2L__AndI_iRegIorL2I_immI_bitmask__rule,
  /*  299 */  _ConvL2I__AndL_iRegL_immL_positive_bitmaskI__rule,
  /*  300 */  _AndI_iRegI_immI_bitmask_rule,
  /*  301 */  _LShiftI_iRegIorL2I_immI_16_rule,
  /*  302 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /*  303 */  _LShiftI_iRegIorL2I_immI_24_rule,
  /*  304 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  305 */  _URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  306 */  _LShiftL_iRegL_immI_48_rule,
  /*  307 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /*  308 */  _LShiftL_iRegL_immI_32_rule,
  /*  309 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /*  310 */  _LShiftL_iRegL_immI_56_rule,
  /*  311 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  312 */  _URShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  313 */  _AndI_iRegIorL2I_immI_255_rule,
  /*  314 */  _AndI_iRegIorL2I_immI_65535_rule,
  /*  315 */  _AndL_iRegL_immL_255_rule,
  /*  316 */  _AndL_iRegL_immL_65535_rule,
  /*  317 */  _AndL_iRegL_immL_4294967295_rule,
  /*  318 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /*  319 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /*  320 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /*  321 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /*  322 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /*  323 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /*  324 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /*  325 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /*  326 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /*  327 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /*  328 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /*  329 */  _NegF_vRegF__rule,
  /*  330 */  _Binary__NegF_vRegF__vRegF_rule,
  /*  331 */  _Binary_vRegF__NegF_vRegF__rule,
  /*  332 */  _NegD_vRegD__rule,
  /*  333 */  _Binary__NegD_vRegD__vRegD_rule,
  /*  334 */  _Binary_vRegD__NegD_vRegD__rule,
  /*  335 */  _SubF_vRegF_vRegF_rule,
  /*  336 */  _SubD_vRegD_vRegD_rule,
  /*  337 */  _OverflowMulI_iRegIorL2I_iRegIorL2I_rule,
  /*  338 */  _OverflowMulL_iRegL_iRegL_rule,
  /*  339 */  _CmpI_iRegIorL2I_immI0_rule,
  /*  340 */  _CmpL_iRegL_immL0_rule,
  /*  341 */  _CmpP_iRegP_immP0_rule,
  /*  342 */  _CmpN_iRegN_immN0_rule,
  /*  343 */  _CmpP__DecodeN_iRegN__immP0_rule,
  /*  344 */  _CmpU_iRegIorL2I_immI0_rule,
  /*  345 */  _CmpUL_iRegL_immL0_rule,
  /*  346 */  _AndL_iRegL_immL_rule,
  /*  347 */  _CmpL__AndL_iRegL_immL_immL0_rule,
  /*  348 */  _AndI_iRegIorL2I_immI_rule,
  /*  349 */  _CmpI__AndI_iRegIorL2I_immI_immI0_rule,
  /*  350 */  _AndL_iRegL_iRegL_rule,
  /*  351 */  _AndI_iRegIorL2I_iRegIorL2I_rule,
  /*  352 */  _PartialSubtypeCheck_iRegP_R4_iRegP_R0_rule,
  /*  353 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /*  354 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /*  355 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /*  356 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /*  357 */  _Binary_iRegP_R3_immI_le_4_rule,
  /*  358 */  _Binary_iRegP_R3_immI_1_rule,
  /*  359 */  _Binary_iRegP_R1_iRegP_R3_rule,
  /*  360 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /*  361 */  _Binary_vReg_pRegGov_rule,
  /*  362 */  _Binary_vReg_vReg_rule,
  /*  363 */  _ReplicateB_immBAddSubV__rule,
  /*  364 */  _ReplicateS_immIAddSubV__rule,
  /*  365 */  _ReplicateI_immIAddSubV__rule,
  /*  366 */  _ReplicateL_immLAddSubV__rule,
  /*  367 */  _ReplicateB_immBLog__rule,
  /*  368 */  _ReplicateS_immSLog__rule,
  /*  369 */  _ReplicateI_immILog__rule,
  /*  370 */  _ReplicateL_immLLog__rule,
  /*  371 */  _XorV_vReg_vReg_rule,
  /*  372 */  _ReplicateB_immI_M1__rule,
  /*  373 */  _ReplicateS_immI_M1__rule,
  /*  374 */  _ReplicateI_immI_M1__rule,
  /*  375 */  _ReplicateL_immL_M1__rule,
  /*  376 */  _Binary_vReg__ReplicateB_immI_M1__rule,
  /*  377 */  _Binary_vReg__ReplicateS_immI_M1__rule,
  /*  378 */  _Binary_vReg__ReplicateI_immI_M1__rule,
  /*  379 */  _Binary_vReg__ReplicateL_immL_M1__rule,
  /*  380 */  _XorV_vReg__ReplicateB_immI_M1__rule,
  /*  381 */  _XorV__ReplicateB_immI_M1__vReg_rule,
  /*  382 */  _XorV_vReg__ReplicateS_immI_M1__rule,
  /*  383 */  _XorV__ReplicateS_immI_M1__vReg_rule,
  /*  384 */  _XorV_vReg__ReplicateI_immI_M1__rule,
  /*  385 */  _XorV__ReplicateI_immI_M1__vReg_rule,
  /*  386 */  _XorV_vReg__ReplicateL_immL_M1__rule,
  /*  387 */  _XorV__ReplicateL_immL_M1__vReg_rule,
  /*  388 */  _Binary_vReg__XorV_vReg__ReplicateB_immI_M1__rule,
  /*  389 */  _Binary_vReg__XorV__ReplicateB_immI_M1__vReg_rule,
  /*  390 */  _Binary_vReg__XorV_vReg__ReplicateS_immI_M1__rule,
  /*  391 */  _Binary_vReg__XorV__ReplicateS_immI_M1__vReg_rule,
  /*  392 */  _Binary_vReg__XorV_vReg__ReplicateI_immI_M1__rule,
  /*  393 */  _Binary_vReg__XorV__ReplicateI_immI_M1__vReg_rule,
  /*  394 */  _Binary_vReg__XorV_vReg__ReplicateL_immL_M1__rule,
  /*  395 */  _Binary_vReg__XorV__ReplicateL_immL_M1__vReg_rule,
  /*  396 */  _SubVF_vReg_vReg_rule,
  /*  397 */  _SubVD_vReg_vReg_rule,
  /*  398 */  _SubVF__Binary_vReg_vReg_pRegGov_rule,
  /*  399 */  _SubVD__Binary_vReg_vReg_pRegGov_rule,
  /*  400 */  _MulVB_vReg_vReg_rule,
  /*  401 */  _MulVS_vReg_vReg_rule,
  /*  402 */  _MulVI_vReg_vReg_rule,
  /*  403 */  _MulVL_vReg_vReg_rule,
  /*  404 */  _Binary_vReg__MulVB_vReg_vReg_rule,
  /*  405 */  _Binary_vReg__MulVS_vReg_vReg_rule,
  /*  406 */  _Binary_vReg__MulVI_vReg_vReg_rule,
  /*  407 */  _Binary_vReg__MulVL_vReg_vReg_rule,
  /*  408 */  _NegVF_vReg__rule,
  /*  409 */  _Binary__NegVF_vReg__vReg_rule,
  /*  410 */  _NegVD_vReg__rule,
  /*  411 */  _Binary__NegVD_vReg__vReg_rule,
  /*  412 */  _Binary_vReg__NegVF_vReg__rule,
  /*  413 */  _Binary_vReg__NegVD_vReg__rule,
  /*  414 */  _Binary__NegVF_vReg__pRegGov_rule,
  /*  415 */  _Binary__NegVD_vReg__pRegGov_rule,
  /*  416 */  _LShiftCntV_immI__rule,
  /*  417 */  _RShiftCntV_immI_positive__rule,
  /*  418 */  _RShiftVB_vReg__RShiftCntV_immI_positive__rule,
  /*  419 */  _RShiftVS_vReg__RShiftCntV_immI_positive__rule,
  /*  420 */  _RShiftVI_vReg__RShiftCntV_immI_positive__rule,
  /*  421 */  _RShiftVL_vReg__RShiftCntV_immI_positive__rule,
  /*  422 */  _URShiftVB_vReg__RShiftCntV_immI_positive__rule,
  /*  423 */  _URShiftVS_vReg__RShiftCntV_immI_positive__rule,
  /*  424 */  _URShiftVI_vReg__RShiftCntV_immI_positive__rule,
  /*  425 */  _URShiftVL_vReg__RShiftCntV_immI_positive__rule,
  /*  426 */  _Binary_vReg__LShiftCntV_immI__rule,
  /*  427 */  _Binary_vReg__RShiftCntV_immI_positive__rule,
  /*  428 */  _Binary_iRegIorL2I_vReg_rule,
  /*  429 */  _Binary_iRegL_vReg_rule,
  /*  430 */  _Binary_vRegF_vReg_rule,
  /*  431 */  _Binary_vRegD_vReg_rule,
  /*  432 */  _Binary_vReg_iRegIorL2I_rule,
  /*  433 */  _Binary_vReg_iRegL_rule,
  /*  434 */  _Binary_vReg_vRegF_rule,
  /*  435 */  _Binary_vReg_vRegD_rule,
  /*  436 */  _LoadVector_indirect__rule,
  /*  437 */  _LoadVectorMasked_vmemA_pRegGov_rule,
  /*  438 */  _VectorStoreMask_pReg_immI_gt_1_rule,
  /*  439 */  _Binary__VectorStoreMask_pReg_immI_gt_1_pRegGov_rule,
  /*  440 */  _MaskAll_immI_M1__rule,
  /*  441 */  _XorVMask_pReg__MaskAll_immI_M1__rule,
  /*  442 */  _MaskAll_immL_M1__rule,
  /*  443 */  _XorVMask_pReg__MaskAll_immL_M1__rule,
  /*  444 */  _Binary_immI_pRegGov_rule,
  /*  445 */  _Binary_cmpOp_immI_rule,
  /*  446 */  _Binary_vReg__Binary_vReg_pRegGov_rule,
  // last internally defined operand
  /*  447 */  iRegINoSp_rule,
  /*  448 */  iRegLNoSp_rule,
  /*  449 */  iRegPNoSp_rule,
  /*  450 */  iRegPNoSp_rule,
  /*  451 */  iRegPNoSp_rule,
  /*  452 */  iRegPNoSp_rule,
  /*  453 */  iRegNNoSp_rule,
  /*  454 */  iRegNNoSp_rule,
  /*  455 */  iRegNNoSp_rule,
  /*  456 */  vRegF_rule,
  /*  457 */  vRegF_rule,
  /*  458 */  vRegD_rule,
  /*  459 */  vRegD_rule,
  /*  460 */  iRegINoSp_rule,
  /*  461 */  iRegINoSp_rule,
  /*  462 */  iRegINoSp_rule,
  /*  463 */  iRegINoSp_rule,
  /*  464 */  iRegPNoSp_rule,
  /*  465 */  iRegLNoSp_rule,
  /*  466 */  iRegPNoSp_rule,
  /*  467 */  iRegPNoSp_rule,
  /*  468 */  iRegI_rule,
  /*  469 */  iRegL_rule,
  /*  470 */  vRegF_rule,
  /*  471 */  vRegD_rule,
  /*  472 */  vReg_rule,
  /*  473 */  pRegGov_rule,
  /*  474 */  vRegF_rule,
  /*  475 */  vRegD_rule,
  /*  476 */  vRegF_rule,
  /*  477 */  vRegD_rule,
  /*  478 */  iRegINoSp_rule,
  /*  479 */  vRegF_rule,
  /*  480 */  iRegLNoSp_rule,
  /*  481 */  vRegD_rule,
  /*  482 */  iRegINoSp_rule,
  /*  483 */  vRegF_rule,
  /*  484 */  iRegLNoSp_rule,
  /*  485 */  vRegD_rule,
  /*  486 */  rFlagsReg_rule,
  /*  487 */  rFlagsReg_rule,
  /*  488 */  rFlagsReg_rule,
  /*  489 */  rFlagsReg_rule,
  /*  490 */  rFlagsReg_rule,
  /*  491 */  rFlagsReg_rule,
  /*  492 */  rFlagsReg_rule,
  /*  493 */  rFlagsReg_rule,
  /*  494 */  rFlagsReg_rule,
  /*  495 */  rFlagsReg_rule,
  /*  496 */  rFlagsReg_rule,
  /*  497 */  rFlagsReg_rule,
  /*  498 */  rFlagsReg_rule,
  /*  499 */  rFlagsReg_rule,
  /*  500 */  rFlagsReg_rule,
  /*  501 */  rFlagsReg_rule,
  /*  502 */  rFlagsRegU_rule,
  /*  503 */  rFlagsRegU_rule,
  /*  504 */  rFlagsRegU_rule,
  /*  505 */  rFlagsRegU_rule,
  /*  506 */  rFlagsReg_rule,
  /*  507 */  rFlagsReg_rule,
  /*  508 */  rFlagsReg_rule,
  /*  509 */  rFlagsReg_rule,
  /*  510 */  rFlagsRegU_rule,
  /*  511 */  rFlagsRegU_rule,
  /*  512 */  rFlagsRegU_rule,
  /*  513 */  rFlagsRegU_rule,
  /*  514 */  rFlagsRegU_rule,
  /*  515 */  rFlagsRegU_rule,
  /*  516 */  rFlagsRegU_rule,
  /*  517 */  rFlagsRegU_rule,
  /*  518 */  rFlagsReg_rule,
  /*  519 */  rFlagsReg_rule,
  /*  520 */  rFlagsReg_rule,
  /*  521 */  rFlagsReg_rule,
  /*  522 */  rFlagsReg_rule,
  /*  523 */  rFlagsReg_rule,
  /*  524 */  rFlagsReg_rule,
  /*  525 */  rFlagsReg_rule,
  /*  526 */  rFlagsReg_rule,
  /*  527 */  rFlagsReg_rule,
  /*  528 */  rFlagsReg_rule,
  /*  529 */  thread_RegP_rule,
  /*  530 */  vReg_rule,
  /*  531 */  vReg_rule,
  /*  532 */  vReg_rule,
  /*  533 */  vReg_rule,
  /*  534 */  vReg_rule,
  /*  535 */  vReg_rule,
  /*  536 */  vReg_rule,
  /*  537 */  vReg_rule,
  /*  538 */  vReg_rule,
  /*  539 */  vReg_rule,
  /*  540 */  vReg_rule,
  /*  541 */  vReg_rule,
  /*  542 */  vReg_rule,
  /*  543 */  vReg_rule,
  /*  544 */  vReg_rule,
  /*  545 */  vReg_rule,
  /*  546 */  vReg_rule,
  /*  547 */  vReg_rule,
  /*  548 */  vReg_rule,
  /*  549 */  vReg_rule,
  /*  550 */  vReg_rule,
  /*  551 */  vReg_rule,
  /*  552 */  vReg_rule,
  /*  553 */  vReg_rule,
  /*  554 */  vReg_rule,
  /*  555 */  vReg_rule,
  /*  556 */  vReg_rule,
  /*  557 */  vReg_rule,
  /*  558 */  vReg_rule,
  /*  559 */  vReg_rule,
  /*  560 */  vReg_rule,
  /*  561 */  vReg_rule,
  /*  562 */  vReg_rule,
  /*  563 */  vReg_rule,
  /*  564 */  vReg_rule,
  /*  565 */  vReg_rule,
  /*  566 */  vReg_rule,
  /*  567 */  vReg_rule,
  /*  568 */  vReg_rule,
  /*  569 */  vReg_rule,
  /*  570 */  vReg_rule,
  /*  571 */  vReg_rule,
  /*  572 */  vReg_rule,
  /*  573 */  vReg_rule,
  /*  574 */  pReg_rule,
  /*  575 */  pReg_rule,
  /*  576 */  pReg_rule,
  /*  577 */  pReg_rule,
  /*  578 */  iRegINoSp_rule,
  /*  579 */  iRegINoSp_rule,
  /*  580 */  iRegINoSp_rule,
  /*  581 */  iRegLNoSp_rule,
  /*  582 */  vReg_rule,
  /*  583 */  vReg_rule,
  /*  584 */  vReg_rule,
  /*  585 */  vReg_rule,
  /*  586 */  vReg_rule,
  /*  587 */  vReg_rule,
  /*  588 */  vReg_rule,
  /*  589 */  iRegINoSp_rule,
  /*  590 */  iRegLNoSp_rule,
  /*  591 */  iRegINoSp_rule,
  /*  592 */  iRegLNoSp_rule,
  /*  593 */  iRegINoSp_rule,
  /*  594 */  iRegLNoSp_rule,
  /*  595 */  iRegINoSp_rule,
  /*  596 */  iRegLNoSp_rule,
  /*  597 */  iRegINoSp_rule,
  /*  598 */  iRegLNoSp_rule,
  /*  599 */  iRegLNoSp_rule,
  /*  600 */  iRegLNoSp_rule,
  /*  601 */  iRegINoSp_rule,
  /*  602 */  iRegPNoSp_rule,
  /*  603 */  iRegNNoSp_rule,
  /*  604 */  iRegPNoSp_rule,
  /*  605 */  iRegNNoSp_rule,
  /*  606 */  vRegF_rule,
  /*  607 */  vRegD_rule,
  /*  608 */  Universe_rule,
  /*  609 */  Universe_rule,
  /*  610 */  Universe_rule,
  /*  611 */  Universe_rule,
  /*  612 */  Universe_rule,
  /*  613 */  Universe_rule,
  /*  614 */  Universe_rule,
  /*  615 */  Universe_rule,
  /*  616 */  Universe_rule,
  /*  617 */  Universe_rule,
  /*  618 */  Universe_rule,
  /*  619 */  Universe_rule,
  /*  620 */  Universe_rule,
  /*  621 */  Universe_rule,
  /*  622 */  Universe_rule,
  /*  623 */  Universe_rule,
  /*  624 */  Universe_rule,
  /*  625 */  Universe_rule,
  /*  626 */  iRegINoSp_rule,
  /*  627 */  iRegLNoSp_rule,
  /*  628 */  iRegINoSp_rule,
  /*  629 */  iRegLNoSp_rule,
  /*  630 */  iRegINoSp_rule,
  /*  631 */  iRegINoSp_rule,
  /*  632 */  iRegLNoSp_rule,
  /*  633 */  iRegLNoSp_rule,
  /*  634 */  iRegINoSp_rule,
  /*  635 */  iRegLNoSp_rule,
  /*  636 */  iRegLNoSp_rule,
  /*  637 */  iRegPNoSp_rule,
  /*  638 */  iRegNNoSp_rule,
  /*  639 */  vRegF_rule,
  /*  640 */  vRegD_rule,
  /*  641 */  Universe_rule,
  /*  642 */  Universe_rule,
  /*  643 */  Universe_rule,
  /*  644 */  Universe_rule,
  /*  645 */  Universe_rule,
  /*  646 */  Universe_rule,
  /*  647 */  Universe_rule,
  /*  648 */  Universe_rule,
  /*  649 */  Universe_rule,
  /*  650 */  Universe_rule,
  /*  651 */  Universe_rule,
  /*  652 */  Universe_rule,
  /*  653 */  Universe_rule,
  /*  654 */  Universe_rule,
  /*  655 */  Universe_rule,
  /*  656 */  Universe_rule,
  /*  657 */  Universe_rule,
  /*  658 */  iRegINoSp_rule,
  /*  659 */  iRegLNoSp_rule,
  /*  660 */  iRegINoSp_rule,
  /*  661 */  iRegINoSp_rule,
  /*  662 */  iRegINoSp_rule,
  /*  663 */  iRegINoSp_rule,
  /*  664 */  iRegINoSp_rule,
  /*  665 */  iRegINoSp_rule,
  /*  666 */  Universe_rule,
  /*  667 */  Universe_rule,
  /*  668 */  Universe_rule,
  /*  669 */  Universe_rule,
  /*  670 */  Universe_rule,
  /*  671 */  Universe_rule,
  /*  672 */  Universe_rule,
  /*  673 */  Universe_rule,
  /*  674 */  Universe_rule,
  /*  675 */  Universe_rule,
  /*  676 */  Universe_rule,
  /*  677 */  Universe_rule,
  /*  678 */  iRegINoSp_rule,
  /*  679 */  iRegINoSp_rule,
  /*  680 */  iRegNNoSp_rule,
  /*  681 */  iRegNNoSp_rule,
  /*  682 */  iRegPNoSp_rule,
  /*  683 */  iRegPNoSp_rule,
  /*  684 */  iRegNNoSp_rule,
  /*  685 */  iRegPNoSp_rule,
  /*  686 */  iRegINoSp_rule,
  /*  687 */  iRegINoSp_rule,
  /*  688 */  iRegINoSp_rule,
  /*  689 */  iRegINoSp_rule,
  /*  690 */  iRegINoSp_rule,
  /*  691 */  iRegINoSp_rule,
  /*  692 */  iRegINoSp_rule,
  /*  693 */  iRegINoSp_rule,
  /*  694 */  iRegINoSp_rule,
  /*  695 */  iRegINoSp_rule,
  /*  696 */  iRegINoSp_rule,
  /*  697 */  iRegINoSp_rule,
  /*  698 */  iRegINoSp_rule,
  /*  699 */  iRegINoSp_rule,
  /*  700 */  iRegINoSp_rule,
  /*  701 */  iRegLNoSp_rule,
  /*  702 */  iRegNNoSp_rule,
  /*  703 */  iRegPNoSp_rule,
  /*  704 */  iRegINoSp_rule,
  /*  705 */  iRegINoSp_rule,
  /*  706 */  iRegINoSp_rule,
  /*  707 */  iRegLNoSp_rule,
  /*  708 */  iRegNNoSp_rule,
  /*  709 */  iRegPNoSp_rule,
  /*  710 */  iRegINoSp_rule,
  /*  711 */  iRegINoSp_rule,
  /*  712 */  iRegINoSp_rule,
  /*  713 */  iRegINoSp_rule,
  /*  714 */  iRegINoSp_rule,
  /*  715 */  iRegINoSp_rule,
  /*  716 */  iRegINoSp_rule,
  /*  717 */  iRegINoSp_rule,
  /*  718 */  iRegINoSp_rule,
  /*  719 */  iRegINoSp_rule,
  /*  720 */  iRegINoSp_rule,
  /*  721 */  iRegINoSp_rule,
  /*  722 */  iRegINoSp_rule,
  /*  723 */  iRegLNoSp_rule,
  /*  724 */  iRegINoSp_rule,
  /*  725 */  iRegPNoSp_rule,
  /*  726 */  iRegINoSp_rule,
  /*  727 */  iRegLNoSp_rule,
  /*  728 */  iRegINoSp_rule,
  /*  729 */  iRegPNoSp_rule,
  /*  730 */  iRegLNoSp_rule,
  /*  731 */  Universe_rule,
  /*  732 */  iRegLNoSp_rule,
  /*  733 */  Universe_rule,
  /*  734 */  iRegINoSp_rule,
  /*  735 */  Universe_rule,
  /*  736 */  iRegINoSp_rule,
  /*  737 */  Universe_rule,
  /*  738 */  iRegLNoSp_rule,
  /*  739 */  Universe_rule,
  /*  740 */  iRegLNoSp_rule,
  /*  741 */  Universe_rule,
  /*  742 */  iRegINoSp_rule,
  /*  743 */  Universe_rule,
  /*  744 */  iRegINoSp_rule,
  /*  745 */  Universe_rule,
  /*  746 */  iRegINoSp_rule,
  /*  747 */  iRegINoSp_rule,
  /*  748 */  iRegINoSp_rule,
  /*  749 */  iRegINoSp_rule,
  /*  750 */  iRegINoSp_rule,
  /*  751 */  iRegINoSp_rule,
  /*  752 */  iRegINoSp_rule,
  /*  753 */  iRegINoSp_rule,
  /*  754 */  iRegINoSp_rule,
  /*  755 */  iRegINoSp_rule,
  /*  756 */  iRegLNoSp_rule,
  /*  757 */  iRegLNoSp_rule,
  /*  758 */  iRegLNoSp_rule,
  /*  759 */  iRegLNoSp_rule,
  /*  760 */  iRegLNoSp_rule,
  /*  761 */  iRegLNoSp_rule,
  /*  762 */  iRegPNoSp_rule,
  /*  763 */  iRegPNoSp_rule,
  /*  764 */  iRegPNoSp_rule,
  /*  765 */  iRegPNoSp_rule,
  /*  766 */  iRegPNoSp_rule,
  /*  767 */  iRegPNoSp_rule,
  /*  768 */  iRegNNoSp_rule,
  /*  769 */  iRegNNoSp_rule,
  /*  770 */  iRegNNoSp_rule,
  /*  771 */  iRegNNoSp_rule,
  /*  772 */  iRegNNoSp_rule,
  /*  773 */  iRegNNoSp_rule,
  /*  774 */  vRegF_rule,
  /*  775 */  vRegF_rule,
  /*  776 */  vRegD_rule,
  /*  777 */  vRegD_rule,
  /*  778 */  iRegINoSp_rule,
  /*  779 */  iRegINoSp_rule,
  /*  780 */  iRegINoSp_rule,
  /*  781 */  iRegPNoSp_rule,
  /*  782 */  iRegPNoSp_rule,
  /*  783 */  iRegPNoSp_rule,
  /*  784 */  iRegPNoSp_rule,
  /*  785 */  iRegLNoSp_rule,
  /*  786 */  iRegPNoSp_rule,
  /*  787 */  iRegLNoSp_rule,
  /*  788 */  iRegLNoSp_rule,
  /*  789 */  iRegINoSp_rule,
  /*  790 */  iRegINoSp_rule,
  /*  791 */  iRegLNoSp_rule,
  /*  792 */  iRegLNoSp_rule,
  /*  793 */  iRegINoSp_rule,
  /*  794 */  iRegLNoSp_rule,
  /*  795 */  iRegINoSp_rule,
  /*  796 */  iRegLNoSp_rule,
  /*  797 */  iRegLNoSp_rule,
  /*  798 */  iRegLNoSp_rule,
  /*  799 */  iRegLNoSp_rule,
  /*  800 */  iRegLNoSp_rule,
  /*  801 */  iRegINoSp_rule,
  /*  802 */  iRegINoSp_rule,
  /*  803 */  iRegINoSp_rule,
  /*  804 */  iRegINoSp_rule,
  /*  805 */  iRegINoSp_rule,
  /*  806 */  iRegLNoSp_rule,
  /*  807 */  iRegLNoSp_rule,
  /*  808 */  iRegLNoSp_rule,
  /*  809 */  iRegLNoSp_rule,
  /*  810 */  iRegLNoSp_rule,
  /*  811 */  iRegLNoSp_rule,
  /*  812 */  iRegLNoSp_rule,
  /*  813 */  iRegLNoSp_rule,
  /*  814 */  iRegLNoSp_rule,
  /*  815 */  iRegLNoSp_rule,
  /*  816 */  iRegLNoSp_rule,
  /*  817 */  iRegLNoSp_rule,
  /*  818 */  iRegLNoSp_rule,
  /*  819 */  iRegINoSp_rule,
  /*  820 */  iRegINoSp_rule,
  /*  821 */  iRegLNoSp_rule,
  /*  822 */  iRegINoSp_rule,
  /*  823 */  iRegLNoSp_rule,
  /*  824 */  iRegINoSp_rule,
  /*  825 */  iRegLNoSp_rule,
  /*  826 */  iRegINoSp_rule,
  /*  827 */  iRegLNoSp_rule,
  /*  828 */  iRegINoSp_rule,
  /*  829 */  iRegINoSp_rule,
  /*  830 */  iRegINoSp_rule,
  /*  831 */  iRegINoSp_rule,
  /*  832 */  iRegINoSp_rule,
  /*  833 */  iRegINoSp_rule,
  /*  834 */  iRegLNoSp_rule,
  /*  835 */  iRegLNoSp_rule,
  /*  836 */  iRegLNoSp_rule,
  /*  837 */  iRegLNoSp_rule,
  /*  838 */  iRegLNoSp_rule,
  /*  839 */  iRegLNoSp_rule,
  /*  840 */  iRegLNoSp_rule,
  /*  841 */  iRegLNoSp_rule,
  /*  842 */  iRegINoSp_rule,
  /*  843 */  iRegINoSp_rule,
  /*  844 */  iRegINoSp_rule,
  /*  845 */  iRegINoSp_rule,
  /*  846 */  iRegLNoSp_rule,
  /*  847 */  iRegLNoSp_rule,
  /*  848 */  iRegLNoSp_rule,
  /*  849 */  iRegINoSp_rule,
  /*  850 */  iRegINoSp_rule,
  /*  851 */  iRegLNoSp_rule,
  /*  852 */  iRegLNoSp_rule,
  /*  853 */  iRegINoSp_rule,
  /*  854 */  iRegINoSp_rule,
  /*  855 */  iRegLNoSp_rule,
  /*  856 */  iRegLNoSp_rule,
  /*  857 */  iRegINoSp_rule,
  /*  858 */  iRegINoSp_rule,
  /*  859 */  iRegLNoSp_rule,
  /*  860 */  iRegLNoSp_rule,
  /*  861 */  iRegINoSp_rule,
  /*  862 */  iRegINoSp_rule,
  /*  863 */  iRegLNoSp_rule,
  /*  864 */  iRegLNoSp_rule,
  /*  865 */  iRegINoSp_rule,
  /*  866 */  iRegINoSp_rule,
  /*  867 */  iRegLNoSp_rule,
  /*  868 */  iRegLNoSp_rule,
  /*  869 */  iRegINoSp_rule,
  /*  870 */  iRegINoSp_rule,
  /*  871 */  iRegLNoSp_rule,
  /*  872 */  iRegLNoSp_rule,
  /*  873 */  iRegINoSp_rule,
  /*  874 */  iRegINoSp_rule,
  /*  875 */  iRegLNoSp_rule,
  /*  876 */  iRegLNoSp_rule,
  /*  877 */  iRegINoSp_rule,
  /*  878 */  iRegINoSp_rule,
  /*  879 */  iRegINoSp_rule,
  /*  880 */  iRegINoSp_rule,
  /*  881 */  iRegLNoSp_rule,
  /*  882 */  iRegLNoSp_rule,
  /*  883 */  iRegLNoSp_rule,
  /*  884 */  iRegLNoSp_rule,
  /*  885 */  iRegINoSp_rule,
  /*  886 */  iRegINoSp_rule,
  /*  887 */  iRegINoSp_rule,
  /*  888 */  iRegINoSp_rule,
  /*  889 */  iRegLNoSp_rule,
  /*  890 */  iRegLNoSp_rule,
  /*  891 */  iRegLNoSp_rule,
  /*  892 */  iRegLNoSp_rule,
  /*  893 */  iRegINoSp_rule,
  /*  894 */  iRegINoSp_rule,
  /*  895 */  iRegINoSp_rule,
  /*  896 */  iRegINoSp_rule,
  /*  897 */  iRegLNoSp_rule,
  /*  898 */  iRegLNoSp_rule,
  /*  899 */  iRegLNoSp_rule,
  /*  900 */  iRegLNoSp_rule,
  /*  901 */  iRegINoSp_rule,
  /*  902 */  iRegINoSp_rule,
  /*  903 */  iRegINoSp_rule,
  /*  904 */  iRegINoSp_rule,
  /*  905 */  iRegLNoSp_rule,
  /*  906 */  iRegLNoSp_rule,
  /*  907 */  iRegLNoSp_rule,
  /*  908 */  iRegLNoSp_rule,
  /*  909 */  iRegINoSp_rule,
  /*  910 */  iRegINoSp_rule,
  /*  911 */  iRegLNoSp_rule,
  /*  912 */  iRegLNoSp_rule,
  /*  913 */  iRegINoSp_rule,
  /*  914 */  iRegINoSp_rule,
  /*  915 */  iRegLNoSp_rule,
  /*  916 */  iRegLNoSp_rule,
  /*  917 */  iRegINoSp_rule,
  /*  918 */  iRegINoSp_rule,
  /*  919 */  iRegLNoSp_rule,
  /*  920 */  iRegLNoSp_rule,
  /*  921 */  iRegINoSp_rule,
  /*  922 */  iRegINoSp_rule,
  /*  923 */  iRegLNoSp_rule,
  /*  924 */  iRegLNoSp_rule,
  /*  925 */  iRegINoSp_rule,
  /*  926 */  iRegINoSp_rule,
  /*  927 */  iRegLNoSp_rule,
  /*  928 */  iRegLNoSp_rule,
  /*  929 */  iRegINoSp_rule,
  /*  930 */  iRegINoSp_rule,
  /*  931 */  iRegLNoSp_rule,
  /*  932 */  iRegLNoSp_rule,
  /*  933 */  iRegINoSp_rule,
  /*  934 */  iRegINoSp_rule,
  /*  935 */  iRegLNoSp_rule,
  /*  936 */  iRegLNoSp_rule,
  /*  937 */  iRegINoSp_rule,
  /*  938 */  iRegINoSp_rule,
  /*  939 */  iRegLNoSp_rule,
  /*  940 */  iRegLNoSp_rule,
  /*  941 */  iRegINoSp_rule,
  /*  942 */  iRegINoSp_rule,
  /*  943 */  iRegLNoSp_rule,
  /*  944 */  iRegLNoSp_rule,
  /*  945 */  iRegINoSp_rule,
  /*  946 */  iRegINoSp_rule,
  /*  947 */  iRegLNoSp_rule,
  /*  948 */  iRegLNoSp_rule,
  /*  949 */  iRegINoSp_rule,
  /*  950 */  iRegINoSp_rule,
  /*  951 */  iRegLNoSp_rule,
  /*  952 */  iRegLNoSp_rule,
  /*  953 */  iRegINoSp_rule,
  /*  954 */  iRegINoSp_rule,
  /*  955 */  iRegLNoSp_rule,
  /*  956 */  iRegLNoSp_rule,
  /*  957 */  iRegINoSp_rule,
  /*  958 */  iRegINoSp_rule,
  /*  959 */  iRegLNoSp_rule,
  /*  960 */  iRegLNoSp_rule,
  /*  961 */  iRegINoSp_rule,
  /*  962 */  iRegINoSp_rule,
  /*  963 */  iRegLNoSp_rule,
  /*  964 */  iRegLNoSp_rule,
  /*  965 */  iRegINoSp_rule,
  /*  966 */  iRegINoSp_rule,
  /*  967 */  iRegLNoSp_rule,
  /*  968 */  iRegLNoSp_rule,
  /*  969 */  iRegINoSp_rule,
  /*  970 */  iRegINoSp_rule,
  /*  971 */  iRegLNoSp_rule,
  /*  972 */  iRegLNoSp_rule,
  /*  973 */  iRegINoSp_rule,
  /*  974 */  iRegINoSp_rule,
  /*  975 */  iRegLNoSp_rule,
  /*  976 */  iRegLNoSp_rule,
  /*  977 */  iRegINoSp_rule,
  /*  978 */  iRegINoSp_rule,
  /*  979 */  iRegLNoSp_rule,
  /*  980 */  iRegLNoSp_rule,
  /*  981 */  iRegINoSp_rule,
  /*  982 */  iRegINoSp_rule,
  /*  983 */  iRegLNoSp_rule,
  /*  984 */  iRegLNoSp_rule,
  /*  985 */  iRegINoSp_rule,
  /*  986 */  iRegLNoSp_rule,
  /*  987 */  iRegINoSp_rule,
  /*  988 */  iRegLNoSp_rule,
  /*  989 */  iRegINoSp_rule,
  /*  990 */  iRegLNoSp_rule,
  /*  991 */  iRegLNoSp_rule,
  /*  992 */  iRegINoSp_rule,
  /*  993 */  iRegLNoSp_rule,
  /*  994 */  iRegINoSp_rule,
  /*  995 */  iRegINoSp_rule,
  /*  996 */  iRegLNoSp_rule,
  /*  997 */  iRegLNoSp_rule,
  /*  998 */  iRegINoSp_rule,
  /*  999 */  iRegLNoSp_rule,
  /* 1000 */  iRegLNoSp_rule,
  /* 1001 */  iRegINoSp_rule,
  /* 1002 */  iRegLNoSp_rule,
  /* 1003 */  iRegINoSp_rule,
  /* 1004 */  iRegLNoSp_rule,
  /* 1005 */  iRegLNoSp_rule,
  /* 1006 */  iRegLNoSp_rule,
  /* 1007 */  iRegINoSp_rule,
  /* 1008 */  iRegINoSp_rule,
  /* 1009 */  iRegLNoSp_rule,
  /* 1010 */  iRegLNoSp_rule,
  /* 1011 */  iRegINoSp_rule,
  /* 1012 */  iRegINoSp_rule,
  /* 1013 */  iRegINoSp_rule,
  /* 1014 */  iRegLNoSp_rule,
  /* 1015 */  iRegINoSp_rule,
  /* 1016 */  iRegLNoSp_rule,
  /* 1017 */  iRegINoSp_rule,
  /* 1018 */  iRegLNoSp_rule,
  /* 1019 */  iRegLNoSp_rule,
  /* 1020 */  iRegLNoSp_rule,
  /* 1021 */  iRegLNoSp_rule,
  /* 1022 */  iRegINoSp_rule,
  /* 1023 */  iRegINoSp_rule,
  /* 1024 */  iRegINoSp_rule,
  /* 1025 */  iRegINoSp_rule,
  /* 1026 */  iRegINoSp_rule,
  /* 1027 */  iRegINoSp_rule,
  /* 1028 */  iRegLNoSp_rule,
  /* 1029 */  iRegLNoSp_rule,
  /* 1030 */  iRegLNoSp_rule,
  /* 1031 */  iRegLNoSp_rule,
  /* 1032 */  iRegLNoSp_rule,
  /* 1033 */  iRegLNoSp_rule,
  /* 1034 */  iRegLNoSp_rule,
  /* 1035 */  iRegLNoSp_rule,
  /* 1036 */  iRegINoSp_rule,
  /* 1037 */  iRegINoSp_rule,
  /* 1038 */  iRegINoSp_rule,
  /* 1039 */  iRegINoSp_rule,
  /* 1040 */  iRegLNoSp_rule,
  /* 1041 */  iRegLNoSp_rule,
  /* 1042 */  iRegLNoSp_rule,
  /* 1043 */  iRegLNoSp_rule,
  /* 1044 */  iRegLNoSp_rule,
  /* 1045 */  iRegLNoSp_rule,
  /* 1046 */  iRegINoSp_rule,
  /* 1047 */  iRegINoSp_rule,
  /* 1048 */  iRegLNoSp_rule,
  /* 1049 */  iRegLNoSp_rule,
  /* 1050 */  iRegLNoSp_rule,
  /* 1051 */  iRegLNoSp_rule,
  /* 1052 */  iRegLNoSp_rule,
  /* 1053 */  iRegLNoSp_rule,
  /* 1054 */  iRegLNoSp_rule,
  /* 1055 */  iRegLNoSp_rule,
  /* 1056 */  iRegLNoSp_rule,
  /* 1057 */  iRegLNoSp_rule,
  /* 1058 */  iRegLNoSp_rule,
  /* 1059 */  iRegLNoSp_rule,
  /* 1060 */  iRegINoSp_rule,
  /* 1061 */  iRegINoSp_rule,
  /* 1062 */  iRegINoSp_rule,
  /* 1063 */  iRegINoSp_rule,
  /* 1064 */  iRegINoSp_rule,
  /* 1065 */  iRegINoSp_rule,
  /* 1066 */  iRegLNoSp_rule,
  /* 1067 */  iRegLNoSp_rule,
  /* 1068 */  iRegLNoSp_rule,
  /* 1069 */  iRegLNoSp_rule,
  /* 1070 */  iRegLNoSp_rule,
  /* 1071 */  iRegLNoSp_rule,
  /* 1072 */  iRegLNoSp_rule,
  /* 1073 */  iRegLNoSp_rule,
  /* 1074 */  iRegLNoSp_rule,
  /* 1075 */  iRegLNoSp_rule,
  /* 1076 */  iRegLNoSp_rule,
  /* 1077 */  iRegLNoSp_rule,
  /* 1078 */  iRegINoSp_rule,
  /* 1079 */  iRegINoSp_rule,
  /* 1080 */  iRegINoSp_rule,
  /* 1081 */  iRegINoSp_rule,
  /* 1082 */  iRegINoSp_rule,
  /* 1083 */  iRegINoSp_rule,
  /* 1084 */  vRegF_rule,
  /* 1085 */  vRegD_rule,
  /* 1086 */  vRegF_rule,
  /* 1087 */  vRegD_rule,
  /* 1088 */  vRegF_rule,
  /* 1089 */  vRegD_rule,
  /* 1090 */  vRegF_rule,
  /* 1091 */  vRegD_rule,
  /* 1092 */  vRegF_rule,
  /* 1093 */  vRegF_rule,
  /* 1094 */  vRegD_rule,
  /* 1095 */  vRegD_rule,
  /* 1096 */  vRegF_rule,
  /* 1097 */  vRegF_rule,
  /* 1098 */  vRegD_rule,
  /* 1099 */  vRegD_rule,
  /* 1100 */  vRegF_rule,
  /* 1101 */  vRegD_rule,
  /* 1102 */  vRegF_rule,
  /* 1103 */  vRegF_rule,
  /* 1104 */  vRegD_rule,
  /* 1105 */  vRegD_rule,
  /* 1106 */  vRegF_rule,
  /* 1107 */  vRegD_rule,
  /* 1108 */  iRegINoSp_rule,
  /* 1109 */  iRegLNoSp_rule,
  /* 1110 */  vRegF_rule,
  /* 1111 */  vRegD_rule,
  /* 1112 */  vRegD_rule,
  /* 1113 */  vRegF_rule,
  /* 1114 */  vRegD_rule,
  /* 1115 */  vRegD_rule,
  /* 1116 */  vRegF_rule,
  /* 1117 */  vRegD_rule,
  /* 1118 */  vRegF_rule,
  /* 1119 */  Universe_rule,
  /* 1120 */  iRegINoSp_rule,
  /* 1121 */  iRegINoSp_rule,
  /* 1122 */  iRegINoSp_rule,
  /* 1123 */  iRegINoSp_rule,
  /* 1124 */  iRegINoSp_rule,
  /* 1125 */  iRegINoSp_rule,
  /* 1126 */  iRegLNoSp_rule,
  /* 1127 */  iRegLNoSp_rule,
  /* 1128 */  iRegLNoSp_rule,
  /* 1129 */  iRegLNoSp_rule,
  /* 1130 */  iRegLNoSp_rule,
  /* 1131 */  iRegLNoSp_rule,
  /* 1132 */  iRegLNoSp_rule,
  /* 1133 */  iRegLNoSp_rule,
  /* 1134 */  iRegINoSp_rule,
  /* 1135 */  iRegINoSp_rule,
  /* 1136 */  iRegINoSp_rule,
  /* 1137 */  vRegF_rule,
  /* 1138 */  vRegD_rule,
  /* 1139 */  iRegINoSp_rule,
  /* 1140 */  iRegLNoSp_rule,
  /* 1141 */  iRegINoSp_rule,
  /* 1142 */  vRegF_rule,
  /* 1143 */  vRegF_rule,
  /* 1144 */  vRegF_rule,
  /* 1145 */  iRegINoSp_rule,
  /* 1146 */  iRegLNoSp_rule,
  /* 1147 */  vRegD_rule,
  /* 1148 */  vRegD_rule,
  /* 1149 */  iRegLNoSp_rule,
  /* 1150 */  iRegINoSp_rule,
  /* 1151 */  stackSlotI_rule,
  /* 1152 */  stackSlotF_rule,
  /* 1153 */  stackSlotL_rule,
  /* 1154 */  stackSlotD_rule,
  /* 1155 */  Universe_rule,
  /* 1156 */  Universe_rule,
  /* 1157 */  Universe_rule,
  /* 1158 */  Universe_rule,
  /* 1159 */  iRegINoSp_rule,
  /* 1160 */  iRegINoSp_rule,
  /* 1161 */  iRegINoSp_rule,
  /* 1162 */  iRegINoSp_rule,
  /* 1163 */  iRegINoSp_rule,
  /* 1164 */  iRegINoSp_rule,
  /* 1165 */  0,
  /* 1166 */  iRegINoSp_rule,
  /* 1167 */  0,
  /* 1168 */  iRegINoSp_rule,
  /* 1169 */  Universe_rule,
  /* 1170 */  Universe_rule,
  /* 1171 */  Universe_rule,
  /* 1172 */  Universe_rule,
  /* 1173 */  Universe_rule,
  /* 1174 */  Universe_rule,
  /* 1175 */  Universe_rule,
  /* 1176 */  Universe_rule,
  /* 1177 */  Universe_rule,
  /* 1178 */  Universe_rule,
  /* 1179 */  Universe_rule,
  /* 1180 */  Universe_rule,
  /* 1181 */  Universe_rule,
  /* 1182 */  Universe_rule,
  /* 1183 */  Universe_rule,
  /* 1184 */  Universe_rule,
  /* 1185 */  Universe_rule,
  /* 1186 */  Universe_rule,
  /* 1187 */  Universe_rule,
  /* 1188 */  Universe_rule,
  /* 1189 */  Universe_rule,
  /* 1190 */  Universe_rule,
  /* 1191 */  Universe_rule,
  /* 1192 */  Universe_rule,
  /* 1193 */  Universe_rule,
  /* 1194 */  Universe_rule,
  /* 1195 */  Universe_rule,
  /* 1196 */  Universe_rule,
  /* 1197 */  iRegP_R0_rule,
  /* 1198 */  Universe_rule,
  /* 1199 */  Universe_rule,
  /* 1200 */  Universe_rule,
  /* 1201 */  iRegP_R5_rule,
  /* 1202 */  iRegI_R0_rule,
  /* 1203 */  iRegI_R0_rule,
  /* 1204 */  iRegI_R0_rule,
  /* 1205 */  iRegI_R0_rule,
  /* 1206 */  iRegI_R0_rule,
  /* 1207 */  iRegI_R0_rule,
  /* 1208 */  iRegI_R0_rule,
  /* 1209 */  iRegI_R0_rule,
  /* 1210 */  iRegI_R0_rule,
  /* 1211 */  iRegI_R0_rule,
  /* 1212 */  iRegI_R0_rule,
  /* 1213 */  iRegI_R0_rule,
  /* 1214 */  iRegI_R0_rule,
  /* 1215 */  iRegI_R0_rule,
  /* 1216 */  iRegI_R0_rule,
  /* 1217 */  iRegI_R0_rule,
  /* 1218 */  iRegI_R0_rule,
  /* 1219 */  iRegI_R0_rule,
  /* 1220 */  iRegI_R0_rule,
  /* 1221 */  iRegI_R0_rule,
  /* 1222 */  iRegI_R0_rule,
  /* 1223 */  iRegI_R0_rule,
  /* 1224 */  iRegI_R0_rule,
  /* 1225 */  iRegI_R0_rule,
  /* 1226 */  Universe_rule,
  /* 1227 */  iRegI_R0_rule,
  /* 1228 */  iRegI_R0_rule,
  /* 1229 */  vReg_rule,
  /* 1230 */  Universe_rule,
  /* 1231 */  vReg_rule,
  /* 1232 */  Universe_rule,
  /* 1233 */  vReg_rule,
  /* 1234 */  Universe_rule,
  /* 1235 */  vReg_rule,
  /* 1236 */  Universe_rule,
  /* 1237 */  vReg_rule,
  /* 1238 */  Universe_rule,
  /* 1239 */  vReg_rule,
  /* 1240 */  Universe_rule,
  /* 1241 */  vReg_rule,
  /* 1242 */  vReg_rule,
  /* 1243 */  vReg_rule,
  /* 1244 */  vReg_rule,
  /* 1245 */  vReg_rule,
  /* 1246 */  vReg_rule,
  /* 1247 */  vReg_rule,
  /* 1248 */  vReg_rule,
  /* 1249 */  vReg_rule,
  /* 1250 */  vReg_rule,
  /* 1251 */  vReg_rule,
  /* 1252 */  vReg_rule,
  /* 1253 */  vReg_rule,
  /* 1254 */  vReg_rule,
  /* 1255 */  vReg_rule,
  /* 1256 */  vReg_rule,
  /* 1257 */  vReg_rule,
  /* 1258 */  vReg_rule,
  /* 1259 */  vReg_rule,
  /* 1260 */  vReg_rule,
  /* 1261 */  vReg_rule,
  /* 1262 */  vReg_rule,
  /* 1263 */  vReg_rule,
  /* 1264 */  vReg_rule,
  /* 1265 */  vReg_rule,
  /* 1266 */  vReg_rule,
  /* 1267 */  vReg_rule,
  /* 1268 */  vReg_rule,
  /* 1269 */  vReg_rule,
  /* 1270 */  vReg_rule,
  /* 1271 */  vReg_rule,
  /* 1272 */  vReg_rule,
  /* 1273 */  vReg_rule,
  /* 1274 */  vReg_rule,
  /* 1275 */  vReg_rule,
  /* 1276 */  vReg_rule,
  /* 1277 */  vReg_rule,
  /* 1278 */  vReg_rule,
  /* 1279 */  vReg_rule,
  /* 1280 */  vReg_rule,
  /* 1281 */  vReg_rule,
  /* 1282 */  vReg_rule,
  /* 1283 */  vReg_rule,
  /* 1284 */  vReg_rule,
  /* 1285 */  vReg_rule,
  /* 1286 */  vReg_rule,
  /* 1287 */  vReg_rule,
  /* 1288 */  vReg_rule,
  /* 1289 */  vReg_rule,
  /* 1290 */  vReg_rule,
  /* 1291 */  vReg_rule,
  /* 1292 */  vReg_rule,
  /* 1293 */  vReg_rule,
  /* 1294 */  vReg_rule,
  /* 1295 */  vReg_rule,
  /* 1296 */  vReg_rule,
  /* 1297 */  vReg_rule,
  /* 1298 */  vReg_rule,
  /* 1299 */  vReg_rule,
  /* 1300 */  vReg_rule,
  /* 1301 */  vReg_rule,
  /* 1302 */  vReg_rule,
  /* 1303 */  vReg_rule,
  /* 1304 */  vReg_rule,
  /* 1305 */  vReg_rule,
  /* 1306 */  vReg_rule,
  /* 1307 */  vReg_rule,
  /* 1308 */  vReg_rule,
  /* 1309 */  vReg_rule,
  /* 1310 */  vReg_rule,
  /* 1311 */  vReg_rule,
  /* 1312 */  vReg_rule,
  /* 1313 */  vReg_rule,
  /* 1314 */  vReg_rule,
  /* 1315 */  vReg_rule,
  /* 1316 */  vReg_rule,
  /* 1317 */  vReg_rule,
  /* 1318 */  vReg_rule,
  /* 1319 */  vReg_rule,
  /* 1320 */  vReg_rule,
  /* 1321 */  vReg_rule,
  /* 1322 */  vReg_rule,
  /* 1323 */  vReg_rule,
  /* 1324 */  vReg_rule,
  /* 1325 */  vReg_rule,
  /* 1326 */  vReg_rule,
  /* 1327 */  vReg_rule,
  /* 1328 */  vReg_rule,
  /* 1329 */  vReg_rule,
  /* 1330 */  vReg_rule,
  /* 1331 */  vReg_rule,
  /* 1332 */  vReg_rule,
  /* 1333 */  vReg_rule,
  /* 1334 */  vReg_rule,
  /* 1335 */  vReg_rule,
  /* 1336 */  vReg_rule,
  /* 1337 */  vReg_rule,
  /* 1338 */  vReg_rule,
  /* 1339 */  vReg_rule,
  /* 1340 */  vReg_rule,
  /* 1341 */  vReg_rule,
  /* 1342 */  vReg_rule,
  /* 1343 */  vReg_rule,
  /* 1344 */  vReg_rule,
  /* 1345 */  vReg_rule,
  /* 1346 */  vReg_rule,
  /* 1347 */  vReg_rule,
  /* 1348 */  vReg_rule,
  /* 1349 */  vReg_rule,
  /* 1350 */  vReg_rule,
  /* 1351 */  vReg_rule,
  /* 1352 */  vReg_rule,
  /* 1353 */  vReg_rule,
  /* 1354 */  vReg_rule,
  /* 1355 */  vReg_rule,
  /* 1356 */  vReg_rule,
  /* 1357 */  vReg_rule,
  /* 1358 */  vReg_rule,
  /* 1359 */  vReg_rule,
  /* 1360 */  vReg_rule,
  /* 1361 */  vReg_rule,
  /* 1362 */  vReg_rule,
  /* 1363 */  vReg_rule,
  /* 1364 */  vReg_rule,
  /* 1365 */  vReg_rule,
  /* 1366 */  vReg_rule,
  /* 1367 */  vReg_rule,
  /* 1368 */  vReg_rule,
  /* 1369 */  vReg_rule,
  /* 1370 */  vReg_rule,
  /* 1371 */  vReg_rule,
  /* 1372 */  vReg_rule,
  /* 1373 */  vReg_rule,
  /* 1374 */  vReg_rule,
  /* 1375 */  vReg_rule,
  /* 1376 */  vReg_rule,
  /* 1377 */  vReg_rule,
  /* 1378 */  vReg_rule,
  /* 1379 */  vReg_rule,
  /* 1380 */  vReg_rule,
  /* 1381 */  vReg_rule,
  /* 1382 */  vReg_rule,
  /* 1383 */  vReg_rule,
  /* 1384 */  vReg_rule,
  /* 1385 */  vReg_rule,
  /* 1386 */  vReg_rule,
  /* 1387 */  vReg_rule,
  /* 1388 */  vReg_rule,
  /* 1389 */  vReg_rule,
  /* 1390 */  vReg_rule,
  /* 1391 */  vReg_rule,
  /* 1392 */  vReg_rule,
  /* 1393 */  vReg_rule,
  /* 1394 */  vReg_rule,
  /* 1395 */  vReg_rule,
  /* 1396 */  vReg_rule,
  /* 1397 */  vReg_rule,
  /* 1398 */  vReg_rule,
  /* 1399 */  vReg_rule,
  /* 1400 */  vReg_rule,
  /* 1401 */  vReg_rule,
  /* 1402 */  vReg_rule,
  /* 1403 */  vReg_rule,
  /* 1404 */  vReg_rule,
  /* 1405 */  vReg_rule,
  /* 1406 */  vReg_rule,
  /* 1407 */  vReg_rule,
  /* 1408 */  vReg_rule,
  /* 1409 */  vReg_rule,
  /* 1410 */  vReg_rule,
  /* 1411 */  vReg_rule,
  /* 1412 */  vReg_rule,
  /* 1413 */  vReg_rule,
  /* 1414 */  vReg_rule,
  /* 1415 */  vReg_rule,
  /* 1416 */  vReg_rule,
  /* 1417 */  vReg_rule,
  /* 1418 */  vReg_rule,
  /* 1419 */  vReg_rule,
  /* 1420 */  vReg_rule,
  /* 1421 */  vReg_rule,
  /* 1422 */  vReg_rule,
  /* 1423 */  vReg_rule,
  /* 1424 */  vReg_rule,
  /* 1425 */  vReg_rule,
  /* 1426 */  vReg_rule,
  /* 1427 */  vReg_rule,
  /* 1428 */  vReg_rule,
  /* 1429 */  vReg_rule,
  /* 1430 */  vReg_rule,
  /* 1431 */  vReg_rule,
  /* 1432 */  vReg_rule,
  /* 1433 */  vReg_rule,
  /* 1434 */  vReg_rule,
  /* 1435 */  vReg_rule,
  /* 1436 */  vReg_rule,
  /* 1437 */  vReg_rule,
  /* 1438 */  vReg_rule,
  /* 1439 */  vReg_rule,
  /* 1440 */  vReg_rule,
  /* 1441 */  vReg_rule,
  /* 1442 */  vReg_rule,
  /* 1443 */  vReg_rule,
  /* 1444 */  vReg_rule,
  /* 1445 */  vReg_rule,
  /* 1446 */  vReg_rule,
  /* 1447 */  vReg_rule,
  /* 1448 */  vReg_rule,
  /* 1449 */  vReg_rule,
  /* 1450 */  vReg_rule,
  /* 1451 */  vReg_rule,
  /* 1452 */  vReg_rule,
  /* 1453 */  vReg_rule,
  /* 1454 */  vReg_rule,
  /* 1455 */  vReg_rule,
  /* 1456 */  vReg_rule,
  /* 1457 */  vReg_rule,
  /* 1458 */  vReg_rule,
  /* 1459 */  vReg_rule,
  /* 1460 */  vReg_rule,
  /* 1461 */  vReg_rule,
  /* 1462 */  vReg_rule,
  /* 1463 */  vReg_rule,
  /* 1464 */  vReg_rule,
  /* 1465 */  vReg_rule,
  /* 1466 */  vReg_rule,
  /* 1467 */  vReg_rule,
  /* 1468 */  vReg_rule,
  /* 1469 */  vReg_rule,
  /* 1470 */  vReg_rule,
  /* 1471 */  vReg_rule,
  /* 1472 */  vReg_rule,
  /* 1473 */  vReg_rule,
  /* 1474 */  vReg_rule,
  /* 1475 */  vReg_rule,
  /* 1476 */  vReg_rule,
  /* 1477 */  vReg_rule,
  /* 1478 */  vReg_rule,
  /* 1479 */  vReg_rule,
  /* 1480 */  vReg_rule,
  /* 1481 */  vReg_rule,
  /* 1482 */  vReg_rule,
  /* 1483 */  vReg_rule,
  /* 1484 */  vReg_rule,
  /* 1485 */  vReg_rule,
  /* 1486 */  vReg_rule,
  /* 1487 */  vReg_rule,
  /* 1488 */  vReg_rule,
  /* 1489 */  vReg_rule,
  /* 1490 */  vReg_rule,
  /* 1491 */  vReg_rule,
  /* 1492 */  vReg_rule,
  /* 1493 */  vReg_rule,
  /* 1494 */  vReg_rule,
  /* 1495 */  vReg_rule,
  /* 1496 */  vReg_rule,
  /* 1497 */  vReg_rule,
  /* 1498 */  vReg_rule,
  /* 1499 */  vReg_rule,
  /* 1500 */  vReg_rule,
  /* 1501 */  vReg_rule,
  /* 1502 */  vReg_rule,
  /* 1503 */  vReg_rule,
  /* 1504 */  vReg_rule,
  /* 1505 */  vReg_rule,
  /* 1506 */  vReg_rule,
  /* 1507 */  vReg_rule,
  /* 1508 */  vReg_rule,
  /* 1509 */  vReg_rule,
  /* 1510 */  vReg_rule,
  /* 1511 */  vReg_rule,
  /* 1512 */  vReg_rule,
  /* 1513 */  vReg_rule,
  /* 1514 */  vReg_rule,
  /* 1515 */  vReg_rule,
  /* 1516 */  vReg_rule,
  /* 1517 */  vReg_rule,
  /* 1518 */  iRegINoSp_rule,
  /* 1519 */  iRegINoSp_rule,
  /* 1520 */  iRegLNoSp_rule,
  /* 1521 */  iRegLNoSp_rule,
  /* 1522 */  vRegF_rule,
  /* 1523 */  vRegF_rule,
  /* 1524 */  vRegD_rule,
  /* 1525 */  vRegD_rule,
  /* 1526 */  iRegINoSp_rule,
  /* 1527 */  iRegLNoSp_rule,
  /* 1528 */  vRegF_rule,
  /* 1529 */  vRegD_rule,
  /* 1530 */  iRegINoSp_rule,
  /* 1531 */  iRegLNoSp_rule,
  /* 1532 */  vRegF_rule,
  /* 1533 */  vRegD_rule,
  /* 1534 */  iRegINoSp_rule,
  /* 1535 */  iRegINoSp_rule,
  /* 1536 */  iRegLNoSp_rule,
  /* 1537 */  iRegLNoSp_rule,
  /* 1538 */  iRegINoSp_rule,
  /* 1539 */  iRegLNoSp_rule,
  /* 1540 */  iRegINoSp_rule,
  /* 1541 */  iRegINoSp_rule,
  /* 1542 */  iRegLNoSp_rule,
  /* 1543 */  iRegLNoSp_rule,
  /* 1544 */  iRegINoSp_rule,
  /* 1545 */  iRegLNoSp_rule,
  /* 1546 */  iRegINoSp_rule,
  /* 1547 */  iRegINoSp_rule,
  /* 1548 */  iRegLNoSp_rule,
  /* 1549 */  iRegLNoSp_rule,
  /* 1550 */  iRegINoSp_rule,
  /* 1551 */  iRegLNoSp_rule,
  /* 1552 */  iRegINoSp_rule,
  /* 1553 */  iRegINoSp_rule,
  /* 1554 */  iRegLNoSp_rule,
  /* 1555 */  iRegLNoSp_rule,
  /* 1556 */  vRegF_rule,
  /* 1557 */  vRegD_rule,
  /* 1558 */  iRegINoSp_rule,
  /* 1559 */  iRegLNoSp_rule,
  /* 1560 */  vRegF_rule,
  /* 1561 */  vRegD_rule,
  /* 1562 */  iRegINoSp_rule,
  /* 1563 */  iRegINoSp_rule,
  /* 1564 */  iRegLNoSp_rule,
  /* 1565 */  iRegLNoSp_rule,
  /* 1566 */  vRegF_rule,
  /* 1567 */  vRegD_rule,
  /* 1568 */  iRegINoSp_rule,
  /* 1569 */  iRegLNoSp_rule,
  /* 1570 */  vRegF_rule,
  /* 1571 */  vRegD_rule,
  /* 1572 */  vReg_rule,
  /* 1573 */  vReg_rule,
  /* 1574 */  vReg_rule,
  /* 1575 */  vReg_rule,
  /* 1576 */  vReg_rule,
  /* 1577 */  vReg_rule,
  /* 1578 */  vReg_rule,
  /* 1579 */  vReg_rule,
  /* 1580 */  vReg_rule,
  /* 1581 */  vReg_rule,
  /* 1582 */  vReg_rule,
  /* 1583 */  vReg_rule,
  /* 1584 */  vReg_rule,
  /* 1585 */  vReg_rule,
  /* 1586 */  vReg_rule,
  /* 1587 */  vReg_rule,
  /* 1588 */  vReg_rule,
  /* 1589 */  vReg_rule,
  /* 1590 */  vReg_rule,
  /* 1591 */  vReg_rule,
  /* 1592 */  vReg_rule,
  /* 1593 */  vReg_rule,
  /* 1594 */  iRegINoSp_rule,
  /* 1595 */  iRegINoSp_rule,
  /* 1596 */  iRegINoSp_rule,
  /* 1597 */  iRegINoSp_rule,
  /* 1598 */  iRegINoSp_rule,
  /* 1599 */  iRegINoSp_rule,
  /* 1600 */  iRegLNoSp_rule,
  /* 1601 */  iRegLNoSp_rule,
  /* 1602 */  vRegF_rule,
  /* 1603 */  vRegD_rule,
  /* 1604 */  pReg_rule,
  /* 1605 */  pReg_rule,
  /* 1606 */  pReg_rule,
  /* 1607 */  pReg_rule,
  /* 1608 */  vReg_rule,
  /* 1609 */  vReg_rule,
  /* 1610 */  vReg_rule,
  /* 1611 */  vReg_rule,
  /* 1612 */  pReg_rule,
  /* 1613 */  pReg_rule,
  /* 1614 */  pReg_rule,
  /* 1615 */  pReg_rule,
  /* 1616 */  Universe_rule,
  /* 1617 */  Universe_rule,
  /* 1618 */  Universe_rule,
  /* 1619 */  Universe_rule,
  /* 1620 */  pReg_rule,
  /* 1621 */  pReg_rule,
  /* 1622 */  pReg_rule,
  /* 1623 */  pReg_rule,
  /* 1624 */  pReg_rule,
  /* 1625 */  vReg_rule,
  /* 1626 */  pReg_rule,
  /* 1627 */  pReg_rule,
  /* 1628 */  pReg_rule,
  /* 1629 */  iRegINoSp_rule,
  /* 1630 */  iRegINoSp_rule,
  /* 1631 */  iRegINoSp_rule,
  /* 1632 */  iRegINoSp_rule,
  /* 1633 */  iRegINoSp_rule,
  /* 1634 */  iRegLNoSp_rule,
  /* 1635 */  pReg_rule,
  /* 1636 */  pReg_rule,
  /* 1637 */  pReg_rule,
  /* 1638 */  pReg_rule,
  /* 1639 */  pReg_rule,
  /* 1640 */  pReg_rule,
  /* 1641 */  pReg_rule,
  /* 1642 */  pReg_rule,
  /* 1643 */  pReg_rule,
  /* 1644 */  pReg_rule,
  /* 1645 */  vReg_rule,
  /* 1646 */  vReg_rule,
  /* 1647 */  vReg_rule,
  /* 1648 */  vReg_rule,
  /* 1649 */  vReg_rule,
  /* 1650 */  vReg_rule,
  /* 1651 */  vReg_rule,
  /* 1652 */  vReg_rule,
  /* 1653 */  vReg_rule,
  /* 1654 */  vReg_rule,
  /* 1655 */  vReg_rule,
  /* 1656 */  vReg_rule,
  /* 1657 */  vReg_rule,
  /* 1658 */  iRegINoSp_rule,
  /* 1659 */  iRegINoSp_rule,
  /* 1660 */  iRegINoSp_rule,
  /* 1661 */  iRegINoSp_rule,
  /* 1662 */  vReg_rule,
  /* 1663 */  vReg_rule,
  /* 1664 */  vReg_rule,
  /* 1665 */  vReg_rule,
  /* 1666 */  vReg_rule,
  /* 1667 */  vReg_rule,
  /* 1668 */  Universe_rule,
  /* 1669 */  Universe_rule,
  /* 1670 */  Universe_rule,
  /* 1671 */  Universe_rule,
  /* 1672 */  vReg_rule,
  /* 1673 */  vReg_rule,
  /* 1674 */  vReg_rule,
  /* 1675 */  vReg_rule,
  /* 1676 */  vReg_rule,
  /* 1677 */  pReg_rule,
  /* 1678 */  vReg_rule,
  /* 1679 */  vReg_rule,
  /* 1680 */  vReg_rule,
  /* 1681 */  vReg_rule,
  /* 1682 */  vReg_rule,
  /* 1683 */  vReg_rule,
  /* 1684 */  vReg_rule,
  /* 1685 */  vReg_rule,
  /* 1686 */  iRegINoSp_rule,
  /* 1687 */  iRegINoSp_rule,
  /* 1688 */  iRegINoSp_rule,
  /* 1689 */  iRegINoSp_rule,
  /* 1690 */  iRegNNoSp_rule,
  /* 1691 */  iRegPNoSp_rule,
  /* 1692 */  iRegNNoSp_rule,
  /* 1693 */  iRegPNoSp_rule,
  /* 1694 */  iRegINoSp_rule,
  /* 1695 */  iRegINoSp_rule,
  /* 1696 */  iRegINoSp_rule,
  /* 1697 */  iRegINoSp_rule,
  /* 1698 */  iRegPNoSp_rule,
  /* 1699 */  iRegPNoSp_rule,
  /* 1700 */  iRegINoSp_rule,
  /* 1701 */  iRegINoSp_rule,
  /* 1702 */  iRegINoSp_rule,
  /* 1703 */  iRegINoSp_rule,
  /* 1704 */  iRegPNoSp_rule,
  /* 1705 */  iRegPNoSp_rule,
  /* 1706 */  iRegPNoSp_rule,
  /* 1707 */  iRegPNoSp_rule,
  // last instruction
  0 // no trailing comma
};

const        int   leftOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  0,
  /*   78 */  0,
  /*   79 */  0,
  /*   80 */  0,
  /*   81 */  0,
  /*   82 */  0,
  /*   83 */  0,
  /*   84 */  0,
  /*   85 */  0,
  /*   86 */  0,
  /*   87 */  0,
  /*   88 */  0,
  /*   89 */  0,
  /*   90 */  0,
  /*   91 */  0,
  /*   92 */  0,
  /*   93 */  0,
  /*   94 */  0,
  /*   95 */  0,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  /*  101 */  0,
  /*  102 */  0,
  /*  103 */  0,
  /*  104 */  0,
  /*  105 */  0,
  /*  106 */  0,
  /*  107 */  0,
  /*  108 */  0,
  /*  109 */  0,
  /*  110 */  0,
  /*  111 */  0,
  /*  112 */  0,
  /*  113 */  0,
  /*  114 */  0,
  /*  115 */  0,
  /*  116 */  0,
  /*  117 */  0,
  /*  118 */  0,
  /*  119 */  0,
  /*  120 */  0,
  /*  121 */  0,
  /*  122 */  0,
  /*  123 */  0,
  /*  124 */  0,
  /*  125 */  0,
  /*  126 */  0,
  /*  127 */  0,
  /*  128 */  0,
  /*  129 */  0,
  /*  130 */  0,
  /*  131 */  0,
  /*  132 */  0,
  /*  133 */  0,
  /*  134 */  0,
  /*  135 */  0,
  /*  136 */  0,
  /*  137 */  0,
  /*  138 */  0,
  /*  139 */  0,
  /*  140 */  0,
  /*  141 */  0,
  /*  142 */  0,
  /*  143 */  0,
  /*  144 */  0,
  /*  145 */  0,
  /*  146 */  0,
  /*  147 */  0,
  /*  148 */  0,
  /*  149 */  0,
  /*  150 */  0,
  /*  151 */  0,
  /*  152 */  0,
  /*  153 */  0,
  /*  154 */  0,
  /*  155 */  0,
  /*  156 */  0,
  /*  157 */  iRegP_rule,
  /*  158 */  iRegP_rule,
  /*  159 */  iRegP_rule,
  /*  160 */  iRegP_rule,
  /*  161 */  iRegP_rule,
  /*  162 */  iRegP_rule,
  /*  163 */  iRegP_rule,
  /*  164 */  iRegP_rule,
  /*  165 */  iRegP_rule,
  /*  166 */  iRegP_rule,
  /*  167 */  iRegP_rule,
  /*  168 */  iRegP_rule,
  /*  169 */  iRegP_rule,
  /*  170 */  iRegP_rule,
  /*  171 */  iRegP_rule,
  /*  172 */  iRegP_rule,
  /*  173 */  iRegN_rule,
  /*  174 */  _DecodeN_iRegN__rule,
  /*  175 */  _DecodeN_iRegN__rule,
  /*  176 */  _DecodeN_iRegN__rule,
  /*  177 */  _DecodeN_iRegN__rule,
  /*  178 */  _DecodeN_iRegN__rule,
  /*  179 */  _DecodeN_iRegN__rule,
  /*  180 */  thread_RegP_rule,
  /*  181 */  0,
  /*  182 */  0,
  /*  183 */  0,
  /*  184 */  0,
  /*  185 */  0,
  /*  186 */  0,
  /*  187 */  0,
  /*  188 */  0,
  /*  189 */  0,
  /*  190 */  0,
  /*  191 */  iRegL_rule,
  /*  192 */  0,
  /*  193 */  0,
  /*  194 */  iRegP_rule,
  /*  195 */  iRegP_rule,
  // last operand
  /*  196 */  0,
  /*  197 */  0,
  /*  198 */  0,
  /*  199 */  0,
  /*  200 */  0,
  /*  201 */  0,
  /*  202 */  0,
  /*  203 */  0,
  /*  204 */  0,
  /*  205 */  0,
  /*  206 */  0,
  // last operand class
  /*  207 */  iRegI_rule,
  /*  208 */  _ConvI2L_iRegI__rule,
  /*  209 */  iRegL_rule,
  /*  210 */  iRegN_rule,
  /*  211 */  memory1_rule,
  /*  212 */  memory1_rule,
  /*  213 */  memory2_rule,
  /*  214 */  memory2_rule,
  /*  215 */  memory4_rule,
  /*  216 */  _LoadI_memory4__rule,
  /*  217 */  indirect_rule,
  /*  218 */  indirect_rule,
  /*  219 */  indirect_rule,
  /*  220 */  indirect_rule,
  /*  221 */  indirect_rule,
  /*  222 */  _LoadI_indirect__rule,
  /*  223 */  memory8_rule,
  /*  224 */  iRegP_rule,
  /*  225 */  _DecodeN_iRegN__rule,
  /*  226 */  iRegINoSp_rule,
  /*  227 */  iRegLNoSp_rule,
  /*  228 */  iRegP_rule,
  /*  229 */  iRegNNoSp_rule,
  /*  230 */  iRegI_rule,
  /*  231 */  iRegL_rule,
  /*  232 */  iRegN_rule,
  /*  233 */  cmpOp_rule,
  /*  234 */  iRegIorL2I_rule,
  /*  235 */  cmpOpU_rule,
  /*  236 */  immI0_rule,
  /*  237 */  iRegIorL2I_rule,
  /*  238 */  immI_1_rule,
  /*  239 */  iRegL_rule,
  /*  240 */  immL0_rule,
  /*  241 */  iRegP_rule,
  /*  242 */  immP0_rule,
  /*  243 */  iRegN_rule,
  /*  244 */  immN0_rule,
  /*  245 */  vRegF_rule,
  /*  246 */  vRegD_rule,
  /*  247 */  iRegL_rule,
  /*  248 */  iRegIorL2I_rule,
  /*  249 */  _ConvI2L_iRegIorL2I__rule,
  /*  250 */  iRegIorL2I_rule,
  /*  251 */  immI0_rule,
  /*  252 */  iRegL_rule,
  /*  253 */  immL0_rule,
  /*  254 */  _ConvI2L_iRegIorL2I__rule,
  /*  255 */  immL0_rule,
  /*  256 */  iRegIorL2I_rule,
  /*  257 */  iRegIorL2I_rule,
  /*  258 */  iRegIorL2I_rule,
  /*  259 */  iRegL_rule,
  /*  260 */  iRegL_rule,
  /*  261 */  iRegL_rule,
  /*  262 */  iRegIorL2I_rule,
  /*  263 */  iRegL_rule,
  /*  264 */  iRegIorL2I_rule,
  /*  265 */  iRegL_rule,
  /*  266 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  267 */  _URShiftL_iRegL_immI_rule,
  /*  268 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  269 */  _RShiftL_iRegL_immI_rule,
  /*  270 */  iRegIorL2I_rule,
  /*  271 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  272 */  iRegL_rule,
  /*  273 */  _RotateRight_iRegL_immI_rule,
  /*  274 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  275 */  _LShiftL_iRegL_immI_rule,
  /*  276 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  277 */  iRegIorL2I_rule,
  /*  278 */  _URShiftL_iRegL_immI_rule,
  /*  279 */  iRegL_rule,
  /*  280 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  281 */  iRegIorL2I_rule,
  /*  282 */  _RShiftL_iRegL_immI_rule,
  /*  283 */  iRegL_rule,
  /*  284 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  285 */  iRegIorL2I_rule,
  /*  286 */  _RotateRight_iRegL_immI_rule,
  /*  287 */  iRegL_rule,
  /*  288 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  289 */  iRegIorL2I_rule,
  /*  290 */  _LShiftL_iRegL_immI_rule,
  /*  291 */  iRegL_rule,
  /*  292 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  293 */  iRegIorL2I_rule,
  /*  294 */  iRegL_rule,
  /*  295 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /*  296 */  iRegL_rule,
  /*  297 */  _AndL_iRegL_immL_positive_bitmaskI_rule,
  /*  298 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /*  299 */  _AndL_iRegL_immL_positive_bitmaskI_rule,
  /*  300 */  iRegI_rule,
  /*  301 */  iRegIorL2I_rule,
  /*  302 */  _LShiftI_iRegIorL2I_immI_16_rule,
  /*  303 */  iRegIorL2I_rule,
  /*  304 */  _LShiftI_iRegIorL2I_immI_24_rule,
  /*  305 */  _LShiftI_iRegIorL2I_immI_24_rule,
  /*  306 */  iRegL_rule,
  /*  307 */  _LShiftL_iRegL_immI_48_rule,
  /*  308 */  iRegL_rule,
  /*  309 */  _LShiftL_iRegL_immI_32_rule,
  /*  310 */  iRegL_rule,
  /*  311 */  _LShiftL_iRegL_immI_56_rule,
  /*  312 */  _LShiftL_iRegL_immI_56_rule,
  /*  313 */  iRegIorL2I_rule,
  /*  314 */  iRegIorL2I_rule,
  /*  315 */  iRegL_rule,
  /*  316 */  iRegL_rule,
  /*  317 */  iRegL_rule,
  /*  318 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  319 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /*  320 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /*  321 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  322 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /*  323 */  _ConvI2L_iRegIorL2I__rule,
  /*  324 */  _AndL_iRegL_immL_255_rule,
  /*  325 */  _AndL_iRegL_immL_65535_rule,
  /*  326 */  _AndL_iRegL_immL_4294967295_rule,
  /*  327 */  _AndI_iRegIorL2I_immI_255_rule,
  /*  328 */  _AndI_iRegIorL2I_immI_65535_rule,
  /*  329 */  vRegF_rule,
  /*  330 */  _NegF_vRegF__rule,
  /*  331 */  vRegF_rule,
  /*  332 */  vRegD_rule,
  /*  333 */  _NegD_vRegD__rule,
  /*  334 */  vRegD_rule,
  /*  335 */  vRegF_rule,
  /*  336 */  vRegD_rule,
  /*  337 */  iRegIorL2I_rule,
  /*  338 */  iRegL_rule,
  /*  339 */  iRegIorL2I_rule,
  /*  340 */  iRegL_rule,
  /*  341 */  iRegP_rule,
  /*  342 */  iRegN_rule,
  /*  343 */  _DecodeN_iRegN__rule,
  /*  344 */  iRegIorL2I_rule,
  /*  345 */  iRegL_rule,
  /*  346 */  iRegL_rule,
  /*  347 */  _AndL_iRegL_immL_rule,
  /*  348 */  iRegIorL2I_rule,
  /*  349 */  _AndI_iRegIorL2I_immI_rule,
  /*  350 */  iRegL_rule,
  /*  351 */  iRegIorL2I_rule,
  /*  352 */  iRegP_R4_rule,
  /*  353 */  iRegP_R1_rule,
  /*  354 */  iRegP_R3_rule,
  /*  355 */  iRegP_R1_rule,
  /*  356 */  iRegP_R3_rule,
  /*  357 */  iRegP_R3_rule,
  /*  358 */  iRegP_R3_rule,
  /*  359 */  iRegP_R1_rule,
  /*  360 */  iRegP_R1_rule,
  /*  361 */  vReg_rule,
  /*  362 */  vReg_rule,
  /*  363 */  immBAddSubV_rule,
  /*  364 */  immIAddSubV_rule,
  /*  365 */  immIAddSubV_rule,
  /*  366 */  immLAddSubV_rule,
  /*  367 */  immBLog_rule,
  /*  368 */  immSLog_rule,
  /*  369 */  immILog_rule,
  /*  370 */  immLLog_rule,
  /*  371 */  vReg_rule,
  /*  372 */  immI_M1_rule,
  /*  373 */  immI_M1_rule,
  /*  374 */  immI_M1_rule,
  /*  375 */  immL_M1_rule,
  /*  376 */  vReg_rule,
  /*  377 */  vReg_rule,
  /*  378 */  vReg_rule,
  /*  379 */  vReg_rule,
  /*  380 */  vReg_rule,
  /*  381 */  _ReplicateB_immI_M1__rule,
  /*  382 */  vReg_rule,
  /*  383 */  _ReplicateS_immI_M1__rule,
  /*  384 */  vReg_rule,
  /*  385 */  _ReplicateI_immI_M1__rule,
  /*  386 */  vReg_rule,
  /*  387 */  _ReplicateL_immL_M1__rule,
  /*  388 */  vReg_rule,
  /*  389 */  vReg_rule,
  /*  390 */  vReg_rule,
  /*  391 */  vReg_rule,
  /*  392 */  vReg_rule,
  /*  393 */  vReg_rule,
  /*  394 */  vReg_rule,
  /*  395 */  vReg_rule,
  /*  396 */  vReg_rule,
  /*  397 */  vReg_rule,
  /*  398 */  _Binary_vReg_vReg_rule,
  /*  399 */  _Binary_vReg_vReg_rule,
  /*  400 */  vReg_rule,
  /*  401 */  vReg_rule,
  /*  402 */  vReg_rule,
  /*  403 */  vReg_rule,
  /*  404 */  vReg_rule,
  /*  405 */  vReg_rule,
  /*  406 */  vReg_rule,
  /*  407 */  vReg_rule,
  /*  408 */  vReg_rule,
  /*  409 */  _NegVF_vReg__rule,
  /*  410 */  vReg_rule,
  /*  411 */  _NegVD_vReg__rule,
  /*  412 */  vReg_rule,
  /*  413 */  vReg_rule,
  /*  414 */  _NegVF_vReg__rule,
  /*  415 */  _NegVD_vReg__rule,
  /*  416 */  immI_rule,
  /*  417 */  immI_positive_rule,
  /*  418 */  vReg_rule,
  /*  419 */  vReg_rule,
  /*  420 */  vReg_rule,
  /*  421 */  vReg_rule,
  /*  422 */  vReg_rule,
  /*  423 */  vReg_rule,
  /*  424 */  vReg_rule,
  /*  425 */  vReg_rule,
  /*  426 */  vReg_rule,
  /*  427 */  vReg_rule,
  /*  428 */  iRegIorL2I_rule,
  /*  429 */  iRegL_rule,
  /*  430 */  vRegF_rule,
  /*  431 */  vRegD_rule,
  /*  432 */  vReg_rule,
  /*  433 */  vReg_rule,
  /*  434 */  vReg_rule,
  /*  435 */  vReg_rule,
  /*  436 */  indirect_rule,
  /*  437 */  vmemA_rule,
  /*  438 */  pReg_rule,
  /*  439 */  _VectorStoreMask_pReg_immI_gt_1_rule,
  /*  440 */  immI_M1_rule,
  /*  441 */  pReg_rule,
  /*  442 */  immL_M1_rule,
  /*  443 */  pReg_rule,
  /*  444 */  immI_rule,
  /*  445 */  cmpOp_rule,
  /*  446 */  vReg_rule,
  // last internally defined operand
  /*  447 */  immI_rule,
  /*  448 */  immL_rule,
  /*  449 */  immP_rule,
  /*  450 */  immP0_rule,
  /*  451 */  immP_1_rule,
  /*  452 */  immByteMapBase_rule,
  /*  453 */  immN_rule,
  /*  454 */  immN0_rule,
  /*  455 */  immNKlass_rule,
  /*  456 */  immFPacked_rule,
  /*  457 */  immF_rule,
  /*  458 */  immDPacked_rule,
  /*  459 */  immD_rule,
  /*  460 */  iRegIorL2I_rule,
  /*  461 */  iRegL_rule,
  /*  462 */  iRegIorL2I_rule,
  /*  463 */  iRegL_rule,
  /*  464 */  iRegL_rule,
  /*  465 */  iRegP_rule,
  /*  466 */  iRegPNoSp_rule,
  /*  467 */  iRegPNoSp_rule,
  /*  468 */  iRegI_rule,
  /*  469 */  iRegL_rule,
  /*  470 */  vRegF_rule,
  /*  471 */  vRegD_rule,
  /*  472 */  vReg_rule,
  /*  473 */  pRegGov_rule,
  /*  474 */  vRegF_rule,
  /*  475 */  vRegD_rule,
  /*  476 */  vRegF_rule,
  /*  477 */  vRegD_rule,
  /*  478 */  stackSlotF_rule,
  /*  479 */  stackSlotI_rule,
  /*  480 */  stackSlotD_rule,
  /*  481 */  stackSlotL_rule,
  /*  482 */  vRegF_rule,
  /*  483 */  iRegI_rule,
  /*  484 */  vRegD_rule,
  /*  485 */  iRegL_rule,
  /*  486 */  iRegIorL2I_rule,
  /*  487 */  iRegIorL2I_rule,
  /*  488 */  iRegL_rule,
  /*  489 */  iRegL_rule,
  /*  490 */  iRegIorL2I_rule,
  /*  491 */  iRegIorL2I_rule,
  /*  492 */  iRegL_rule,
  /*  493 */  iRegL_rule,
  /*  494 */  immI0_rule,
  /*  495 */  immI0_rule,
  /*  496 */  iRegIorL2I_rule,
  /*  497 */  iRegL_rule,
  /*  498 */  iRegI_rule,
  /*  499 */  iRegI_rule,
  /*  500 */  iRegI_rule,
  /*  501 */  iRegI_rule,
  /*  502 */  iRegI_rule,
  /*  503 */  iRegI_rule,
  /*  504 */  iRegI_rule,
  /*  505 */  iRegI_rule,
  /*  506 */  iRegL_rule,
  /*  507 */  iRegL_rule,
  /*  508 */  iRegL_rule,
  /*  509 */  iRegL_rule,
  /*  510 */  iRegL_rule,
  /*  511 */  iRegL_rule,
  /*  512 */  iRegL_rule,
  /*  513 */  iRegL_rule,
  /*  514 */  iRegP_rule,
  /*  515 */  iRegN_rule,
  /*  516 */  iRegP_rule,
  /*  517 */  iRegN_rule,
  /*  518 */  vRegF_rule,
  /*  519 */  vRegF_rule,
  /*  520 */  vRegD_rule,
  /*  521 */  vRegD_rule,
  /*  522 */  _AndL_iRegL_immL_rule,
  /*  523 */  _AndI_iRegIorL2I_immI_rule,
  /*  524 */  _AndL_iRegL_iRegL_rule,
  /*  525 */  _AndI_iRegIorL2I_iRegIorL2I_rule,
  /*  526 */  iRegP_rule,
  /*  527 */  iRegP_rule,
  /*  528 */  _PartialSubtypeCheck_iRegP_R4_iRegP_R0_rule,
  /*  529 */  0,
  /*  530 */  immI0_rule,
  /*  531 */  vReg_rule,
  /*  532 */  vReg_rule,
  /*  533 */  vReg_rule,
  /*  534 */  vReg_rule,
  /*  535 */  vReg_rule,
  /*  536 */  vReg_rule,
  /*  537 */  vReg_rule,
  /*  538 */  vReg_rule,
  /*  539 */  vReg_rule,
  /*  540 */  vReg_rule,
  /*  541 */  vReg_rule,
  /*  542 */  vReg_rule,
  /*  543 */  iRegIorL2I_rule,
  /*  544 */  iRegIorL2I_rule,
  /*  545 */  vReg_rule,
  /*  546 */  vReg_rule,
  /*  547 */  vReg_rule,
  /*  548 */  vReg_rule,
  /*  549 */  vReg_rule,
  /*  550 */  vReg_rule,
  /*  551 */  vReg_rule,
  /*  552 */  vReg_rule,
  /*  553 */  vReg_rule,
  /*  554 */  vReg_rule,
  /*  555 */  vReg_rule,
  /*  556 */  iRegIorL2I_rule,
  /*  557 */  iRegIorL2I_rule,
  /*  558 */  iRegIorL2I_rule,
  /*  559 */  iRegL_rule,
  /*  560 */  vRegF_rule,
  /*  561 */  vRegD_rule,
  /*  562 */  immI_rule,
  /*  563 */  immI_rule,
  /*  564 */  immI_rule,
  /*  565 */  immI8_rule,
  /*  566 */  immI8_shift8_rule,
  /*  567 */  immI8_shift8_rule,
  /*  568 */  immL_rule,
  /*  569 */  immL8_shift8_rule,
  /*  570 */  vReg_rule,
  /*  571 */  vReg_rule,
  /*  572 */  vReg_rule,
  /*  573 */  vReg_rule,
  /*  574 */  pReg_rule,
  /*  575 */  pReg_rule,
  /*  576 */  pReg_rule,
  /*  577 */  pReg_rule,
  /*  578 */  pReg_rule,
  /*  579 */  vReg_rule,
  /*  580 */  vReg_rule,
  /*  581 */  vReg_rule,
  /*  582 */  vReg_rule,
  /*  583 */  vReg_rule,
  /*  584 */  vReg_rule,
  /*  585 */  vReg_rule,
  /*  586 */  vReg_rule,
  /*  587 */  vReg_rule,
  /*  588 */  vReg_rule,
  /*  589 */  memory1_rule,
  /*  590 */  _LoadB_memory1__rule,
  /*  591 */  memory1_rule,
  /*  592 */  _LoadUB_memory1__rule,
  /*  593 */  memory2_rule,
  /*  594 */  _LoadS_memory2__rule,
  /*  595 */  memory2_rule,
  /*  596 */  _LoadUS_memory2__rule,
  /*  597 */  memory4_rule,
  /*  598 */  _LoadI_memory4__rule,
  /*  599 */  _ConvI2L__LoadI_memory4___rule,
  /*  600 */  memory8_rule,
  /*  601 */  memory4_rule,
  /*  602 */  memory8_rule,
  /*  603 */  memory4_rule,
  /*  604 */  memory8_rule,
  /*  605 */  memory4_rule,
  /*  606 */  memory4_rule,
  /*  607 */  memory8_rule,
  /*  608 */  memory1_rule,
  /*  609 */  memory1_rule,
  /*  610 */  memory1_rule,
  /*  611 */  memory1_rule,
  /*  612 */  memory2_rule,
  /*  613 */  memory2_rule,
  /*  614 */  memory4_rule,
  /*  615 */  memory4_rule,
  /*  616 */  memory8_rule,
  /*  617 */  memory8_rule,
  /*  618 */  memory8_rule,
  /*  619 */  memory8_rule,
  /*  620 */  memory4_rule,
  /*  621 */  memory4_rule,
  /*  622 */  memory4_rule,
  /*  623 */  memory8_rule,
  /*  624 */  memory4_rule,
  /*  625 */  memory8_rule,
  /*  626 */  indirect_rule,
  /*  627 */  _LoadB_indirect__rule,
  /*  628 */  indirect_rule,
  /*  629 */  _LoadUB_indirect__rule,
  /*  630 */  indirect_rule,
  /*  631 */  indirect_rule,
  /*  632 */  _LoadUS_indirect__rule,
  /*  633 */  _LoadS_indirect__rule,
  /*  634 */  indirect_rule,
  /*  635 */  _ConvI2L__LoadI_indirect___rule,
  /*  636 */  indirect_rule,
  /*  637 */  indirect_rule,
  /*  638 */  indirect_rule,
  /*  639 */  indirect_rule,
  /*  640 */  indirect_rule,
  /*  641 */  indirect_rule,
  /*  642 */  indirect_rule,
  /*  643 */  indirect_rule,
  /*  644 */  indirect_rule,
  /*  645 */  indirect_rule,
  /*  646 */  indirect_rule,
  /*  647 */  indirect_rule,
  /*  648 */  indirect_rule,
  /*  649 */  indirect_rule,
  /*  650 */  indirect_rule,
  /*  651 */  indirect_rule,
  /*  652 */  indirect_rule,
  /*  653 */  indirect_rule,
  /*  654 */  indirect_rule,
  /*  655 */  indirect_rule,
  /*  656 */  0,
  /*  657 */  0,
  /*  658 */  iRegIorL2I_rule,
  /*  659 */  iRegL_rule,
  /*  660 */  iRegIorL2I_rule,
  /*  661 */  iRegIorL2I_rule,
  /*  662 */  iRegIorL2I_rule,
  /*  663 */  _LoadI_memory4__rule,
  /*  664 */  iRegL_rule,
  /*  665 */  _LoadL_memory8__rule,
  /*  666 */  0,
  /*  667 */  0,
  /*  668 */  0,
  /*  669 */  0,
  /*  670 */  0,
  /*  671 */  0,
  /*  672 */  0,
  /*  673 */  0,
  /*  674 */  0,
  /*  675 */  0,
  /*  676 */  0,
  /*  677 */  0,
  /*  678 */  _CastP2X_iRegP__rule,
  /*  679 */  _CastP2X__DecodeN_iRegN___rule,
  /*  680 */  iRegP_rule,
  /*  681 */  iRegP_rule,
  /*  682 */  iRegN_rule,
  /*  683 */  iRegN_rule,
  /*  684 */  iRegP_rule,
  /*  685 */  iRegN_rule,
  /*  686 */  indirect_rule,
  /*  687 */  indirect_rule,
  /*  688 */  indirect_rule,
  /*  689 */  indirect_rule,
  /*  690 */  indirect_rule,
  /*  691 */  indirect_rule,
  /*  692 */  indirect_rule,
  /*  693 */  indirect_rule,
  /*  694 */  indirect_rule,
  /*  695 */  indirect_rule,
  /*  696 */  indirect_rule,
  /*  697 */  indirect_rule,
  /*  698 */  indirect_rule,
  /*  699 */  indirect_rule,
  /*  700 */  indirect_rule,
  /*  701 */  indirect_rule,
  /*  702 */  indirect_rule,
  /*  703 */  indirect_rule,
  /*  704 */  indirect_rule,
  /*  705 */  indirect_rule,
  /*  706 */  indirect_rule,
  /*  707 */  indirect_rule,
  /*  708 */  indirect_rule,
  /*  709 */  indirect_rule,
  /*  710 */  indirect_rule,
  /*  711 */  indirect_rule,
  /*  712 */  indirect_rule,
  /*  713 */  indirect_rule,
  /*  714 */  indirect_rule,
  /*  715 */  indirect_rule,
  /*  716 */  indirect_rule,
  /*  717 */  indirect_rule,
  /*  718 */  indirect_rule,
  /*  719 */  indirect_rule,
  /*  720 */  indirect_rule,
  /*  721 */  indirect_rule,
  /*  722 */  indirect_rule,
  /*  723 */  indirect_rule,
  /*  724 */  indirect_rule,
  /*  725 */  indirect_rule,
  /*  726 */  indirect_rule,
  /*  727 */  indirect_rule,
  /*  728 */  indirect_rule,
  /*  729 */  indirect_rule,
  /*  730 */  indirect_rule,
  /*  731 */  indirect_rule,
  /*  732 */  indirect_rule,
  /*  733 */  indirect_rule,
  /*  734 */  indirect_rule,
  /*  735 */  indirect_rule,
  /*  736 */  indirect_rule,
  /*  737 */  indirect_rule,
  /*  738 */  indirect_rule,
  /*  739 */  indirect_rule,
  /*  740 */  indirect_rule,
  /*  741 */  indirect_rule,
  /*  742 */  indirect_rule,
  /*  743 */  indirect_rule,
  /*  744 */  indirect_rule,
  /*  745 */  indirect_rule,
  /*  746 */  iRegL_rule,
  /*  747 */  iRegL_rule,
  /*  748 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  749 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  750 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  751 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  752 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  753 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  754 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  755 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  756 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  757 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  758 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  759 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  760 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  761 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  762 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  763 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  764 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  765 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  766 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  767 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  768 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  769 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  770 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  771 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  772 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  773 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  774 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  775 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  776 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  777 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  778 */  iRegIorL2I_rule,
  /*  779 */  iRegIorL2I_rule,
  /*  780 */  _ConvL2I_iRegL__rule,
  /*  781 */  iRegP_rule,
  /*  782 */  iRegP_rule,
  /*  783 */  iRegP_rule,
  /*  784 */  iRegP_rule,
  /*  785 */  _ConvI2L_iRegIorL2I__rule,
  /*  786 */  iRegP_rule,
  /*  787 */  iRegL_rule,
  /*  788 */  iRegL_rule,
  /*  789 */  iRegIorL2I_rule,
  /*  790 */  iRegIorL2I_rule,
  /*  791 */  iRegL_rule,
  /*  792 */  iRegL_rule,
  /*  793 */  immI0_rule,
  /*  794 */  immL0_rule,
  /*  795 */  iRegIorL2I_rule,
  /*  796 */  _ConvI2L_iRegIorL2I__rule,
  /*  797 */  _ConvI2L_iRegIorL2I__rule,
  /*  798 */  iRegL_rule,
  /*  799 */  iRegL_rule,
  /*  800 */  iRegL_rule,
  /*  801 */  iRegIorL2I_rule,
  /*  802 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  803 */  iRegIorL2I_rule,
  /*  804 */  _SubI_immI0_iRegIorL2I_rule,
  /*  805 */  iRegIorL2I_rule,
  /*  806 */  iRegL_rule,
  /*  807 */  _MulL_iRegL_iRegL_rule,
  /*  808 */  iRegL_rule,
  /*  809 */  _SubL_immL0_iRegL_rule,
  /*  810 */  iRegL_rule,
  /*  811 */  iRegLNoSp_rule,
  /*  812 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  813 */  iRegLNoSp_rule,
  /*  814 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  815 */  iRegLNoSp_rule,
  /*  816 */  iRegLNoSp_rule,
  /*  817 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  818 */  _ConvI2L_iRegIorL2I__rule,
  /*  819 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  820 */  iRegIorL2I_rule,
  /*  821 */  iRegL_rule,
  /*  822 */  iRegIorL2I_rule,
  /*  823 */  iRegL_rule,
  /*  824 */  iRegIorL2I_rule,
  /*  825 */  iRegL_rule,
  /*  826 */  iRegIorL2I_rule,
  /*  827 */  iRegL_rule,
  /*  828 */  iRegIorL2I_rule,
  /*  829 */  iRegIorL2I_rule,
  /*  830 */  iRegIorL2I_rule,
  /*  831 */  iRegIorL2I_rule,
  /*  832 */  iRegIorL2I_rule,
  /*  833 */  iRegIorL2I_rule,
  /*  834 */  iRegL_rule,
  /*  835 */  iRegL_rule,
  /*  836 */  iRegL_rule,
  /*  837 */  iRegL_rule,
  /*  838 */  _CastP2X_iRegP__rule,
  /*  839 */  iRegL_rule,
  /*  840 */  iRegL_rule,
  /*  841 */  iRegL_rule,
  /*  842 */  iRegIorL2I_rule,
  /*  843 */  immI0_rule,
  /*  844 */  immI0_rule,
  /*  845 */  immI0_rule,
  /*  846 */  immL0_rule,
  /*  847 */  immL0_rule,
  /*  848 */  immL0_rule,
  /*  849 */  iRegIorL2I_rule,
  /*  850 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  851 */  iRegL_rule,
  /*  852 */  _XorL_iRegL_immL_M1_rule,
  /*  853 */  iRegIorL2I_rule,
  /*  854 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  855 */  iRegL_rule,
  /*  856 */  _XorL_iRegL_immL_M1_rule,
  /*  857 */  immI_M1_rule,
  /*  858 */  _XorI_iRegIorL2I_iRegIorL2I_rule,
  /*  859 */  immL_M1_rule,
  /*  860 */  _XorL_iRegL_iRegL_rule,
  /*  861 */  iRegIorL2I_rule,
  /*  862 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  863 */  iRegL_rule,
  /*  864 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  865 */  iRegIorL2I_rule,
  /*  866 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  867 */  iRegL_rule,
  /*  868 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  869 */  iRegIorL2I_rule,
  /*  870 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /*  871 */  iRegL_rule,
  /*  872 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /*  873 */  iRegIorL2I_rule,
  /*  874 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  875 */  iRegL_rule,
  /*  876 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  877 */  immI_M1_rule,
  /*  878 */  _XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  879 */  immI_M1_rule,
  /*  880 */  _XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI_rule,
  /*  881 */  immL_M1_rule,
  /*  882 */  _XorL__URShiftL_iRegL_immI_iRegL_rule,
  /*  883 */  immL_M1_rule,
  /*  884 */  _XorL_iRegL__URShiftL_iRegL_immI_rule,
  /*  885 */  immI_M1_rule,
  /*  886 */  _XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  887 */  immI_M1_rule,
  /*  888 */  _XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI_rule,
  /*  889 */  immL_M1_rule,
  /*  890 */  _XorL__RShiftL_iRegL_immI_iRegL_rule,
  /*  891 */  immL_M1_rule,
  /*  892 */  _XorL_iRegL__RShiftL_iRegL_immI_rule,
  /*  893 */  immI_M1_rule,
  /*  894 */  _XorI__RotateRight_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  895 */  immI_M1_rule,
  /*  896 */  _XorI_iRegIorL2I__RotateRight_iRegIorL2I_immI_rule,
  /*  897 */  immL_M1_rule,
  /*  898 */  _XorL__RotateRight_iRegL_immI_iRegL_rule,
  /*  899 */  immL_M1_rule,
  /*  900 */  _XorL_iRegL__RotateRight_iRegL_immI_rule,
  /*  901 */  immI_M1_rule,
  /*  902 */  _XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  903 */  immI_M1_rule,
  /*  904 */  _XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI_rule,
  /*  905 */  immL_M1_rule,
  /*  906 */  _XorL__LShiftL_iRegL_immI_iRegL_rule,
  /*  907 */  immL_M1_rule,
  /*  908 */  _XorL_iRegL__LShiftL_iRegL_immI_rule,
  /*  909 */  iRegIorL2I_rule,
  /*  910 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  911 */  iRegL_rule,
  /*  912 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  913 */  iRegIorL2I_rule,
  /*  914 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  915 */  iRegL_rule,
  /*  916 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  917 */  iRegIorL2I_rule,
  /*  918 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /*  919 */  iRegL_rule,
  /*  920 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /*  921 */  iRegIorL2I_rule,
  /*  922 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  923 */  iRegL_rule,
  /*  924 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  925 */  iRegIorL2I_rule,
  /*  926 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  927 */  iRegL_rule,
  /*  928 */  _URShiftL_iRegL_immI_rule,
  /*  929 */  iRegIorL2I_rule,
  /*  930 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  931 */  iRegL_rule,
  /*  932 */  _RShiftL_iRegL_immI_rule,
  /*  933 */  iRegIorL2I_rule,
  /*  934 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  935 */  iRegL_rule,
  /*  936 */  _LShiftL_iRegL_immI_rule,
  /*  937 */  iRegIorL2I_rule,
  /*  938 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  939 */  iRegL_rule,
  /*  940 */  _RotateRight_iRegL_immI_rule,
  /*  941 */  iRegIorL2I_rule,
  /*  942 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  943 */  iRegL_rule,
  /*  944 */  _URShiftL_iRegL_immI_rule,
  /*  945 */  iRegIorL2I_rule,
  /*  946 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  947 */  iRegL_rule,
  /*  948 */  _RShiftL_iRegL_immI_rule,
  /*  949 */  iRegIorL2I_rule,
  /*  950 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  951 */  iRegL_rule,
  /*  952 */  _LShiftL_iRegL_immI_rule,
  /*  953 */  iRegIorL2I_rule,
  /*  954 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  955 */  iRegL_rule,
  /*  956 */  _RotateRight_iRegL_immI_rule,
  /*  957 */  iRegIorL2I_rule,
  /*  958 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  959 */  iRegL_rule,
  /*  960 */  _URShiftL_iRegL_immI_rule,
  /*  961 */  iRegIorL2I_rule,
  /*  962 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  963 */  iRegL_rule,
  /*  964 */  _RShiftL_iRegL_immI_rule,
  /*  965 */  iRegIorL2I_rule,
  /*  966 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  967 */  iRegL_rule,
  /*  968 */  _LShiftL_iRegL_immI_rule,
  /*  969 */  iRegIorL2I_rule,
  /*  970 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  971 */  iRegL_rule,
  /*  972 */  _RotateRight_iRegL_immI_rule,
  /*  973 */  iRegIorL2I_rule,
  /*  974 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  975 */  iRegL_rule,
  /*  976 */  _URShiftL_iRegL_immI_rule,
  /*  977 */  iRegIorL2I_rule,
  /*  978 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  979 */  iRegL_rule,
  /*  980 */  _RShiftL_iRegL_immI_rule,
  /*  981 */  iRegIorL2I_rule,
  /*  982 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  983 */  iRegL_rule,
  /*  984 */  _LShiftL_iRegL_immI_rule,
  /*  985 */  iRegIorL2I_rule,
  /*  986 */  iRegL_rule,
  /*  987 */  iRegIorL2I_rule,
  /*  988 */  iRegL_rule,
  /*  989 */  iRegIorL2I_rule,
  /*  990 */  iRegL_rule,
  /*  991 */  _LShiftL_iRegL_immI_rule,
  /*  992 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  993 */  _LShiftL_iRegL_immI_rule,
  /*  994 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  995 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  996 */  _URShiftL_iRegL_immI_rule,
  /*  997 */  _AndI__URShiftI_iRegIorL2I_immI_immI_bitmask_rule,
  /*  998 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /*  999 */  _AndL_iRegL_immL_bitmask_rule,
  /* 1000 */  _LShiftI__AndI_iRegIorL2I_immI_bitmask_immI_rule,
  /* 1001 */  _LShiftL__AndL_iRegL_immL_positive_bitmaskI_immI_rule,
  /* 1002 */  _ConvI2L__AndI_iRegIorL2I_immI_bitmask__rule,
  /* 1003 */  _ConvL2I__AndL_iRegL_immL_positive_bitmaskI__rule,
  /* 1004 */  _AndI_iRegI_immI_bitmask_rule,
  /* 1005 */  _LShiftL_iRegL_immI_rule,
  /* 1006 */  _URShiftL_iRegL_immI_rule,
  /* 1007 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1008 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1009 */  _LShiftL_iRegL_immI_rule,
  /* 1010 */  _URShiftL_iRegL_immI_rule,
  /* 1011 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1012 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1013 */  iRegI_rule,
  /* 1014 */  iRegL_rule,
  /* 1015 */  iRegI_rule,
  /* 1016 */  iRegL_rule,
  /* 1017 */  iRegI_rule,
  /* 1018 */  iRegL_rule,
  /* 1019 */  iRegL_rule,
  /* 1020 */  _ConvI2L_iRegIorL2I__rule,
  /* 1021 */  iRegL_rule,
  /* 1022 */  iRegIorL2I_rule,
  /* 1023 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /* 1024 */  iRegIorL2I_rule,
  /* 1025 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /* 1026 */  iRegIorL2I_rule,
  /* 1027 */  _URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /* 1028 */  iRegL_rule,
  /* 1029 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /* 1030 */  iRegL_rule,
  /* 1031 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /* 1032 */  iRegL_rule,
  /* 1033 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /* 1034 */  iRegL_rule,
  /* 1035 */  _URShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /* 1036 */  iRegIorL2I_rule,
  /* 1037 */  _AndI_iRegIorL2I_immI_255_rule,
  /* 1038 */  iRegIorL2I_rule,
  /* 1039 */  _AndI_iRegIorL2I_immI_65535_rule,
  /* 1040 */  iRegL_rule,
  /* 1041 */  _AndL_iRegL_immL_255_rule,
  /* 1042 */  iRegL_rule,
  /* 1043 */  _AndL_iRegL_immL_65535_rule,
  /* 1044 */  iRegL_rule,
  /* 1045 */  _AndL_iRegL_immL_4294967295_rule,
  /* 1046 */  iRegIorL2I_rule,
  /* 1047 */  iRegIorL2I_rule,
  /* 1048 */  iRegL_rule,
  /* 1049 */  iRegL_rule,
  /* 1050 */  iRegL_rule,
  /* 1051 */  iRegL_rule,
  /* 1052 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /* 1053 */  iRegL_rule,
  /* 1054 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /* 1055 */  iRegL_rule,
  /* 1056 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /* 1057 */  iRegL_rule,
  /* 1058 */  iRegL_rule,
  /* 1059 */  iRegL_rule,
  /* 1060 */  iRegIorL2I_rule,
  /* 1061 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /* 1062 */  iRegIorL2I_rule,
  /* 1063 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /* 1064 */  iRegIorL2I_rule,
  /* 1065 */  iRegIorL2I_rule,
  /* 1066 */  iRegL_rule,
  /* 1067 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /* 1068 */  iRegL_rule,
  /* 1069 */  iRegL_rule,
  /* 1070 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /* 1071 */  iRegL_rule,
  /* 1072 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /* 1073 */  iRegL_rule,
  /* 1074 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /* 1075 */  iRegL_rule,
  /* 1076 */  iRegL_rule,
  /* 1077 */  iRegL_rule,
  /* 1078 */  iRegIorL2I_rule,
  /* 1079 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /* 1080 */  iRegIorL2I_rule,
  /* 1081 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /* 1082 */  iRegIorL2I_rule,
  /* 1083 */  iRegIorL2I_rule,
  /* 1084 */  vRegF_rule,
  /* 1085 */  vRegD_rule,
  /* 1086 */  vRegF_rule,
  /* 1087 */  vRegD_rule,
  /* 1088 */  vRegF_rule,
  /* 1089 */  vRegD_rule,
  /* 1090 */  vRegF_rule,
  /* 1091 */  vRegD_rule,
  /* 1092 */  vRegF_rule,
  /* 1093 */  vRegF_rule,
  /* 1094 */  vRegD_rule,
  /* 1095 */  vRegD_rule,
  /* 1096 */  _NegF_vRegF__rule,
  /* 1097 */  _NegF_vRegF__rule,
  /* 1098 */  _NegD_vRegD__rule,
  /* 1099 */  _NegD_vRegD__rule,
  /* 1100 */  _NegF_vRegF__rule,
  /* 1101 */  _NegD_vRegD__rule,
  /* 1102 */  vRegF_rule,
  /* 1103 */  vRegF_rule,
  /* 1104 */  vRegD_rule,
  /* 1105 */  vRegD_rule,
  /* 1106 */  vRegF_rule,
  /* 1107 */  vRegD_rule,
  /* 1108 */  iRegIorL2I_rule,
  /* 1109 */  iRegL_rule,
  /* 1110 */  _SubF_vRegF_vRegF_rule,
  /* 1111 */  _SubD_vRegD_vRegD_rule,
  /* 1112 */  vRegD_rule,
  /* 1113 */  vRegF_rule,
  /* 1114 */  vRegD_rule,
  /* 1115 */  vRegD_rule,
  /* 1116 */  vRegF_rule,
  /* 1117 */  vRegD_rule,
  /* 1118 */  vRegF_rule,
  /* 1119 */  0,
  /* 1120 */  iRegIorL2I_rule,
  /* 1121 */  iRegIorL2I_rule,
  /* 1122 */  iRegIorL2I_rule,
  /* 1123 */  iRegIorL2I_rule,
  /* 1124 */  iRegIorL2I_rule,
  /* 1125 */  iRegIorL2I_rule,
  /* 1126 */  iRegL_rule,
  /* 1127 */  iRegL_rule,
  /* 1128 */  iRegL_rule,
  /* 1129 */  iRegL_rule,
  /* 1130 */  iRegL_rule,
  /* 1131 */  iRegL_rule,
  /* 1132 */  iRegIorL2I_rule,
  /* 1133 */  _ConvI2L_iRegIorL2I__rule,
  /* 1134 */  iRegL_rule,
  /* 1135 */  iRegIorL2I_rule,
  /* 1136 */  iRegP_rule,
  /* 1137 */  vRegD_rule,
  /* 1138 */  vRegF_rule,
  /* 1139 */  vRegF_rule,
  /* 1140 */  vRegF_rule,
  /* 1141 */  vRegF_rule,
  /* 1142 */  iRegINoSp_rule,
  /* 1143 */  iRegIorL2I_rule,
  /* 1144 */  iRegL_rule,
  /* 1145 */  vRegD_rule,
  /* 1146 */  vRegD_rule,
  /* 1147 */  iRegIorL2I_rule,
  /* 1148 */  iRegL_rule,
  /* 1149 */  vRegD_rule,
  /* 1150 */  vRegF_rule,
  /* 1151 */  vRegF_rule,
  /* 1152 */  iRegI_rule,
  /* 1153 */  vRegD_rule,
  /* 1154 */  iRegL_rule,
  /* 1155 */  iRegL_R11_rule,
  /* 1156 */  immL_rule,
  /* 1157 */  cmpOp_rule,
  /* 1158 */  cmpOp_rule,
  /* 1159 */  vRegF_rule,
  /* 1160 */  vRegD_rule,
  /* 1161 */  vRegF_rule,
  /* 1162 */  vRegD_rule,
  /* 1163 */  iRegIorL2I_rule,
  /* 1164 */  iRegIorL2I_rule,
  /* 1165 */  0,
  /* 1166 */  iRegI_rule,
  /* 1167 */  0,
  /* 1168 */  iRegI_rule,
  /* 1169 */  0,
  /* 1170 */  cmpOp_rule,
  /* 1171 */  cmpOpU_rule,
  /* 1172 */  cmpOpEqNe_rule,
  /* 1173 */  cmpOpEqNe_rule,
  /* 1174 */  cmpOpEqNe_rule,
  /* 1175 */  cmpOpEqNe_rule,
  /* 1176 */  cmpOpEqNe_rule,
  /* 1177 */  cmpOpUEqNeLtGe_rule,
  /* 1178 */  cmpOpUEqNeLtGe_rule,
  /* 1179 */  cmpOpLtGe_rule,
  /* 1180 */  cmpOpLtGe_rule,
  /* 1181 */  cmpOpEqNe_rule,
  /* 1182 */  cmpOpEqNe_rule,
  /* 1183 */  cmpOpLtGe_rule,
  /* 1184 */  cmpOpLtGe_rule,
  /* 1185 */  cmpOpEqNe_rule,
  /* 1186 */  cmpOpEqNe_rule,
  /* 1187 */  cmpOp_rule,
  /* 1188 */  cmpOpU_rule,
  /* 1189 */  iRegP_rule,
  /* 1190 */  0,
  /* 1191 */  0,
  /* 1192 */  0,
  /* 1193 */  0,
  /* 1194 */  0,
  /* 1195 */  iRegPNoSp_rule,
  /* 1196 */  iRegPNoSp_rule,
  /* 1197 */  0,
  /* 1198 */  0,
  /* 1199 */  0,
  /* 1200 */  0,
  /* 1201 */  iRegP_R4_rule,
  /* 1202 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1203 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1204 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1205 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1206 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1207 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1208 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1209 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1210 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1211 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1212 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1213 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1214 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1215 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1216 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1217 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1218 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1219 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1220 */  _Binary_iRegP_R1_iRegP_R3_rule,
  /* 1221 */  _Binary_iRegP_R1_iRegP_R3_rule,
  /* 1222 */  iRegP_R1_rule,
  /* 1223 */  iRegP_R1_rule,
  /* 1224 */  iRegP_R1_rule,
  /* 1225 */  iRegP_R2_rule,
  /* 1226 */  iRegP_R0_rule,
  /* 1227 */  iRegP_R2_rule,
  /* 1228 */  iRegP_R2_rule,
  /* 1229 */  vmem2_rule,
  /* 1230 */  vmem2_rule,
  /* 1231 */  vmem4_rule,
  /* 1232 */  vmem4_rule,
  /* 1233 */  vmem8_rule,
  /* 1234 */  vmem8_rule,
  /* 1235 */  vmem16_rule,
  /* 1236 */  vmem16_rule,
  /* 1237 */  vmemA_rule,
  /* 1238 */  vmemA_rule,
  /* 1239 */  vmemA_rule,
  /* 1240 */  vmemA_rule,
  /* 1241 */  vReg_rule,
  /* 1242 */  vReg_rule,
  /* 1243 */  vReg_rule,
  /* 1244 */  vReg_rule,
  /* 1245 */  vReg_rule,
  /* 1246 */  vReg_rule,
  /* 1247 */  _Binary_vReg_vReg_rule,
  /* 1248 */  _Binary_vReg_vReg_rule,
  /* 1249 */  _Binary_vReg_vReg_rule,
  /* 1250 */  _Binary_vReg_vReg_rule,
  /* 1251 */  _Binary_vReg_vReg_rule,
  /* 1252 */  _Binary_vReg_vReg_rule,
  /* 1253 */  vReg_rule,
  /* 1254 */  _ReplicateB_immBAddSubV__rule,
  /* 1255 */  vReg_rule,
  /* 1256 */  _ReplicateS_immIAddSubV__rule,
  /* 1257 */  vReg_rule,
  /* 1258 */  _ReplicateI_immIAddSubV__rule,
  /* 1259 */  vReg_rule,
  /* 1260 */  _ReplicateL_immLAddSubV__rule,
  /* 1261 */  vReg_rule,
  /* 1262 */  vReg_rule,
  /* 1263 */  vReg_rule,
  /* 1264 */  vReg_rule,
  /* 1265 */  vReg_rule,
  /* 1266 */  vReg_rule,
  /* 1267 */  _Binary_vReg_vReg_rule,
  /* 1268 */  _Binary_vReg_vReg_rule,
  /* 1269 */  _Binary_vReg_vReg_rule,
  /* 1270 */  _Binary_vReg_vReg_rule,
  /* 1271 */  _Binary_vReg_vReg_rule,
  /* 1272 */  _Binary_vReg_vReg_rule,
  /* 1273 */  vReg_rule,
  /* 1274 */  vReg_rule,
  /* 1275 */  vReg_rule,
  /* 1276 */  vReg_rule,
  /* 1277 */  vReg_rule,
  /* 1278 */  vReg_rule,
  /* 1279 */  vReg_rule,
  /* 1280 */  vReg_rule,
  /* 1281 */  vReg_rule,
  /* 1282 */  vReg_rule,
  /* 1283 */  _Binary_vReg_vReg_rule,
  /* 1284 */  _Binary_vReg_vReg_rule,
  /* 1285 */  _Binary_vReg_vReg_rule,
  /* 1286 */  _Binary_vReg_vReg_rule,
  /* 1287 */  _Binary_vReg_vReg_rule,
  /* 1288 */  _Binary_vReg_vReg_rule,
  /* 1289 */  vReg_rule,
  /* 1290 */  vReg_rule,
  /* 1291 */  vReg_rule,
  /* 1292 */  vReg_rule,
  /* 1293 */  _Binary_vReg_vReg_rule,
  /* 1294 */  _Binary_vReg_vReg_rule,
  /* 1295 */  vReg_rule,
  /* 1296 */  _Binary_vReg_vReg_rule,
  /* 1297 */  vReg_rule,
  /* 1298 */  _ReplicateB_immBLog__rule,
  /* 1299 */  vReg_rule,
  /* 1300 */  _ReplicateS_immSLog__rule,
  /* 1301 */  vReg_rule,
  /* 1302 */  _ReplicateI_immILog__rule,
  /* 1303 */  vReg_rule,
  /* 1304 */  _ReplicateL_immLLog__rule,
  /* 1305 */  vReg_rule,
  /* 1306 */  _Binary_vReg_vReg_rule,
  /* 1307 */  vReg_rule,
  /* 1308 */  _ReplicateB_immBLog__rule,
  /* 1309 */  vReg_rule,
  /* 1310 */  _ReplicateS_immSLog__rule,
  /* 1311 */  vReg_rule,
  /* 1312 */  _ReplicateI_immILog__rule,
  /* 1313 */  vReg_rule,
  /* 1314 */  _ReplicateL_immLLog__rule,
  /* 1315 */  vReg_rule,
  /* 1316 */  _Binary_vReg_vReg_rule,
  /* 1317 */  vReg_rule,
  /* 1318 */  _ReplicateB_immBLog__rule,
  /* 1319 */  vReg_rule,
  /* 1320 */  _ReplicateS_immSLog__rule,
  /* 1321 */  vReg_rule,
  /* 1322 */  _ReplicateI_immILog__rule,
  /* 1323 */  vReg_rule,
  /* 1324 */  _ReplicateL_immLLog__rule,
  /* 1325 */  vReg_rule,
  /* 1326 */  _XorV_vReg_vReg_rule,
  /* 1327 */  vReg_rule,
  /* 1328 */  _XorV_vReg_vReg_rule,
  /* 1329 */  vReg_rule,
  /* 1330 */  _ReplicateB_immI_M1__rule,
  /* 1331 */  vReg_rule,
  /* 1332 */  _ReplicateS_immI_M1__rule,
  /* 1333 */  vReg_rule,
  /* 1334 */  _ReplicateI_immI_M1__rule,
  /* 1335 */  vReg_rule,
  /* 1336 */  _ReplicateL_immL_M1__rule,
  /* 1337 */  _Binary_vReg__ReplicateB_immI_M1__rule,
  /* 1338 */  _Binary_vReg__ReplicateS_immI_M1__rule,
  /* 1339 */  _Binary_vReg__ReplicateI_immI_M1__rule,
  /* 1340 */  _Binary_vReg__ReplicateL_immL_M1__rule,
  /* 1341 */  vReg_rule,
  /* 1342 */  _XorV_vReg__ReplicateB_immI_M1__rule,
  /* 1343 */  vReg_rule,
  /* 1344 */  _XorV__ReplicateB_immI_M1__vReg_rule,
  /* 1345 */  vReg_rule,
  /* 1346 */  _XorV_vReg__ReplicateS_immI_M1__rule,
  /* 1347 */  vReg_rule,
  /* 1348 */  _XorV__ReplicateS_immI_M1__vReg_rule,
  /* 1349 */  vReg_rule,
  /* 1350 */  _XorV_vReg__ReplicateI_immI_M1__rule,
  /* 1351 */  vReg_rule,
  /* 1352 */  _XorV__ReplicateI_immI_M1__vReg_rule,
  /* 1353 */  vReg_rule,
  /* 1354 */  _XorV_vReg__ReplicateL_immL_M1__rule,
  /* 1355 */  vReg_rule,
  /* 1356 */  _XorV__ReplicateL_immL_M1__vReg_rule,
  /* 1357 */  _Binary_vReg__XorV_vReg__ReplicateB_immI_M1__rule,
  /* 1358 */  _Binary_vReg__XorV__ReplicateB_immI_M1__vReg_rule,
  /* 1359 */  _Binary_vReg__XorV_vReg__ReplicateS_immI_M1__rule,
  /* 1360 */  _Binary_vReg__XorV__ReplicateS_immI_M1__vReg_rule,
  /* 1361 */  _Binary_vReg__XorV_vReg__ReplicateI_immI_M1__rule,
  /* 1362 */  _Binary_vReg__XorV__ReplicateI_immI_M1__vReg_rule,
  /* 1363 */  _Binary_vReg__XorV_vReg__ReplicateL_immL_M1__rule,
  /* 1364 */  _Binary_vReg__XorV__ReplicateL_immL_M1__vReg_rule,
  /* 1365 */  vReg_rule,
  /* 1366 */  vReg_rule,
  /* 1367 */  vReg_rule,
  /* 1368 */  vReg_rule,
  /* 1369 */  vReg_rule,
  /* 1370 */  vReg_rule,
  /* 1371 */  _SubVF_vReg_vReg_rule,
  /* 1372 */  _SubVD_vReg_vReg_rule,
  /* 1373 */  _SubVF_vReg_vReg_rule,
  /* 1374 */  _SubVD_vReg_vReg_rule,
  /* 1375 */  _SubVF__Binary_vReg_vReg_pRegGov_rule,
  /* 1376 */  _SubVD__Binary_vReg_vReg_pRegGov_rule,
  /* 1377 */  vReg_rule,
  /* 1378 */  vReg_rule,
  /* 1379 */  vReg_rule,
  /* 1380 */  vReg_rule,
  /* 1381 */  vReg_rule,
  /* 1382 */  vReg_rule,
  /* 1383 */  vReg_rule,
  /* 1384 */  vReg_rule,
  /* 1385 */  vReg_rule,
  /* 1386 */  vReg_rule,
  /* 1387 */  _Binary_vReg_vReg_rule,
  /* 1388 */  vReg_rule,
  /* 1389 */  vReg_rule,
  /* 1390 */  vReg_rule,
  /* 1391 */  vReg_rule,
  /* 1392 */  _Binary_vReg_vReg_rule,
  /* 1393 */  vReg_rule,
  /* 1394 */  _MulVB_vReg_vReg_rule,
  /* 1395 */  vReg_rule,
  /* 1396 */  _MulVS_vReg_vReg_rule,
  /* 1397 */  vReg_rule,
  /* 1398 */  _MulVI_vReg_vReg_rule,
  /* 1399 */  vReg_rule,
  /* 1400 */  _MulVL_vReg_vReg_rule,
  /* 1401 */  _Binary_vReg__MulVB_vReg_vReg_rule,
  /* 1402 */  _Binary_vReg__MulVS_vReg_vReg_rule,
  /* 1403 */  _Binary_vReg__MulVI_vReg_vReg_rule,
  /* 1404 */  _Binary_vReg__MulVL_vReg_vReg_rule,
  /* 1405 */  vReg_rule,
  /* 1406 */  vReg_rule,
  /* 1407 */  _Binary_vReg_vReg_rule,
  /* 1408 */  _Binary_vReg_vReg_rule,
  /* 1409 */  vReg_rule,
  /* 1410 */  vReg_rule,
  /* 1411 */  vReg_rule,
  /* 1412 */  vReg_rule,
  /* 1413 */  _Binary_vReg__MulVB_vReg_vReg_rule,
  /* 1414 */  _Binary_vReg__MulVS_vReg_vReg_rule,
  /* 1415 */  _Binary_vReg__MulVI_vReg_vReg_rule,
  /* 1416 */  _Binary_vReg__MulVL_vReg_vReg_rule,
  /* 1417 */  vReg_rule,
  /* 1418 */  vReg_rule,
  /* 1419 */  vReg_rule,
  /* 1420 */  vReg_rule,
  /* 1421 */  _Binary_vReg__NegVF_vReg__rule,
  /* 1422 */  _Binary_vReg__NegVD_vReg__rule,
  /* 1423 */  _NegVF_vReg__rule,
  /* 1424 */  _NegVD_vReg__rule,
  /* 1425 */  _NegVF_vReg__rule,
  /* 1426 */  _NegVD_vReg__rule,
  /* 1427 */  _Binary_vReg__NegVF_vReg__rule,
  /* 1428 */  _Binary_vReg__NegVD_vReg__rule,
  /* 1429 */  _NegVF_vReg__rule,
  /* 1430 */  _NegVD_vReg__rule,
  /* 1431 */  _Binary_vReg_vReg_rule,
  /* 1432 */  _Binary_vReg_vReg_rule,
  /* 1433 */  vReg_rule,
  /* 1434 */  vReg_rule,
  /* 1435 */  vReg_rule,
  /* 1436 */  vReg_rule,
  /* 1437 */  vReg_rule,
  /* 1438 */  vReg_rule,
  /* 1439 */  vReg_rule,
  /* 1440 */  vReg_rule,
  /* 1441 */  vReg_rule,
  /* 1442 */  vReg_rule,
  /* 1443 */  vReg_rule,
  /* 1444 */  vReg_rule,
  /* 1445 */  vReg_rule,
  /* 1446 */  vReg_rule,
  /* 1447 */  vReg_rule,
  /* 1448 */  vReg_rule,
  /* 1449 */  vReg_rule,
  /* 1450 */  vReg_rule,
  /* 1451 */  vReg_rule,
  /* 1452 */  vReg_rule,
  /* 1453 */  vReg_rule,
  /* 1454 */  vReg_rule,
  /* 1455 */  vReg_rule,
  /* 1456 */  vReg_rule,
  /* 1457 */  vReg_rule,
  /* 1458 */  vReg_rule,
  /* 1459 */  vReg_rule,
  /* 1460 */  vReg_rule,
  /* 1461 */  vReg_rule,
  /* 1462 */  vReg_rule,
  /* 1463 */  vReg_rule,
  /* 1464 */  vReg_rule,
  /* 1465 */  vReg_rule,
  /* 1466 */  vReg_rule,
  /* 1467 */  vReg_rule,
  /* 1468 */  vReg_rule,
  /* 1469 */  vReg_rule,
  /* 1470 */  vReg_rule,
  /* 1471 */  vReg_rule,
  /* 1472 */  vReg_rule,
  /* 1473 */  vReg_rule,
  /* 1474 */  vReg_rule,
  /* 1475 */  vReg_rule,
  /* 1476 */  vReg_rule,
  /* 1477 */  vReg_rule,
  /* 1478 */  vReg_rule,
  /* 1479 */  _RShiftVB_vReg__RShiftCntV_immI_positive__rule,
  /* 1480 */  vReg_rule,
  /* 1481 */  _RShiftVS_vReg__RShiftCntV_immI_positive__rule,
  /* 1482 */  vReg_rule,
  /* 1483 */  _RShiftVI_vReg__RShiftCntV_immI_positive__rule,
  /* 1484 */  vReg_rule,
  /* 1485 */  _RShiftVL_vReg__RShiftCntV_immI_positive__rule,
  /* 1486 */  vReg_rule,
  /* 1487 */  _URShiftVB_vReg__RShiftCntV_immI_positive__rule,
  /* 1488 */  vReg_rule,
  /* 1489 */  _URShiftVS_vReg__RShiftCntV_immI_positive__rule,
  /* 1490 */  vReg_rule,
  /* 1491 */  _URShiftVI_vReg__RShiftCntV_immI_positive__rule,
  /* 1492 */  vReg_rule,
  /* 1493 */  _URShiftVL_vReg__RShiftCntV_immI_positive__rule,
  /* 1494 */  _Binary_vReg_vReg_rule,
  /* 1495 */  _Binary_vReg_vReg_rule,
  /* 1496 */  _Binary_vReg_vReg_rule,
  /* 1497 */  _Binary_vReg_vReg_rule,
  /* 1498 */  _Binary_vReg_vReg_rule,
  /* 1499 */  _Binary_vReg_vReg_rule,
  /* 1500 */  _Binary_vReg_vReg_rule,
  /* 1501 */  _Binary_vReg_vReg_rule,
  /* 1502 */  _Binary_vReg_vReg_rule,
  /* 1503 */  _Binary_vReg_vReg_rule,
  /* 1504 */  _Binary_vReg_vReg_rule,
  /* 1505 */  _Binary_vReg_vReg_rule,
  /* 1506 */  _Binary_vReg__LShiftCntV_immI__rule,
  /* 1507 */  _Binary_vReg__LShiftCntV_immI__rule,
  /* 1508 */  _Binary_vReg__LShiftCntV_immI__rule,
  /* 1509 */  _Binary_vReg__LShiftCntV_immI__rule,
  /* 1510 */  _Binary_vReg__RShiftCntV_immI_positive__rule,
  /* 1511 */  _Binary_vReg__RShiftCntV_immI_positive__rule,
  /* 1512 */  _Binary_vReg__RShiftCntV_immI_positive__rule,
  /* 1513 */  _Binary_vReg__RShiftCntV_immI_positive__rule,
  /* 1514 */  _Binary_vReg__RShiftCntV_immI_positive__rule,
  /* 1515 */  _Binary_vReg__RShiftCntV_immI_positive__rule,
  /* 1516 */  _Binary_vReg__RShiftCntV_immI_positive__rule,
  /* 1517 */  _Binary_vReg__RShiftCntV_immI_positive__rule,
  /* 1518 */  iRegIorL2I_rule,
  /* 1519 */  iRegIorL2I_rule,
  /* 1520 */  iRegL_rule,
  /* 1521 */  iRegL_rule,
  /* 1522 */  vRegF_rule,
  /* 1523 */  vRegF_rule,
  /* 1524 */  vRegD_rule,
  /* 1525 */  vRegD_rule,
  /* 1526 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1527 */  _Binary_iRegL_vReg_rule,
  /* 1528 */  _Binary_vRegF_vReg_rule,
  /* 1529 */  _Binary_vRegD_vReg_rule,
  /* 1530 */  iRegIorL2I_rule,
  /* 1531 */  iRegL_rule,
  /* 1532 */  vRegF_rule,
  /* 1533 */  vRegD_rule,
  /* 1534 */  iRegIorL2I_rule,
  /* 1535 */  iRegIorL2I_rule,
  /* 1536 */  iRegL_rule,
  /* 1537 */  iRegL_rule,
  /* 1538 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1539 */  _Binary_iRegL_vReg_rule,
  /* 1540 */  iRegIorL2I_rule,
  /* 1541 */  iRegIorL2I_rule,
  /* 1542 */  iRegL_rule,
  /* 1543 */  iRegL_rule,
  /* 1544 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1545 */  _Binary_iRegL_vReg_rule,
  /* 1546 */  iRegIorL2I_rule,
  /* 1547 */  iRegIorL2I_rule,
  /* 1548 */  iRegL_rule,
  /* 1549 */  iRegL_rule,
  /* 1550 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1551 */  _Binary_iRegL_vReg_rule,
  /* 1552 */  iRegIorL2I_rule,
  /* 1553 */  iRegIorL2I_rule,
  /* 1554 */  iRegL_rule,
  /* 1555 */  iRegL_rule,
  /* 1556 */  vRegF_rule,
  /* 1557 */  vRegD_rule,
  /* 1558 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1559 */  _Binary_iRegL_vReg_rule,
  /* 1560 */  _Binary_vRegF_vReg_rule,
  /* 1561 */  _Binary_vRegD_vReg_rule,
  /* 1562 */  iRegIorL2I_rule,
  /* 1563 */  iRegIorL2I_rule,
  /* 1564 */  iRegL_rule,
  /* 1565 */  iRegL_rule,
  /* 1566 */  vRegF_rule,
  /* 1567 */  vRegD_rule,
  /* 1568 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1569 */  _Binary_iRegL_vReg_rule,
  /* 1570 */  _Binary_vRegF_vReg_rule,
  /* 1571 */  _Binary_vRegD_vReg_rule,
  /* 1572 */  vReg_rule,
  /* 1573 */  vReg_rule,
  /* 1574 */  vReg_rule,
  /* 1575 */  vReg_rule,
  /* 1576 */  vReg_rule,
  /* 1577 */  vReg_rule,
  /* 1578 */  vReg_rule,
  /* 1579 */  vReg_rule,
  /* 1580 */  vReg_rule,
  /* 1581 */  vReg_rule,
  /* 1582 */  vReg_rule,
  /* 1583 */  vReg_rule,
  /* 1584 */  _Binary_vReg_iRegIorL2I_rule,
  /* 1585 */  _Binary_vReg_iRegIorL2I_rule,
  /* 1586 */  _Binary_vReg_iRegIorL2I_rule,
  /* 1587 */  _Binary_vReg_iRegL_rule,
  /* 1588 */  _Binary_vReg_iRegL_rule,
  /* 1589 */  _Binary_vReg_vRegF_rule,
  /* 1590 */  _Binary_vReg_vRegF_rule,
  /* 1591 */  _Binary_vReg_vRegF_rule,
  /* 1592 */  _Binary_vReg_vRegD_rule,
  /* 1593 */  _Binary_vReg_vRegD_rule,
  /* 1594 */  vReg_rule,
  /* 1595 */  vReg_rule,
  /* 1596 */  vReg_rule,
  /* 1597 */  vReg_rule,
  /* 1598 */  vReg_rule,
  /* 1599 */  vReg_rule,
  /* 1600 */  vReg_rule,
  /* 1601 */  vReg_rule,
  /* 1602 */  vReg_rule,
  /* 1603 */  vReg_rule,
  /* 1604 */  vReg_rule,
  /* 1605 */  vReg_rule,
  /* 1606 */  vReg_rule,
  /* 1607 */  vReg_rule,
  /* 1608 */  vReg_rule,
  /* 1609 */  vReg_rule,
  /* 1610 */  pReg_rule,
  /* 1611 */  pReg_rule,
  /* 1612 */  _LoadVector_indirect__rule,
  /* 1613 */  _LoadVector_indirect__rule,
  /* 1614 */  _LoadVectorMasked_vmemA_pRegGov_rule,
  /* 1615 */  _LoadVectorMasked_vmemA_pRegGov_rule,
  /* 1616 */  indirect_rule,
  /* 1617 */  indirect_rule,
  /* 1618 */  vmemA_rule,
  /* 1619 */  vmemA_rule,
  /* 1620 */  pReg_rule,
  /* 1621 */  pReg_rule,
  /* 1622 */  pReg_rule,
  /* 1623 */  pReg_rule,
  /* 1624 */  pReg_rule,
  /* 1625 */  _Binary_vReg_vReg_rule,
  /* 1626 */  _Binary_vReg_vReg_rule,
  /* 1627 */  _Binary_vReg_vReg_rule,
  /* 1628 */  pReg_rule,
  /* 1629 */  vReg_rule,
  /* 1630 */  vReg_rule,
  /* 1631 */  pReg_rule,
  /* 1632 */  pReg_rule,
  /* 1633 */  pReg_rule,
  /* 1634 */  pReg_rule,
  /* 1635 */  iRegL_rule,
  /* 1636 */  immI_rule,
  /* 1637 */  iRegIorL2I_rule,
  /* 1638 */  iRegIorL2I_rule,
  /* 1639 */  immL_rule,
  /* 1640 */  iRegL_rule,
  /* 1641 */  iRegL_rule,
  /* 1642 */  _ConvI2L_iRegIorL2I__rule,
  /* 1643 */  iRegL_rule,
  /* 1644 */  immL_rule,
  /* 1645 */  vReg_rule,
  /* 1646 */  vReg_rule,
  /* 1647 */  _Binary_vReg_vReg_rule,
  /* 1648 */  _Binary_vReg_vReg_rule,
  /* 1649 */  _Binary_cmpOp_immI_rule,
  /* 1650 */  _Binary_cmpOp_immI_rule,
  /* 1651 */  _Binary_cmpOp_immI_rule,
  /* 1652 */  _Binary_cmpOp_immI_rule,
  /* 1653 */  vReg_rule,
  /* 1654 */  vReg_rule,
  /* 1655 */  vReg_rule,
  /* 1656 */  vReg_rule,
  /* 1657 */  vReg_rule,
  /* 1658 */  vReg_rule,
  /* 1659 */  pReg_rule,
  /* 1660 */  vReg_rule,
  /* 1661 */  pReg_rule,
  /* 1662 */  vReg_rule,
  /* 1663 */  vReg_rule,
  /* 1664 */  indirect_rule,
  /* 1665 */  indirect_rule,
  /* 1666 */  indirect_rule,
  /* 1667 */  indirect_rule,
  /* 1668 */  indirect_rule,
  /* 1669 */  indirect_rule,
  /* 1670 */  indirect_rule,
  /* 1671 */  indirect_rule,
  /* 1672 */  vReg_rule,
  /* 1673 */  vReg_rule,
  /* 1674 */  vReg_rule,
  /* 1675 */  vReg_rule,
  /* 1676 */  iRegIorL2I_rule,
  /* 1677 */  pReg_rule,
  /* 1678 */  vReg_rule,
  /* 1679 */  vReg_rule,
  /* 1680 */  vReg_rule,
  /* 1681 */  vReg_rule,
  /* 1682 */  vReg_rule,
  /* 1683 */  vReg_rule,
  /* 1684 */  vReg_rule,
  /* 1685 */  vReg_rule,
  /* 1686 */  indirect_rule,
  /* 1687 */  indirect_rule,
  /* 1688 */  indirect_rule,
  /* 1689 */  indirect_rule,
  /* 1690 */  indirect_rule,
  /* 1691 */  indirect_rule,
  /* 1692 */  indirect_rule,
  /* 1693 */  indirect_rule,
  /* 1694 */  indirect_rule,
  /* 1695 */  indirect_rule,
  /* 1696 */  indirect_rule,
  /* 1697 */  indirect_rule,
  /* 1698 */  memory8_rule,
  /* 1699 */  indirect_rule,
  /* 1700 */  indirect_rule,
  /* 1701 */  indirect_rule,
  /* 1702 */  indirect_rule,
  /* 1703 */  indirect_rule,
  /* 1704 */  indirect_rule,
  /* 1705 */  indirect_rule,
  /* 1706 */  indirect_rule,
  /* 1707 */  indirect_rule,
  // last instruction
  0 // no trailing comma
};

const        int   rightOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  0,
  /*   78 */  0,
  /*   79 */  0,
  /*   80 */  0,
  /*   81 */  0,
  /*   82 */  0,
  /*   83 */  0,
  /*   84 */  0,
  /*   85 */  0,
  /*   86 */  0,
  /*   87 */  0,
  /*   88 */  0,
  /*   89 */  0,
  /*   90 */  0,
  /*   91 */  0,
  /*   92 */  0,
  /*   93 */  0,
  /*   94 */  0,
  /*   95 */  0,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  /*  101 */  0,
  /*  102 */  0,
  /*  103 */  0,
  /*  104 */  0,
  /*  105 */  0,
  /*  106 */  0,
  /*  107 */  0,
  /*  108 */  0,
  /*  109 */  0,
  /*  110 */  0,
  /*  111 */  0,
  /*  112 */  0,
  /*  113 */  0,
  /*  114 */  0,
  /*  115 */  0,
  /*  116 */  0,
  /*  117 */  0,
  /*  118 */  0,
  /*  119 */  0,
  /*  120 */  0,
  /*  121 */  0,
  /*  122 */  0,
  /*  123 */  0,
  /*  124 */  0,
  /*  125 */  0,
  /*  126 */  0,
  /*  127 */  0,
  /*  128 */  0,
  /*  129 */  0,
  /*  130 */  0,
  /*  131 */  0,
  /*  132 */  0,
  /*  133 */  0,
  /*  134 */  0,
  /*  135 */  0,
  /*  136 */  0,
  /*  137 */  0,
  /*  138 */  0,
  /*  139 */  0,
  /*  140 */  0,
  /*  141 */  0,
  /*  142 */  0,
  /*  143 */  0,
  /*  144 */  0,
  /*  145 */  0,
  /*  146 */  0,
  /*  147 */  0,
  /*  148 */  0,
  /*  149 */  0,
  /*  150 */  0,
  /*  151 */  0,
  /*  152 */  0,
  /*  153 */  0,
  /*  154 */  0,
  /*  155 */  0,
  /*  156 */  0,
  /*  157 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  158 */  _LShiftL_iRegL_immIScale_rule,
  /*  159 */  _ConvI2L_iRegI__rule,
  /*  160 */  iRegL_rule,
  /*  161 */  immIOffset_rule,
  /*  162 */  immIOffset1_rule,
  /*  163 */  immIOffset2_rule,
  /*  164 */  immIOffset4_rule,
  /*  165 */  immIOffset8_rule,
  /*  166 */  immIOffset16_rule,
  /*  167 */  immLoffset_rule,
  /*  168 */  immLoffset1_rule,
  /*  169 */  immLoffset2_rule,
  /*  170 */  immLoffset4_rule,
  /*  171 */  immLoffset8_rule,
  /*  172 */  immLoffset16_rule,
  /*  173 */  0,
  /*  174 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  175 */  _LShiftL_iRegL_immIScale_rule,
  /*  176 */  _ConvI2L_iRegI__rule,
  /*  177 */  iRegL_rule,
  /*  178 */  immIOffset_rule,
  /*  179 */  immLoffset_rule,
  /*  180 */  immL_pc_off_rule,
  /*  181 */  0,
  /*  182 */  0,
  /*  183 */  0,
  /*  184 */  0,
  /*  185 */  0,
  /*  186 */  0,
  /*  187 */  0,
  /*  188 */  0,
  /*  189 */  0,
  /*  190 */  0,
  /*  191 */  0,
  /*  192 */  0,
  /*  193 */  0,
  /*  194 */  vmemA_immIOffset4_rule,
  /*  195 */  vmemA_immLOffset4_rule,
  // last operand
  /*  196 */  0,
  /*  197 */  0,
  /*  198 */  0,
  /*  199 */  0,
  /*  200 */  0,
  /*  201 */  0,
  /*  202 */  0,
  /*  203 */  0,
  /*  204 */  0,
  /*  205 */  0,
  /*  206 */  0,
  // last operand class
  /*  207 */  0,
  /*  208 */  immIScale_rule,
  /*  209 */  immIScale_rule,
  /*  210 */  0,
  /*  211 */  0,
  /*  212 */  0,
  /*  213 */  0,
  /*  214 */  0,
  /*  215 */  0,
  /*  216 */  0,
  /*  217 */  0,
  /*  218 */  0,
  /*  219 */  0,
  /*  220 */  0,
  /*  221 */  0,
  /*  222 */  0,
  /*  223 */  0,
  /*  224 */  0,
  /*  225 */  0,
  /*  226 */  iRegINoSp_rule,
  /*  227 */  iRegLNoSp_rule,
  /*  228 */  iRegP_rule,
  /*  229 */  iRegNNoSp_rule,
  /*  230 */  iRegI_rule,
  /*  231 */  iRegL_rule,
  /*  232 */  iRegN_rule,
  /*  233 */  rFlagsReg_rule,
  /*  234 */  iRegIorL2I_rule,
  /*  235 */  rFlagsRegU_rule,
  /*  236 */  iRegIorL2I_rule,
  /*  237 */  immI0_rule,
  /*  238 */  immI0_rule,
  /*  239 */  immL0_rule,
  /*  240 */  iRegL_rule,
  /*  241 */  immP0_rule,
  /*  242 */  iRegP_rule,
  /*  243 */  immN0_rule,
  /*  244 */  iRegN_rule,
  /*  245 */  vRegF_rule,
  /*  246 */  vRegD_rule,
  /*  247 */  0,
  /*  248 */  0,
  /*  249 */  immIScale_rule,
  /*  250 */  iRegIorL2I_rule,
  /*  251 */  iRegIorL2I_rule,
  /*  252 */  iRegL_rule,
  /*  253 */  iRegL_rule,
  /*  254 */  _ConvI2L_iRegIorL2I__rule,
  /*  255 */  _ConvI2L_iRegIorL2I__rule,
  /*  256 */  immI_rule,
  /*  257 */  immI_rule,
  /*  258 */  immI_rule,
  /*  259 */  immI_rule,
  /*  260 */  immI_rule,
  /*  261 */  immI_rule,
  /*  262 */  immI_M1_rule,
  /*  263 */  immL_M1_rule,
  /*  264 */  iRegIorL2I_rule,
  /*  265 */  iRegL_rule,
  /*  266 */  immI_M1_rule,
  /*  267 */  immL_M1_rule,
  /*  268 */  immI_M1_rule,
  /*  269 */  immL_M1_rule,
  /*  270 */  immI_rule,
  /*  271 */  immI_M1_rule,
  /*  272 */  immI_rule,
  /*  273 */  immL_M1_rule,
  /*  274 */  immI_M1_rule,
  /*  275 */  immL_M1_rule,
  /*  276 */  iRegIorL2I_rule,
  /*  277 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  278 */  iRegL_rule,
  /*  279 */  _URShiftL_iRegL_immI_rule,
  /*  280 */  iRegIorL2I_rule,
  /*  281 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  282 */  iRegL_rule,
  /*  283 */  _RShiftL_iRegL_immI_rule,
  /*  284 */  iRegIorL2I_rule,
  /*  285 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  286 */  iRegL_rule,
  /*  287 */  _RotateRight_iRegL_immI_rule,
  /*  288 */  iRegIorL2I_rule,
  /*  289 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  290 */  iRegL_rule,
  /*  291 */  _LShiftL_iRegL_immI_rule,
  /*  292 */  immI_bitmask_rule,
  /*  293 */  immI_bitmask_rule,
  /*  294 */  immL_bitmask_rule,
  /*  295 */  immI_rule,
  /*  296 */  immL_positive_bitmaskI_rule,
  /*  297 */  immI_rule,
  /*  298 */  0,
  /*  299 */  0,
  /*  300 */  immI_bitmask_rule,
  /*  301 */  immI_16_rule,
  /*  302 */  immI_16_rule,
  /*  303 */  immI_24_rule,
  /*  304 */  immI_24_rule,
  /*  305 */  immI_24_rule,
  /*  306 */  immI_48_rule,
  /*  307 */  immI_48_rule,
  /*  308 */  immI_32_rule,
  /*  309 */  immI_32_rule,
  /*  310 */  immI_56_rule,
  /*  311 */  immI_56_rule,
  /*  312 */  immI_56_rule,
  /*  313 */  immI_255_rule,
  /*  314 */  immI_65535_rule,
  /*  315 */  immL_255_rule,
  /*  316 */  immL_65535_rule,
  /*  317 */  immL_4294967295_rule,
  /*  318 */  immIExt_rule,
  /*  319 */  immIExt_rule,
  /*  320 */  immIExt_rule,
  /*  321 */  immIExt_rule,
  /*  322 */  immIExt_rule,
  /*  323 */  immIExt_rule,
  /*  324 */  immIExt_rule,
  /*  325 */  immIExt_rule,
  /*  326 */  immIExt_rule,
  /*  327 */  immIExt_rule,
  /*  328 */  immIExt_rule,
  /*  329 */  0,
  /*  330 */  vRegF_rule,
  /*  331 */  _NegF_vRegF__rule,
  /*  332 */  0,
  /*  333 */  vRegD_rule,
  /*  334 */  _NegD_vRegD__rule,
  /*  335 */  vRegF_rule,
  /*  336 */  vRegD_rule,
  /*  337 */  iRegIorL2I_rule,
  /*  338 */  iRegL_rule,
  /*  339 */  immI0_rule,
  /*  340 */  immL0_rule,
  /*  341 */  immP0_rule,
  /*  342 */  immN0_rule,
  /*  343 */  immP0_rule,
  /*  344 */  immI0_rule,
  /*  345 */  immL0_rule,
  /*  346 */  immL_rule,
  /*  347 */  immL0_rule,
  /*  348 */  immI_rule,
  /*  349 */  immI0_rule,
  /*  350 */  iRegL_rule,
  /*  351 */  iRegIorL2I_rule,
  /*  352 */  iRegP_R0_rule,
  /*  353 */  iRegI_R2_rule,
  /*  354 */  iRegI_R4_rule,
  /*  355 */  iRegI_R4_rule,
  /*  356 */  iRegI_R2_rule,
  /*  357 */  immI_le_4_rule,
  /*  358 */  immI_1_rule,
  /*  359 */  iRegP_R3_rule,
  /*  360 */  iRegI_R3_rule,
  /*  361 */  pRegGov_rule,
  /*  362 */  vReg_rule,
  /*  363 */  0,
  /*  364 */  0,
  /*  365 */  0,
  /*  366 */  0,
  /*  367 */  0,
  /*  368 */  0,
  /*  369 */  0,
  /*  370 */  0,
  /*  371 */  vReg_rule,
  /*  372 */  0,
  /*  373 */  0,
  /*  374 */  0,
  /*  375 */  0,
  /*  376 */  _ReplicateB_immI_M1__rule,
  /*  377 */  _ReplicateS_immI_M1__rule,
  /*  378 */  _ReplicateI_immI_M1__rule,
  /*  379 */  _ReplicateL_immL_M1__rule,
  /*  380 */  _ReplicateB_immI_M1__rule,
  /*  381 */  vReg_rule,
  /*  382 */  _ReplicateS_immI_M1__rule,
  /*  383 */  vReg_rule,
  /*  384 */  _ReplicateI_immI_M1__rule,
  /*  385 */  vReg_rule,
  /*  386 */  _ReplicateL_immL_M1__rule,
  /*  387 */  vReg_rule,
  /*  388 */  _XorV_vReg__ReplicateB_immI_M1__rule,
  /*  389 */  _XorV__ReplicateB_immI_M1__vReg_rule,
  /*  390 */  _XorV_vReg__ReplicateS_immI_M1__rule,
  /*  391 */  _XorV__ReplicateS_immI_M1__vReg_rule,
  /*  392 */  _XorV_vReg__ReplicateI_immI_M1__rule,
  /*  393 */  _XorV__ReplicateI_immI_M1__vReg_rule,
  /*  394 */  _XorV_vReg__ReplicateL_immL_M1__rule,
  /*  395 */  _XorV__ReplicateL_immL_M1__vReg_rule,
  /*  396 */  vReg_rule,
  /*  397 */  vReg_rule,
  /*  398 */  pRegGov_rule,
  /*  399 */  pRegGov_rule,
  /*  400 */  vReg_rule,
  /*  401 */  vReg_rule,
  /*  402 */  vReg_rule,
  /*  403 */  vReg_rule,
  /*  404 */  _MulVB_vReg_vReg_rule,
  /*  405 */  _MulVS_vReg_vReg_rule,
  /*  406 */  _MulVI_vReg_vReg_rule,
  /*  407 */  _MulVL_vReg_vReg_rule,
  /*  408 */  0,
  /*  409 */  vReg_rule,
  /*  410 */  0,
  /*  411 */  vReg_rule,
  /*  412 */  _NegVF_vReg__rule,
  /*  413 */  _NegVD_vReg__rule,
  /*  414 */  pRegGov_rule,
  /*  415 */  pRegGov_rule,
  /*  416 */  0,
  /*  417 */  0,
  /*  418 */  _RShiftCntV_immI_positive__rule,
  /*  419 */  _RShiftCntV_immI_positive__rule,
  /*  420 */  _RShiftCntV_immI_positive__rule,
  /*  421 */  _RShiftCntV_immI_positive__rule,
  /*  422 */  _RShiftCntV_immI_positive__rule,
  /*  423 */  _RShiftCntV_immI_positive__rule,
  /*  424 */  _RShiftCntV_immI_positive__rule,
  /*  425 */  _RShiftCntV_immI_positive__rule,
  /*  426 */  _LShiftCntV_immI__rule,
  /*  427 */  _RShiftCntV_immI_positive__rule,
  /*  428 */  vReg_rule,
  /*  429 */  vReg_rule,
  /*  430 */  vReg_rule,
  /*  431 */  vReg_rule,
  /*  432 */  iRegIorL2I_rule,
  /*  433 */  iRegL_rule,
  /*  434 */  vRegF_rule,
  /*  435 */  vRegD_rule,
  /*  436 */  0,
  /*  437 */  pRegGov_rule,
  /*  438 */  immI_gt_1_rule,
  /*  439 */  pRegGov_rule,
  /*  440 */  0,
  /*  441 */  _MaskAll_immI_M1__rule,
  /*  442 */  0,
  /*  443 */  _MaskAll_immL_M1__rule,
  /*  444 */  pRegGov_rule,
  /*  445 */  immI_rule,
  /*  446 */  _Binary_vReg_pRegGov_rule,
  // last internally defined operand
  /*  447 */  0,
  /*  448 */  0,
  /*  449 */  0,
  /*  450 */  0,
  /*  451 */  0,
  /*  452 */  0,
  /*  453 */  0,
  /*  454 */  0,
  /*  455 */  0,
  /*  456 */  0,
  /*  457 */  0,
  /*  458 */  0,
  /*  459 */  0,
  /*  460 */  0,
  /*  461 */  0,
  /*  462 */  0,
  /*  463 */  0,
  /*  464 */  0,
  /*  465 */  0,
  /*  466 */  0,
  /*  467 */  0,
  /*  468 */  0,
  /*  469 */  0,
  /*  470 */  0,
  /*  471 */  0,
  /*  472 */  0,
  /*  473 */  0,
  /*  474 */  0,
  /*  475 */  0,
  /*  476 */  0,
  /*  477 */  0,
  /*  478 */  0,
  /*  479 */  0,
  /*  480 */  0,
  /*  481 */  0,
  /*  482 */  0,
  /*  483 */  0,
  /*  484 */  0,
  /*  485 */  0,
  /*  486 */  iRegIorL2I_rule,
  /*  487 */  immIAddSub_rule,
  /*  488 */  iRegL_rule,
  /*  489 */  immLAddSub_rule,
  /*  490 */  iRegIorL2I_rule,
  /*  491 */  immIAddSub_rule,
  /*  492 */  iRegL_rule,
  /*  493 */  immLAddSub_rule,
  /*  494 */  iRegIorL2I_rule,
  /*  495 */  iRegL_rule,
  /*  496 */  iRegIorL2I_rule,
  /*  497 */  iRegL_rule,
  /*  498 */  iRegI_rule,
  /*  499 */  immI0_rule,
  /*  500 */  immIAddSub_rule,
  /*  501 */  immI_rule,
  /*  502 */  iRegI_rule,
  /*  503 */  immI0_rule,
  /*  504 */  immIAddSub_rule,
  /*  505 */  immI_rule,
  /*  506 */  iRegL_rule,
  /*  507 */  immL0_rule,
  /*  508 */  immLAddSub_rule,
  /*  509 */  immL_rule,
  /*  510 */  iRegL_rule,
  /*  511 */  immL0_rule,
  /*  512 */  immLAddSub_rule,
  /*  513 */  immL_rule,
  /*  514 */  iRegP_rule,
  /*  515 */  iRegN_rule,
  /*  516 */  immP0_rule,
  /*  517 */  immN0_rule,
  /*  518 */  vRegF_rule,
  /*  519 */  immF0_rule,
  /*  520 */  vRegD_rule,
  /*  521 */  immD0_rule,
  /*  522 */  immL0_rule,
  /*  523 */  immI0_rule,
  /*  524 */  immL0_rule,
  /*  525 */  immI0_rule,
  /*  526 */  iRegP_rule,
  /*  527 */  iRegP_rule,
  /*  528 */  immP0_rule,
  /*  529 */  0,
  /*  530 */  0,
  /*  531 */  0,
  /*  532 */  0,
  /*  533 */  0,
  /*  534 */  0,
  /*  535 */  0,
  /*  536 */  0,
  /*  537 */  0,
  /*  538 */  0,
  /*  539 */  0,
  /*  540 */  0,
  /*  541 */  0,
  /*  542 */  0,
  /*  543 */  0,
  /*  544 */  0,
  /*  545 */  0,
  /*  546 */  0,
  /*  547 */  0,
  /*  548 */  0,
  /*  549 */  0,
  /*  550 */  0,
  /*  551 */  0,
  /*  552 */  0,
  /*  553 */  0,
  /*  554 */  0,
  /*  555 */  0,
  /*  556 */  0,
  /*  557 */  0,
  /*  558 */  0,
  /*  559 */  0,
  /*  560 */  0,
  /*  561 */  0,
  /*  562 */  0,
  /*  563 */  0,
  /*  564 */  0,
  /*  565 */  0,
  /*  566 */  0,
  /*  567 */  0,
  /*  568 */  0,
  /*  569 */  0,
  /*  570 */  0,
  /*  571 */  0,
  /*  572 */  0,
  /*  573 */  0,
  /*  574 */  0,
  /*  575 */  0,
  /*  576 */  0,
  /*  577 */  0,
  /*  578 */  0,
  /*  579 */  0,
  /*  580 */  0,
  /*  581 */  0,
  /*  582 */  0,
  /*  583 */  0,
  /*  584 */  0,
  /*  585 */  0,
  /*  586 */  0,
  /*  587 */  0,
  /*  588 */  0,
  /*  589 */  0,
  /*  590 */  0,
  /*  591 */  0,
  /*  592 */  0,
  /*  593 */  0,
  /*  594 */  0,
  /*  595 */  0,
  /*  596 */  0,
  /*  597 */  0,
  /*  598 */  0,
  /*  599 */  immL_32bits_rule,
  /*  600 */  0,
  /*  601 */  0,
  /*  602 */  0,
  /*  603 */  0,
  /*  604 */  0,
  /*  605 */  0,
  /*  606 */  0,
  /*  607 */  0,
  /*  608 */  immI0_rule,
  /*  609 */  immI0_rule,
  /*  610 */  iRegIorL2I_rule,
  /*  611 */  immI0_rule,
  /*  612 */  iRegIorL2I_rule,
  /*  613 */  immI0_rule,
  /*  614 */  iRegIorL2I_rule,
  /*  615 */  immI0_rule,
  /*  616 */  iRegL_rule,
  /*  617 */  immL0_rule,
  /*  618 */  iRegP_rule,
  /*  619 */  immP0_rule,
  /*  620 */  iRegN_rule,
  /*  621 */  immN0_rule,
  /*  622 */  vRegF_rule,
  /*  623 */  vRegD_rule,
  /*  624 */  iRegN_rule,
  /*  625 */  0,
  /*  626 */  0,
  /*  627 */  0,
  /*  628 */  0,
  /*  629 */  0,
  /*  630 */  0,
  /*  631 */  0,
  /*  632 */  0,
  /*  633 */  0,
  /*  634 */  0,
  /*  635 */  immL_32bits_rule,
  /*  636 */  0,
  /*  637 */  0,
  /*  638 */  0,
  /*  639 */  0,
  /*  640 */  0,
  /*  641 */  iRegIorL2I_rule,
  /*  642 */  immI0_rule,
  /*  643 */  iRegIorL2I_rule,
  /*  644 */  immI0_rule,
  /*  645 */  iRegIorL2I_rule,
  /*  646 */  immI0_rule,
  /*  647 */  iRegL_rule,
  /*  648 */  immL0_rule,
  /*  649 */  iRegP_rule,
  /*  650 */  immP0_rule,
  /*  651 */  iRegN_rule,
  /*  652 */  immN0_rule,
  /*  653 */  vRegF_rule,
  /*  654 */  vRegD_rule,
  /*  655 */  0,
  /*  656 */  0,
  /*  657 */  0,
  /*  658 */  0,
  /*  659 */  0,
  /*  660 */  0,
  /*  661 */  0,
  /*  662 */  0,
  /*  663 */  0,
  /*  664 */  0,
  /*  665 */  0,
  /*  666 */  0,
  /*  667 */  0,
  /*  668 */  0,
  /*  669 */  0,
  /*  670 */  0,
  /*  671 */  0,
  /*  672 */  0,
  /*  673 */  0,
  /*  674 */  0,
  /*  675 */  0,
  /*  676 */  0,
  /*  677 */  0,
  /*  678 */  0,
  /*  679 */  0,
  /*  680 */  0,
  /*  681 */  0,
  /*  682 */  0,
  /*  683 */  0,
  /*  684 */  0,
  /*  685 */  0,
  /*  686 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  687 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  688 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  689 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  690 */  _Binary_iRegP_iRegP_rule,
  /*  691 */  _Binary_iRegNNoSp_iRegNNoSp_rule,
  /*  692 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  693 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  694 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  695 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  696 */  _Binary_iRegP_iRegP_rule,
  /*  697 */  _Binary_iRegNNoSp_iRegNNoSp_rule,
  /*  698 */  _Binary_iRegI_iRegI_rule,
  /*  699 */  _Binary_iRegI_iRegI_rule,
  /*  700 */  _Binary_iRegI_iRegI_rule,
  /*  701 */  _Binary_iRegL_iRegL_rule,
  /*  702 */  _Binary_iRegN_iRegN_rule,
  /*  703 */  _Binary_iRegP_iRegP_rule,
  /*  704 */  _Binary_iRegI_iRegI_rule,
  /*  705 */  _Binary_iRegI_iRegI_rule,
  /*  706 */  _Binary_iRegI_iRegI_rule,
  /*  707 */  _Binary_iRegL_iRegL_rule,
  /*  708 */  _Binary_iRegN_iRegN_rule,
  /*  709 */  _Binary_iRegP_iRegP_rule,
  /*  710 */  _Binary_iRegI_iRegI_rule,
  /*  711 */  _Binary_iRegI_iRegI_rule,
  /*  712 */  _Binary_iRegI_iRegI_rule,
  /*  713 */  _Binary_iRegL_iRegL_rule,
  /*  714 */  _Binary_iRegN_iRegN_rule,
  /*  715 */  _Binary_iRegP_iRegP_rule,
  /*  716 */  _Binary_iRegI_iRegI_rule,
  /*  717 */  _Binary_iRegI_iRegI_rule,
  /*  718 */  _Binary_iRegI_iRegI_rule,
  /*  719 */  _Binary_iRegL_iRegL_rule,
  /*  720 */  _Binary_iRegN_iRegN_rule,
  /*  721 */  _Binary_iRegP_iRegP_rule,
  /*  722 */  iRegI_rule,
  /*  723 */  iRegL_rule,
  /*  724 */  iRegN_rule,
  /*  725 */  iRegP_rule,
  /*  726 */  iRegI_rule,
  /*  727 */  iRegL_rule,
  /*  728 */  iRegN_rule,
  /*  729 */  iRegP_rule,
  /*  730 */  iRegL_rule,
  /*  731 */  iRegL_rule,
  /*  732 */  immLAddSub_rule,
  /*  733 */  immLAddSub_rule,
  /*  734 */  iRegIorL2I_rule,
  /*  735 */  iRegIorL2I_rule,
  /*  736 */  immIAddSub_rule,
  /*  737 */  immIAddSub_rule,
  /*  738 */  iRegL_rule,
  /*  739 */  iRegL_rule,
  /*  740 */  immLAddSub_rule,
  /*  741 */  immLAddSub_rule,
  /*  742 */  iRegIorL2I_rule,
  /*  743 */  iRegIorL2I_rule,
  /*  744 */  immIAddSub_rule,
  /*  745 */  immIAddSub_rule,
  /*  746 */  iRegL_rule,
  /*  747 */  immLAddSub_rule,
  /*  748 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  749 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  750 */  _Binary_immI0_iRegIorL2I_rule,
  /*  751 */  _Binary_immI0_iRegIorL2I_rule,
  /*  752 */  _Binary_iRegIorL2I_immI0_rule,
  /*  753 */  _Binary_iRegIorL2I_immI0_rule,
  /*  754 */  _Binary_immI_1_immI0_rule,
  /*  755 */  _Binary_immI_1_immI0_rule,
  /*  756 */  _Binary_iRegL_iRegL_rule,
  /*  757 */  _Binary_iRegL_iRegL_rule,
  /*  758 */  _Binary_iRegL_immL0_rule,
  /*  759 */  _Binary_iRegL_immL0_rule,
  /*  760 */  _Binary_immL0_iRegL_rule,
  /*  761 */  _Binary_immL0_iRegL_rule,
  /*  762 */  _Binary_iRegP_iRegP_rule,
  /*  763 */  _Binary_iRegP_iRegP_rule,
  /*  764 */  _Binary_iRegP_immP0_rule,
  /*  765 */  _Binary_iRegP_immP0_rule,
  /*  766 */  _Binary_immP0_iRegP_rule,
  /*  767 */  _Binary_immP0_iRegP_rule,
  /*  768 */  _Binary_iRegN_iRegN_rule,
  /*  769 */  _Binary_iRegN_iRegN_rule,
  /*  770 */  _Binary_iRegN_immN0_rule,
  /*  771 */  _Binary_iRegN_immN0_rule,
  /*  772 */  _Binary_immN0_iRegN_rule,
  /*  773 */  _Binary_immN0_iRegN_rule,
  /*  774 */  _Binary_vRegF_vRegF_rule,
  /*  775 */  _Binary_vRegF_vRegF_rule,
  /*  776 */  _Binary_vRegD_vRegD_rule,
  /*  777 */  _Binary_vRegD_vRegD_rule,
  /*  778 */  iRegIorL2I_rule,
  /*  779 */  immIAddSub_rule,
  /*  780 */  immIAddSub_rule,
  /*  781 */  iRegL_rule,
  /*  782 */  _ConvI2L_iRegIorL2I__rule,
  /*  783 */  _LShiftL_iRegL_immIScale_rule,
  /*  784 */  _LShiftL__ConvI2L_iRegIorL2I__immIScale_rule,
  /*  785 */  immI_rule,
  /*  786 */  immLAddSub_rule,
  /*  787 */  iRegL_rule,
  /*  788 */  immLAddSub_rule,
  /*  789 */  iRegIorL2I_rule,
  /*  790 */  immIAddSub_rule,
  /*  791 */  iRegL_rule,
  /*  792 */  immLAddSub_rule,
  /*  793 */  iRegIorL2I_rule,
  /*  794 */  iRegL_rule,
  /*  795 */  iRegIorL2I_rule,
  /*  796 */  _ConvI2L_iRegIorL2I__rule,
  /*  797 */  _ConvI2L_iRegIorL2I__rule,
  /*  798 */  iRegL_rule,
  /*  799 */  iRegL_rule,
  /*  800 */  iRegL_rule,
  /*  801 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  802 */  iRegIorL2I_rule,
  /*  803 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  804 */  iRegIorL2I_rule,
  /*  805 */  _SubI_immI0_iRegIorL2I_rule,
  /*  806 */  _MulL_iRegL_iRegL_rule,
  /*  807 */  iRegL_rule,
  /*  808 */  _MulL_iRegL_iRegL_rule,
  /*  809 */  iRegL_rule,
  /*  810 */  _SubL_immL0_iRegL_rule,
  /*  811 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  812 */  iRegLNoSp_rule,
  /*  813 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  814 */  iRegLNoSp_rule,
  /*  815 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  816 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  817 */  _ConvI2L_iRegIorL2I__rule,
  /*  818 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  819 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  820 */  iRegIorL2I_rule,
  /*  821 */  iRegL_rule,
  /*  822 */  iRegIorL2I_rule,
  /*  823 */  iRegL_rule,
  /*  824 */  iRegIorL2I_rule,
  /*  825 */  iRegL_rule,
  /*  826 */  iRegIorL2I_rule,
  /*  827 */  iRegL_rule,
  /*  828 */  iRegIorL2I_rule,
  /*  829 */  immI_rule,
  /*  830 */  iRegIorL2I_rule,
  /*  831 */  immI_rule,
  /*  832 */  iRegIorL2I_rule,
  /*  833 */  immI_rule,
  /*  834 */  iRegIorL2I_rule,
  /*  835 */  immI_rule,
  /*  836 */  iRegIorL2I_rule,
  /*  837 */  immI_rule,
  /*  838 */  immI_rule,
  /*  839 */  iRegIorL2I_rule,
  /*  840 */  immI_rule,
  /*  841 */  immL_M1_rule,
  /*  842 */  immI_M1_rule,
  /*  843 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  844 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  845 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  846 */  _URShiftL_iRegL_immI_rule,
  /*  847 */  _RShiftL_iRegL_immI_rule,
  /*  848 */  _LShiftL_iRegL_immI_rule,
  /*  849 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  850 */  iRegIorL2I_rule,
  /*  851 */  _XorL_iRegL_immL_M1_rule,
  /*  852 */  iRegL_rule,
  /*  853 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  854 */  iRegIorL2I_rule,
  /*  855 */  _XorL_iRegL_immL_M1_rule,
  /*  856 */  iRegL_rule,
  /*  857 */  _XorI_iRegIorL2I_iRegIorL2I_rule,
  /*  858 */  immI_M1_rule,
  /*  859 */  _XorL_iRegL_iRegL_rule,
  /*  860 */  immL_M1_rule,
  /*  861 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  862 */  iRegIorL2I_rule,
  /*  863 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  864 */  iRegL_rule,
  /*  865 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  866 */  iRegIorL2I_rule,
  /*  867 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  868 */  iRegL_rule,
  /*  869 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /*  870 */  iRegIorL2I_rule,
  /*  871 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /*  872 */  iRegL_rule,
  /*  873 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  874 */  iRegIorL2I_rule,
  /*  875 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  876 */  iRegL_rule,
  /*  877 */  _XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  878 */  immI_M1_rule,
  /*  879 */  _XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI_rule,
  /*  880 */  immI_M1_rule,
  /*  881 */  _XorL__URShiftL_iRegL_immI_iRegL_rule,
  /*  882 */  immL_M1_rule,
  /*  883 */  _XorL_iRegL__URShiftL_iRegL_immI_rule,
  /*  884 */  immL_M1_rule,
  /*  885 */  _XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  886 */  immI_M1_rule,
  /*  887 */  _XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI_rule,
  /*  888 */  immI_M1_rule,
  /*  889 */  _XorL__RShiftL_iRegL_immI_iRegL_rule,
  /*  890 */  immL_M1_rule,
  /*  891 */  _XorL_iRegL__RShiftL_iRegL_immI_rule,
  /*  892 */  immL_M1_rule,
  /*  893 */  _XorI__RotateRight_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  894 */  immI_M1_rule,
  /*  895 */  _XorI_iRegIorL2I__RotateRight_iRegIorL2I_immI_rule,
  /*  896 */  immI_M1_rule,
  /*  897 */  _XorL__RotateRight_iRegL_immI_iRegL_rule,
  /*  898 */  immL_M1_rule,
  /*  899 */  _XorL_iRegL__RotateRight_iRegL_immI_rule,
  /*  900 */  immL_M1_rule,
  /*  901 */  _XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  902 */  immI_M1_rule,
  /*  903 */  _XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI_rule,
  /*  904 */  immI_M1_rule,
  /*  905 */  _XorL__LShiftL_iRegL_immI_iRegL_rule,
  /*  906 */  immL_M1_rule,
  /*  907 */  _XorL_iRegL__LShiftL_iRegL_immI_rule,
  /*  908 */  immL_M1_rule,
  /*  909 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  910 */  iRegIorL2I_rule,
  /*  911 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  912 */  iRegL_rule,
  /*  913 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  914 */  iRegIorL2I_rule,
  /*  915 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  916 */  iRegL_rule,
  /*  917 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /*  918 */  iRegIorL2I_rule,
  /*  919 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /*  920 */  iRegL_rule,
  /*  921 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  922 */  iRegIorL2I_rule,
  /*  923 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  924 */  iRegL_rule,
  /*  925 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  926 */  iRegIorL2I_rule,
  /*  927 */  _URShiftL_iRegL_immI_rule,
  /*  928 */  iRegL_rule,
  /*  929 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  930 */  iRegIorL2I_rule,
  /*  931 */  _RShiftL_iRegL_immI_rule,
  /*  932 */  iRegL_rule,
  /*  933 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  934 */  iRegIorL2I_rule,
  /*  935 */  _LShiftL_iRegL_immI_rule,
  /*  936 */  iRegL_rule,
  /*  937 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  938 */  iRegIorL2I_rule,
  /*  939 */  _RotateRight_iRegL_immI_rule,
  /*  940 */  iRegL_rule,
  /*  941 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  942 */  iRegIorL2I_rule,
  /*  943 */  _URShiftL_iRegL_immI_rule,
  /*  944 */  iRegL_rule,
  /*  945 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  946 */  iRegIorL2I_rule,
  /*  947 */  _RShiftL_iRegL_immI_rule,
  /*  948 */  iRegL_rule,
  /*  949 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  950 */  iRegIorL2I_rule,
  /*  951 */  _LShiftL_iRegL_immI_rule,
  /*  952 */  iRegL_rule,
  /*  953 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  954 */  iRegIorL2I_rule,
  /*  955 */  _RotateRight_iRegL_immI_rule,
  /*  956 */  iRegL_rule,
  /*  957 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  958 */  iRegIorL2I_rule,
  /*  959 */  _URShiftL_iRegL_immI_rule,
  /*  960 */  iRegL_rule,
  /*  961 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  962 */  iRegIorL2I_rule,
  /*  963 */  _RShiftL_iRegL_immI_rule,
  /*  964 */  iRegL_rule,
  /*  965 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  966 */  iRegIorL2I_rule,
  /*  967 */  _LShiftL_iRegL_immI_rule,
  /*  968 */  iRegL_rule,
  /*  969 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  970 */  iRegIorL2I_rule,
  /*  971 */  _RotateRight_iRegL_immI_rule,
  /*  972 */  iRegL_rule,
  /*  973 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  974 */  iRegIorL2I_rule,
  /*  975 */  _URShiftL_iRegL_immI_rule,
  /*  976 */  iRegL_rule,
  /*  977 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  978 */  iRegIorL2I_rule,
  /*  979 */  _RShiftL_iRegL_immI_rule,
  /*  980 */  iRegL_rule,
  /*  981 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  982 */  iRegIorL2I_rule,
  /*  983 */  _LShiftL_iRegL_immI_rule,
  /*  984 */  iRegL_rule,
  /*  985 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  986 */  _URShiftL_iRegL_immI_rule,
  /*  987 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  988 */  _RShiftL_iRegL_immI_rule,
  /*  989 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  990 */  _LShiftL_iRegL_immI_rule,
  /*  991 */  immI_rule,
  /*  992 */  immI_rule,
  /*  993 */  immI_rule,
  /*  994 */  immI_rule,
  /*  995 */  immI_bitmask_rule,
  /*  996 */  immL_bitmask_rule,
  /*  997 */  0,
  /*  998 */  immI_rule,
  /*  999 */  immI_rule,
  /* 1000 */  0,
  /* 1001 */  0,
  /* 1002 */  immI_rule,
  /* 1003 */  immI_rule,
  /* 1004 */  0,
  /* 1005 */  _URShiftL_iRegL_immI_rule,
  /* 1006 */  _LShiftL_iRegL_immI_rule,
  /* 1007 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1008 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1009 */  _URShiftL_iRegL_immI_rule,
  /* 1010 */  _LShiftL_iRegL_immI_rule,
  /* 1011 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1012 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1013 */  immI_rule,
  /* 1014 */  immI_rule,
  /* 1015 */  iRegI_rule,
  /* 1016 */  iRegI_rule,
  /* 1017 */  iRegI_rule,
  /* 1018 */  iRegI_rule,
  /* 1019 */  _ConvI2L_iRegIorL2I__rule,
  /* 1020 */  iRegL_rule,
  /* 1021 */  _ConvI2L_iRegIorL2I__rule,
  /* 1022 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /* 1023 */  iRegIorL2I_rule,
  /* 1024 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /* 1025 */  iRegIorL2I_rule,
  /* 1026 */  _URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /* 1027 */  iRegIorL2I_rule,
  /* 1028 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /* 1029 */  iRegL_rule,
  /* 1030 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /* 1031 */  iRegL_rule,
  /* 1032 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /* 1033 */  iRegL_rule,
  /* 1034 */  _URShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /* 1035 */  iRegL_rule,
  /* 1036 */  _AndI_iRegIorL2I_immI_255_rule,
  /* 1037 */  iRegIorL2I_rule,
  /* 1038 */  _AndI_iRegIorL2I_immI_65535_rule,
  /* 1039 */  iRegIorL2I_rule,
  /* 1040 */  _AndL_iRegL_immL_255_rule,
  /* 1041 */  iRegL_rule,
  /* 1042 */  _AndL_iRegL_immL_65535_rule,
  /* 1043 */  iRegL_rule,
  /* 1044 */  _AndL_iRegL_immL_4294967295_rule,
  /* 1045 */  iRegL_rule,
  /* 1046 */  _AndI_iRegIorL2I_immI_255_rule,
  /* 1047 */  _AndI_iRegIorL2I_immI_65535_rule,
  /* 1048 */  _AndL_iRegL_immL_255_rule,
  /* 1049 */  _AndL_iRegL_immL_65535_rule,
  /* 1050 */  _AndL_iRegL_immL_4294967295_rule,
  /* 1051 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /* 1052 */  iRegL_rule,
  /* 1053 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /* 1054 */  iRegL_rule,
  /* 1055 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /* 1056 */  iRegL_rule,
  /* 1057 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /* 1058 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /* 1059 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /* 1060 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /* 1061 */  iRegIorL2I_rule,
  /* 1062 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /* 1063 */  iRegIorL2I_rule,
  /* 1064 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /* 1065 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /* 1066 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /* 1067 */  iRegL_rule,
  /* 1068 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /* 1069 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /* 1070 */  iRegL_rule,
  /* 1071 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /* 1072 */  iRegL_rule,
  /* 1073 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /* 1074 */  iRegL_rule,
  /* 1075 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /* 1076 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /* 1077 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /* 1078 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /* 1079 */  iRegIorL2I_rule,
  /* 1080 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /* 1081 */  iRegIorL2I_rule,
  /* 1082 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /* 1083 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /* 1084 */  vRegF_rule,
  /* 1085 */  vRegD_rule,
  /* 1086 */  vRegF_rule,
  /* 1087 */  vRegD_rule,
  /* 1088 */  vRegF_rule,
  /* 1089 */  vRegD_rule,
  /* 1090 */  _Binary_vRegF_vRegF_rule,
  /* 1091 */  _Binary_vRegD_vRegD_rule,
  /* 1092 */  _Binary__NegF_vRegF__vRegF_rule,
  /* 1093 */  _Binary_vRegF__NegF_vRegF__rule,
  /* 1094 */  _Binary__NegD_vRegD__vRegD_rule,
  /* 1095 */  _Binary_vRegD__NegD_vRegD__rule,
  /* 1096 */  _Binary__NegF_vRegF__vRegF_rule,
  /* 1097 */  _Binary_vRegF__NegF_vRegF__rule,
  /* 1098 */  _Binary__NegD_vRegD__vRegD_rule,
  /* 1099 */  _Binary_vRegD__NegD_vRegD__rule,
  /* 1100 */  _Binary_vRegF_vRegF_rule,
  /* 1101 */  _Binary_vRegD_vRegD_rule,
  /* 1102 */  vRegF_rule,
  /* 1103 */  vRegF_rule,
  /* 1104 */  vRegD_rule,
  /* 1105 */  vRegD_rule,
  /* 1106 */  vRegF_rule,
  /* 1107 */  vRegD_rule,
  /* 1108 */  0,
  /* 1109 */  0,
  /* 1110 */  0,
  /* 1111 */  0,
  /* 1112 */  0,
  /* 1113 */  0,
  /* 1114 */  immI_rule,
  /* 1115 */  _Binary_vRegD_vRegD_rule,
  /* 1116 */  vRegF_rule,
  /* 1117 */  _Binary_vRegD_vRegD_rule,
  /* 1118 */  _Binary_vRegF_vRegF_rule,
  /* 1119 */  0,
  /* 1120 */  iRegIorL2I_rule,
  /* 1121 */  immILog_rule,
  /* 1122 */  iRegIorL2I_rule,
  /* 1123 */  immILog_rule,
  /* 1124 */  iRegIorL2I_rule,
  /* 1125 */  immILog_rule,
  /* 1126 */  iRegL_rule,
  /* 1127 */  immLLog_rule,
  /* 1128 */  iRegL_rule,
  /* 1129 */  immLLog_rule,
  /* 1130 */  iRegL_rule,
  /* 1131 */  immLLog_rule,
  /* 1132 */  0,
  /* 1133 */  immL_32bits_rule,
  /* 1134 */  0,
  /* 1135 */  0,
  /* 1136 */  0,
  /* 1137 */  0,
  /* 1138 */  0,
  /* 1139 */  0,
  /* 1140 */  0,
  /* 1141 */  0,
  /* 1142 */  0,
  /* 1143 */  0,
  /* 1144 */  0,
  /* 1145 */  0,
  /* 1146 */  0,
  /* 1147 */  0,
  /* 1148 */  0,
  /* 1149 */  0,
  /* 1150 */  0,
  /* 1151 */  0,
  /* 1152 */  0,
  /* 1153 */  0,
  /* 1154 */  0,
  /* 1155 */  iRegP_R10_rule,
  /* 1156 */  iRegP_R10_rule,
  /* 1157 */  _OverflowMulI_iRegIorL2I_iRegIorL2I_rule,
  /* 1158 */  _OverflowMulL_iRegL_iRegL_rule,
  /* 1159 */  vRegF_rule,
  /* 1160 */  vRegD_rule,
  /* 1161 */  immF0_rule,
  /* 1162 */  immD0_rule,
  /* 1163 */  iRegIorL2I_rule,
  /* 1164 */  immI0_rule,
  /* 1165 */  0,
  /* 1166 */  iRegI_rule,
  /* 1167 */  0,
  /* 1168 */  iRegI_rule,
  /* 1169 */  0,
  /* 1170 */  rFlagsReg_rule,
  /* 1171 */  rFlagsRegU_rule,
  /* 1172 */  _CmpI_iRegIorL2I_immI0_rule,
  /* 1173 */  _CmpL_iRegL_immL0_rule,
  /* 1174 */  _CmpP_iRegP_immP0_rule,
  /* 1175 */  _CmpN_iRegN_immN0_rule,
  /* 1176 */  _CmpP__DecodeN_iRegN__immP0_rule,
  /* 1177 */  _CmpU_iRegIorL2I_immI0_rule,
  /* 1178 */  _CmpUL_iRegL_immL0_rule,
  /* 1179 */  _CmpL_iRegL_immL0_rule,
  /* 1180 */  _CmpI_iRegIorL2I_immI0_rule,
  /* 1181 */  _CmpL__AndL_iRegL_immL_immL0_rule,
  /* 1182 */  _CmpI__AndI_iRegIorL2I_immI_immI0_rule,
  /* 1183 */  _CmpL_iRegL_immL0_rule,
  /* 1184 */  _CmpI_iRegIorL2I_immI0_rule,
  /* 1185 */  _CmpL__AndL_iRegL_immL_immL0_rule,
  /* 1186 */  _CmpI__AndI_iRegIorL2I_immI_immI0_rule,
  /* 1187 */  rFlagsReg_rule,
  /* 1188 */  rFlagsRegU_rule,
  /* 1189 */  0,
  /* 1190 */  0,
  /* 1191 */  0,
  /* 1192 */  0,
  /* 1193 */  0,
  /* 1194 */  0,
  /* 1195 */  inline_cache_RegP_rule,
  /* 1196 */  iRegP_R0_rule,
  /* 1197 */  0,
  /* 1198 */  0,
  /* 1199 */  0,
  /* 1200 */  0,
  /* 1201 */  iRegP_R0_rule,
  /* 1202 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1203 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1204 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1205 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1206 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1207 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1208 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1209 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1210 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /* 1211 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /* 1212 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /* 1213 */  _Binary_iRegP_R3_immI_le_4_rule,
  /* 1214 */  _Binary_iRegP_R3_immI_le_4_rule,
  /* 1215 */  _Binary_iRegP_R3_immI_1_rule,
  /* 1216 */  iRegI_R3_rule,
  /* 1217 */  iRegI_R3_rule,
  /* 1218 */  iRegI_R3_rule,
  /* 1219 */  iRegI_R3_rule,
  /* 1220 */  iRegI_R4_rule,
  /* 1221 */  iRegI_R4_rule,
  /* 1222 */  iRegP_R2_rule,
  /* 1223 */  iRegP_R2_rule,
  /* 1224 */  iRegI_R2_rule,
  /* 1225 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /* 1226 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1227 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /* 1228 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /* 1229 */  0,
  /* 1230 */  vReg_rule,
  /* 1231 */  0,
  /* 1232 */  vReg_rule,
  /* 1233 */  0,
  /* 1234 */  vReg_rule,
  /* 1235 */  0,
  /* 1236 */  vReg_rule,
  /* 1237 */  0,
  /* 1238 */  vReg_rule,
  /* 1239 */  pRegGov_rule,
  /* 1240 */  _Binary_vReg_pRegGov_rule,
  /* 1241 */  vReg_rule,
  /* 1242 */  vReg_rule,
  /* 1243 */  vReg_rule,
  /* 1244 */  vReg_rule,
  /* 1245 */  vReg_rule,
  /* 1246 */  vReg_rule,
  /* 1247 */  pRegGov_rule,
  /* 1248 */  pRegGov_rule,
  /* 1249 */  pRegGov_rule,
  /* 1250 */  pRegGov_rule,
  /* 1251 */  pRegGov_rule,
  /* 1252 */  pRegGov_rule,
  /* 1253 */  _ReplicateB_immBAddSubV__rule,
  /* 1254 */  vReg_rule,
  /* 1255 */  _ReplicateS_immIAddSubV__rule,
  /* 1256 */  vReg_rule,
  /* 1257 */  _ReplicateI_immIAddSubV__rule,
  /* 1258 */  vReg_rule,
  /* 1259 */  _ReplicateL_immLAddSubV__rule,
  /* 1260 */  vReg_rule,
  /* 1261 */  vReg_rule,
  /* 1262 */  vReg_rule,
  /* 1263 */  vReg_rule,
  /* 1264 */  vReg_rule,
  /* 1265 */  vReg_rule,
  /* 1266 */  vReg_rule,
  /* 1267 */  pRegGov_rule,
  /* 1268 */  pRegGov_rule,
  /* 1269 */  pRegGov_rule,
  /* 1270 */  pRegGov_rule,
  /* 1271 */  pRegGov_rule,
  /* 1272 */  pRegGov_rule,
  /* 1273 */  vReg_rule,
  /* 1274 */  vReg_rule,
  /* 1275 */  vReg_rule,
  /* 1276 */  vReg_rule,
  /* 1277 */  vReg_rule,
  /* 1278 */  vReg_rule,
  /* 1279 */  vReg_rule,
  /* 1280 */  vReg_rule,
  /* 1281 */  vReg_rule,
  /* 1282 */  vReg_rule,
  /* 1283 */  pRegGov_rule,
  /* 1284 */  pRegGov_rule,
  /* 1285 */  pRegGov_rule,
  /* 1286 */  pRegGov_rule,
  /* 1287 */  pRegGov_rule,
  /* 1288 */  pRegGov_rule,
  /* 1289 */  vReg_rule,
  /* 1290 */  vReg_rule,
  /* 1291 */  vReg_rule,
  /* 1292 */  vReg_rule,
  /* 1293 */  pRegGov_rule,
  /* 1294 */  pRegGov_rule,
  /* 1295 */  vReg_rule,
  /* 1296 */  pRegGov_rule,
  /* 1297 */  _ReplicateB_immBLog__rule,
  /* 1298 */  vReg_rule,
  /* 1299 */  _ReplicateS_immSLog__rule,
  /* 1300 */  vReg_rule,
  /* 1301 */  _ReplicateI_immILog__rule,
  /* 1302 */  vReg_rule,
  /* 1303 */  _ReplicateL_immLLog__rule,
  /* 1304 */  vReg_rule,
  /* 1305 */  vReg_rule,
  /* 1306 */  pRegGov_rule,
  /* 1307 */  _ReplicateB_immBLog__rule,
  /* 1308 */  vReg_rule,
  /* 1309 */  _ReplicateS_immSLog__rule,
  /* 1310 */  vReg_rule,
  /* 1311 */  _ReplicateI_immILog__rule,
  /* 1312 */  vReg_rule,
  /* 1313 */  _ReplicateL_immLLog__rule,
  /* 1314 */  vReg_rule,
  /* 1315 */  vReg_rule,
  /* 1316 */  pRegGov_rule,
  /* 1317 */  _ReplicateB_immBLog__rule,
  /* 1318 */  vReg_rule,
  /* 1319 */  _ReplicateS_immSLog__rule,
  /* 1320 */  vReg_rule,
  /* 1321 */  _ReplicateI_immILog__rule,
  /* 1322 */  vReg_rule,
  /* 1323 */  _ReplicateL_immLLog__rule,
  /* 1324 */  vReg_rule,
  /* 1325 */  _XorV_vReg_vReg_rule,
  /* 1326 */  vReg_rule,
  /* 1327 */  _XorV_vReg_vReg_rule,
  /* 1328 */  vReg_rule,
  /* 1329 */  _ReplicateB_immI_M1__rule,
  /* 1330 */  vReg_rule,
  /* 1331 */  _ReplicateS_immI_M1__rule,
  /* 1332 */  vReg_rule,
  /* 1333 */  _ReplicateI_immI_M1__rule,
  /* 1334 */  vReg_rule,
  /* 1335 */  _ReplicateL_immL_M1__rule,
  /* 1336 */  vReg_rule,
  /* 1337 */  pRegGov_rule,
  /* 1338 */  pRegGov_rule,
  /* 1339 */  pRegGov_rule,
  /* 1340 */  pRegGov_rule,
  /* 1341 */  _XorV_vReg__ReplicateB_immI_M1__rule,
  /* 1342 */  vReg_rule,
  /* 1343 */  _XorV__ReplicateB_immI_M1__vReg_rule,
  /* 1344 */  vReg_rule,
  /* 1345 */  _XorV_vReg__ReplicateS_immI_M1__rule,
  /* 1346 */  vReg_rule,
  /* 1347 */  _XorV__ReplicateS_immI_M1__vReg_rule,
  /* 1348 */  vReg_rule,
  /* 1349 */  _XorV_vReg__ReplicateI_immI_M1__rule,
  /* 1350 */  vReg_rule,
  /* 1351 */  _XorV__ReplicateI_immI_M1__vReg_rule,
  /* 1352 */  vReg_rule,
  /* 1353 */  _XorV_vReg__ReplicateL_immL_M1__rule,
  /* 1354 */  vReg_rule,
  /* 1355 */  _XorV__ReplicateL_immL_M1__vReg_rule,
  /* 1356 */  vReg_rule,
  /* 1357 */  pRegGov_rule,
  /* 1358 */  pRegGov_rule,
  /* 1359 */  pRegGov_rule,
  /* 1360 */  pRegGov_rule,
  /* 1361 */  pRegGov_rule,
  /* 1362 */  pRegGov_rule,
  /* 1363 */  pRegGov_rule,
  /* 1364 */  pRegGov_rule,
  /* 1365 */  pRegGov_rule,
  /* 1366 */  pRegGov_rule,
  /* 1367 */  pRegGov_rule,
  /* 1368 */  pRegGov_rule,
  /* 1369 */  pRegGov_rule,
  /* 1370 */  pRegGov_rule,
  /* 1371 */  0,
  /* 1372 */  0,
  /* 1373 */  0,
  /* 1374 */  0,
  /* 1375 */  pRegGov_rule,
  /* 1376 */  pRegGov_rule,
  /* 1377 */  pRegGov_rule,
  /* 1378 */  pRegGov_rule,
  /* 1379 */  pRegGov_rule,
  /* 1380 */  pRegGov_rule,
  /* 1381 */  pRegGov_rule,
  /* 1382 */  pRegGov_rule,
  /* 1383 */  vReg_rule,
  /* 1384 */  vReg_rule,
  /* 1385 */  vReg_rule,
  /* 1386 */  vReg_rule,
  /* 1387 */  pRegGov_rule,
  /* 1388 */  vReg_rule,
  /* 1389 */  vReg_rule,
  /* 1390 */  vReg_rule,
  /* 1391 */  vReg_rule,
  /* 1392 */  pRegGov_rule,
  /* 1393 */  _MulVB_vReg_vReg_rule,
  /* 1394 */  vReg_rule,
  /* 1395 */  _MulVS_vReg_vReg_rule,
  /* 1396 */  vReg_rule,
  /* 1397 */  _MulVI_vReg_vReg_rule,
  /* 1398 */  vReg_rule,
  /* 1399 */  _MulVL_vReg_vReg_rule,
  /* 1400 */  vReg_rule,
  /* 1401 */  pRegGov_rule,
  /* 1402 */  pRegGov_rule,
  /* 1403 */  pRegGov_rule,
  /* 1404 */  pRegGov_rule,
  /* 1405 */  _Binary_vReg_vReg_rule,
  /* 1406 */  _Binary_vReg_vReg_rule,
  /* 1407 */  _Binary_vReg_pRegGov_rule,
  /* 1408 */  _Binary_vReg_pRegGov_rule,
  /* 1409 */  _MulVB_vReg_vReg_rule,
  /* 1410 */  _MulVS_vReg_vReg_rule,
  /* 1411 */  _MulVI_vReg_vReg_rule,
  /* 1412 */  _MulVL_vReg_vReg_rule,
  /* 1413 */  pRegGov_rule,
  /* 1414 */  pRegGov_rule,
  /* 1415 */  pRegGov_rule,
  /* 1416 */  pRegGov_rule,
  /* 1417 */  _Binary__NegVF_vReg__vReg_rule,
  /* 1418 */  _Binary__NegVD_vReg__vReg_rule,
  /* 1419 */  _Binary_vReg__NegVF_vReg__rule,
  /* 1420 */  _Binary_vReg__NegVD_vReg__rule,
  /* 1421 */  _Binary_vReg_pRegGov_rule,
  /* 1422 */  _Binary_vReg_pRegGov_rule,
  /* 1423 */  _Binary__NegVF_vReg__vReg_rule,
  /* 1424 */  _Binary__NegVD_vReg__vReg_rule,
  /* 1425 */  _Binary_vReg__NegVF_vReg__rule,
  /* 1426 */  _Binary_vReg__NegVD_vReg__rule,
  /* 1427 */  _Binary__NegVF_vReg__pRegGov_rule,
  /* 1428 */  _Binary__NegVD_vReg__pRegGov_rule,
  /* 1429 */  _Binary_vReg_vReg_rule,
  /* 1430 */  _Binary_vReg_vReg_rule,
  /* 1431 */  _Binary__NegVF_vReg__pRegGov_rule,
  /* 1432 */  _Binary__NegVD_vReg__pRegGov_rule,
  /* 1433 */  vReg_rule,
  /* 1434 */  vReg_rule,
  /* 1435 */  vReg_rule,
  /* 1436 */  vReg_rule,
  /* 1437 */  vReg_rule,
  /* 1438 */  vReg_rule,
  /* 1439 */  vReg_rule,
  /* 1440 */  vReg_rule,
  /* 1441 */  vReg_rule,
  /* 1442 */  vReg_rule,
  /* 1443 */  vReg_rule,
  /* 1444 */  vReg_rule,
  /* 1445 */  vReg_rule,
  /* 1446 */  vReg_rule,
  /* 1447 */  vReg_rule,
  /* 1448 */  vReg_rule,
  /* 1449 */  vReg_rule,
  /* 1450 */  vReg_rule,
  /* 1451 */  vReg_rule,
  /* 1452 */  vReg_rule,
  /* 1453 */  vReg_rule,
  /* 1454 */  vReg_rule,
  /* 1455 */  vReg_rule,
  /* 1456 */  vReg_rule,
  /* 1457 */  vReg_rule,
  /* 1458 */  vReg_rule,
  /* 1459 */  vReg_rule,
  /* 1460 */  vReg_rule,
  /* 1461 */  vReg_rule,
  /* 1462 */  vReg_rule,
  /* 1463 */  vReg_rule,
  /* 1464 */  vReg_rule,
  /* 1465 */  vReg_rule,
  /* 1466 */  _LShiftCntV_immI__rule,
  /* 1467 */  _LShiftCntV_immI__rule,
  /* 1468 */  _LShiftCntV_immI__rule,
  /* 1469 */  _LShiftCntV_immI__rule,
  /* 1470 */  _RShiftCntV_immI_positive__rule,
  /* 1471 */  _RShiftCntV_immI_positive__rule,
  /* 1472 */  _RShiftCntV_immI_positive__rule,
  /* 1473 */  _RShiftCntV_immI_positive__rule,
  /* 1474 */  _RShiftCntV_immI_positive__rule,
  /* 1475 */  _RShiftCntV_immI_positive__rule,
  /* 1476 */  _RShiftCntV_immI_positive__rule,
  /* 1477 */  _RShiftCntV_immI_positive__rule,
  /* 1478 */  _RShiftVB_vReg__RShiftCntV_immI_positive__rule,
  /* 1479 */  vReg_rule,
  /* 1480 */  _RShiftVS_vReg__RShiftCntV_immI_positive__rule,
  /* 1481 */  vReg_rule,
  /* 1482 */  _RShiftVI_vReg__RShiftCntV_immI_positive__rule,
  /* 1483 */  vReg_rule,
  /* 1484 */  _RShiftVL_vReg__RShiftCntV_immI_positive__rule,
  /* 1485 */  vReg_rule,
  /* 1486 */  _URShiftVB_vReg__RShiftCntV_immI_positive__rule,
  /* 1487 */  vReg_rule,
  /* 1488 */  _URShiftVS_vReg__RShiftCntV_immI_positive__rule,
  /* 1489 */  vReg_rule,
  /* 1490 */  _URShiftVI_vReg__RShiftCntV_immI_positive__rule,
  /* 1491 */  vReg_rule,
  /* 1492 */  _URShiftVL_vReg__RShiftCntV_immI_positive__rule,
  /* 1493 */  vReg_rule,
  /* 1494 */  pRegGov_rule,
  /* 1495 */  pRegGov_rule,
  /* 1496 */  pRegGov_rule,
  /* 1497 */  pRegGov_rule,
  /* 1498 */  pRegGov_rule,
  /* 1499 */  pRegGov_rule,
  /* 1500 */  pRegGov_rule,
  /* 1501 */  pRegGov_rule,
  /* 1502 */  pRegGov_rule,
  /* 1503 */  pRegGov_rule,
  /* 1504 */  pRegGov_rule,
  /* 1505 */  pRegGov_rule,
  /* 1506 */  pRegGov_rule,
  /* 1507 */  pRegGov_rule,
  /* 1508 */  pRegGov_rule,
  /* 1509 */  pRegGov_rule,
  /* 1510 */  pRegGov_rule,
  /* 1511 */  pRegGov_rule,
  /* 1512 */  pRegGov_rule,
  /* 1513 */  pRegGov_rule,
  /* 1514 */  pRegGov_rule,
  /* 1515 */  pRegGov_rule,
  /* 1516 */  pRegGov_rule,
  /* 1517 */  pRegGov_rule,
  /* 1518 */  vReg_rule,
  /* 1519 */  vReg_rule,
  /* 1520 */  vReg_rule,
  /* 1521 */  vReg_rule,
  /* 1522 */  vReg_rule,
  /* 1523 */  vReg_rule,
  /* 1524 */  vReg_rule,
  /* 1525 */  vReg_rule,
  /* 1526 */  pRegGov_rule,
  /* 1527 */  pRegGov_rule,
  /* 1528 */  pRegGov_rule,
  /* 1529 */  pRegGov_rule,
  /* 1530 */  vReg_rule,
  /* 1531 */  vReg_rule,
  /* 1532 */  vReg_rule,
  /* 1533 */  vReg_rule,
  /* 1534 */  vReg_rule,
  /* 1535 */  vReg_rule,
  /* 1536 */  vReg_rule,
  /* 1537 */  vReg_rule,
  /* 1538 */  pRegGov_rule,
  /* 1539 */  pRegGov_rule,
  /* 1540 */  vReg_rule,
  /* 1541 */  vReg_rule,
  /* 1542 */  vReg_rule,
  /* 1543 */  vReg_rule,
  /* 1544 */  pRegGov_rule,
  /* 1545 */  pRegGov_rule,
  /* 1546 */  vReg_rule,
  /* 1547 */  vReg_rule,
  /* 1548 */  vReg_rule,
  /* 1549 */  vReg_rule,
  /* 1550 */  pRegGov_rule,
  /* 1551 */  pRegGov_rule,
  /* 1552 */  vReg_rule,
  /* 1553 */  vReg_rule,
  /* 1554 */  vReg_rule,
  /* 1555 */  vReg_rule,
  /* 1556 */  vReg_rule,
  /* 1557 */  vReg_rule,
  /* 1558 */  pRegGov_rule,
  /* 1559 */  pRegGov_rule,
  /* 1560 */  pRegGov_rule,
  /* 1561 */  pRegGov_rule,
  /* 1562 */  vReg_rule,
  /* 1563 */  vReg_rule,
  /* 1564 */  vReg_rule,
  /* 1565 */  vReg_rule,
  /* 1566 */  vReg_rule,
  /* 1567 */  vReg_rule,
  /* 1568 */  pRegGov_rule,
  /* 1569 */  pRegGov_rule,
  /* 1570 */  pRegGov_rule,
  /* 1571 */  pRegGov_rule,
  /* 1572 */  0,
  /* 1573 */  0,
  /* 1574 */  0,
  /* 1575 */  0,
  /* 1576 */  0,
  /* 1577 */  0,
  /* 1578 */  0,
  /* 1579 */  0,
  /* 1580 */  0,
  /* 1581 */  0,
  /* 1582 */  0,
  /* 1583 */  0,
  /* 1584 */  immI_rule,
  /* 1585 */  immI_rule,
  /* 1586 */  immI_rule,
  /* 1587 */  immI_rule,
  /* 1588 */  immI_rule,
  /* 1589 */  immI_rule,
  /* 1590 */  immI_rule,
  /* 1591 */  immI_rule,
  /* 1592 */  immI_rule,
  /* 1593 */  immI_rule,
  /* 1594 */  immI_rule,
  /* 1595 */  immI_rule,
  /* 1596 */  immI_rule,
  /* 1597 */  immI_rule,
  /* 1598 */  immI_rule,
  /* 1599 */  immI_rule,
  /* 1600 */  immI_rule,
  /* 1601 */  immI_rule,
  /* 1602 */  immI_rule,
  /* 1603 */  immI_rule,
  /* 1604 */  0,
  /* 1605 */  0,
  /* 1606 */  pRegGov_rule,
  /* 1607 */  pRegGov_rule,
  /* 1608 */  immI_1_rule,
  /* 1609 */  immI_gt_1_rule,
  /* 1610 */  immI_1_rule,
  /* 1611 */  immI_gt_1_rule,
  /* 1612 */  0,
  /* 1613 */  pRegGov_rule,
  /* 1614 */  0,
  /* 1615 */  pRegGov_rule,
  /* 1616 */  _VectorStoreMask_pReg_immI_gt_1_rule,
  /* 1617 */  _VectorStoreMask_pReg_immI_gt_1_rule,
  /* 1618 */  _Binary__VectorStoreMask_pReg_immI_gt_1_pRegGov_rule,
  /* 1619 */  _Binary__VectorStoreMask_pReg_immI_gt_1_pRegGov_rule,
  /* 1620 */  pReg_rule,
  /* 1621 */  pReg_rule,
  /* 1622 */  pReg_rule,
  /* 1623 */  _XorVMask_pReg__MaskAll_immI_M1__rule,
  /* 1624 */  _XorVMask_pReg__MaskAll_immL_M1__rule,
  /* 1625 */  immI_rule,
  /* 1626 */  immI_rule,
  /* 1627 */  _Binary_immI_pRegGov_rule,
  /* 1628 */  0,
  /* 1629 */  0,
  /* 1630 */  0,
  /* 1631 */  0,
  /* 1632 */  pReg_rule,
  /* 1633 */  0,
  /* 1634 */  0,
  /* 1635 */  0,
  /* 1636 */  0,
  /* 1637 */  0,
  /* 1638 */  pRegGov_rule,
  /* 1639 */  0,
  /* 1640 */  0,
  /* 1641 */  pRegGov_rule,
  /* 1642 */  0,
  /* 1643 */  0,
  /* 1644 */  0,
  /* 1645 */  pRegGov_rule,
  /* 1646 */  pRegGov_rule,
  /* 1647 */  vReg_rule,
  /* 1648 */  pReg_rule,
  /* 1649 */  _Binary_vReg_vReg_rule,
  /* 1650 */  _Binary_vReg_vReg_rule,
  /* 1651 */  _Binary_vReg_vReg_rule,
  /* 1652 */  _Binary_vReg_vReg_rule,
  /* 1653 */  0,
  /* 1654 */  0,
  /* 1655 */  0,
  /* 1656 */  0,
  /* 1657 */  immI_rule,
  /* 1658 */  vReg_rule,
  /* 1659 */  pReg_rule,
  /* 1660 */  vReg_rule,
  /* 1661 */  pReg_rule,
  /* 1662 */  vReg_rule,
  /* 1663 */  vReg_rule,
  /* 1664 */  vReg_rule,
  /* 1665 */  vReg_rule,
  /* 1666 */  _Binary_vReg_pRegGov_rule,
  /* 1667 */  _Binary_vReg_pRegGov_rule,
  /* 1668 */  _Binary_vReg_vReg_rule,
  /* 1669 */  _Binary_vReg_vReg_rule,
  /* 1670 */  _Binary_vReg__Binary_vReg_pRegGov_rule,
  /* 1671 */  _Binary_vReg__Binary_vReg_pRegGov_rule,
  /* 1672 */  pRegGov_rule,
  /* 1673 */  pRegGov_rule,
  /* 1674 */  pRegGov_rule,
  /* 1675 */  pRegGov_rule,
  /* 1676 */  immI_rule,
  /* 1677 */  0,
  /* 1678 */  pRegGov_rule,
  /* 1679 */  pReg_rule,
  /* 1680 */  pReg_rule,
  /* 1681 */  pRegGov_rule,
  /* 1682 */  _Binary_vReg_vReg_rule,
  /* 1683 */  _Binary_vReg_vReg_rule,
  /* 1684 */  _Binary_vReg_vReg_rule,
  /* 1685 */  _Binary_vReg_vReg_rule,
  /* 1686 */  _Binary_iRegP_iRegP_rule,
  /* 1687 */  _Binary_iRegN_iRegN_rule,
  /* 1688 */  _Binary_iRegP_iRegP_rule,
  /* 1689 */  _Binary_iRegN_iRegN_rule,
  /* 1690 */  _Binary_iRegN_iRegN_rule,
  /* 1691 */  _Binary_iRegP_iRegP_rule,
  /* 1692 */  _Binary_iRegN_iRegN_rule,
  /* 1693 */  _Binary_iRegP_iRegP_rule,
  /* 1694 */  _Binary_iRegN_iRegN_rule,
  /* 1695 */  _Binary_iRegP_iRegP_rule,
  /* 1696 */  _Binary_iRegN_iRegN_rule,
  /* 1697 */  _Binary_iRegP_iRegP_rule,
  /* 1698 */  0,
  /* 1699 */  0,
  /* 1700 */  _Binary_iRegP_iRegP_rule,
  /* 1701 */  _Binary_iRegP_iRegP_rule,
  /* 1702 */  _Binary_iRegP_iRegP_rule,
  /* 1703 */  _Binary_iRegP_iRegP_rule,
  /* 1704 */  _Binary_iRegP_iRegP_rule,
  /* 1705 */  _Binary_iRegP_iRegP_rule,
  /* 1706 */  iRegP_rule,
  /* 1707 */  iRegP_rule,
  // last instruction
  0 // no trailing comma
};

const char        *ruleName[] = {
  /*    0 */  "UNIVERSE",
  /*    1 */  "LABEL",
  /*    2 */  "SREGI",
  /*    3 */  "SREGP",
  /*    4 */  "SREGF",
  /*    5 */  "SREGD",
  /*    6 */  "SREGL",
  /*    7 */  "METHOD",
  /*    8 */  "IMMI",
  /*    9 */  "IMMI0",
  /*   10 */  "IMMI_1",
  /*   11 */  "IMMI_M1",
  /*   12 */  "IMMIEXT",
  /*   13 */  "IMMI_GT_1",
  /*   14 */  "IMMI_LE_4",
  /*   15 */  "IMMI_16",
  /*   16 */  "IMMI_24",
  /*   17 */  "IMMI_32",
  /*   18 */  "IMMI_48",
  /*   19 */  "IMMI_56",
  /*   20 */  "IMMI_63",
  /*   21 */  "IMMI_64",
  /*   22 */  "IMMI_255",
  /*   23 */  "IMMI_65535",
  /*   24 */  "IMMI_POSITIVE",
  /*   25 */  "IMML_255",
  /*   26 */  "IMML_65535",
  /*   27 */  "IMML_4294967295",
  /*   28 */  "IMML_BITMASK",
  /*   29 */  "IMMI_BITMASK",
  /*   30 */  "IMML_POSITIVE_BITMASKI",
  /*   31 */  "IMMISCALE",
  /*   32 */  "IMMI26",
  /*   33 */  "IMMI19",
  /*   34 */  "IMMIU12",
  /*   35 */  "IMMLU12",
  /*   36 */  "IMMIOFFSET",
  /*   37 */  "IMMIOFFSET1",
  /*   38 */  "IMMIOFFSET2",
  /*   39 */  "IMMIOFFSET4",
  /*   40 */  "IMMIOFFSET8",
  /*   41 */  "IMMIOFFSET16",
  /*   42 */  "IMMLOFFSET",
  /*   43 */  "IMMLOFFSET1",
  /*   44 */  "IMMLOFFSET2",
  /*   45 */  "IMMLOFFSET4",
  /*   46 */  "IMMLOFFSET8",
  /*   47 */  "IMMLOFFSET16",
  /*   48 */  "IMMI8",
  /*   49 */  "IMMI8_SHIFT8",
  /*   50 */  "IMML8_SHIFT8",
  /*   51 */  "IMMBADDSUBV",
  /*   52 */  "IMMIADDSUB",
  /*   53 */  "IMMIADDSUBV",
  /*   54 */  "IMMBLOG",
  /*   55 */  "IMMSLOG",
  /*   56 */  "IMMILOG",
  /*   57 */  "IMML",
  /*   58 */  "IMML0",
  /*   59 */  "IMML_1",
  /*   60 */  "IMML_M1",
  /*   61 */  "IMML_PC_OFF",
  /*   62 */  "IMMLADDSUB",
  /*   63 */  "IMMLADDSUBV",
  /*   64 */  "IMMLLOG",
  /*   65 */  "IMML_32BITS",
  /*   66 */  "IMMP",
  /*   67 */  "IMMP0",
  /*   68 */  "IMMP_1",
  /*   69 */  "IMMBYTEMAPBASE",
  /*   70 */  "IMMP_M1",
  /*   71 */  "IMMP_M2",
  /*   72 */  "IMMD",
  /*   73 */  "IMMD0",
  /*   74 */  "IMMDPACKED",
  /*   75 */  "IMMF",
  /*   76 */  "IMMF0",
  /*   77 */  "IMMFPACKED",
  /*   78 */  "IMMN",
  /*   79 */  "IMMN0",
  /*   80 */  "IMMNKLASS",
  /*   81 */  "IREGI",
  /*   82 */  "IREGINOSP",
  /*   83 */  "IREGL",
  /*   84 */  "IREGLNOSP",
  /*   85 */  "IREGP",
  /*   86 */  "IREGPNOSP",
  /*   87 */  "IREGP_R0",
  /*   88 */  "IREGP_R1",
  /*   89 */  "IREGP_R2",
  /*   90 */  "IREGP_R3",
  /*   91 */  "IREGP_R4",
  /*   92 */  "IREGP_R5",
  /*   93 */  "IREGP_R10",
  /*   94 */  "IREGL_R0",
  /*   95 */  "IREGL_R2",
  /*   96 */  "IREGL_R3",
  /*   97 */  "IREGL_R11",
  /*   98 */  "IREGP_FP",
  /*   99 */  "IREGI_R0",
  /*  100 */  "IREGI_R2",
  /*  101 */  "IREGI_R3",
  /*  102 */  "IREGI_R4",
  /*  103 */  "IREGN",
  /*  104 */  "IREGN_R0",
  /*  105 */  "IREGN_R2",
  /*  106 */  "IREGN_R3",
  /*  107 */  "IREGNNOSP",
  /*  108 */  "IREGIHEAPBASE",
  /*  109 */  "VREGF",
  /*  110 */  "VREGD",
  /*  111 */  "VREG",
  /*  112 */  "VECA",
  /*  113 */  "VECD",
  /*  114 */  "VECX",
  /*  115 */  "VREGD_V0",
  /*  116 */  "VREGD_V1",
  /*  117 */  "VREGD_V2",
  /*  118 */  "VREGD_V3",
  /*  119 */  "VREGD_V4",
  /*  120 */  "VREGD_V5",
  /*  121 */  "VREGD_V6",
  /*  122 */  "VREGD_V7",
  /*  123 */  "VREGD_V8",
  /*  124 */  "VREGD_V9",
  /*  125 */  "VREGD_V10",
  /*  126 */  "VREGD_V11",
  /*  127 */  "VREGD_V12",
  /*  128 */  "VREGD_V13",
  /*  129 */  "VREGD_V14",
  /*  130 */  "VREGD_V15",
  /*  131 */  "VREGD_V16",
  /*  132 */  "VREGD_V17",
  /*  133 */  "VREGD_V18",
  /*  134 */  "VREGD_V19",
  /*  135 */  "VREGD_V20",
  /*  136 */  "VREGD_V21",
  /*  137 */  "VREGD_V22",
  /*  138 */  "VREGD_V23",
  /*  139 */  "VREGD_V24",
  /*  140 */  "VREGD_V25",
  /*  141 */  "VREGD_V26",
  /*  142 */  "VREGD_V27",
  /*  143 */  "VREGD_V28",
  /*  144 */  "VREGD_V29",
  /*  145 */  "VREGD_V30",
  /*  146 */  "VREGD_V31",
  /*  147 */  "PREG",
  /*  148 */  "PREGGOV",
  /*  149 */  "PREGGOV_P0",
  /*  150 */  "PREGGOV_P1",
  /*  151 */  "RFLAGSREG",
  /*  152 */  "RFLAGSREGU",
  /*  153 */  "INLINE_CACHE_REGP",
  /*  154 */  "THREAD_REGP",
  /*  155 */  "LR_REGP",
  /*  156 */  "INDIRECT",
  /*  157 */  "INDINDEXSCALEDI2L",
  /*  158 */  "INDINDEXSCALED",
  /*  159 */  "INDINDEXI2L",
  /*  160 */  "INDINDEX",
  /*  161 */  "INDOFFI",
  /*  162 */  "INDOFFI1",
  /*  163 */  "INDOFFI2",
  /*  164 */  "INDOFFI4",
  /*  165 */  "INDOFFI8",
  /*  166 */  "INDOFFI16",
  /*  167 */  "INDOFFL",
  /*  168 */  "INDOFFL1",
  /*  169 */  "INDOFFL2",
  /*  170 */  "INDOFFL4",
  /*  171 */  "INDOFFL8",
  /*  172 */  "INDOFFL16",
  /*  173 */  "INDIRECTN",
  /*  174 */  "INDINDEXSCALEDI2LN",
  /*  175 */  "INDINDEXSCALEDN",
  /*  176 */  "INDINDEXI2LN",
  /*  177 */  "INDINDEXN",
  /*  178 */  "INDOFFIN",
  /*  179 */  "INDOFFLN",
  /*  180 */  "THREAD_ANCHOR_PC",
  /*  181 */  "STACKSLOTP",
  /*  182 */  "STACKSLOTI",
  /*  183 */  "STACKSLOTF",
  /*  184 */  "STACKSLOTD",
  /*  185 */  "STACKSLOTL",
  /*  186 */  "CMPOP",
  /*  187 */  "CMPOPU",
  /*  188 */  "CMPOPEQNE",
  /*  189 */  "CMPOPLTGE",
  /*  190 */  "CMPOPUEQNELTGE",
  /*  191 */  "IREGL2I",
  /*  192 */  "VMEMA_IMMIOFFSET4",
  /*  193 */  "VMEMA_IMMLOFFSET4",
  /*  194 */  "VMEMA_INDOFFI4",
  /*  195 */  "VMEMA_INDOFFL4",
  // last operand
  /*  196 */  "VMEM2",
  /*  197 */  "VMEM4",
  /*  198 */  "VMEM8",
  /*  199 */  "VMEM16",
  /*  200 */  "MEMORY1",
  /*  201 */  "MEMORY2",
  /*  202 */  "MEMORY4",
  /*  203 */  "MEMORY8",
  /*  204 */  "MEMORY",
  /*  205 */  "IREGIORL2I",
  /*  206 */  "VMEMA",
  // last operand class
  /*  207 */  "_ConvI2L_iRegI_",
  /*  208 */  "_LShiftL__ConvI2L_iRegI__immIScale",
  /*  209 */  "_LShiftL_iRegL_immIScale",
  /*  210 */  "_DecodeN_iRegN_",
  /*  211 */  "_LoadB_memory1_",
  /*  212 */  "_LoadUB_memory1_",
  /*  213 */  "_LoadS_memory2_",
  /*  214 */  "_LoadUS_memory2_",
  /*  215 */  "_LoadI_memory4_",
  /*  216 */  "_ConvI2L__LoadI_memory4__",
  /*  217 */  "_LoadB_indirect_",
  /*  218 */  "_LoadUB_indirect_",
  /*  219 */  "_LoadUS_indirect_",
  /*  220 */  "_LoadS_indirect_",
  /*  221 */  "_LoadI_indirect_",
  /*  222 */  "_ConvI2L__LoadI_indirect__",
  /*  223 */  "_LoadL_memory8_",
  /*  224 */  "_CastP2X_iRegP_",
  /*  225 */  "_CastP2X__DecodeN_iRegN__",
  /*  226 */  "_Binary_iRegINoSp_iRegINoSp",
  /*  227 */  "_Binary_iRegLNoSp_iRegLNoSp",
  /*  228 */  "_Binary_iRegP_iRegP",
  /*  229 */  "_Binary_iRegNNoSp_iRegNNoSp",
  /*  230 */  "_Binary_iRegI_iRegI",
  /*  231 */  "_Binary_iRegL_iRegL",
  /*  232 */  "_Binary_iRegN_iRegN",
  /*  233 */  "_Binary_cmpOp_rFlagsReg",
  /*  234 */  "_Binary_iRegIorL2I_iRegIorL2I",
  /*  235 */  "_Binary_cmpOpU_rFlagsRegU",
  /*  236 */  "_Binary_immI0_iRegIorL2I",
  /*  237 */  "_Binary_iRegIorL2I_immI0",
  /*  238 */  "_Binary_immI_1_immI0",
  /*  239 */  "_Binary_iRegL_immL0",
  /*  240 */  "_Binary_immL0_iRegL",
  /*  241 */  "_Binary_iRegP_immP0",
  /*  242 */  "_Binary_immP0_iRegP",
  /*  243 */  "_Binary_iRegN_immN0",
  /*  244 */  "_Binary_immN0_iRegN",
  /*  245 */  "_Binary_vRegF_vRegF",
  /*  246 */  "_Binary_vRegD_vRegD",
  /*  247 */  "_ConvL2I_iRegL_",
  /*  248 */  "_ConvI2L_iRegIorL2I_",
  /*  249 */  "_LShiftL__ConvI2L_iRegIorL2I__immIScale",
  /*  250 */  "_MulI_iRegIorL2I_iRegIorL2I",
  /*  251 */  "_SubI_immI0_iRegIorL2I",
  /*  252 */  "_MulL_iRegL_iRegL",
  /*  253 */  "_SubL_immL0_iRegL",
  /*  254 */  "_MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I_",
  /*  255 */  "_SubL_immL0__ConvI2L_iRegIorL2I_",
  /*  256 */  "_URShiftI_iRegIorL2I_immI",
  /*  257 */  "_RShiftI_iRegIorL2I_immI",
  /*  258 */  "_LShiftI_iRegIorL2I_immI",
  /*  259 */  "_URShiftL_iRegL_immI",
  /*  260 */  "_RShiftL_iRegL_immI",
  /*  261 */  "_LShiftL_iRegL_immI",
  /*  262 */  "_XorI_iRegIorL2I_immI_M1",
  /*  263 */  "_XorL_iRegL_immL_M1",
  /*  264 */  "_XorI_iRegIorL2I_iRegIorL2I",
  /*  265 */  "_XorL_iRegL_iRegL",
  /*  266 */  "_XorI__URShiftI_iRegIorL2I_immI_immI_M1",
  /*  267 */  "_XorL__URShiftL_iRegL_immI_immL_M1",
  /*  268 */  "_XorI__RShiftI_iRegIorL2I_immI_immI_M1",
  /*  269 */  "_XorL__RShiftL_iRegL_immI_immL_M1",
  /*  270 */  "_RotateRight_iRegIorL2I_immI",
  /*  271 */  "_XorI__RotateRight_iRegIorL2I_immI_immI_M1",
  /*  272 */  "_RotateRight_iRegL_immI",
  /*  273 */  "_XorL__RotateRight_iRegL_immI_immL_M1",
  /*  274 */  "_XorI__LShiftI_iRegIorL2I_immI_immI_M1",
  /*  275 */  "_XorL__LShiftL_iRegL_immI_immL_M1",
  /*  276 */  "_XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I",
  /*  277 */  "_XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI",
  /*  278 */  "_XorL__URShiftL_iRegL_immI_iRegL",
  /*  279 */  "_XorL_iRegL__URShiftL_iRegL_immI",
  /*  280 */  "_XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I",
  /*  281 */  "_XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI",
  /*  282 */  "_XorL__RShiftL_iRegL_immI_iRegL",
  /*  283 */  "_XorL_iRegL__RShiftL_iRegL_immI",
  /*  284 */  "_XorI__RotateRight_iRegIorL2I_immI_iRegIorL2I",
  /*  285 */  "_XorI_iRegIorL2I__RotateRight_iRegIorL2I_immI",
  /*  286 */  "_XorL__RotateRight_iRegL_immI_iRegL",
  /*  287 */  "_XorL_iRegL__RotateRight_iRegL_immI",
  /*  288 */  "_XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I",
  /*  289 */  "_XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI",
  /*  290 */  "_XorL__LShiftL_iRegL_immI_iRegL",
  /*  291 */  "_XorL_iRegL__LShiftL_iRegL_immI",
  /*  292 */  "_AndI__URShiftI_iRegIorL2I_immI_immI_bitmask",
  /*  293 */  "_AndI_iRegIorL2I_immI_bitmask",
  /*  294 */  "_AndL_iRegL_immL_bitmask",
  /*  295 */  "_LShiftI__AndI_iRegIorL2I_immI_bitmask_immI",
  /*  296 */  "_AndL_iRegL_immL_positive_bitmaskI",
  /*  297 */  "_LShiftL__AndL_iRegL_immL_positive_bitmaskI_immI",
  /*  298 */  "_ConvI2L__AndI_iRegIorL2I_immI_bitmask_",
  /*  299 */  "_ConvL2I__AndL_iRegL_immL_positive_bitmaskI_",
  /*  300 */  "_AndI_iRegI_immI_bitmask",
  /*  301 */  "_LShiftI_iRegIorL2I_immI_16",
  /*  302 */  "_RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16",
  /*  303 */  "_LShiftI_iRegIorL2I_immI_24",
  /*  304 */  "_RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24",
  /*  305 */  "_URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24",
  /*  306 */  "_LShiftL_iRegL_immI_48",
  /*  307 */  "_RShiftL__LShiftL_iRegL_immI_48_immI_48",
  /*  308 */  "_LShiftL_iRegL_immI_32",
  /*  309 */  "_RShiftL__LShiftL_iRegL_immI_32_immI_32",
  /*  310 */  "_LShiftL_iRegL_immI_56",
  /*  311 */  "_RShiftL__LShiftL_iRegL_immI_56_immI_56",
  /*  312 */  "_URShiftL__LShiftL_iRegL_immI_56_immI_56",
  /*  313 */  "_AndI_iRegIorL2I_immI_255",
  /*  314 */  "_AndI_iRegIorL2I_immI_65535",
  /*  315 */  "_AndL_iRegL_immL_255",
  /*  316 */  "_AndL_iRegL_immL_65535",
  /*  317 */  "_AndL_iRegL_immL_4294967295",
  /*  318 */  "_LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt",
  /*  319 */  "_LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt",
  /*  320 */  "_LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt",
  /*  321 */  "_LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt",
  /*  322 */  "_LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt",
  /*  323 */  "_LShiftL__ConvI2L_iRegIorL2I__immIExt",
  /*  324 */  "_LShiftL__AndL_iRegL_immL_255_immIExt",
  /*  325 */  "_LShiftL__AndL_iRegL_immL_65535_immIExt",
  /*  326 */  "_LShiftL__AndL_iRegL_immL_4294967295_immIExt",
  /*  327 */  "_LShiftI__AndI_iRegIorL2I_immI_255_immIExt",
  /*  328 */  "_LShiftI__AndI_iRegIorL2I_immI_65535_immIExt",
  /*  329 */  "_NegF_vRegF_",
  /*  330 */  "_Binary__NegF_vRegF__vRegF",
  /*  331 */  "_Binary_vRegF__NegF_vRegF_",
  /*  332 */  "_NegD_vRegD_",
  /*  333 */  "_Binary__NegD_vRegD__vRegD",
  /*  334 */  "_Binary_vRegD__NegD_vRegD_",
  /*  335 */  "_SubF_vRegF_vRegF",
  /*  336 */  "_SubD_vRegD_vRegD",
  /*  337 */  "_OverflowMulI_iRegIorL2I_iRegIorL2I",
  /*  338 */  "_OverflowMulL_iRegL_iRegL",
  /*  339 */  "_CmpI_iRegIorL2I_immI0",
  /*  340 */  "_CmpL_iRegL_immL0",
  /*  341 */  "_CmpP_iRegP_immP0",
  /*  342 */  "_CmpN_iRegN_immN0",
  /*  343 */  "_CmpP__DecodeN_iRegN__immP0",
  /*  344 */  "_CmpU_iRegIorL2I_immI0",
  /*  345 */  "_CmpUL_iRegL_immL0",
  /*  346 */  "_AndL_iRegL_immL",
  /*  347 */  "_CmpL__AndL_iRegL_immL_immL0",
  /*  348 */  "_AndI_iRegIorL2I_immI",
  /*  349 */  "_CmpI__AndI_iRegIorL2I_immI_immI0",
  /*  350 */  "_AndL_iRegL_iRegL",
  /*  351 */  "_AndI_iRegIorL2I_iRegIorL2I",
  /*  352 */  "_PartialSubtypeCheck_iRegP_R4_iRegP_R0",
  /*  353 */  "_Binary_iRegP_R1_iRegI_R2",
  /*  354 */  "_Binary_iRegP_R3_iRegI_R4",
  /*  355 */  "_Binary_iRegP_R1_iRegI_R4",
  /*  356 */  "_Binary_iRegP_R3_iRegI_R2",
  /*  357 */  "_Binary_iRegP_R3_immI_le_4",
  /*  358 */  "_Binary_iRegP_R3_immI_1",
  /*  359 */  "_Binary_iRegP_R1_iRegP_R3",
  /*  360 */  "_Binary_iRegP_R1_iRegI_R3",
  /*  361 */  "_Binary_vReg_pRegGov",
  /*  362 */  "_Binary_vReg_vReg",
  /*  363 */  "_ReplicateB_immBAddSubV_",
  /*  364 */  "_ReplicateS_immIAddSubV_",
  /*  365 */  "_ReplicateI_immIAddSubV_",
  /*  366 */  "_ReplicateL_immLAddSubV_",
  /*  367 */  "_ReplicateB_immBLog_",
  /*  368 */  "_ReplicateS_immSLog_",
  /*  369 */  "_ReplicateI_immILog_",
  /*  370 */  "_ReplicateL_immLLog_",
  /*  371 */  "_XorV_vReg_vReg",
  /*  372 */  "_ReplicateB_immI_M1_",
  /*  373 */  "_ReplicateS_immI_M1_",
  /*  374 */  "_ReplicateI_immI_M1_",
  /*  375 */  "_ReplicateL_immL_M1_",
  /*  376 */  "_Binary_vReg__ReplicateB_immI_M1_",
  /*  377 */  "_Binary_vReg__ReplicateS_immI_M1_",
  /*  378 */  "_Binary_vReg__ReplicateI_immI_M1_",
  /*  379 */  "_Binary_vReg__ReplicateL_immL_M1_",
  /*  380 */  "_XorV_vReg__ReplicateB_immI_M1_",
  /*  381 */  "_XorV__ReplicateB_immI_M1__vReg",
  /*  382 */  "_XorV_vReg__ReplicateS_immI_M1_",
  /*  383 */  "_XorV__ReplicateS_immI_M1__vReg",
  /*  384 */  "_XorV_vReg__ReplicateI_immI_M1_",
  /*  385 */  "_XorV__ReplicateI_immI_M1__vReg",
  /*  386 */  "_XorV_vReg__ReplicateL_immL_M1_",
  /*  387 */  "_XorV__ReplicateL_immL_M1__vReg",
  /*  388 */  "_Binary_vReg__XorV_vReg__ReplicateB_immI_M1_",
  /*  389 */  "_Binary_vReg__XorV__ReplicateB_immI_M1__vReg",
  /*  390 */  "_Binary_vReg__XorV_vReg__ReplicateS_immI_M1_",
  /*  391 */  "_Binary_vReg__XorV__ReplicateS_immI_M1__vReg",
  /*  392 */  "_Binary_vReg__XorV_vReg__ReplicateI_immI_M1_",
  /*  393 */  "_Binary_vReg__XorV__ReplicateI_immI_M1__vReg",
  /*  394 */  "_Binary_vReg__XorV_vReg__ReplicateL_immL_M1_",
  /*  395 */  "_Binary_vReg__XorV__ReplicateL_immL_M1__vReg",
  /*  396 */  "_SubVF_vReg_vReg",
  /*  397 */  "_SubVD_vReg_vReg",
  /*  398 */  "_SubVF__Binary_vReg_vReg_pRegGov",
  /*  399 */  "_SubVD__Binary_vReg_vReg_pRegGov",
  /*  400 */  "_MulVB_vReg_vReg",
  /*  401 */  "_MulVS_vReg_vReg",
  /*  402 */  "_MulVI_vReg_vReg",
  /*  403 */  "_MulVL_vReg_vReg",
  /*  404 */  "_Binary_vReg__MulVB_vReg_vReg",
  /*  405 */  "_Binary_vReg__MulVS_vReg_vReg",
  /*  406 */  "_Binary_vReg__MulVI_vReg_vReg",
  /*  407 */  "_Binary_vReg__MulVL_vReg_vReg",
  /*  408 */  "_NegVF_vReg_",
  /*  409 */  "_Binary__NegVF_vReg__vReg",
  /*  410 */  "_NegVD_vReg_",
  /*  411 */  "_Binary__NegVD_vReg__vReg",
  /*  412 */  "_Binary_vReg__NegVF_vReg_",
  /*  413 */  "_Binary_vReg__NegVD_vReg_",
  /*  414 */  "_Binary__NegVF_vReg__pRegGov",
  /*  415 */  "_Binary__NegVD_vReg__pRegGov",
  /*  416 */  "_LShiftCntV_immI_",
  /*  417 */  "_RShiftCntV_immI_positive_",
  /*  418 */  "_RShiftVB_vReg__RShiftCntV_immI_positive_",
  /*  419 */  "_RShiftVS_vReg__RShiftCntV_immI_positive_",
  /*  420 */  "_RShiftVI_vReg__RShiftCntV_immI_positive_",
  /*  421 */  "_RShiftVL_vReg__RShiftCntV_immI_positive_",
  /*  422 */  "_URShiftVB_vReg__RShiftCntV_immI_positive_",
  /*  423 */  "_URShiftVS_vReg__RShiftCntV_immI_positive_",
  /*  424 */  "_URShiftVI_vReg__RShiftCntV_immI_positive_",
  /*  425 */  "_URShiftVL_vReg__RShiftCntV_immI_positive_",
  /*  426 */  "_Binary_vReg__LShiftCntV_immI_",
  /*  427 */  "_Binary_vReg__RShiftCntV_immI_positive_",
  /*  428 */  "_Binary_iRegIorL2I_vReg",
  /*  429 */  "_Binary_iRegL_vReg",
  /*  430 */  "_Binary_vRegF_vReg",
  /*  431 */  "_Binary_vRegD_vReg",
  /*  432 */  "_Binary_vReg_iRegIorL2I",
  /*  433 */  "_Binary_vReg_iRegL",
  /*  434 */  "_Binary_vReg_vRegF",
  /*  435 */  "_Binary_vReg_vRegD",
  /*  436 */  "_LoadVector_indirect_",
  /*  437 */  "_LoadVectorMasked_vmemA_pRegGov",
  /*  438 */  "_VectorStoreMask_pReg_immI_gt_1",
  /*  439 */  "_Binary__VectorStoreMask_pReg_immI_gt_1_pRegGov",
  /*  440 */  "_MaskAll_immI_M1_",
  /*  441 */  "_XorVMask_pReg__MaskAll_immI_M1_",
  /*  442 */  "_MaskAll_immL_M1_",
  /*  443 */  "_XorVMask_pReg__MaskAll_immL_M1_",
  /*  444 */  "_Binary_immI_pRegGov",
  /*  445 */  "_Binary_cmpOp_immI",
  /*  446 */  "_Binary_vReg__Binary_vReg_pRegGov",
  // last internally defined operand
  /*  447 */  "loadConI",
  /*  448 */  "loadConL",
  /*  449 */  "loadConP",
  /*  450 */  "loadConP0",
  /*  451 */  "loadConP1",
  /*  452 */  "loadByteMapBase",
  /*  453 */  "loadConN",
  /*  454 */  "loadConN0",
  /*  455 */  "loadConNKlass",
  /*  456 */  "loadConF_packed",
  /*  457 */  "loadConF",
  /*  458 */  "loadConD_packed",
  /*  459 */  "loadConD",
  /*  460 */  "countLeadingZerosI",
  /*  461 */  "countLeadingZerosL",
  /*  462 */  "countTrailingZerosI",
  /*  463 */  "countTrailingZerosL",
  /*  464 */  "castX2P",
  /*  465 */  "castP2X",
  /*  466 */  "checkCastPP",
  /*  467 */  "castPP",
  /*  468 */  "castII",
  /*  469 */  "castLL",
  /*  470 */  "castFF",
  /*  471 */  "castDD",
  /*  472 */  "castVV",
  /*  473 */  "castVVMask",
  /*  474 */  "negF_reg_reg",
  /*  475 */  "negD_reg_reg",
  /*  476 */  "absF_reg",
  /*  477 */  "absD_reg",
  /*  478 */  "MoveF2I_stack_reg",
  /*  479 */  "MoveI2F_stack_reg",
  /*  480 */  "MoveD2L_stack_reg",
  /*  481 */  "MoveL2D_stack_reg",
  /*  482 */  "MoveF2I_reg_reg",
  /*  483 */  "MoveI2F_reg_reg",
  /*  484 */  "MoveD2L_reg_reg",
  /*  485 */  "MoveL2D_reg_reg",
  /*  486 */  "overflowAddI_reg_reg",
  /*  487 */  "overflowAddI_reg_imm",
  /*  488 */  "overflowAddL_reg_reg",
  /*  489 */  "overflowAddL_reg_imm",
  /*  490 */  "overflowSubI_reg_reg",
  /*  491 */  "overflowSubI_reg_imm",
  /*  492 */  "overflowSubL_reg_reg",
  /*  493 */  "overflowSubL_reg_imm",
  /*  494 */  "overflowNegI_reg",
  /*  495 */  "overflowNegL_reg",
  /*  496 */  "overflowMulI_reg",
  /*  497 */  "overflowMulL_reg",
  /*  498 */  "compI_reg_reg",
  /*  499 */  "compI_reg_immI0",
  /*  500 */  "compI_reg_immIAddSub",
  /*  501 */  "compI_reg_immI",
  /*  502 */  "compU_reg_reg",
  /*  503 */  "compU_reg_immI0",
  /*  504 */  "compU_reg_immIAddSub",
  /*  505 */  "compU_reg_immI",
  /*  506 */  "compL_reg_reg",
  /*  507 */  "compL_reg_immL0",
  /*  508 */  "compL_reg_immLAddSub",
  /*  509 */  "compL_reg_immL",
  /*  510 */  "compUL_reg_reg",
  /*  511 */  "compUL_reg_immL0",
  /*  512 */  "compUL_reg_immLAddSub",
  /*  513 */  "compUL_reg_immL",
  /*  514 */  "compP_reg_reg",
  /*  515 */  "compN_reg_reg",
  /*  516 */  "testP_reg",
  /*  517 */  "testN_reg",
  /*  518 */  "compF_reg_reg",
  /*  519 */  "compF_reg_zero",
  /*  520 */  "compD_reg_reg",
  /*  521 */  "compD_reg_zero",
  /*  522 */  "cmpL_and",
  /*  523 */  "cmpI_and",
  /*  524 */  "cmpL_and_reg",
  /*  525 */  "cmpI_and_reg",
  /*  526 */  "cmpFastLock",
  /*  527 */  "cmpFastUnlock",
  /*  528 */  "partialSubtypeCheckVsZero",
  /*  529 */  "tlsLoadP",
  /*  530 */  "vloadcon",
  /*  531 */  "vabsB",
  /*  532 */  "vabsS",
  /*  533 */  "vabsI",
  /*  534 */  "vabsL",
  /*  535 */  "vabsF",
  /*  536 */  "vabsD",
  /*  537 */  "vnegI",
  /*  538 */  "vnegL",
  /*  539 */  "vnegF",
  /*  540 */  "vnegD",
  /*  541 */  "vsqrtF",
  /*  542 */  "vsqrtD",
  /*  543 */  "vshiftcntL",
  /*  544 */  "vshiftcntR",
  /*  545 */  "reinterpret_same_size",
  /*  546 */  "reinterpret_resize_le128b",
  /*  547 */  "vcvtBtoX",
  /*  548 */  "vcvtStoB_neon",
  /*  549 */  "vcvtStoX_extend",
  /*  550 */  "vcvtItoX",
  /*  551 */  "vcvtLtoI_neon",
  /*  552 */  "vcvtLtoD",
  /*  553 */  "vcvtFtoX",
  /*  554 */  "vcvtDtoL",
  /*  555 */  "vcvtDtoF_64b",
  /*  556 */  "replicateB",
  /*  557 */  "replicateS",
  /*  558 */  "replicateI",
  /*  559 */  "replicateL",
  /*  560 */  "replicateF",
  /*  561 */  "replicateD",
  /*  562 */  "replicateI_imm_le128b",
  /*  563 */  "replicateI_imm_le128b_0",
  /*  564 */  "replicateI_imm_le128b_1",
  /*  565 */  "replicateB_imm8_gt128b",
  /*  566 */  "replicateS_imm8_gt128b",
  /*  567 */  "replicateI_imm8_gt128b",
  /*  568 */  "replicateL_imm_128b",
  /*  569 */  "replicateL_imm8_gt128b",
  /*  570 */  "vloadmask_neon",
  /*  571 */  "vmaskcast_same_esize_neon",
  /*  572 */  "vmaskcast_extend_neon",
  /*  573 */  "vmaskcast_narrow_neon",
  /*  574 */  "vmaskcast_same_esize_sve",
  /*  575 */  "vmaskcast_extend_sve",
  /*  576 */  "vmaskcast_narrow_sve",
  /*  577 */  "vmask_reinterpret_same_esize",
  /*  578 */  "vmask_truecount_sve",
  /*  579 */  "vmask_firsttrue_8or16e",
  /*  580 */  "vmask_lasttrue_neon",
  /*  581 */  "vmask_tolong_neon",
  /*  582 */  "vpopcountI",
  /*  583 */  "vpopcountL",
  /*  584 */  "loadshuffle",
  /*  585 */  "vcountLeadingZeros",
  /*  586 */  "vcountTrailingZeros",
  /*  587 */  "vreverse",
  /*  588 */  "vreverseBytes",
  /*  589 */  "loadB",
  /*  590 */  "loadB2L",
  /*  591 */  "loadUB",
  /*  592 */  "loadUB2L",
  /*  593 */  "loadS",
  /*  594 */  "loadS2L",
  /*  595 */  "loadUS",
  /*  596 */  "loadUS2L",
  /*  597 */  "loadI",
  /*  598 */  "loadI2L",
  /*  599 */  "loadUI2L",
  /*  600 */  "loadL",
  /*  601 */  "loadRange",
  /*  602 */  "loadP",
  /*  603 */  "loadN",
  /*  604 */  "loadKlass",
  /*  605 */  "loadNKlass",
  /*  606 */  "loadF",
  /*  607 */  "loadD",
  /*  608 */  "storeimmCM0",
  /*  609 */  "storeimmCM0_ordered",
  /*  610 */  "storeB",
  /*  611 */  "storeimmB0",
  /*  612 */  "storeC",
  /*  613 */  "storeimmC0",
  /*  614 */  "storeI",
  /*  615 */  "storeimmI0",
  /*  616 */  "storeL",
  /*  617 */  "storeimmL0",
  /*  618 */  "storeP",
  /*  619 */  "storeimmP0",
  /*  620 */  "storeN",
  /*  621 */  "storeImmN0",
  /*  622 */  "storeF",
  /*  623 */  "storeD",
  /*  624 */  "storeNKlass",
  /*  625 */  "prefetchalloc",
  /*  626 */  "loadB_volatile",
  /*  627 */  "loadB2L_volatile",
  /*  628 */  "loadUB_volatile",
  /*  629 */  "loadUB2L_volatile",
  /*  630 */  "loadS_volatile",
  /*  631 */  "loadUS_volatile",
  /*  632 */  "loadUS2L_volatile",
  /*  633 */  "loadS2L_volatile",
  /*  634 */  "loadI_volatile",
  /*  635 */  "loadUI2L_volatile",
  /*  636 */  "loadL_volatile",
  /*  637 */  "loadP_volatile",
  /*  638 */  "loadN_volatile",
  /*  639 */  "loadF_volatile",
  /*  640 */  "loadD_volatile",
  /*  641 */  "storeB_volatile",
  /*  642 */  "storeimmB0_volatile",
  /*  643 */  "storeC_volatile",
  /*  644 */  "storeimmC0_volatile",
  /*  645 */  "storeI_volatile",
  /*  646 */  "storeimmI0_volatile",
  /*  647 */  "storeL_volatile",
  /*  648 */  "storeimmL0_volatile",
  /*  649 */  "storeP_volatile",
  /*  650 */  "storeimmP0_volatile",
  /*  651 */  "storeN_volatile",
  /*  652 */  "storeimmN0_volatile",
  /*  653 */  "storeF_volatile",
  /*  654 */  "storeD_volatile",
  /*  655 */  "cacheWB",
  /*  656 */  "cacheWBPreSync",
  /*  657 */  "cacheWBPostSync",
  /*  658 */  "bytes_reverse_int",
  /*  659 */  "bytes_reverse_long",
  /*  660 */  "bytes_reverse_unsigned_short",
  /*  661 */  "bytes_reverse_short",
  /*  662 */  "popCountI",
  /*  663 */  "popCountI_mem",
  /*  664 */  "popCountL",
  /*  665 */  "popCountL_mem",
  /*  666 */  "load_fence",
  /*  667 */  "unnecessary_membar_acquire",
  /*  668 */  "membar_acquire",
  /*  669 */  "membar_acquire_lock",
  /*  670 */  "store_fence",
  /*  671 */  "unnecessary_membar_release",
  /*  672 */  "membar_release",
  /*  673 */  "membar_storestore",
  /*  674 */  "membar_storestore_0",
  /*  675 */  "membar_release_lock",
  /*  676 */  "unnecessary_membar_volatile",
  /*  677 */  "membar_volatile",
  /*  678 */  "convP2I",
  /*  679 */  "convN2I",
  /*  680 */  "encodeHeapOop",
  /*  681 */  "encodeHeapOop_not_null",
  /*  682 */  "decodeHeapOop",
  /*  683 */  "decodeHeapOop_not_null",
  /*  684 */  "encodeKlass_not_null",
  /*  685 */  "decodeKlass_not_null",
  /*  686 */  "compareAndSwapB",
  /*  687 */  "compareAndSwapS",
  /*  688 */  "compareAndSwapI",
  /*  689 */  "compareAndSwapL",
  /*  690 */  "compareAndSwapP",
  /*  691 */  "compareAndSwapN",
  /*  692 */  "compareAndSwapBAcq",
  /*  693 */  "compareAndSwapSAcq",
  /*  694 */  "compareAndSwapIAcq",
  /*  695 */  "compareAndSwapLAcq",
  /*  696 */  "compareAndSwapPAcq",
  /*  697 */  "compareAndSwapNAcq",
  /*  698 */  "compareAndExchangeB",
  /*  699 */  "compareAndExchangeS",
  /*  700 */  "compareAndExchangeI",
  /*  701 */  "compareAndExchangeL",
  /*  702 */  "compareAndExchangeN",
  /*  703 */  "compareAndExchangeP",
  /*  704 */  "compareAndExchangeBAcq",
  /*  705 */  "compareAndExchangeSAcq",
  /*  706 */  "compareAndExchangeIAcq",
  /*  707 */  "compareAndExchangeLAcq",
  /*  708 */  "compareAndExchangeNAcq",
  /*  709 */  "compareAndExchangePAcq",
  /*  710 */  "weakCompareAndSwapB",
  /*  711 */  "weakCompareAndSwapS",
  /*  712 */  "weakCompareAndSwapI",
  /*  713 */  "weakCompareAndSwapL",
  /*  714 */  "weakCompareAndSwapN",
  /*  715 */  "weakCompareAndSwapP",
  /*  716 */  "weakCompareAndSwapBAcq",
  /*  717 */  "weakCompareAndSwapSAcq",
  /*  718 */  "weakCompareAndSwapIAcq",
  /*  719 */  "weakCompareAndSwapLAcq",
  /*  720 */  "weakCompareAndSwapNAcq",
  /*  721 */  "weakCompareAndSwapPAcq",
  /*  722 */  "get_and_setI",
  /*  723 */  "get_and_setL",
  /*  724 */  "get_and_setN",
  /*  725 */  "get_and_setP",
  /*  726 */  "get_and_setIAcq",
  /*  727 */  "get_and_setLAcq",
  /*  728 */  "get_and_setNAcq",
  /*  729 */  "get_and_setPAcq",
  /*  730 */  "get_and_addL",
  /*  731 */  "get_and_addL_no_res",
  /*  732 */  "get_and_addLi",
  /*  733 */  "get_and_addLi_no_res",
  /*  734 */  "get_and_addI",
  /*  735 */  "get_and_addI_no_res",
  /*  736 */  "get_and_addIi",
  /*  737 */  "get_and_addIi_no_res",
  /*  738 */  "get_and_addLAcq",
  /*  739 */  "get_and_addL_no_resAcq",
  /*  740 */  "get_and_addLiAcq",
  /*  741 */  "get_and_addLi_no_resAcq",
  /*  742 */  "get_and_addIAcq",
  /*  743 */  "get_and_addI_no_resAcq",
  /*  744 */  "get_and_addIiAcq",
  /*  745 */  "get_and_addIi_no_resAcq",
  /*  746 */  "cmpL3_reg_reg",
  /*  747 */  "cmpL3_reg_imm",
  /*  748 */  "cmovI_reg_reg",
  /*  749 */  "cmovUI_reg_reg",
  /*  750 */  "cmovI_zero_reg",
  /*  751 */  "cmovUI_zero_reg",
  /*  752 */  "cmovI_reg_zero",
  /*  753 */  "cmovUI_reg_zero",
  /*  754 */  "cmovI_reg_zero_one",
  /*  755 */  "cmovUI_reg_zero_one",
  /*  756 */  "cmovL_reg_reg",
  /*  757 */  "cmovUL_reg_reg",
  /*  758 */  "cmovL_reg_zero",
  /*  759 */  "cmovUL_reg_zero",
  /*  760 */  "cmovL_zero_reg",
  /*  761 */  "cmovUL_zero_reg",
  /*  762 */  "cmovP_reg_reg",
  /*  763 */  "cmovUP_reg_reg",
  /*  764 */  "cmovP_reg_zero",
  /*  765 */  "cmovUP_reg_zero",
  /*  766 */  "cmovP_zero_reg",
  /*  767 */  "cmovUP_zero_reg",
  /*  768 */  "cmovN_reg_reg",
  /*  769 */  "cmovUN_reg_reg",
  /*  770 */  "cmovN_reg_zero",
  /*  771 */  "cmovUN_reg_zero",
  /*  772 */  "cmovN_zero_reg",
  /*  773 */  "cmovUN_zero_reg",
  /*  774 */  "cmovF_reg",
  /*  775 */  "cmovUF_reg",
  /*  776 */  "cmovD_reg",
  /*  777 */  "cmovUD_reg",
  /*  778 */  "addI_reg_reg",
  /*  779 */  "addI_reg_imm",
  /*  780 */  "addI_reg_imm_i2l",
  /*  781 */  "addP_reg_reg",
  /*  782 */  "addP_reg_reg_ext",
  /*  783 */  "addP_reg_reg_lsl",
  /*  784 */  "addP_reg_reg_ext_shift",
  /*  785 */  "lshift_ext",
  /*  786 */  "addP_reg_imm",
  /*  787 */  "addL_reg_reg",
  /*  788 */  "addL_reg_imm",
  /*  789 */  "subI_reg_reg",
  /*  790 */  "subI_reg_imm",
  /*  791 */  "subL_reg_reg",
  /*  792 */  "subL_reg_imm",
  /*  793 */  "negI_reg",
  /*  794 */  "negL_reg",
  /*  795 */  "mulI",
  /*  796 */  "smulI",
  /*  797 */  "smulI_0",
  /*  798 */  "mulL",
  /*  799 */  "mulHiL_rReg",
  /*  800 */  "umulHiL_rReg",
  /*  801 */  "maddI",
  /*  802 */  "maddI_0",
  /*  803 */  "msubI",
  /*  804 */  "mnegI",
  /*  805 */  "mnegI_0",
  /*  806 */  "maddL",
  /*  807 */  "maddL_0",
  /*  808 */  "msubL",
  /*  809 */  "mnegL",
  /*  810 */  "mnegL_0",
  /*  811 */  "smaddL",
  /*  812 */  "smaddL_1",
  /*  813 */  "smaddL_0",
  /*  814 */  "smaddL_2",
  /*  815 */  "smsubL",
  /*  816 */  "smsubL_0",
  /*  817 */  "smnegL",
  /*  818 */  "smnegL_0",
  /*  819 */  "muladdS2I",
  /*  820 */  "divI",
  /*  821 */  "divL",
  /*  822 */  "modI",
  /*  823 */  "modL",
  /*  824 */  "UdivI_reg_reg",
  /*  825 */  "UdivL_reg_reg",
  /*  826 */  "UmodI_reg_reg",
  /*  827 */  "UModL_reg_reg",
  /*  828 */  "lShiftI_reg_reg",
  /*  829 */  "lShiftI_reg_imm",
  /*  830 */  "urShiftI_reg_reg",
  /*  831 */  "urShiftI_reg_imm",
  /*  832 */  "rShiftI_reg_reg",
  /*  833 */  "rShiftI_reg_imm",
  /*  834 */  "lShiftL_reg_reg",
  /*  835 */  "lShiftL_reg_imm",
  /*  836 */  "urShiftL_reg_reg",
  /*  837 */  "urShiftL_reg_imm",
  /*  838 */  "urShiftP_reg_imm",
  /*  839 */  "rShiftL_reg_reg",
  /*  840 */  "rShiftL_reg_imm",
  /*  841 */  "regL_not_reg",
  /*  842 */  "regI_not_reg",
  /*  843 */  "NegI_reg_URShift_reg",
  /*  844 */  "NegI_reg_RShift_reg",
  /*  845 */  "NegI_reg_LShift_reg",
  /*  846 */  "NegL_reg_URShift_reg",
  /*  847 */  "NegL_reg_RShift_reg",
  /*  848 */  "NegL_reg_LShift_reg",
  /*  849 */  "AndI_reg_not_reg",
  /*  850 */  "AndI_reg_not_reg_0",
  /*  851 */  "AndL_reg_not_reg",
  /*  852 */  "AndL_reg_not_reg_0",
  /*  853 */  "OrI_reg_not_reg",
  /*  854 */  "OrI_reg_not_reg_0",
  /*  855 */  "OrL_reg_not_reg",
  /*  856 */  "OrL_reg_not_reg_0",
  /*  857 */  "XorI_reg_not_reg",
  /*  858 */  "XorI_reg_not_reg_0",
  /*  859 */  "XorL_reg_not_reg",
  /*  860 */  "XorL_reg_not_reg_0",
  /*  861 */  "AndI_reg_URShift_not_reg",
  /*  862 */  "AndI_reg_URShift_not_reg_0",
  /*  863 */  "AndL_reg_URShift_not_reg",
  /*  864 */  "AndL_reg_URShift_not_reg_0",
  /*  865 */  "AndI_reg_RShift_not_reg",
  /*  866 */  "AndI_reg_RShift_not_reg_0",
  /*  867 */  "AndL_reg_RShift_not_reg",
  /*  868 */  "AndL_reg_RShift_not_reg_0",
  /*  869 */  "AndI_reg_RotateRight_not_reg",
  /*  870 */  "AndI_reg_RotateRight_not_reg_0",
  /*  871 */  "AndL_reg_RotateRight_not_reg",
  /*  872 */  "AndL_reg_RotateRight_not_reg_0",
  /*  873 */  "AndI_reg_LShift_not_reg",
  /*  874 */  "AndI_reg_LShift_not_reg_0",
  /*  875 */  "AndL_reg_LShift_not_reg",
  /*  876 */  "AndL_reg_LShift_not_reg_0",
  /*  877 */  "XorI_reg_URShift_not_reg",
  /*  878 */  "XorI_reg_URShift_not_reg_1",
  /*  879 */  "XorI_reg_URShift_not_reg_0",
  /*  880 */  "XorI_reg_URShift_not_reg_2",
  /*  881 */  "XorL_reg_URShift_not_reg",
  /*  882 */  "XorL_reg_URShift_not_reg_1",
  /*  883 */  "XorL_reg_URShift_not_reg_0",
  /*  884 */  "XorL_reg_URShift_not_reg_2",
  /*  885 */  "XorI_reg_RShift_not_reg",
  /*  886 */  "XorI_reg_RShift_not_reg_1",
  /*  887 */  "XorI_reg_RShift_not_reg_0",
  /*  888 */  "XorI_reg_RShift_not_reg_2",
  /*  889 */  "XorL_reg_RShift_not_reg",
  /*  890 */  "XorL_reg_RShift_not_reg_1",
  /*  891 */  "XorL_reg_RShift_not_reg_0",
  /*  892 */  "XorL_reg_RShift_not_reg_2",
  /*  893 */  "XorI_reg_RotateRight_not_reg",
  /*  894 */  "XorI_reg_RotateRight_not_reg_1",
  /*  895 */  "XorI_reg_RotateRight_not_reg_0",
  /*  896 */  "XorI_reg_RotateRight_not_reg_2",
  /*  897 */  "XorL_reg_RotateRight_not_reg",
  /*  898 */  "XorL_reg_RotateRight_not_reg_1",
  /*  899 */  "XorL_reg_RotateRight_not_reg_0",
  /*  900 */  "XorL_reg_RotateRight_not_reg_2",
  /*  901 */  "XorI_reg_LShift_not_reg",
  /*  902 */  "XorI_reg_LShift_not_reg_1",
  /*  903 */  "XorI_reg_LShift_not_reg_0",
  /*  904 */  "XorI_reg_LShift_not_reg_2",
  /*  905 */  "XorL_reg_LShift_not_reg",
  /*  906 */  "XorL_reg_LShift_not_reg_1",
  /*  907 */  "XorL_reg_LShift_not_reg_0",
  /*  908 */  "XorL_reg_LShift_not_reg_2",
  /*  909 */  "OrI_reg_URShift_not_reg",
  /*  910 */  "OrI_reg_URShift_not_reg_0",
  /*  911 */  "OrL_reg_URShift_not_reg",
  /*  912 */  "OrL_reg_URShift_not_reg_0",
  /*  913 */  "OrI_reg_RShift_not_reg",
  /*  914 */  "OrI_reg_RShift_not_reg_0",
  /*  915 */  "OrL_reg_RShift_not_reg",
  /*  916 */  "OrL_reg_RShift_not_reg_0",
  /*  917 */  "OrI_reg_RotateRight_not_reg",
  /*  918 */  "OrI_reg_RotateRight_not_reg_0",
  /*  919 */  "OrL_reg_RotateRight_not_reg",
  /*  920 */  "OrL_reg_RotateRight_not_reg_0",
  /*  921 */  "OrI_reg_LShift_not_reg",
  /*  922 */  "OrI_reg_LShift_not_reg_0",
  /*  923 */  "OrL_reg_LShift_not_reg",
  /*  924 */  "OrL_reg_LShift_not_reg_0",
  /*  925 */  "AndI_reg_URShift_reg",
  /*  926 */  "AndI_reg_URShift_reg_0",
  /*  927 */  "AndL_reg_URShift_reg",
  /*  928 */  "AndL_reg_URShift_reg_0",
  /*  929 */  "AndI_reg_RShift_reg",
  /*  930 */  "AndI_reg_RShift_reg_0",
  /*  931 */  "AndL_reg_RShift_reg",
  /*  932 */  "AndL_reg_RShift_reg_0",
  /*  933 */  "AndI_reg_LShift_reg",
  /*  934 */  "AndI_reg_LShift_reg_0",
  /*  935 */  "AndL_reg_LShift_reg",
  /*  936 */  "AndL_reg_LShift_reg_0",
  /*  937 */  "AndI_reg_RotateRight_reg",
  /*  938 */  "AndI_reg_RotateRight_reg_0",
  /*  939 */  "AndL_reg_RotateRight_reg",
  /*  940 */  "AndL_reg_RotateRight_reg_0",
  /*  941 */  "XorI_reg_URShift_reg",
  /*  942 */  "XorI_reg_URShift_reg_0",
  /*  943 */  "XorL_reg_URShift_reg",
  /*  944 */  "XorL_reg_URShift_reg_0",
  /*  945 */  "XorI_reg_RShift_reg",
  /*  946 */  "XorI_reg_RShift_reg_0",
  /*  947 */  "XorL_reg_RShift_reg",
  /*  948 */  "XorL_reg_RShift_reg_0",
  /*  949 */  "XorI_reg_LShift_reg",
  /*  950 */  "XorI_reg_LShift_reg_0",
  /*  951 */  "XorL_reg_LShift_reg",
  /*  952 */  "XorL_reg_LShift_reg_0",
  /*  953 */  "XorI_reg_RotateRight_reg",
  /*  954 */  "XorI_reg_RotateRight_reg_0",
  /*  955 */  "XorL_reg_RotateRight_reg",
  /*  956 */  "XorL_reg_RotateRight_reg_0",
  /*  957 */  "OrI_reg_URShift_reg",
  /*  958 */  "OrI_reg_URShift_reg_0",
  /*  959 */  "OrL_reg_URShift_reg",
  /*  960 */  "OrL_reg_URShift_reg_0",
  /*  961 */  "OrI_reg_RShift_reg",
  /*  962 */  "OrI_reg_RShift_reg_0",
  /*  963 */  "OrL_reg_RShift_reg",
  /*  964 */  "OrL_reg_RShift_reg_0",
  /*  965 */  "OrI_reg_LShift_reg",
  /*  966 */  "OrI_reg_LShift_reg_0",
  /*  967 */  "OrL_reg_LShift_reg",
  /*  968 */  "OrL_reg_LShift_reg_0",
  /*  969 */  "OrI_reg_RotateRight_reg",
  /*  970 */  "OrI_reg_RotateRight_reg_0",
  /*  971 */  "OrL_reg_RotateRight_reg",
  /*  972 */  "OrL_reg_RotateRight_reg_0",
  /*  973 */  "AddI_reg_URShift_reg",
  /*  974 */  "AddI_reg_URShift_reg_0",
  /*  975 */  "AddL_reg_URShift_reg",
  /*  976 */  "AddL_reg_URShift_reg_0",
  /*  977 */  "AddI_reg_RShift_reg",
  /*  978 */  "AddI_reg_RShift_reg_0",
  /*  979 */  "AddL_reg_RShift_reg",
  /*  980 */  "AddL_reg_RShift_reg_0",
  /*  981 */  "AddI_reg_LShift_reg",
  /*  982 */  "AddI_reg_LShift_reg_0",
  /*  983 */  "AddL_reg_LShift_reg",
  /*  984 */  "AddL_reg_LShift_reg_0",
  /*  985 */  "SubI_reg_URShift_reg",
  /*  986 */  "SubL_reg_URShift_reg",
  /*  987 */  "SubI_reg_RShift_reg",
  /*  988 */  "SubL_reg_RShift_reg",
  /*  989 */  "SubI_reg_LShift_reg",
  /*  990 */  "SubL_reg_LShift_reg",
  /*  991 */  "sbfmL",
  /*  992 */  "sbfmwI",
  /*  993 */  "ubfmL",
  /*  994 */  "ubfmwI",
  /*  995 */  "ubfxwI",
  /*  996 */  "ubfxL",
  /*  997 */  "ubfxIConvI2L",
  /*  998 */  "ubfizwI",
  /*  999 */  "ubfizL",
  /* 1000 */  "ubfizwIConvI2L",
  /* 1001 */  "ubfizLConvL2I",
  /* 1002 */  "ubfizIConvI2L",
  /* 1003 */  "ubfizLConvL2Ix",
  /* 1004 */  "ubfizIConvI2LAndI",
  /* 1005 */  "extrOrL",
  /* 1006 */  "extrOrL_0",
  /* 1007 */  "extrOrI",
  /* 1008 */  "extrOrI_0",
  /* 1009 */  "extrAddL",
  /* 1010 */  "extrAddL_0",
  /* 1011 */  "extrAddI",
  /* 1012 */  "extrAddI_0",
  /* 1013 */  "rorI_imm",
  /* 1014 */  "rorL_imm",
  /* 1015 */  "rorI_reg",
  /* 1016 */  "rorL_reg",
  /* 1017 */  "rolI_reg",
  /* 1018 */  "rolL_reg",
  /* 1019 */  "AddExtI",
  /* 1020 */  "AddExtI_0",
  /* 1021 */  "SubExtI",
  /* 1022 */  "AddExtI_sxth",
  /* 1023 */  "AddExtI_sxth_0",
  /* 1024 */  "AddExtI_sxtb",
  /* 1025 */  "AddExtI_sxtb_0",
  /* 1026 */  "AddExtI_uxtb",
  /* 1027 */  "AddExtI_uxtb_0",
  /* 1028 */  "AddExtL_sxth",
  /* 1029 */  "AddExtL_sxth_0",
  /* 1030 */  "AddExtL_sxtw",
  /* 1031 */  "AddExtL_sxtw_0",
  /* 1032 */  "AddExtL_sxtb",
  /* 1033 */  "AddExtL_sxtb_0",
  /* 1034 */  "AddExtL_uxtb",
  /* 1035 */  "AddExtL_uxtb_0",
  /* 1036 */  "AddExtI_uxtb_and",
  /* 1037 */  "AddExtI_uxtb_and_0",
  /* 1038 */  "AddExtI_uxth_and",
  /* 1039 */  "AddExtI_uxth_and_0",
  /* 1040 */  "AddExtL_uxtb_and",
  /* 1041 */  "AddExtL_uxtb_and_0",
  /* 1042 */  "AddExtL_uxth_and",
  /* 1043 */  "AddExtL_uxth_and_0",
  /* 1044 */  "AddExtL_uxtw_and",
  /* 1045 */  "AddExtL_uxtw_and_0",
  /* 1046 */  "SubExtI_uxtb_and",
  /* 1047 */  "SubExtI_uxth_and",
  /* 1048 */  "SubExtL_uxtb_and",
  /* 1049 */  "SubExtL_uxth_and",
  /* 1050 */  "SubExtL_uxtw_and",
  /* 1051 */  "AddExtL_sxtb_shift",
  /* 1052 */  "AddExtL_sxtb_shift_0",
  /* 1053 */  "AddExtL_sxth_shift",
  /* 1054 */  "AddExtL_sxth_shift_0",
  /* 1055 */  "AddExtL_sxtw_shift",
  /* 1056 */  "AddExtL_sxtw_shift_0",
  /* 1057 */  "SubExtL_sxtb_shift",
  /* 1058 */  "SubExtL_sxth_shift",
  /* 1059 */  "SubExtL_sxtw_shift",
  /* 1060 */  "AddExtI_sxtb_shift",
  /* 1061 */  "AddExtI_sxtb_shift_0",
  /* 1062 */  "AddExtI_sxth_shift",
  /* 1063 */  "AddExtI_sxth_shift_0",
  /* 1064 */  "SubExtI_sxtb_shift",
  /* 1065 */  "SubExtI_sxth_shift",
  /* 1066 */  "AddExtI_shift",
  /* 1067 */  "AddExtI_shift_0",
  /* 1068 */  "SubExtI_shift",
  /* 1069 */  "AddExtL_uxtb_and_shift",
  /* 1070 */  "AddExtL_uxtb_and_shift_0",
  /* 1071 */  "AddExtL_uxth_and_shift",
  /* 1072 */  "AddExtL_uxth_and_shift_0",
  /* 1073 */  "AddExtL_uxtw_and_shift",
  /* 1074 */  "AddExtL_uxtw_and_shift_0",
  /* 1075 */  "SubExtL_uxtb_and_shift",
  /* 1076 */  "SubExtL_uxth_and_shift",
  /* 1077 */  "SubExtL_uxtw_and_shift",
  /* 1078 */  "AddExtI_uxtb_and_shift",
  /* 1079 */  "AddExtI_uxtb_and_shift_0",
  /* 1080 */  "AddExtI_uxth_and_shift",
  /* 1081 */  "AddExtI_uxth_and_shift_0",
  /* 1082 */  "SubExtI_uxtb_and_shift",
  /* 1083 */  "SubExtI_uxth_and_shift",
  /* 1084 */  "addF_reg_reg",
  /* 1085 */  "addD_reg_reg",
  /* 1086 */  "subF_reg_reg",
  /* 1087 */  "subD_reg_reg",
  /* 1088 */  "mulF_reg_reg",
  /* 1089 */  "mulD_reg_reg",
  /* 1090 */  "maddF_reg_reg",
  /* 1091 */  "maddD_reg_reg",
  /* 1092 */  "msubF_reg_reg",
  /* 1093 */  "msubF_reg_reg_0",
  /* 1094 */  "msubD_reg_reg",
  /* 1095 */  "msubD_reg_reg_0",
  /* 1096 */  "mnaddF_reg_reg",
  /* 1097 */  "mnaddF_reg_reg_0",
  /* 1098 */  "mnaddD_reg_reg",
  /* 1099 */  "mnaddD_reg_reg_0",
  /* 1100 */  "mnsubF_reg_reg",
  /* 1101 */  "mnsubD_reg_reg",
  /* 1102 */  "maxF_reg_reg",
  /* 1103 */  "minF_reg_reg",
  /* 1104 */  "maxD_reg_reg",
  /* 1105 */  "minD_reg_reg",
  /* 1106 */  "divF_reg_reg",
  /* 1107 */  "divD_reg_reg",
  /* 1108 */  "absI_reg",
  /* 1109 */  "absL_reg",
  /* 1110 */  "absdF_reg",
  /* 1111 */  "absdD_reg",
  /* 1112 */  "sqrtD_reg",
  /* 1113 */  "sqrtF_reg",
  /* 1114 */  "roundD_reg",
  /* 1115 */  "copySignD_reg",
  /* 1116 */  "copySignF_reg",
  /* 1117 */  "signumD_reg",
  /* 1118 */  "signumF_reg",
  /* 1119 */  "onspinwait",
  /* 1120 */  "andI_reg_reg",
  /* 1121 */  "andI_reg_imm",
  /* 1122 */  "orI_reg_reg",
  /* 1123 */  "orI_reg_imm",
  /* 1124 */  "xorI_reg_reg",
  /* 1125 */  "xorI_reg_imm",
  /* 1126 */  "andL_reg_reg",
  /* 1127 */  "andL_reg_imm",
  /* 1128 */  "orL_reg_reg",
  /* 1129 */  "orL_reg_imm",
  /* 1130 */  "xorL_reg_reg",
  /* 1131 */  "xorL_reg_imm",
  /* 1132 */  "convI2L_reg_reg",
  /* 1133 */  "convUI2L_reg_reg",
  /* 1134 */  "convL2I_reg",
  /* 1135 */  "convI2B",
  /* 1136 */  "convP2B",
  /* 1137 */  "convD2F_reg",
  /* 1138 */  "convF2D_reg",
  /* 1139 */  "convF2I_reg_reg",
  /* 1140 */  "convF2L_reg_reg",
  /* 1141 */  "convF2HF_reg_reg",
  /* 1142 */  "convHF2F_reg_reg",
  /* 1143 */  "convI2F_reg_reg",
  /* 1144 */  "convL2F_reg_reg",
  /* 1145 */  "convD2I_reg_reg",
  /* 1146 */  "convD2L_reg_reg",
  /* 1147 */  "convI2D_reg_reg",
  /* 1148 */  "convL2D_reg_reg",
  /* 1149 */  "round_double_reg",
  /* 1150 */  "round_float_reg",
  /* 1151 */  "MoveF2I_reg_stack",
  /* 1152 */  "MoveI2F_reg_stack",
  /* 1153 */  "MoveD2L_reg_stack",
  /* 1154 */  "MoveL2D_reg_stack",
  /* 1155 */  "clearArray_reg_reg",
  /* 1156 */  "clearArray_imm_reg",
  /* 1157 */  "overflowMulI_reg_branch",
  /* 1158 */  "overflowMulL_reg_branch",
  /* 1159 */  "compF3_reg_reg",
  /* 1160 */  "compD3_reg_reg",
  /* 1161 */  "compF3_reg_immF0",
  /* 1162 */  "compD3_reg_immD0",
  /* 1163 */  "cmpLTMask_reg_reg",
  /* 1164 */  "cmpLTMask_reg_zero",
  /* 1165 */  "cmovI_reg_reg_lt",
  /* 1166 */  "minI_rReg",
  /* 1167 */  "cmovI_reg_reg_gt",
  /* 1168 */  "maxI_rReg",
  /* 1169 */  "branch",
  /* 1170 */  "branchCon",
  /* 1171 */  "branchConU",
  /* 1172 */  "cmpI_imm0_branch",
  /* 1173 */  "cmpL_imm0_branch",
  /* 1174 */  "cmpP_imm0_branch",
  /* 1175 */  "cmpN_imm0_branch",
  /* 1176 */  "cmpP_narrowOop_imm0_branch",
  /* 1177 */  "cmpUI_imm0_branch",
  /* 1178 */  "cmpUL_imm0_branch",
  /* 1179 */  "cmpL_branch_sign",
  /* 1180 */  "cmpI_branch_sign",
  /* 1181 */  "cmpL_branch_bit",
  /* 1182 */  "cmpI_branch_bit",
  /* 1183 */  "far_cmpL_branch_sign",
  /* 1184 */  "far_cmpI_branch_sign",
  /* 1185 */  "far_cmpL_branch_bit",
  /* 1186 */  "far_cmpI_branch_bit",
  /* 1187 */  "branchLoopEnd",
  /* 1188 */  "branchLoopEndU",
  /* 1189 */  "safePoint",
  /* 1190 */  "CallStaticJavaDirect",
  /* 1191 */  "CallDynamicJavaDirect",
  /* 1192 */  "CallRuntimeDirect",
  /* 1193 */  "CallLeafDirect",
  /* 1194 */  "CallLeafNoFPDirect",
  /* 1195 */  "TailCalljmpInd",
  /* 1196 */  "TailjmpInd",
  /* 1197 */  "CreateException",
  /* 1198 */  "RethrowException",
  /* 1199 */  "Ret",
  /* 1200 */  "ShouldNotReachHere",
  /* 1201 */  "partialSubtypeCheck",
  /* 1202 */  "string_compareU",
  /* 1203 */  "string_compareL",
  /* 1204 */  "string_compareUL",
  /* 1205 */  "string_compareLU",
  /* 1206 */  "string_compareLL_sve",
  /* 1207 */  "string_compareLU_sve",
  /* 1208 */  "string_compareUL_sve",
  /* 1209 */  "string_compareUU_sve",
  /* 1210 */  "string_indexofUU",
  /* 1211 */  "string_indexofLL",
  /* 1212 */  "string_indexofUL",
  /* 1213 */  "string_indexof_conUU",
  /* 1214 */  "string_indexof_conLL",
  /* 1215 */  "string_indexof_conUL",
  /* 1216 */  "string_indexof_char",
  /* 1217 */  "stringL_indexof_char",
  /* 1218 */  "stringL_indexof_char_sve",
  /* 1219 */  "stringU_indexof_char_sve",
  /* 1220 */  "string_equalsL",
  /* 1221 */  "string_equalsU",
  /* 1222 */  "array_equalsB",
  /* 1223 */  "array_equalsC",
  /* 1224 */  "count_positives",
  /* 1225 */  "string_compress",
  /* 1226 */  "string_inflate",
  /* 1227 */  "encode_iso_array",
  /* 1228 */  "encode_ascii_array",
  /* 1229 */  "loadV2",
  /* 1230 */  "storeV2",
  /* 1231 */  "loadV4",
  /* 1232 */  "storeV4",
  /* 1233 */  "loadV8",
  /* 1234 */  "storeV8",
  /* 1235 */  "loadV16",
  /* 1236 */  "storeV16",
  /* 1237 */  "loadV",
  /* 1238 */  "storeV",
  /* 1239 */  "loadV_masked",
  /* 1240 */  "storeV_masked",
  /* 1241 */  "vaddB",
  /* 1242 */  "vaddS",
  /* 1243 */  "vaddI",
  /* 1244 */  "vaddL",
  /* 1245 */  "vaddF",
  /* 1246 */  "vaddD",
  /* 1247 */  "vaddB_masked",
  /* 1248 */  "vaddS_masked",
  /* 1249 */  "vaddI_masked",
  /* 1250 */  "vaddL_masked",
  /* 1251 */  "vaddF_masked",
  /* 1252 */  "vaddD_masked",
  /* 1253 */  "vaddImmB",
  /* 1254 */  "vaddImmB_0",
  /* 1255 */  "vaddImmS",
  /* 1256 */  "vaddImmS_0",
  /* 1257 */  "vaddImmI",
  /* 1258 */  "vaddImmI_0",
  /* 1259 */  "vaddImmL",
  /* 1260 */  "vaddImmL_0",
  /* 1261 */  "vsubB",
  /* 1262 */  "vsubS",
  /* 1263 */  "vsubI",
  /* 1264 */  "vsubL",
  /* 1265 */  "vsubF",
  /* 1266 */  "vsubD",
  /* 1267 */  "vsubB_masked",
  /* 1268 */  "vsubS_masked",
  /* 1269 */  "vsubI_masked",
  /* 1270 */  "vsubL_masked",
  /* 1271 */  "vsubF_masked",
  /* 1272 */  "vsubD_masked",
  /* 1273 */  "vmulB_neon",
  /* 1274 */  "vmulB_sve",
  /* 1275 */  "vmulS_neon",
  /* 1276 */  "vmulS_sve",
  /* 1277 */  "vmulI_neon",
  /* 1278 */  "vmulI_sve",
  /* 1279 */  "vmulL_neon",
  /* 1280 */  "vmulL_sve",
  /* 1281 */  "vmulF",
  /* 1282 */  "vmulD",
  /* 1283 */  "vmulB_masked",
  /* 1284 */  "vmulS_masked",
  /* 1285 */  "vmulI_masked",
  /* 1286 */  "vmulL_masked",
  /* 1287 */  "vmulF_masked",
  /* 1288 */  "vmulD_masked",
  /* 1289 */  "vdivF_neon",
  /* 1290 */  "vdivF_sve",
  /* 1291 */  "vdivD_neon",
  /* 1292 */  "vdivD_sve",
  /* 1293 */  "vdivF_masked",
  /* 1294 */  "vdivD_masked",
  /* 1295 */  "vand",
  /* 1296 */  "vand_masked",
  /* 1297 */  "vandImmB",
  /* 1298 */  "vandImmB_0",
  /* 1299 */  "vandImmS",
  /* 1300 */  "vandImmS_0",
  /* 1301 */  "vandImmI",
  /* 1302 */  "vandImmI_0",
  /* 1303 */  "vandImmL",
  /* 1304 */  "vandImmL_0",
  /* 1305 */  "vor",
  /* 1306 */  "vor_masked",
  /* 1307 */  "vorImmB",
  /* 1308 */  "vorImmB_0",
  /* 1309 */  "vorImmS",
  /* 1310 */  "vorImmS_0",
  /* 1311 */  "vorImmI",
  /* 1312 */  "vorImmI_0",
  /* 1313 */  "vorImmL",
  /* 1314 */  "vorImmL_0",
  /* 1315 */  "vxor",
  /* 1316 */  "vxor_masked",
  /* 1317 */  "vxorImmB",
  /* 1318 */  "vxorImmB_0",
  /* 1319 */  "vxorImmS",
  /* 1320 */  "vxorImmS_0",
  /* 1321 */  "vxorImmI",
  /* 1322 */  "vxorImmI_0",
  /* 1323 */  "vxorImmL",
  /* 1324 */  "vxorImmL_0",
  /* 1325 */  "veor3_neon",
  /* 1326 */  "veor3_neon_0",
  /* 1327 */  "veor3_sve",
  /* 1328 */  "veor3_sve_0",
  /* 1329 */  "vnotI",
  /* 1330 */  "vnotI_0",
  /* 1331 */  "vnotI_1",
  /* 1332 */  "vnotI_2",
  /* 1333 */  "vnotI_3",
  /* 1334 */  "vnotI_4",
  /* 1335 */  "vnotL",
  /* 1336 */  "vnotL_0",
  /* 1337 */  "vnotI_masked",
  /* 1338 */  "vnotI_masked_0",
  /* 1339 */  "vnotI_masked_1",
  /* 1340 */  "vnotL_masked",
  /* 1341 */  "vand_notI",
  /* 1342 */  "vand_notI_1",
  /* 1343 */  "vand_notI_0",
  /* 1344 */  "vand_notI_2",
  /* 1345 */  "vand_notI_3",
  /* 1346 */  "vand_notI_5",
  /* 1347 */  "vand_notI_4",
  /* 1348 */  "vand_notI_6",
  /* 1349 */  "vand_notI_7",
  /* 1350 */  "vand_notI_9",
  /* 1351 */  "vand_notI_8",
  /* 1352 */  "vand_notI_10",
  /* 1353 */  "vand_notL",
  /* 1354 */  "vand_notL_1",
  /* 1355 */  "vand_notL_0",
  /* 1356 */  "vand_notL_2",
  /* 1357 */  "vand_notI_masked",
  /* 1358 */  "vand_notI_masked_0",
  /* 1359 */  "vand_notI_masked_1",
  /* 1360 */  "vand_notI_masked_2",
  /* 1361 */  "vand_notI_masked_3",
  /* 1362 */  "vand_notI_masked_4",
  /* 1363 */  "vand_notL_masked",
  /* 1364 */  "vand_notL_masked_0",
  /* 1365 */  "vabsB_masked",
  /* 1366 */  "vabsS_masked",
  /* 1367 */  "vabsI_masked",
  /* 1368 */  "vabsL_masked",
  /* 1369 */  "vabsF_masked",
  /* 1370 */  "vabsD_masked",
  /* 1371 */  "vfabd_neon",
  /* 1372 */  "vfabd_neon_0",
  /* 1373 */  "vfabd_sve",
  /* 1374 */  "vfabd_sve_0",
  /* 1375 */  "vfabd_masked",
  /* 1376 */  "vfabd_masked_0",
  /* 1377 */  "vnegI_masked",
  /* 1378 */  "vnegL_masked",
  /* 1379 */  "vnegF_masked",
  /* 1380 */  "vnegD_masked",
  /* 1381 */  "vsqrtF_masked",
  /* 1382 */  "vsqrtD_masked",
  /* 1383 */  "vminL_neon",
  /* 1384 */  "vminL_sve",
  /* 1385 */  "vmin_neon",
  /* 1386 */  "vmin_sve",
  /* 1387 */  "vmin_masked",
  /* 1388 */  "vmaxL_neon",
  /* 1389 */  "vmaxL_sve",
  /* 1390 */  "vmax_neon",
  /* 1391 */  "vmax_sve",
  /* 1392 */  "vmax_masked",
  /* 1393 */  "vmla",
  /* 1394 */  "vmla_0",
  /* 1395 */  "vmla_1",
  /* 1396 */  "vmla_2",
  /* 1397 */  "vmla_3",
  /* 1398 */  "vmla_4",
  /* 1399 */  "vmlaL",
  /* 1400 */  "vmlaL_0",
  /* 1401 */  "vmla_masked",
  /* 1402 */  "vmla_masked_0",
  /* 1403 */  "vmla_masked_1",
  /* 1404 */  "vmla_masked_2",
  /* 1405 */  "vfmla",
  /* 1406 */  "vfmla_0",
  /* 1407 */  "vfmad_masked",
  /* 1408 */  "vfmad_masked_0",
  /* 1409 */  "vmls",
  /* 1410 */  "vmls_0",
  /* 1411 */  "vmls_1",
  /* 1412 */  "vmlsL",
  /* 1413 */  "vmls_masked",
  /* 1414 */  "vmls_masked_0",
  /* 1415 */  "vmls_masked_1",
  /* 1416 */  "vmls_masked_2",
  /* 1417 */  "vfmls1",
  /* 1418 */  "vfmls1_0",
  /* 1419 */  "vfmls2",
  /* 1420 */  "vfmls2_0",
  /* 1421 */  "vfmsb_masked",
  /* 1422 */  "vfmsb_masked_0",
  /* 1423 */  "vfnmla1",
  /* 1424 */  "vfnmla1_0",
  /* 1425 */  "vfnmla2",
  /* 1426 */  "vfnmla2_0",
  /* 1427 */  "vfnmad_masked",
  /* 1428 */  "vfnmad_masked_0",
  /* 1429 */  "vfnmls",
  /* 1430 */  "vfnmls_0",
  /* 1431 */  "vfnmsb_masked",
  /* 1432 */  "vfnmsb_masked_0",
  /* 1433 */  "vmuladdS2I",
  /* 1434 */  "vlsl_neon",
  /* 1435 */  "vlsl_neon_0",
  /* 1436 */  "vlsl_neon_1",
  /* 1437 */  "vlsl_neon_2",
  /* 1438 */  "vlsl_sve",
  /* 1439 */  "vlsl_sve_0",
  /* 1440 */  "vlsl_sve_1",
  /* 1441 */  "vlsl_sve_2",
  /* 1442 */  "vasr_neon",
  /* 1443 */  "vasr_neon_0",
  /* 1444 */  "vasr_neon_1",
  /* 1445 */  "vasr_neon_2",
  /* 1446 */  "vasr_neon_var",
  /* 1447 */  "vasr_neon_var_0",
  /* 1448 */  "vasr_neon_var_1",
  /* 1449 */  "vasr_neon_var_2",
  /* 1450 */  "vasr_sve",
  /* 1451 */  "vasr_sve_0",
  /* 1452 */  "vasr_sve_1",
  /* 1453 */  "vasr_sve_2",
  /* 1454 */  "vlsr_neon",
  /* 1455 */  "vlsr_neon_0",
  /* 1456 */  "vlsr_neon_1",
  /* 1457 */  "vlsr_neon_2",
  /* 1458 */  "vlsr_neon_var",
  /* 1459 */  "vlsr_neon_var_0",
  /* 1460 */  "vlsr_neon_var_1",
  /* 1461 */  "vlsr_neon_var_2",
  /* 1462 */  "vlsr_sve",
  /* 1463 */  "vlsr_sve_0",
  /* 1464 */  "vlsr_sve_1",
  /* 1465 */  "vlsr_sve_2",
  /* 1466 */  "vlsl_imm",
  /* 1467 */  "vlsl_imm_0",
  /* 1468 */  "vlsl_imm_1",
  /* 1469 */  "vlsl_imm_2",
  /* 1470 */  "vasr_imm",
  /* 1471 */  "vasr_imm_0",
  /* 1472 */  "vasr_imm_1",
  /* 1473 */  "vasr_imm_2",
  /* 1474 */  "vlsr_imm",
  /* 1475 */  "vlsr_imm_0",
  /* 1476 */  "vlsr_imm_1",
  /* 1477 */  "vlsr_imm_2",
  /* 1478 */  "vasra_imm",
  /* 1479 */  "vasra_imm_0",
  /* 1480 */  "vasra_imm_1",
  /* 1481 */  "vasra_imm_2",
  /* 1482 */  "vasra_imm_3",
  /* 1483 */  "vasra_imm_4",
  /* 1484 */  "vasra_imm_5",
  /* 1485 */  "vasra_imm_6",
  /* 1486 */  "vlsra_imm",
  /* 1487 */  "vlsra_imm_0",
  /* 1488 */  "vlsra_imm_1",
  /* 1489 */  "vlsra_imm_2",
  /* 1490 */  "vlsra_imm_3",
  /* 1491 */  "vlsra_imm_4",
  /* 1492 */  "vlsra_imm_5",
  /* 1493 */  "vlsra_imm_6",
  /* 1494 */  "vlsl_masked",
  /* 1495 */  "vlsl_masked_0",
  /* 1496 */  "vlsl_masked_1",
  /* 1497 */  "vlsl_masked_2",
  /* 1498 */  "vasr_masked",
  /* 1499 */  "vasr_masked_0",
  /* 1500 */  "vasr_masked_1",
  /* 1501 */  "vasr_masked_2",
  /* 1502 */  "vlsr_masked",
  /* 1503 */  "vlsr_masked_0",
  /* 1504 */  "vlsr_masked_1",
  /* 1505 */  "vlsr_masked_2",
  /* 1506 */  "vlsl_imm_masked",
  /* 1507 */  "vlsl_imm_masked_0",
  /* 1508 */  "vlsl_imm_masked_1",
  /* 1509 */  "vlsl_imm_masked_2",
  /* 1510 */  "vasr_imm_masked",
  /* 1511 */  "vasr_imm_masked_0",
  /* 1512 */  "vasr_imm_masked_1",
  /* 1513 */  "vasr_imm_masked_2",
  /* 1514 */  "vlsr_imm_masked",
  /* 1515 */  "vlsr_imm_masked_0",
  /* 1516 */  "vlsr_imm_masked_1",
  /* 1517 */  "vlsr_imm_masked_2",
  /* 1518 */  "reduce_addI_neon",
  /* 1519 */  "reduce_addI_sve",
  /* 1520 */  "reduce_addL_neon",
  /* 1521 */  "reduce_addL_sve",
  /* 1522 */  "reduce_addF_neon",
  /* 1523 */  "reduce_addF_sve",
  /* 1524 */  "reduce_addD_neon",
  /* 1525 */  "reduce_addD_sve",
  /* 1526 */  "reduce_addI_masked",
  /* 1527 */  "reduce_addL_masked",
  /* 1528 */  "reduce_addF_masked",
  /* 1529 */  "reduce_addD_masked",
  /* 1530 */  "reduce_mulI",
  /* 1531 */  "reduce_mulL",
  /* 1532 */  "reduce_mulF",
  /* 1533 */  "reduce_mulD",
  /* 1534 */  "reduce_andI_neon",
  /* 1535 */  "reduce_andI_sve",
  /* 1536 */  "reduce_andL_neon",
  /* 1537 */  "reduce_andL_sve",
  /* 1538 */  "reduce_andI_masked",
  /* 1539 */  "reduce_andL_masked",
  /* 1540 */  "reduce_orI_neon",
  /* 1541 */  "reduce_orI_sve",
  /* 1542 */  "reduce_orL_neon",
  /* 1543 */  "reduce_orL_sve",
  /* 1544 */  "reduce_orI_masked",
  /* 1545 */  "reduce_orL_masked",
  /* 1546 */  "reduce_xorI_neon",
  /* 1547 */  "reduce_xorI_sve",
  /* 1548 */  "reduce_xorL_neon",
  /* 1549 */  "reduce_xorL_sve",
  /* 1550 */  "reduce_xorI_masked",
  /* 1551 */  "reduce_xorL_masked",
  /* 1552 */  "reduce_maxI_neon",
  /* 1553 */  "reduce_maxI_sve",
  /* 1554 */  "reduce_maxL_neon",
  /* 1555 */  "reduce_maxL_sve",
  /* 1556 */  "reduce_maxF",
  /* 1557 */  "reduce_maxD",
  /* 1558 */  "reduce_maxI_masked",
  /* 1559 */  "reduce_maxL_masked",
  /* 1560 */  "reduce_maxF_masked",
  /* 1561 */  "reduce_maxD_masked",
  /* 1562 */  "reduce_minI_neon",
  /* 1563 */  "reduce_minI_sve",
  /* 1564 */  "reduce_minL_neon",
  /* 1565 */  "reduce_minL_sve",
  /* 1566 */  "reduce_minF",
  /* 1567 */  "reduce_minD",
  /* 1568 */  "reduce_minI_masked",
  /* 1569 */  "reduce_minL_masked",
  /* 1570 */  "reduce_minF_masked",
  /* 1571 */  "reduce_minD_masked",
  /* 1572 */  "reinterpret_resize_gt128b",
  /* 1573 */  "vcvtStoB_sve",
  /* 1574 */  "vcvtItoX_narrow_neon",
  /* 1575 */  "vcvtItoX_narrow_sve",
  /* 1576 */  "vcvtLtoI_sve",
  /* 1577 */  "vcvtLtoF_neon",
  /* 1578 */  "vcvtLtoF_sve",
  /* 1579 */  "vcvtFtoX_narrow_neon",
  /* 1580 */  "vcvtFtoX_narrow_sve",
  /* 1581 */  "vcvtDtoI_neon",
  /* 1582 */  "vcvtDtoI_sve",
  /* 1583 */  "vcvtDtoF_gt64b",
  /* 1584 */  "insertI_le128b",
  /* 1585 */  "insertI_index_lt32",
  /* 1586 */  "insertI_index_ge32",
  /* 1587 */  "insertL_128b",
  /* 1588 */  "insertL_gt128b",
  /* 1589 */  "insertF_le128b",
  /* 1590 */  "insertF_index_lt32",
  /* 1591 */  "insertF_index_ge32",
  /* 1592 */  "insertD_128b",
  /* 1593 */  "insertD_gt128b",
  /* 1594 */  "extractB_index_lt16",
  /* 1595 */  "extractB_index_ge16",
  /* 1596 */  "extractS_index_lt8",
  /* 1597 */  "extractS_index_ge8",
  /* 1598 */  "extractI_index_lt4",
  /* 1599 */  "extractI_index_ge4",
  /* 1600 */  "extractL_index_lt2",
  /* 1601 */  "extractL_index_ge2",
  /* 1602 */  "extractF",
  /* 1603 */  "extractD",
  /* 1604 */  "vloadmaskB_sve",
  /* 1605 */  "vloadmask_extend_sve",
  /* 1606 */  "vloadmaskB_masked",
  /* 1607 */  "vloadmask_extend_masked",
  /* 1608 */  "vstoremaskB_neon",
  /* 1609 */  "vstoremask_narrow_neon",
  /* 1610 */  "vstoremaskB_sve",
  /* 1611 */  "vstoremask_narrow_sve",
  /* 1612 */  "vloadmask_loadV",
  /* 1613 */  "vloadmask_loadV_masked",
  /* 1614 */  "vloadmask_loadVMasked",
  /* 1615 */  "vloadmask_loadVMasked_masked",
  /* 1616 */  "storeV_vstoremask",
  /* 1617 */  "storeV_vstoremask_masked",
  /* 1618 */  "storeVMasked_vstoremask",
  /* 1619 */  "storeVMasked_vstoremask_masked",
  /* 1620 */  "vmask_and",
  /* 1621 */  "vmask_or",
  /* 1622 */  "vmask_xor",
  /* 1623 */  "vmask_and_notI",
  /* 1624 */  "vmask_and_notL",
  /* 1625 */  "vmaskcmp_neon",
  /* 1626 */  "vmaskcmp_sve",
  /* 1627 */  "vmaskcmp_masked",
  /* 1628 */  "vmask_reinterpret_diff_esize",
  /* 1629 */  "vmask_truecount_neon",
  /* 1630 */  "vmask_firsttrue_lt8e",
  /* 1631 */  "vmask_firsttrue_sve",
  /* 1632 */  "vmask_firsttrue_masked",
  /* 1633 */  "vmask_lasttrue_sve",
  /* 1634 */  "vmask_tolong_sve",
  /* 1635 */  "vmask_fromlong",
  /* 1636 */  "vmaskAll_immI",
  /* 1637 */  "vmaskAllI",
  /* 1638 */  "vmaskAllI_masked",
  /* 1639 */  "vmaskAll_immL",
  /* 1640 */  "vmaskAllL",
  /* 1641 */  "vmaskAllL_masked",
  /* 1642 */  "vmask_gen_I",
  /* 1643 */  "vmask_gen_L",
  /* 1644 */  "vmask_gen_imm",
  /* 1645 */  "vpopcountI_masked",
  /* 1646 */  "vpopcountL_masked",
  /* 1647 */  "vblend_neon",
  /* 1648 */  "vblend_sve",
  /* 1649 */  "vcmove_neon",
  /* 1650 */  "vcmove_neon_0",
  /* 1651 */  "vcmove_sve",
  /* 1652 */  "vcmove_sve_0",
  /* 1653 */  "vround_le128b",
  /* 1654 */  "vround_le128b_0",
  /* 1655 */  "vround_gt128b",
  /* 1656 */  "vround_gt128b_0",
  /* 1657 */  "vroundD",
  /* 1658 */  "vtest_anytrue_neon",
  /* 1659 */  "vtest_anytrue_sve",
  /* 1660 */  "vtest_alltrue_neon",
  /* 1661 */  "vtest_alltrue_sve",
  /* 1662 */  "rearrange_HS_neon",
  /* 1663 */  "rearrange",
  /* 1664 */  "gather_loadS",
  /* 1665 */  "gather_loadD",
  /* 1666 */  "gather_loadS_masked",
  /* 1667 */  "gather_loadD_masked",
  /* 1668 */  "scatter_storeS",
  /* 1669 */  "scatter_storeD",
  /* 1670 */  "scatter_storeS_masked",
  /* 1671 */  "scatter_storeD_masked",
  /* 1672 */  "vcountLeadingZeros_masked",
  /* 1673 */  "vcountTrailingZeros_masked",
  /* 1674 */  "vreverse_masked",
  /* 1675 */  "vreverseBytes_masked",
  /* 1676 */  "populateindex",
  /* 1677 */  "mcompress",
  /* 1678 */  "vcompress",
  /* 1679 */  "vcompressB",
  /* 1680 */  "vcompressS",
  /* 1681 */  "vexpand",
  /* 1682 */  "vsignum_le128b",
  /* 1683 */  "vsignum_le128b_0",
  /* 1684 */  "vsignum_gt128b",
  /* 1685 */  "vsignum_gt128b_0",
  /* 1686 */  "compareAndSwapP_shenandoah",
  /* 1687 */  "compareAndSwapN_shenandoah",
  /* 1688 */  "compareAndSwapPAcq_shenandoah",
  /* 1689 */  "compareAndSwapNAcq_shenandoah",
  /* 1690 */  "compareAndExchangeN_shenandoah",
  /* 1691 */  "compareAndExchangeP_shenandoah",
  /* 1692 */  "compareAndExchangeNAcq_shenandoah",
  /* 1693 */  "compareAndExchangePAcq_shenandoah",
  /* 1694 */  "weakCompareAndSwapN_shenandoah",
  /* 1695 */  "weakCompareAndSwapP_shenandoah",
  /* 1696 */  "weakCompareAndSwapNAcq_shenandoah",
  /* 1697 */  "weakCompareAndSwapPAcq_shenandoah",
  /* 1698 */  "zLoadP",
  /* 1699 */  "zLoadPVolatile",
  /* 1700 */  "zCompareAndSwapP",
  /* 1701 */  "zCompareAndSwapP_0",
  /* 1702 */  "zCompareAndSwapPAcq",
  /* 1703 */  "zCompareAndSwapPAcq_0",
  /* 1704 */  "zCompareAndExchangeP",
  /* 1705 */  "zCompareAndExchangePAcq",
  /* 1706 */  "zGetAndSetP",
  /* 1707 */  "zGetAndSetPAcq",
  // last instruction
  "invalid rule name" // no trailing comma
};

const        bool  swallowed[] = {
  /*    0 */  false,
  /*    1 */  false,
  /*    2 */  false,
  /*    3 */  false,
  /*    4 */  false,
  /*    5 */  false,
  /*    6 */  false,
  /*    7 */  false,
  /*    8 */  true,
  /*    9 */  true,
  /*   10 */  true,
  /*   11 */  true,
  /*   12 */  true,
  /*   13 */  true,
  /*   14 */  true,
  /*   15 */  true,
  /*   16 */  true,
  /*   17 */  true,
  /*   18 */  true,
  /*   19 */  true,
  /*   20 */  true,
  /*   21 */  true,
  /*   22 */  true,
  /*   23 */  true,
  /*   24 */  true,
  /*   25 */  true,
  /*   26 */  true,
  /*   27 */  true,
  /*   28 */  true,
  /*   29 */  true,
  /*   30 */  true,
  /*   31 */  true,
  /*   32 */  true,
  /*   33 */  true,
  /*   34 */  true,
  /*   35 */  true,
  /*   36 */  true,
  /*   37 */  true,
  /*   38 */  true,
  /*   39 */  true,
  /*   40 */  true,
  /*   41 */  true,
  /*   42 */  true,
  /*   43 */  true,
  /*   44 */  true,
  /*   45 */  true,
  /*   46 */  true,
  /*   47 */  true,
  /*   48 */  true,
  /*   49 */  true,
  /*   50 */  true,
  /*   51 */  true,
  /*   52 */  true,
  /*   53 */  true,
  /*   54 */  true,
  /*   55 */  true,
  /*   56 */  true,
  /*   57 */  true,
  /*   58 */  true,
  /*   59 */  true,
  /*   60 */  true,
  /*   61 */  true,
  /*   62 */  true,
  /*   63 */  true,
  /*   64 */  true,
  /*   65 */  true,
  /*   66 */  true,
  /*   67 */  true,
  /*   68 */  true,
  /*   69 */  true,
  /*   70 */  true,
  /*   71 */  true,
  /*   72 */  true,
  /*   73 */  true,
  /*   74 */  true,
  /*   75 */  true,
  /*   76 */  true,
  /*   77 */  true,
  /*   78 */  true,
  /*   79 */  true,
  /*   80 */  true,
  /*   81 */  false,
  /*   82 */  false,
  /*   83 */  false,
  /*   84 */  false,
  /*   85 */  false,
  /*   86 */  false,
  /*   87 */  false,
  /*   88 */  false,
  /*   89 */  false,
  /*   90 */  false,
  /*   91 */  false,
  /*   92 */  false,
  /*   93 */  false,
  /*   94 */  false,
  /*   95 */  false,
  /*   96 */  false,
  /*   97 */  false,
  /*   98 */  false,
  /*   99 */  false,
  /*  100 */  false,
  /*  101 */  false,
  /*  102 */  false,
  /*  103 */  false,
  /*  104 */  false,
  /*  105 */  false,
  /*  106 */  false,
  /*  107 */  false,
  /*  108 */  false,
  /*  109 */  false,
  /*  110 */  false,
  /*  111 */  false,
  /*  112 */  false,
  /*  113 */  false,
  /*  114 */  false,
  /*  115 */  false,
  /*  116 */  false,
  /*  117 */  false,
  /*  118 */  false,
  /*  119 */  false,
  /*  120 */  false,
  /*  121 */  false,
  /*  122 */  false,
  /*  123 */  false,
  /*  124 */  false,
  /*  125 */  false,
  /*  126 */  false,
  /*  127 */  false,
  /*  128 */  false,
  /*  129 */  false,
  /*  130 */  false,
  /*  131 */  false,
  /*  132 */  false,
  /*  133 */  false,
  /*  134 */  false,
  /*  135 */  false,
  /*  136 */  false,
  /*  137 */  false,
  /*  138 */  false,
  /*  139 */  false,
  /*  140 */  false,
  /*  141 */  false,
  /*  142 */  false,
  /*  143 */  false,
  /*  144 */  false,
  /*  145 */  false,
  /*  146 */  false,
  /*  147 */  false,
  /*  148 */  false,
  /*  149 */  false,
  /*  150 */  false,
  /*  151 */  false,
  /*  152 */  false,
  /*  153 */  false,
  /*  154 */  false,
  /*  155 */  false,
  /*  156 */  false,
  /*  157 */  false,
  /*  158 */  false,
  /*  159 */  false,
  /*  160 */  false,
  /*  161 */  false,
  /*  162 */  false,
  /*  163 */  false,
  /*  164 */  false,
  /*  165 */  false,
  /*  166 */  false,
  /*  167 */  false,
  /*  168 */  false,
  /*  169 */  false,
  /*  170 */  false,
  /*  171 */  false,
  /*  172 */  false,
  /*  173 */  false,
  /*  174 */  false,
  /*  175 */  false,
  /*  176 */  false,
  /*  177 */  false,
  /*  178 */  false,
  /*  179 */  false,
  /*  180 */  false,
  /*  181 */  false,
  /*  182 */  false,
  /*  183 */  false,
  /*  184 */  false,
  /*  185 */  false,
  /*  186 */  true,
  /*  187 */  true,
  /*  188 */  true,
  /*  189 */  true,
  /*  190 */  true,
  /*  191 */  false,
  /*  192 */  true,
  /*  193 */  true,
  /*  194 */  false,
  /*  195 */  false,
  // last operand
  /*  196 */  false,
  /*  197 */  false,
  /*  198 */  false,
  /*  199 */  false,
  /*  200 */  false,
  /*  201 */  false,
  /*  202 */  false,
  /*  203 */  false,
  /*  204 */  false,
  /*  205 */  false,
  /*  206 */  false,
  // last operand class
  /*  207 */  false,
  /*  208 */  false,
  /*  209 */  false,
  /*  210 */  false,
  /*  211 */  false,
  /*  212 */  false,
  /*  213 */  false,
  /*  214 */  false,
  /*  215 */  false,
  /*  216 */  false,
  /*  217 */  false,
  /*  218 */  false,
  /*  219 */  false,
  /*  220 */  false,
  /*  221 */  false,
  /*  222 */  false,
  /*  223 */  false,
  /*  224 */  false,
  /*  225 */  false,
  /*  226 */  false,
  /*  227 */  false,
  /*  228 */  false,
  /*  229 */  false,
  /*  230 */  false,
  /*  231 */  false,
  /*  232 */  false,
  /*  233 */  false,
  /*  234 */  false,
  /*  235 */  false,
  /*  236 */  false,
  /*  237 */  false,
  /*  238 */  false,
  /*  239 */  false,
  /*  240 */  false,
  /*  241 */  false,
  /*  242 */  false,
  /*  243 */  false,
  /*  244 */  false,
  /*  245 */  false,
  /*  246 */  false,
  /*  247 */  false,
  /*  248 */  false,
  /*  249 */  false,
  /*  250 */  false,
  /*  251 */  false,
  /*  252 */  false,
  /*  253 */  false,
  /*  254 */  false,
  /*  255 */  false,
  /*  256 */  false,
  /*  257 */  false,
  /*  258 */  false,
  /*  259 */  false,
  /*  260 */  false,
  /*  261 */  false,
  /*  262 */  false,
  /*  263 */  false,
  /*  264 */  false,
  /*  265 */  false,
  /*  266 */  false,
  /*  267 */  false,
  /*  268 */  false,
  /*  269 */  false,
  /*  270 */  false,
  /*  271 */  false,
  /*  272 */  false,
  /*  273 */  false,
  /*  274 */  false,
  /*  275 */  false,
  /*  276 */  false,
  /*  277 */  false,
  /*  278 */  false,
  /*  279 */  false,
  /*  280 */  false,
  /*  281 */  false,
  /*  282 */  false,
  /*  283 */  false,
  /*  284 */  false,
  /*  285 */  false,
  /*  286 */  false,
  /*  287 */  false,
  /*  288 */  false,
  /*  289 */  false,
  /*  290 */  false,
  /*  291 */  false,
  /*  292 */  false,
  /*  293 */  false,
  /*  294 */  false,
  /*  295 */  false,
  /*  296 */  false,
  /*  297 */  false,
  /*  298 */  false,
  /*  299 */  false,
  /*  300 */  false,
  /*  301 */  false,
  /*  302 */  false,
  /*  303 */  false,
  /*  304 */  false,
  /*  305 */  false,
  /*  306 */  false,
  /*  307 */  false,
  /*  308 */  false,
  /*  309 */  false,
  /*  310 */  false,
  /*  311 */  false,
  /*  312 */  false,
  /*  313 */  false,
  /*  314 */  false,
  /*  315 */  false,
  /*  316 */  false,
  /*  317 */  false,
  /*  318 */  false,
  /*  319 */  false,
  /*  320 */  false,
  /*  321 */  false,
  /*  322 */  false,
  /*  323 */  false,
  /*  324 */  false,
  /*  325 */  false,
  /*  326 */  false,
  /*  327 */  false,
  /*  328 */  false,
  /*  329 */  false,
  /*  330 */  false,
  /*  331 */  false,
  /*  332 */  false,
  /*  333 */  false,
  /*  334 */  false,
  /*  335 */  false,
  /*  336 */  false,
  /*  337 */  false,
  /*  338 */  false,
  /*  339 */  false,
  /*  340 */  false,
  /*  341 */  false,
  /*  342 */  false,
  /*  343 */  false,
  /*  344 */  false,
  /*  345 */  false,
  /*  346 */  false,
  /*  347 */  false,
  /*  348 */  false,
  /*  349 */  false,
  /*  350 */  false,
  /*  351 */  false,
  /*  352 */  false,
  /*  353 */  false,
  /*  354 */  false,
  /*  355 */  false,
  /*  356 */  false,
  /*  357 */  false,
  /*  358 */  false,
  /*  359 */  false,
  /*  360 */  false,
  /*  361 */  false,
  /*  362 */  false,
  /*  363 */  false,
  /*  364 */  false,
  /*  365 */  false,
  /*  366 */  false,
  /*  367 */  false,
  /*  368 */  false,
  /*  369 */  false,
  /*  370 */  false,
  /*  371 */  false,
  /*  372 */  false,
  /*  373 */  false,
  /*  374 */  false,
  /*  375 */  false,
  /*  376 */  false,
  /*  377 */  false,
  /*  378 */  false,
  /*  379 */  false,
  /*  380 */  false,
  /*  381 */  false,
  /*  382 */  false,
  /*  383 */  false,
  /*  384 */  false,
  /*  385 */  false,
  /*  386 */  false,
  /*  387 */  false,
  /*  388 */  false,
  /*  389 */  false,
  /*  390 */  false,
  /*  391 */  false,
  /*  392 */  false,
  /*  393 */  false,
  /*  394 */  false,
  /*  395 */  false,
  /*  396 */  false,
  /*  397 */  false,
  /*  398 */  false,
  /*  399 */  false,
  /*  400 */  false,
  /*  401 */  false,
  /*  402 */  false,
  /*  403 */  false,
  /*  404 */  false,
  /*  405 */  false,
  /*  406 */  false,
  /*  407 */  false,
  /*  408 */  false,
  /*  409 */  false,
  /*  410 */  false,
  /*  411 */  false,
  /*  412 */  false,
  /*  413 */  false,
  /*  414 */  false,
  /*  415 */  false,
  /*  416 */  false,
  /*  417 */  false,
  /*  418 */  false,
  /*  419 */  false,
  /*  420 */  false,
  /*  421 */  false,
  /*  422 */  false,
  /*  423 */  false,
  /*  424 */  false,
  /*  425 */  false,
  /*  426 */  false,
  /*  427 */  false,
  /*  428 */  false,
  /*  429 */  false,
  /*  430 */  false,
  /*  431 */  false,
  /*  432 */  false,
  /*  433 */  false,
  /*  434 */  false,
  /*  435 */  false,
  /*  436 */  false,
  /*  437 */  false,
  /*  438 */  false,
  /*  439 */  false,
  /*  440 */  false,
  /*  441 */  false,
  /*  442 */  false,
  /*  443 */  false,
  /*  444 */  false,
  /*  445 */  false,
  /*  446 */  false,
  // last internally defined operand
  /*  447 */  false,
  /*  448 */  false,
  /*  449 */  false,
  /*  450 */  false,
  /*  451 */  false,
  /*  452 */  false,
  /*  453 */  false,
  /*  454 */  false,
  /*  455 */  false,
  /*  456 */  false,
  /*  457 */  false,
  /*  458 */  false,
  /*  459 */  false,
  /*  460 */  false,
  /*  461 */  false,
  /*  462 */  false,
  /*  463 */  false,
  /*  464 */  false,
  /*  465 */  false,
  /*  466 */  false,
  /*  467 */  false,
  /*  468 */  false,
  /*  469 */  false,
  /*  470 */  false,
  /*  471 */  false,
  /*  472 */  false,
  /*  473 */  false,
  /*  474 */  false,
  /*  475 */  false,
  /*  476 */  false,
  /*  477 */  false,
  /*  478 */  false,
  /*  479 */  false,
  /*  480 */  false,
  /*  481 */  false,
  /*  482 */  false,
  /*  483 */  false,
  /*  484 */  false,
  /*  485 */  false,
  /*  486 */  false,
  /*  487 */  false,
  /*  488 */  false,
  /*  489 */  false,
  /*  490 */  false,
  /*  491 */  false,
  /*  492 */  false,
  /*  493 */  false,
  /*  494 */  false,
  /*  495 */  false,
  /*  496 */  false,
  /*  497 */  false,
  /*  498 */  false,
  /*  499 */  false,
  /*  500 */  false,
  /*  501 */  false,
  /*  502 */  false,
  /*  503 */  false,
  /*  504 */  false,
  /*  505 */  false,
  /*  506 */  false,
  /*  507 */  false,
  /*  508 */  false,
  /*  509 */  false,
  /*  510 */  false,
  /*  511 */  false,
  /*  512 */  false,
  /*  513 */  false,
  /*  514 */  false,
  /*  515 */  false,
  /*  516 */  false,
  /*  517 */  false,
  /*  518 */  false,
  /*  519 */  false,
  /*  520 */  false,
  /*  521 */  false,
  /*  522 */  false,
  /*  523 */  false,
  /*  524 */  false,
  /*  525 */  false,
  /*  526 */  false,
  /*  527 */  false,
  /*  528 */  false,
  /*  529 */  false,
  /*  530 */  false,
  /*  531 */  false,
  /*  532 */  false,
  /*  533 */  false,
  /*  534 */  false,
  /*  535 */  false,
  /*  536 */  false,
  /*  537 */  false,
  /*  538 */  false,
  /*  539 */  false,
  /*  540 */  false,
  /*  541 */  false,
  /*  542 */  false,
  /*  543 */  false,
  /*  544 */  false,
  /*  545 */  false,
  /*  546 */  false,
  /*  547 */  false,
  /*  548 */  false,
  /*  549 */  false,
  /*  550 */  false,
  /*  551 */  false,
  /*  552 */  false,
  /*  553 */  false,
  /*  554 */  false,
  /*  555 */  false,
  /*  556 */  false,
  /*  557 */  false,
  /*  558 */  false,
  /*  559 */  false,
  /*  560 */  false,
  /*  561 */  false,
  /*  562 */  false,
  /*  563 */  false,
  /*  564 */  false,
  /*  565 */  false,
  /*  566 */  false,
  /*  567 */  false,
  /*  568 */  false,
  /*  569 */  false,
  /*  570 */  false,
  /*  571 */  false,
  /*  572 */  false,
  /*  573 */  false,
  /*  574 */  false,
  /*  575 */  false,
  /*  576 */  false,
  /*  577 */  false,
  /*  578 */  false,
  /*  579 */  false,
  /*  580 */  false,
  /*  581 */  false,
  /*  582 */  false,
  /*  583 */  false,
  /*  584 */  false,
  /*  585 */  false,
  /*  586 */  false,
  /*  587 */  false,
  /*  588 */  false,
  /*  589 */  false,
  /*  590 */  false,
  /*  591 */  false,
  /*  592 */  false,
  /*  593 */  false,
  /*  594 */  false,
  /*  595 */  false,
  /*  596 */  false,
  /*  597 */  false,
  /*  598 */  false,
  /*  599 */  false,
  /*  600 */  false,
  /*  601 */  false,
  /*  602 */  false,
  /*  603 */  false,
  /*  604 */  false,
  /*  605 */  false,
  /*  606 */  false,
  /*  607 */  false,
  /*  608 */  false,
  /*  609 */  false,
  /*  610 */  false,
  /*  611 */  false,
  /*  612 */  false,
  /*  613 */  false,
  /*  614 */  false,
  /*  615 */  false,
  /*  616 */  false,
  /*  617 */  false,
  /*  618 */  false,
  /*  619 */  false,
  /*  620 */  false,
  /*  621 */  false,
  /*  622 */  false,
  /*  623 */  false,
  /*  624 */  false,
  /*  625 */  false,
  /*  626 */  false,
  /*  627 */  false,
  /*  628 */  false,
  /*  629 */  false,
  /*  630 */  false,
  /*  631 */  false,
  /*  632 */  false,
  /*  633 */  false,
  /*  634 */  false,
  /*  635 */  false,
  /*  636 */  false,
  /*  637 */  false,
  /*  638 */  false,
  /*  639 */  false,
  /*  640 */  false,
  /*  641 */  false,
  /*  642 */  false,
  /*  643 */  false,
  /*  644 */  false,
  /*  645 */  false,
  /*  646 */  false,
  /*  647 */  false,
  /*  648 */  false,
  /*  649 */  false,
  /*  650 */  false,
  /*  651 */  false,
  /*  652 */  false,
  /*  653 */  false,
  /*  654 */  false,
  /*  655 */  false,
  /*  656 */  false,
  /*  657 */  false,
  /*  658 */  false,
  /*  659 */  false,
  /*  660 */  false,
  /*  661 */  false,
  /*  662 */  false,
  /*  663 */  false,
  /*  664 */  false,
  /*  665 */  false,
  /*  666 */  false,
  /*  667 */  false,
  /*  668 */  false,
  /*  669 */  false,
  /*  670 */  false,
  /*  671 */  false,
  /*  672 */  false,
  /*  673 */  false,
  /*  674 */  false,
  /*  675 */  false,
  /*  676 */  false,
  /*  677 */  false,
  /*  678 */  false,
  /*  679 */  false,
  /*  680 */  false,
  /*  681 */  false,
  /*  682 */  false,
  /*  683 */  false,
  /*  684 */  false,
  /*  685 */  false,
  /*  686 */  false,
  /*  687 */  false,
  /*  688 */  false,
  /*  689 */  false,
  /*  690 */  false,
  /*  691 */  false,
  /*  692 */  false,
  /*  693 */  false,
  /*  694 */  false,
  /*  695 */  false,
  /*  696 */  false,
  /*  697 */  false,
  /*  698 */  false,
  /*  699 */  false,
  /*  700 */  false,
  /*  701 */  false,
  /*  702 */  false,
  /*  703 */  false,
  /*  704 */  false,
  /*  705 */  false,
  /*  706 */  false,
  /*  707 */  false,
  /*  708 */  false,
  /*  709 */  false,
  /*  710 */  false,
  /*  711 */  false,
  /*  712 */  false,
  /*  713 */  false,
  /*  714 */  false,
  /*  715 */  false,
  /*  716 */  false,
  /*  717 */  false,
  /*  718 */  false,
  /*  719 */  false,
  /*  720 */  false,
  /*  721 */  false,
  /*  722 */  false,
  /*  723 */  false,
  /*  724 */  false,
  /*  725 */  false,
  /*  726 */  false,
  /*  727 */  false,
  /*  728 */  false,
  /*  729 */  false,
  /*  730 */  false,
  /*  731 */  false,
  /*  732 */  false,
  /*  733 */  false,
  /*  734 */  false,
  /*  735 */  false,
  /*  736 */  false,
  /*  737 */  false,
  /*  738 */  false,
  /*  739 */  false,
  /*  740 */  false,
  /*  741 */  false,
  /*  742 */  false,
  /*  743 */  false,
  /*  744 */  false,
  /*  745 */  false,
  /*  746 */  false,
  /*  747 */  false,
  /*  748 */  false,
  /*  749 */  false,
  /*  750 */  false,
  /*  751 */  false,
  /*  752 */  false,
  /*  753 */  false,
  /*  754 */  false,
  /*  755 */  false,
  /*  756 */  false,
  /*  757 */  false,
  /*  758 */  false,
  /*  759 */  false,
  /*  760 */  false,
  /*  761 */  false,
  /*  762 */  false,
  /*  763 */  false,
  /*  764 */  false,
  /*  765 */  false,
  /*  766 */  false,
  /*  767 */  false,
  /*  768 */  false,
  /*  769 */  false,
  /*  770 */  false,
  /*  771 */  false,
  /*  772 */  false,
  /*  773 */  false,
  /*  774 */  false,
  /*  775 */  false,
  /*  776 */  false,
  /*  777 */  false,
  /*  778 */  false,
  /*  779 */  false,
  /*  780 */  false,
  /*  781 */  false,
  /*  782 */  false,
  /*  783 */  false,
  /*  784 */  false,
  /*  785 */  false,
  /*  786 */  false,
  /*  787 */  false,
  /*  788 */  false,
  /*  789 */  false,
  /*  790 */  false,
  /*  791 */  false,
  /*  792 */  false,
  /*  793 */  false,
  /*  794 */  false,
  /*  795 */  false,
  /*  796 */  false,
  /*  797 */  false,
  /*  798 */  false,
  /*  799 */  false,
  /*  800 */  false,
  /*  801 */  false,
  /*  802 */  false,
  /*  803 */  false,
  /*  804 */  false,
  /*  805 */  false,
  /*  806 */  false,
  /*  807 */  false,
  /*  808 */  false,
  /*  809 */  false,
  /*  810 */  false,
  /*  811 */  false,
  /*  812 */  false,
  /*  813 */  false,
  /*  814 */  false,
  /*  815 */  false,
  /*  816 */  false,
  /*  817 */  false,
  /*  818 */  false,
  /*  819 */  false,
  /*  820 */  false,
  /*  821 */  false,
  /*  822 */  false,
  /*  823 */  false,
  /*  824 */  false,
  /*  825 */  false,
  /*  826 */  false,
  /*  827 */  false,
  /*  828 */  false,
  /*  829 */  false,
  /*  830 */  false,
  /*  831 */  false,
  /*  832 */  false,
  /*  833 */  false,
  /*  834 */  false,
  /*  835 */  false,
  /*  836 */  false,
  /*  837 */  false,
  /*  838 */  false,
  /*  839 */  false,
  /*  840 */  false,
  /*  841 */  false,
  /*  842 */  false,
  /*  843 */  false,
  /*  844 */  false,
  /*  845 */  false,
  /*  846 */  false,
  /*  847 */  false,
  /*  848 */  false,
  /*  849 */  false,
  /*  850 */  false,
  /*  851 */  false,
  /*  852 */  false,
  /*  853 */  false,
  /*  854 */  false,
  /*  855 */  false,
  /*  856 */  false,
  /*  857 */  false,
  /*  858 */  false,
  /*  859 */  false,
  /*  860 */  false,
  /*  861 */  false,
  /*  862 */  false,
  /*  863 */  false,
  /*  864 */  false,
  /*  865 */  false,
  /*  866 */  false,
  /*  867 */  false,
  /*  868 */  false,
  /*  869 */  false,
  /*  870 */  false,
  /*  871 */  false,
  /*  872 */  false,
  /*  873 */  false,
  /*  874 */  false,
  /*  875 */  false,
  /*  876 */  false,
  /*  877 */  false,
  /*  878 */  false,
  /*  879 */  false,
  /*  880 */  false,
  /*  881 */  false,
  /*  882 */  false,
  /*  883 */  false,
  /*  884 */  false,
  /*  885 */  false,
  /*  886 */  false,
  /*  887 */  false,
  /*  888 */  false,
  /*  889 */  false,
  /*  890 */  false,
  /*  891 */  false,
  /*  892 */  false,
  /*  893 */  false,
  /*  894 */  false,
  /*  895 */  false,
  /*  896 */  false,
  /*  897 */  false,
  /*  898 */  false,
  /*  899 */  false,
  /*  900 */  false,
  /*  901 */  false,
  /*  902 */  false,
  /*  903 */  false,
  /*  904 */  false,
  /*  905 */  false,
  /*  906 */  false,
  /*  907 */  false,
  /*  908 */  false,
  /*  909 */  false,
  /*  910 */  false,
  /*  911 */  false,
  /*  912 */  false,
  /*  913 */  false,
  /*  914 */  false,
  /*  915 */  false,
  /*  916 */  false,
  /*  917 */  false,
  /*  918 */  false,
  /*  919 */  false,
  /*  920 */  false,
  /*  921 */  false,
  /*  922 */  false,
  /*  923 */  false,
  /*  924 */  false,
  /*  925 */  false,
  /*  926 */  false,
  /*  927 */  false,
  /*  928 */  false,
  /*  929 */  false,
  /*  930 */  false,
  /*  931 */  false,
  /*  932 */  false,
  /*  933 */  false,
  /*  934 */  false,
  /*  935 */  false,
  /*  936 */  false,
  /*  937 */  false,
  /*  938 */  false,
  /*  939 */  false,
  /*  940 */  false,
  /*  941 */  false,
  /*  942 */  false,
  /*  943 */  false,
  /*  944 */  false,
  /*  945 */  false,
  /*  946 */  false,
  /*  947 */  false,
  /*  948 */  false,
  /*  949 */  false,
  /*  950 */  false,
  /*  951 */  false,
  /*  952 */  false,
  /*  953 */  false,
  /*  954 */  false,
  /*  955 */  false,
  /*  956 */  false,
  /*  957 */  false,
  /*  958 */  false,
  /*  959 */  false,
  /*  960 */  false,
  /*  961 */  false,
  /*  962 */  false,
  /*  963 */  false,
  /*  964 */  false,
  /*  965 */  false,
  /*  966 */  false,
  /*  967 */  false,
  /*  968 */  false,
  /*  969 */  false,
  /*  970 */  false,
  /*  971 */  false,
  /*  972 */  false,
  /*  973 */  false,
  /*  974 */  false,
  /*  975 */  false,
  /*  976 */  false,
  /*  977 */  false,
  /*  978 */  false,
  /*  979 */  false,
  /*  980 */  false,
  /*  981 */  false,
  /*  982 */  false,
  /*  983 */  false,
  /*  984 */  false,
  /*  985 */  false,
  /*  986 */  false,
  /*  987 */  false,
  /*  988 */  false,
  /*  989 */  false,
  /*  990 */  false,
  /*  991 */  false,
  /*  992 */  false,
  /*  993 */  false,
  /*  994 */  false,
  /*  995 */  false,
  /*  996 */  false,
  /*  997 */  false,
  /*  998 */  false,
  /*  999 */  false,
  /* 1000 */  false,
  /* 1001 */  false,
  /* 1002 */  false,
  /* 1003 */  false,
  /* 1004 */  false,
  /* 1005 */  false,
  /* 1006 */  false,
  /* 1007 */  false,
  /* 1008 */  false,
  /* 1009 */  false,
  /* 1010 */  false,
  /* 1011 */  false,
  /* 1012 */  false,
  /* 1013 */  false,
  /* 1014 */  false,
  /* 1015 */  false,
  /* 1016 */  false,
  /* 1017 */  false,
  /* 1018 */  false,
  /* 1019 */  false,
  /* 1020 */  false,
  /* 1021 */  false,
  /* 1022 */  false,
  /* 1023 */  false,
  /* 1024 */  false,
  /* 1025 */  false,
  /* 1026 */  false,
  /* 1027 */  false,
  /* 1028 */  false,
  /* 1029 */  false,
  /* 1030 */  false,
  /* 1031 */  false,
  /* 1032 */  false,
  /* 1033 */  false,
  /* 1034 */  false,
  /* 1035 */  false,
  /* 1036 */  false,
  /* 1037 */  false,
  /* 1038 */  false,
  /* 1039 */  false,
  /* 1040 */  false,
  /* 1041 */  false,
  /* 1042 */  false,
  /* 1043 */  false,
  /* 1044 */  false,
  /* 1045 */  false,
  /* 1046 */  false,
  /* 1047 */  false,
  /* 1048 */  false,
  /* 1049 */  false,
  /* 1050 */  false,
  /* 1051 */  false,
  /* 1052 */  false,
  /* 1053 */  false,
  /* 1054 */  false,
  /* 1055 */  false,
  /* 1056 */  false,
  /* 1057 */  false,
  /* 1058 */  false,
  /* 1059 */  false,
  /* 1060 */  false,
  /* 1061 */  false,
  /* 1062 */  false,
  /* 1063 */  false,
  /* 1064 */  false,
  /* 1065 */  false,
  /* 1066 */  false,
  /* 1067 */  false,
  /* 1068 */  false,
  /* 1069 */  false,
  /* 1070 */  false,
  /* 1071 */  false,
  /* 1072 */  false,
  /* 1073 */  false,
  /* 1074 */  false,
  /* 1075 */  false,
  /* 1076 */  false,
  /* 1077 */  false,
  /* 1078 */  false,
  /* 1079 */  false,
  /* 1080 */  false,
  /* 1081 */  false,
  /* 1082 */  false,
  /* 1083 */  false,
  /* 1084 */  false,
  /* 1085 */  false,
  /* 1086 */  false,
  /* 1087 */  false,
  /* 1088 */  false,
  /* 1089 */  false,
  /* 1090 */  false,
  /* 1091 */  false,
  /* 1092 */  false,
  /* 1093 */  false,
  /* 1094 */  false,
  /* 1095 */  false,
  /* 1096 */  false,
  /* 1097 */  false,
  /* 1098 */  false,
  /* 1099 */  false,
  /* 1100 */  false,
  /* 1101 */  false,
  /* 1102 */  false,
  /* 1103 */  false,
  /* 1104 */  false,
  /* 1105 */  false,
  /* 1106 */  false,
  /* 1107 */  false,
  /* 1108 */  false,
  /* 1109 */  false,
  /* 1110 */  false,
  /* 1111 */  false,
  /* 1112 */  false,
  /* 1113 */  false,
  /* 1114 */  false,
  /* 1115 */  false,
  /* 1116 */  false,
  /* 1117 */  false,
  /* 1118 */  false,
  /* 1119 */  false,
  /* 1120 */  false,
  /* 1121 */  false,
  /* 1122 */  false,
  /* 1123 */  false,
  /* 1124 */  false,
  /* 1125 */  false,
  /* 1126 */  false,
  /* 1127 */  false,
  /* 1128 */  false,
  /* 1129 */  false,
  /* 1130 */  false,
  /* 1131 */  false,
  /* 1132 */  false,
  /* 1133 */  false,
  /* 1134 */  false,
  /* 1135 */  false,
  /* 1136 */  false,
  /* 1137 */  false,
  /* 1138 */  false,
  /* 1139 */  false,
  /* 1140 */  false,
  /* 1141 */  false,
  /* 1142 */  false,
  /* 1143 */  false,
  /* 1144 */  false,
  /* 1145 */  false,
  /* 1146 */  false,
  /* 1147 */  false,
  /* 1148 */  false,
  /* 1149 */  false,
  /* 1150 */  false,
  /* 1151 */  false,
  /* 1152 */  false,
  /* 1153 */  false,
  /* 1154 */  false,
  /* 1155 */  false,
  /* 1156 */  false,
  /* 1157 */  false,
  /* 1158 */  false,
  /* 1159 */  false,
  /* 1160 */  false,
  /* 1161 */  false,
  /* 1162 */  false,
  /* 1163 */  false,
  /* 1164 */  false,
  /* 1165 */  false,
  /* 1166 */  false,
  /* 1167 */  false,
  /* 1168 */  false,
  /* 1169 */  false,
  /* 1170 */  false,
  /* 1171 */  false,
  /* 1172 */  false,
  /* 1173 */  false,
  /* 1174 */  false,
  /* 1175 */  false,
  /* 1176 */  false,
  /* 1177 */  false,
  /* 1178 */  false,
  /* 1179 */  false,
  /* 1180 */  false,
  /* 1181 */  false,
  /* 1182 */  false,
  /* 1183 */  false,
  /* 1184 */  false,
  /* 1185 */  false,
  /* 1186 */  false,
  /* 1187 */  false,
  /* 1188 */  false,
  /* 1189 */  false,
  /* 1190 */  false,
  /* 1191 */  false,
  /* 1192 */  false,
  /* 1193 */  false,
  /* 1194 */  false,
  /* 1195 */  false,
  /* 1196 */  false,
  /* 1197 */  false,
  /* 1198 */  false,
  /* 1199 */  false,
  /* 1200 */  false,
  /* 1201 */  false,
  /* 1202 */  false,
  /* 1203 */  false,
  /* 1204 */  false,
  /* 1205 */  false,
  /* 1206 */  false,
  /* 1207 */  false,
  /* 1208 */  false,
  /* 1209 */  false,
  /* 1210 */  false,
  /* 1211 */  false,
  /* 1212 */  false,
  /* 1213 */  false,
  /* 1214 */  false,
  /* 1215 */  false,
  /* 1216 */  false,
  /* 1217 */  false,
  /* 1218 */  false,
  /* 1219 */  false,
  /* 1220 */  false,
  /* 1221 */  false,
  /* 1222 */  false,
  /* 1223 */  false,
  /* 1224 */  false,
  /* 1225 */  false,
  /* 1226 */  false,
  /* 1227 */  false,
  /* 1228 */  false,
  /* 1229 */  false,
  /* 1230 */  false,
  /* 1231 */  false,
  /* 1232 */  false,
  /* 1233 */  false,
  /* 1234 */  false,
  /* 1235 */  false,
  /* 1236 */  false,
  /* 1237 */  false,
  /* 1238 */  false,
  /* 1239 */  false,
  /* 1240 */  false,
  /* 1241 */  false,
  /* 1242 */  false,
  /* 1243 */  false,
  /* 1244 */  false,
  /* 1245 */  false,
  /* 1246 */  false,
  /* 1247 */  false,
  /* 1248 */  false,
  /* 1249 */  false,
  /* 1250 */  false,
  /* 1251 */  false,
  /* 1252 */  false,
  /* 1253 */  false,
  /* 1254 */  false,
  /* 1255 */  false,
  /* 1256 */  false,
  /* 1257 */  false,
  /* 1258 */  false,
  /* 1259 */  false,
  /* 1260 */  false,
  /* 1261 */  false,
  /* 1262 */  false,
  /* 1263 */  false,
  /* 1264 */  false,
  /* 1265 */  false,
  /* 1266 */  false,
  /* 1267 */  false,
  /* 1268 */  false,
  /* 1269 */  false,
  /* 1270 */  false,
  /* 1271 */  false,
  /* 1272 */  false,
  /* 1273 */  false,
  /* 1274 */  false,
  /* 1275 */  false,
  /* 1276 */  false,
  /* 1277 */  false,
  /* 1278 */  false,
  /* 1279 */  false,
  /* 1280 */  false,
  /* 1281 */  false,
  /* 1282 */  false,
  /* 1283 */  false,
  /* 1284 */  false,
  /* 1285 */  false,
  /* 1286 */  false,
  /* 1287 */  false,
  /* 1288 */  false,
  /* 1289 */  false,
  /* 1290 */  false,
  /* 1291 */  false,
  /* 1292 */  false,
  /* 1293 */  false,
  /* 1294 */  false,
  /* 1295 */  false,
  /* 1296 */  false,
  /* 1297 */  false,
  /* 1298 */  false,
  /* 1299 */  false,
  /* 1300 */  false,
  /* 1301 */  false,
  /* 1302 */  false,
  /* 1303 */  false,
  /* 1304 */  false,
  /* 1305 */  false,
  /* 1306 */  false,
  /* 1307 */  false,
  /* 1308 */  false,
  /* 1309 */  false,
  /* 1310 */  false,
  /* 1311 */  false,
  /* 1312 */  false,
  /* 1313 */  false,
  /* 1314 */  false,
  /* 1315 */  false,
  /* 1316 */  false,
  /* 1317 */  false,
  /* 1318 */  false,
  /* 1319 */  false,
  /* 1320 */  false,
  /* 1321 */  false,
  /* 1322 */  false,
  /* 1323 */  false,
  /* 1324 */  false,
  /* 1325 */  false,
  /* 1326 */  false,
  /* 1327 */  false,
  /* 1328 */  false,
  /* 1329 */  false,
  /* 1330 */  false,
  /* 1331 */  false,
  /* 1332 */  false,
  /* 1333 */  false,
  /* 1334 */  false,
  /* 1335 */  false,
  /* 1336 */  false,
  /* 1337 */  false,
  /* 1338 */  false,
  /* 1339 */  false,
  /* 1340 */  false,
  /* 1341 */  false,
  /* 1342 */  false,
  /* 1343 */  false,
  /* 1344 */  false,
  /* 1345 */  false,
  /* 1346 */  false,
  /* 1347 */  false,
  /* 1348 */  false,
  /* 1349 */  false,
  /* 1350 */  false,
  /* 1351 */  false,
  /* 1352 */  false,
  /* 1353 */  false,
  /* 1354 */  false,
  /* 1355 */  false,
  /* 1356 */  false,
  /* 1357 */  false,
  /* 1358 */  false,
  /* 1359 */  false,
  /* 1360 */  false,
  /* 1361 */  false,
  /* 1362 */  false,
  /* 1363 */  false,
  /* 1364 */  false,
  /* 1365 */  false,
  /* 1366 */  false,
  /* 1367 */  false,
  /* 1368 */  false,
  /* 1369 */  false,
  /* 1370 */  false,
  /* 1371 */  false,
  /* 1372 */  false,
  /* 1373 */  false,
  /* 1374 */  false,
  /* 1375 */  false,
  /* 1376 */  false,
  /* 1377 */  false,
  /* 1378 */  false,
  /* 1379 */  false,
  /* 1380 */  false,
  /* 1381 */  false,
  /* 1382 */  false,
  /* 1383 */  false,
  /* 1384 */  false,
  /* 1385 */  false,
  /* 1386 */  false,
  /* 1387 */  false,
  /* 1388 */  false,
  /* 1389 */  false,
  /* 1390 */  false,
  /* 1391 */  false,
  /* 1392 */  false,
  /* 1393 */  false,
  /* 1394 */  false,
  /* 1395 */  false,
  /* 1396 */  false,
  /* 1397 */  false,
  /* 1398 */  false,
  /* 1399 */  false,
  /* 1400 */  false,
  /* 1401 */  false,
  /* 1402 */  false,
  /* 1403 */  false,
  /* 1404 */  false,
  /* 1405 */  false,
  /* 1406 */  false,
  /* 1407 */  false,
  /* 1408 */  false,
  /* 1409 */  false,
  /* 1410 */  false,
  /* 1411 */  false,
  /* 1412 */  false,
  /* 1413 */  false,
  /* 1414 */  false,
  /* 1415 */  false,
  /* 1416 */  false,
  /* 1417 */  false,
  /* 1418 */  false,
  /* 1419 */  false,
  /* 1420 */  false,
  /* 1421 */  false,
  /* 1422 */  false,
  /* 1423 */  false,
  /* 1424 */  false,
  /* 1425 */  false,
  /* 1426 */  false,
  /* 1427 */  false,
  /* 1428 */  false,
  /* 1429 */  false,
  /* 1430 */  false,
  /* 1431 */  false,
  /* 1432 */  false,
  /* 1433 */  false,
  /* 1434 */  false,
  /* 1435 */  false,
  /* 1436 */  false,
  /* 1437 */  false,
  /* 1438 */  false,
  /* 1439 */  false,
  /* 1440 */  false,
  /* 1441 */  false,
  /* 1442 */  false,
  /* 1443 */  false,
  /* 1444 */  false,
  /* 1445 */  false,
  /* 1446 */  false,
  /* 1447 */  false,
  /* 1448 */  false,
  /* 1449 */  false,
  /* 1450 */  false,
  /* 1451 */  false,
  /* 1452 */  false,
  /* 1453 */  false,
  /* 1454 */  false,
  /* 1455 */  false,
  /* 1456 */  false,
  /* 1457 */  false,
  /* 1458 */  false,
  /* 1459 */  false,
  /* 1460 */  false,
  /* 1461 */  false,
  /* 1462 */  false,
  /* 1463 */  false,
  /* 1464 */  false,
  /* 1465 */  false,
  /* 1466 */  false,
  /* 1467 */  false,
  /* 1468 */  false,
  /* 1469 */  false,
  /* 1470 */  false,
  /* 1471 */  false,
  /* 1472 */  false,
  /* 1473 */  false,
  /* 1474 */  false,
  /* 1475 */  false,
  /* 1476 */  false,
  /* 1477 */  false,
  /* 1478 */  false,
  /* 1479 */  false,
  /* 1480 */  false,
  /* 1481 */  false,
  /* 1482 */  false,
  /* 1483 */  false,
  /* 1484 */  false,
  /* 1485 */  false,
  /* 1486 */  false,
  /* 1487 */  false,
  /* 1488 */  false,
  /* 1489 */  false,
  /* 1490 */  false,
  /* 1491 */  false,
  /* 1492 */  false,
  /* 1493 */  false,
  /* 1494 */  false,
  /* 1495 */  false,
  /* 1496 */  false,
  /* 1497 */  false,
  /* 1498 */  false,
  /* 1499 */  false,
  /* 1500 */  false,
  /* 1501 */  false,
  /* 1502 */  false,
  /* 1503 */  false,
  /* 1504 */  false,
  /* 1505 */  false,
  /* 1506 */  false,
  /* 1507 */  false,
  /* 1508 */  false,
  /* 1509 */  false,
  /* 1510 */  false,
  /* 1511 */  false,
  /* 1512 */  false,
  /* 1513 */  false,
  /* 1514 */  false,
  /* 1515 */  false,
  /* 1516 */  false,
  /* 1517 */  false,
  /* 1518 */  false,
  /* 1519 */  false,
  /* 1520 */  false,
  /* 1521 */  false,
  /* 1522 */  false,
  /* 1523 */  false,
  /* 1524 */  false,
  /* 1525 */  false,
  /* 1526 */  false,
  /* 1527 */  false,
  /* 1528 */  false,
  /* 1529 */  false,
  /* 1530 */  false,
  /* 1531 */  false,
  /* 1532 */  false,
  /* 1533 */  false,
  /* 1534 */  false,
  /* 1535 */  false,
  /* 1536 */  false,
  /* 1537 */  false,
  /* 1538 */  false,
  /* 1539 */  false,
  /* 1540 */  false,
  /* 1541 */  false,
  /* 1542 */  false,
  /* 1543 */  false,
  /* 1544 */  false,
  /* 1545 */  false,
  /* 1546 */  false,
  /* 1547 */  false,
  /* 1548 */  false,
  /* 1549 */  false,
  /* 1550 */  false,
  /* 1551 */  false,
  /* 1552 */  false,
  /* 1553 */  false,
  /* 1554 */  false,
  /* 1555 */  false,
  /* 1556 */  false,
  /* 1557 */  false,
  /* 1558 */  false,
  /* 1559 */  false,
  /* 1560 */  false,
  /* 1561 */  false,
  /* 1562 */  false,
  /* 1563 */  false,
  /* 1564 */  false,
  /* 1565 */  false,
  /* 1566 */  false,
  /* 1567 */  false,
  /* 1568 */  false,
  /* 1569 */  false,
  /* 1570 */  false,
  /* 1571 */  false,
  /* 1572 */  false,
  /* 1573 */  false,
  /* 1574 */  false,
  /* 1575 */  false,
  /* 1576 */  false,
  /* 1577 */  false,
  /* 1578 */  false,
  /* 1579 */  false,
  /* 1580 */  false,
  /* 1581 */  false,
  /* 1582 */  false,
  /* 1583 */  false,
  /* 1584 */  false,
  /* 1585 */  false,
  /* 1586 */  false,
  /* 1587 */  false,
  /* 1588 */  false,
  /* 1589 */  false,
  /* 1590 */  false,
  /* 1591 */  false,
  /* 1592 */  false,
  /* 1593 */  false,
  /* 1594 */  false,
  /* 1595 */  false,
  /* 1596 */  false,
  /* 1597 */  false,
  /* 1598 */  false,
  /* 1599 */  false,
  /* 1600 */  false,
  /* 1601 */  false,
  /* 1602 */  false,
  /* 1603 */  false,
  /* 1604 */  false,
  /* 1605 */  false,
  /* 1606 */  false,
  /* 1607 */  false,
  /* 1608 */  false,
  /* 1609 */  false,
  /* 1610 */  false,
  /* 1611 */  false,
  /* 1612 */  false,
  /* 1613 */  false,
  /* 1614 */  false,
  /* 1615 */  false,
  /* 1616 */  false,
  /* 1617 */  false,
  /* 1618 */  false,
  /* 1619 */  false,
  /* 1620 */  false,
  /* 1621 */  false,
  /* 1622 */  false,
  /* 1623 */  false,
  /* 1624 */  false,
  /* 1625 */  false,
  /* 1626 */  false,
  /* 1627 */  false,
  /* 1628 */  false,
  /* 1629 */  false,
  /* 1630 */  false,
  /* 1631 */  false,
  /* 1632 */  false,
  /* 1633 */  false,
  /* 1634 */  false,
  /* 1635 */  false,
  /* 1636 */  false,
  /* 1637 */  false,
  /* 1638 */  false,
  /* 1639 */  false,
  /* 1640 */  false,
  /* 1641 */  false,
  /* 1642 */  false,
  /* 1643 */  false,
  /* 1644 */  false,
  /* 1645 */  false,
  /* 1646 */  false,
  /* 1647 */  false,
  /* 1648 */  false,
  /* 1649 */  false,
  /* 1650 */  false,
  /* 1651 */  false,
  /* 1652 */  false,
  /* 1653 */  false,
  /* 1654 */  false,
  /* 1655 */  false,
  /* 1656 */  false,
  /* 1657 */  false,
  /* 1658 */  false,
  /* 1659 */  false,
  /* 1660 */  false,
  /* 1661 */  false,
  /* 1662 */  false,
  /* 1663 */  false,
  /* 1664 */  false,
  /* 1665 */  false,
  /* 1666 */  false,
  /* 1667 */  false,
  /* 1668 */  false,
  /* 1669 */  false,
  /* 1670 */  false,
  /* 1671 */  false,
  /* 1672 */  false,
  /* 1673 */  false,
  /* 1674 */  false,
  /* 1675 */  false,
  /* 1676 */  false,
  /* 1677 */  false,
  /* 1678 */  false,
  /* 1679 */  false,
  /* 1680 */  false,
  /* 1681 */  false,
  /* 1682 */  false,
  /* 1683 */  false,
  /* 1684 */  false,
  /* 1685 */  false,
  /* 1686 */  false,
  /* 1687 */  false,
  /* 1688 */  false,
  /* 1689 */  false,
  /* 1690 */  false,
  /* 1691 */  false,
  /* 1692 */  false,
  /* 1693 */  false,
  /* 1694 */  false,
  /* 1695 */  false,
  /* 1696 */  false,
  /* 1697 */  false,
  /* 1698 */  false,
  /* 1699 */  false,
  /* 1700 */  false,
  /* 1701 */  false,
  /* 1702 */  false,
  /* 1703 */  false,
  /* 1704 */  false,
  /* 1705 */  false,
  /* 1706 */  false,
  /* 1707 */  false,
  // last instruction
  false // no trailing comma
};

// Mapping from machine-independent opcode to boolean
const        char must_clone[] = {
  0, // Node: 0
  0, // Set: 1
  0, // RegN: 2
  0, // RegI: 3
  0, // RegP: 4
  0, // RegF: 5
  0, // RegD: 6
  0, // RegL: 7
  0, // VecA: 8
  0, // VecS: 9
  0, // VecD: 10
  0, // VecX: 11
  0, // VecY: 12
  0, // VecZ: 13
  0, // RegVectMask: 14
  0, // RegFlags: 15
  0, // _last_machine_leaf: 16
  0, // AbsD: 17
  0, // AbsF: 18
  0, // AbsI: 19
  0, // AbsL: 20
  0, // AddD: 21
  0, // AddF: 22
  0, // AddI: 23
  0, // AddL: 24
  0, // AddP: 25
  0, // Allocate: 26
  0, // AllocateArray: 27
  0, // AndI: 28
  0, // AndL: 29
  0, // ArrayCopy: 30
  0, // AryEq: 31
  0, // AtanD: 32
  1, // Binary: 33
  0, // Blackhole: 34
  1, // Bool: 35
  0, // BoxLock: 36
  0, // ReverseBytesI: 37
  0, // ReverseBytesL: 38
  0, // ReverseBytesUS: 39
  0, // ReverseBytesS: 40
  0, // ReverseBytesV: 41
  0, // CProj: 42
  0, // CacheWB: 43
  0, // CacheWBPreSync: 44
  0, // CacheWBPostSync: 45
  0, // CallDynamicJava: 46
  0, // CallJava: 47
  0, // CallLeaf: 48
  0, // CallLeafNoFP: 49
  0, // CallLeafVector: 50
  0, // CallRuntime: 51
  0, // CallStaticJava: 52
  0, // CastDD: 53
  0, // CastFF: 54
  0, // CastII: 55
  0, // CastLL: 56
  0, // CastVV: 57
  0, // CastX2P: 58
  0, // CastP2X: 59
  0, // CastPP: 60
  0, // Catch: 61
  0, // CatchProj: 62
  0, // CheckCastPP: 63
  0, // ClearArray: 64
  0, // CompressBits: 65
  0, // ExpandBits: 66
  0, // ConstraintCast: 67
  0, // CMoveD: 68
  0, // CMoveVD: 69
  0, // CMoveF: 70
  0, // CMoveVF: 71
  0, // CMoveI: 72
  0, // CMoveL: 73
  0, // CMoveP: 74
  0, // CMoveN: 75
  1, // CmpN: 76
  1, // CmpD: 77
  0, // CmpD3: 78
  1, // CmpF: 79
  0, // CmpF3: 80
  1, // CmpI: 81
  1, // CmpL: 82
  0, // CmpL3: 83
  0, // CmpLTMask: 84
  1, // CmpP: 85
  1, // CmpU: 86
  0, // CmpU3: 87
  1, // CmpUL: 88
  0, // CmpUL3: 89
  0, // CompareAndSwapB: 90
  0, // CompareAndSwapS: 91
  0, // CompareAndSwapI: 92
  0, // CompareAndSwapL: 93
  0, // CompareAndSwapP: 94
  0, // CompareAndSwapN: 95
  0, // WeakCompareAndSwapB: 96
  0, // WeakCompareAndSwapS: 97
  0, // WeakCompareAndSwapI: 98
  0, // WeakCompareAndSwapL: 99
  0, // WeakCompareAndSwapP: 100
  0, // WeakCompareAndSwapN: 101
  0, // CompareAndExchangeB: 102
  0, // CompareAndExchangeS: 103
  0, // CompareAndExchangeI: 104
  0, // CompareAndExchangeL: 105
  0, // CompareAndExchangeP: 106
  0, // CompareAndExchangeN: 107
  0, // GetAndAddB: 108
  0, // GetAndAddS: 109
  0, // GetAndAddI: 110
  0, // GetAndAddL: 111
  0, // GetAndSetB: 112
  0, // GetAndSetS: 113
  0, // GetAndSetI: 114
  0, // GetAndSetL: 115
  0, // GetAndSetP: 116
  0, // GetAndSetN: 117
  0, // Con: 118
  0, // ConN: 119
  0, // ConNKlass: 120
  0, // ConD: 121
  0, // ConF: 122
  0, // ConI: 123
  0, // ConL: 124
  0, // ConP: 125
  0, // Conv2B: 126
  0, // ConvD2F: 127
  0, // ConvD2I: 128
  0, // ConvD2L: 129
  0, // ConvF2D: 130
  0, // ConvF2I: 131
  0, // ConvF2L: 132
  0, // ConvI2D: 133
  0, // ConvI2F: 134
  0, // ConvI2L: 135
  0, // ConvL2D: 136
  0, // ConvL2F: 137
  0, // ConvL2I: 138
  0, // ConvF2HF: 139
  0, // ConvHF2F: 140
  0, // CountedLoop: 141
  0, // CountedLoopEnd: 142
  0, // OuterStripMinedLoop: 143
  0, // OuterStripMinedLoopEnd: 144
  0, // LongCountedLoop: 145
  0, // LongCountedLoopEnd: 146
  0, // CountLeadingZerosI: 147
  0, // CountLeadingZerosL: 148
  0, // CountLeadingZerosV: 149
  0, // CountTrailingZerosI: 150
  0, // CountTrailingZerosL: 151
  0, // CountTrailingZerosV: 152
  0, // CreateEx: 153
  0, // DecodeN: 154
  0, // DecodeNKlass: 155
  0, // DivD: 156
  0, // DivF: 157
  0, // DivI: 158
  0, // DivL: 159
  0, // UDivI: 160
  0, // UDivL: 161
  0, // DivMod: 162
  0, // DivModI: 163
  0, // DivModL: 164
  0, // UDivModI: 165
  0, // UDivModL: 166
  0, // EncodeISOArray: 167
  0, // EncodeP: 168
  0, // EncodePKlass: 169
  1, // FastLock: 170
  1, // FastUnlock: 171
  0, // FmaD: 172
  0, // FmaF: 173
  0, // Goto: 174
  0, // Halt: 175
  0, // CountPositives: 176
  0, // If: 177
  0, // RangeCheck: 178
  0, // IfFalse: 179
  0, // IfTrue: 180
  0, // Initialize: 181
  0, // JProj: 182
  0, // Jump: 183
  0, // JumpProj: 184
  0, // LShiftI: 185
  0, // LShiftL: 186
  0, // LoadB: 187
  0, // LoadUB: 188
  0, // LoadUS: 189
  0, // LoadD: 190
  0, // LoadD_unaligned: 191
  0, // LoadF: 192
  0, // LoadI: 193
  0, // LoadKlass: 194
  0, // LoadNKlass: 195
  0, // LoadL: 196
  0, // LoadL_unaligned: 197
  0, // LoadP: 198
  0, // LoadN: 199
  0, // LoadRange: 200
  0, // LoadS: 201
  0, // Lock: 202
  0, // Loop: 203
  0, // LoopLimit: 204
  0, // Mach: 205
  0, // MachNullCheck: 206
  0, // MachProj: 207
  0, // MulAddS2I: 208
  0, // MaxI: 209
  0, // MaxL: 210
  0, // MaxD: 211
  0, // MaxF: 212
  0, // MemBarAcquire: 213
  0, // LoadFence: 214
  0, // MemBarAcquireLock: 215
  0, // MemBarCPUOrder: 216
  0, // MemBarRelease: 217
  0, // StoreFence: 218
  0, // StoreStoreFence: 219
  0, // MemBarReleaseLock: 220
  0, // MemBarVolatile: 221
  0, // MemBarStoreStore: 222
  0, // MergeMem: 223
  0, // MinI: 224
  0, // MinL: 225
  0, // MinF: 226
  0, // MinD: 227
  0, // ModD: 228
  0, // ModF: 229
  0, // ModI: 230
  0, // ModL: 231
  0, // UModI: 232
  0, // UModL: 233
  0, // MoveI2F: 234
  0, // MoveF2I: 235
  0, // MoveL2D: 236
  0, // MoveD2L: 237
  0, // IsInfiniteF: 238
  0, // IsFiniteF: 239
  0, // IsInfiniteD: 240
  0, // IsFiniteD: 241
  0, // MulD: 242
  0, // MulF: 243
  0, // MulHiL: 244
  0, // UMulHiL: 245
  0, // MulI: 246
  0, // MulL: 247
  0, // Multi: 248
  0, // NegI: 249
  0, // NegL: 250
  0, // NegD: 251
  0, // NegF: 252
  0, // NeverBranch: 253
  0, // OnSpinWait: 254
  0, // Opaque1: 255
  0, // OpaqueLoopInit: 256
  0, // OpaqueLoopStride: 257
  0, // OpaqueZeroTripGuard: 258
  0, // Opaque3: 259
  0, // Opaque4: 260
  0, // ProfileBoolean: 261
  0, // OrI: 262
  0, // OrL: 263
  1, // OverflowAddI: 264
  1, // OverflowSubI: 265
  1, // OverflowMulI: 266
  1, // OverflowAddL: 267
  1, // OverflowSubL: 268
  1, // OverflowMulL: 269
  0, // PCTable: 270
  0, // Parm: 271
  0, // PartialSubtypeCheck: 272
  0, // SubTypeCheck: 273
  0, // Phi: 274
  0, // PopCountI: 275
  0, // PopCountL: 276
  0, // PopCountVI: 277
  0, // PopCountVL: 278
  0, // PopulateIndex: 279
  0, // PrefetchAllocation: 280
  0, // Proj: 281
  0, // RShiftI: 282
  0, // RShiftL: 283
  0, // Region: 284
  0, // Rethrow: 285
  0, // Return: 286
  0, // ReverseI: 287
  0, // ReverseL: 288
  0, // ReverseV: 289
  0, // Root: 290
  0, // RoundDouble: 291
  0, // RoundDoubleMode: 292
  0, // RoundDoubleModeV: 293
  0, // RoundFloat: 294
  0, // RotateLeft: 295
  0, // RotateLeftV: 296
  0, // RotateRight: 297
  0, // RotateRightV: 298
  0, // SafePoint: 299
  0, // SafePointScalarObject: 300
  0, // ShenandoahCompareAndExchangeP: 301
  0, // ShenandoahCompareAndExchangeN: 302
  0, // ShenandoahCompareAndSwapN: 303
  0, // ShenandoahCompareAndSwapP: 304
  0, // ShenandoahWeakCompareAndSwapN: 305
  0, // ShenandoahWeakCompareAndSwapP: 306
  0, // ShenandoahIUBarrier: 307
  0, // ShenandoahLoadReferenceBarrier: 308
  0, // SCMemProj: 309
  0, // CopySignD: 310
  0, // CopySignF: 311
  0, // SignumD: 312
  0, // SignumF: 313
  0, // SignumVF: 314
  0, // SignumVD: 315
  0, // SqrtD: 316
  0, // SqrtF: 317
  0, // RoundF: 318
  0, // RoundD: 319
  0, // Start: 320
  0, // StartOSR: 321
  0, // StoreB: 322
  0, // StoreC: 323
  0, // StoreCM: 324
  0, // StoreD: 325
  0, // StoreF: 326
  0, // StoreI: 327
  0, // StoreL: 328
  0, // StoreP: 329
  0, // StoreN: 330
  0, // StoreNKlass: 331
  0, // StrComp: 332
  0, // StrCompressedCopy: 333
  0, // StrEquals: 334
  0, // StrIndexOf: 335
  0, // StrIndexOfChar: 336
  0, // StrInflatedCopy: 337
  0, // SubD: 338
  0, // SubF: 339
  0, // SubI: 340
  0, // SubL: 341
  0, // TailCall: 342
  0, // TailJump: 343
  0, // MacroLogicV: 344
  0, // ThreadLocal: 345
  0, // Unlock: 346
  0, // URShiftB: 347
  0, // URShiftS: 348
  0, // URShiftI: 349
  0, // URShiftL: 350
  0, // XorI: 351
  0, // XorL: 352
  0, // Vector: 353
  0, // AddVB: 354
  0, // AddVS: 355
  0, // AddVI: 356
  0, // AddReductionVI: 357
  0, // AddVL: 358
  0, // AddReductionVL: 359
  0, // AddVF: 360
  0, // AddReductionVF: 361
  0, // AddVD: 362
  0, // AddReductionVD: 363
  0, // SubVB: 364
  0, // SubVS: 365
  0, // SubVI: 366
  0, // SubVL: 367
  0, // SubVF: 368
  0, // SubVD: 369
  0, // MulVB: 370
  0, // MulVS: 371
  0, // MulVI: 372
  0, // MulReductionVI: 373
  0, // MulVL: 374
  0, // MulReductionVL: 375
  0, // MulVF: 376
  0, // MulReductionVF: 377
  0, // MulVD: 378
  0, // MulReductionVD: 379
  0, // MulAddVS2VI: 380
  0, // FmaVD: 381
  0, // FmaVF: 382
  0, // DivVF: 383
  0, // DivVD: 384
  0, // AbsVB: 385
  0, // AbsVS: 386
  0, // AbsVI: 387
  0, // AbsVL: 388
  0, // AbsVF: 389
  0, // AbsVD: 390
  0, // NegVI: 391
  0, // NegVL: 392
  0, // NegVF: 393
  0, // NegVD: 394
  0, // SqrtVD: 395
  0, // SqrtVF: 396
  0, // LShiftCntV: 397
  0, // RShiftCntV: 398
  0, // LShiftVB: 399
  0, // LShiftVS: 400
  0, // LShiftVI: 401
  0, // LShiftVL: 402
  0, // RShiftVB: 403
  0, // RShiftVS: 404
  0, // RShiftVI: 405
  0, // RShiftVL: 406
  0, // URShiftVB: 407
  0, // URShiftVS: 408
  0, // URShiftVI: 409
  0, // URShiftVL: 410
  0, // AndV: 411
  0, // AndReductionV: 412
  0, // OrV: 413
  0, // OrReductionV: 414
  0, // XorV: 415
  0, // XorReductionV: 416
  0, // MinV: 417
  0, // MaxV: 418
  0, // MinReductionV: 419
  0, // MaxReductionV: 420
  0, // CompressV: 421
  0, // CompressM: 422
  0, // ExpandV: 423
  0, // LoadVector: 424
  0, // LoadVectorGather: 425
  0, // LoadVectorGatherMasked: 426
  0, // StoreVector: 427
  0, // StoreVectorScatter: 428
  0, // StoreVectorScatterMasked: 429
  0, // LoadVectorMasked: 430
  0, // StoreVectorMasked: 431
  0, // VectorCmpMasked: 432
  0, // VectorMaskGen: 433
  0, // VectorMaskOp: 434
  0, // VectorMaskTrueCount: 435
  0, // VectorMaskFirstTrue: 436
  0, // VectorMaskLastTrue: 437
  0, // VectorMaskToLong: 438
  0, // VectorLongToMask: 439
  0, // Pack: 440
  0, // PackB: 441
  0, // PackS: 442
  0, // PackI: 443
  0, // PackL: 444
  0, // PackF: 445
  0, // PackD: 446
  0, // Pack2L: 447
  0, // Pack2D: 448
  0, // ReplicateB: 449
  0, // ReplicateS: 450
  0, // ReplicateI: 451
  0, // ReplicateL: 452
  0, // ReplicateF: 453
  0, // ReplicateD: 454
  0, // RoundVF: 455
  0, // RoundVD: 456
  0, // Extract: 457
  0, // ExtractB: 458
  0, // ExtractUB: 459
  0, // ExtractC: 460
  0, // ExtractS: 461
  0, // ExtractI: 462
  0, // ExtractL: 463
  0, // ExtractF: 464
  0, // ExtractD: 465
  0, // Digit: 466
  0, // LowerCase: 467
  0, // UpperCase: 468
  0, // Whitespace: 469
  0, // VectorBox: 470
  0, // VectorBoxAllocate: 471
  0, // VectorUnbox: 472
  0, // VectorMaskWrapper: 473
  0, // VectorMaskCmp: 474
  0, // VectorMaskCast: 475
  0, // VectorTest: 476
  0, // VectorBlend: 477
  0, // VectorRearrange: 478
  0, // VectorLoadMask: 479
  0, // VectorLoadShuffle: 480
  0, // VectorLoadConst: 481
  0, // VectorStoreMask: 482
  0, // VectorReinterpret: 483
  0, // VectorCast: 484
  0, // VectorCastB2X: 485
  0, // VectorCastS2X: 486
  0, // VectorCastI2X: 487
  0, // VectorCastL2X: 488
  0, // VectorCastF2X: 489
  0, // VectorCastD2X: 490
  0, // VectorCastF2HF: 491
  0, // VectorCastHF2F: 492
  0, // VectorUCastB2X: 493
  0, // VectorUCastS2X: 494
  0, // VectorUCastI2X: 495
  0, // VectorInsert: 496
  0, // MaskAll: 497
  0, // AndVMask: 498
  0, // OrVMask: 499
  0 // no trailing comma // XorVMask: 500
};
//  The following instructions can cisc-spill



// An array of character pointers to machine register names.
const char *Matcher::regName[REG_COUNT] = {
  "R10",
  "R10_H",
  "R11",
  "R11_H",
  "R12",
  "R12_H",
  "R13",
  "R13_H",
  "R14",
  "R14_H",
  "R15",
  "R15_H",
  "R16",
  "R16_H",
  "R17",
  "R17_H",
  "R18",
  "R18_H",
  "R0",
  "R0_H",
  "R1",
  "R1_H",
  "R2",
  "R2_H",
  "R3",
  "R3_H",
  "R4",
  "R4_H",
  "R5",
  "R5_H",
  "R6",
  "R6_H",
  "R7",
  "R7_H",
  "R19",
  "R19_H",
  "R20",
  "R20_H",
  "R21",
  "R21_H",
  "R22",
  "R22_H",
  "R23",
  "R23_H",
  "R24",
  "R24_H",
  "R25",
  "R25_H",
  "R26",
  "R26_H",
  "R27",
  "R27_H",
  "R28",
  "R28_H",
  "R29",
  "R29_H",
  "R30",
  "R30_H",
  "R31",
  "R31_H",
  "R8",
  "R8_H",
  "R9",
  "R9_H",
  "V16",
  "V16_H",
  "V16_J",
  "V16_K",
  "V17",
  "V17_H",
  "V17_J",
  "V17_K",
  "V18",
  "V18_H",
  "V18_J",
  "V18_K",
  "V19",
  "V19_H",
  "V19_J",
  "V19_K",
  "V20",
  "V20_H",
  "V20_J",
  "V20_K",
  "V21",
  "V21_H",
  "V21_J",
  "V21_K",
  "V22",
  "V22_H",
  "V22_J",
  "V22_K",
  "V23",
  "V23_H",
  "V23_J",
  "V23_K",
  "V24",
  "V24_H",
  "V24_J",
  "V24_K",
  "V25",
  "V25_H",
  "V25_J",
  "V25_K",
  "V26",
  "V26_H",
  "V26_J",
  "V26_K",
  "V27",
  "V27_H",
  "V27_J",
  "V27_K",
  "V28",
  "V28_H",
  "V28_J",
  "V28_K",
  "V29",
  "V29_H",
  "V29_J",
  "V29_K",
  "V30",
  "V30_H",
  "V30_J",
  "V30_K",
  "V31",
  "V31_H",
  "V31_J",
  "V31_K",
  "V0",
  "V0_H",
  "V0_J",
  "V0_K",
  "V1",
  "V1_H",
  "V1_J",
  "V1_K",
  "V2",
  "V2_H",
  "V2_J",
  "V2_K",
  "V3",
  "V3_H",
  "V3_J",
  "V3_K",
  "V4",
  "V4_H",
  "V4_J",
  "V4_K",
  "V5",
  "V5_H",
  "V5_J",
  "V5_K",
  "V6",
  "V6_H",
  "V6_J",
  "V6_K",
  "V7",
  "V7_H",
  "V7_J",
  "V7_K",
  "V8",
  "V8_H",
  "V8_J",
  "V8_K",
  "V9",
  "V9_H",
  "V9_J",
  "V9_K",
  "V10",
  "V10_H",
  "V10_J",
  "V10_K",
  "V11",
  "V11_H",
  "V11_J",
  "V11_K",
  "V12",
  "V12_H",
  "V12_J",
  "V12_K",
  "V13",
  "V13_H",
  "V13_J",
  "V13_K",
  "V14",
  "V14_H",
  "V14_J",
  "V14_K",
  "V15",
  "V15_H",
  "V15_J",
  "V15_K",
  "P0",
  "P1",
  "P2",
  "P3",
  "P4",
  "P5",
  "P6",
  "P8",
  "P9",
  "P10",
  "P11",
  "P12",
  "P13",
  "P14",
  "P15",
  "P7",
  "RFLAGS" // no trailing comma
};

// An array of character pointers to machine register names.
const VMReg OptoReg::opto2vm[REG_COUNT] = {
	r10->as_VMReg()        ,
	r10->as_VMReg()->next(),
	r11->as_VMReg()        ,
	r11->as_VMReg()->next(),
	r12->as_VMReg()        ,
	r12->as_VMReg()->next(),
	r13->as_VMReg()        ,
	r13->as_VMReg()->next(),
	r14->as_VMReg()        ,
	r14->as_VMReg()->next(),
	r15->as_VMReg()        ,
	r15->as_VMReg()->next(),
	r16->as_VMReg()        ,
	r16->as_VMReg()->next(),
	r17->as_VMReg()        ,
	r17->as_VMReg()->next(),
	r18_tls->as_VMReg()        ,
	r18_tls->as_VMReg()->next(),
	r0->as_VMReg()         ,
	r0->as_VMReg()->next() ,
	r1->as_VMReg()         ,
	r1->as_VMReg()->next() ,
	r2->as_VMReg()         ,
	r2->as_VMReg()->next() ,
	r3->as_VMReg()         ,
	r3->as_VMReg()->next() ,
	r4->as_VMReg()         ,
	r4->as_VMReg()->next() ,
	r5->as_VMReg()         ,
	r5->as_VMReg()->next() ,
	r6->as_VMReg()         ,
	r6->as_VMReg()->next() ,
	r7->as_VMReg()         ,
	r7->as_VMReg()->next() ,
	r19->as_VMReg()        ,
	r19->as_VMReg()->next(),
	r20->as_VMReg()        ,
	r20->as_VMReg()->next(),
	r21->as_VMReg()        ,
	r21->as_VMReg()->next(),
	r22->as_VMReg()        ,
	r22->as_VMReg()->next(),
	r23->as_VMReg()        ,
	r23->as_VMReg()->next(),
	r24->as_VMReg()        ,
	r24->as_VMReg()->next(),
	r25->as_VMReg()        ,
	r25->as_VMReg()->next(),
	r26->as_VMReg()        ,
	r26->as_VMReg()->next(),
	r27->as_VMReg()        ,
	r27->as_VMReg()->next(),
	r28->as_VMReg()        ,
	r28->as_VMReg()->next(),
	r29->as_VMReg()        ,
	r29->as_VMReg()->next(),
	r30->as_VMReg()        ,
	r30->as_VMReg()->next(),
	r31_sp->as_VMReg()     ,
	r31_sp->as_VMReg()->next(),
	r8->as_VMReg()         ,
	r8->as_VMReg()->next() ,
	r9->as_VMReg()         ,
	r9->as_VMReg()->next() ,
	v16->as_VMReg()          ,
	v16->as_VMReg()->next()  ,
	v16->as_VMReg()->next(2) ,
	v16->as_VMReg()->next(3) ,
	v17->as_VMReg()          ,
	v17->as_VMReg()->next()  ,
	v17->as_VMReg()->next(2) ,
	v17->as_VMReg()->next(3) ,
	v18->as_VMReg()          ,
	v18->as_VMReg()->next()  ,
	v18->as_VMReg()->next(2) ,
	v18->as_VMReg()->next(3) ,
	v19->as_VMReg()          ,
	v19->as_VMReg()->next()  ,
	v19->as_VMReg()->next(2) ,
	v19->as_VMReg()->next(3) ,
	v20->as_VMReg()          ,
	v20->as_VMReg()->next()  ,
	v20->as_VMReg()->next(2) ,
	v20->as_VMReg()->next(3) ,
	v21->as_VMReg()          ,
	v21->as_VMReg()->next()  ,
	v21->as_VMReg()->next(2) ,
	v21->as_VMReg()->next(3) ,
	v22->as_VMReg()          ,
	v22->as_VMReg()->next()  ,
	v22->as_VMReg()->next(2) ,
	v22->as_VMReg()->next(3) ,
	v23->as_VMReg()          ,
	v23->as_VMReg()->next()  ,
	v23->as_VMReg()->next(2) ,
	v23->as_VMReg()->next(3) ,
	v24->as_VMReg()          ,
	v24->as_VMReg()->next()  ,
	v24->as_VMReg()->next(2) ,
	v24->as_VMReg()->next(3) ,
	v25->as_VMReg()          ,
	v25->as_VMReg()->next()  ,
	v25->as_VMReg()->next(2) ,
	v25->as_VMReg()->next(3) ,
	v26->as_VMReg()          ,
	v26->as_VMReg()->next()  ,
	v26->as_VMReg()->next(2) ,
	v26->as_VMReg()->next(3) ,
	v27->as_VMReg()          ,
	v27->as_VMReg()->next()  ,
	v27->as_VMReg()->next(2) ,
	v27->as_VMReg()->next(3) ,
	v28->as_VMReg()          ,
	v28->as_VMReg()->next()  ,
	v28->as_VMReg()->next(2) ,
	v28->as_VMReg()->next(3) ,
	v29->as_VMReg()          ,
	v29->as_VMReg()->next()  ,
	v29->as_VMReg()->next(2) ,
	v29->as_VMReg()->next(3) ,
	v30->as_VMReg()          ,
	v30->as_VMReg()->next()  ,
	v30->as_VMReg()->next(2) ,
	v30->as_VMReg()->next(3) ,
	v31->as_VMReg()          ,
	v31->as_VMReg()->next()  ,
	v31->as_VMReg()->next(2) ,
	v31->as_VMReg()->next(3) ,
	v0->as_VMReg()          ,
	v0->as_VMReg()->next()  ,
	v0->as_VMReg()->next(2) ,
	v0->as_VMReg()->next(3) ,
	v1->as_VMReg()          ,
	v1->as_VMReg()->next()  ,
	v1->as_VMReg()->next(2) ,
	v1->as_VMReg()->next(3) ,
	v2->as_VMReg()          ,
	v2->as_VMReg()->next()  ,
	v2->as_VMReg()->next(2) ,
	v2->as_VMReg()->next(3) ,
	v3->as_VMReg()          ,
	v3->as_VMReg()->next()  ,
	v3->as_VMReg()->next(2) ,
	v3->as_VMReg()->next(3) ,
	v4->as_VMReg()          ,
	v4->as_VMReg()->next()  ,
	v4->as_VMReg()->next(2) ,
	v4->as_VMReg()->next(3) ,
	v5->as_VMReg()          ,
	v5->as_VMReg()->next()  ,
	v5->as_VMReg()->next(2) ,
	v5->as_VMReg()->next(3) ,
	v6->as_VMReg()          ,
	v6->as_VMReg()->next()  ,
	v6->as_VMReg()->next(2) ,
	v6->as_VMReg()->next(3) ,
	v7->as_VMReg()          ,
	v7->as_VMReg()->next()  ,
	v7->as_VMReg()->next(2) ,
	v7->as_VMReg()->next(3) ,
	v8->as_VMReg()          ,
	v8->as_VMReg()->next()  ,
	v8->as_VMReg()->next(2) ,
	v8->as_VMReg()->next(3) ,
	v9->as_VMReg()          ,
	v9->as_VMReg()->next()  ,
	v9->as_VMReg()->next(2) ,
	v9->as_VMReg()->next(3) ,
	v10->as_VMReg()          ,
	v10->as_VMReg()->next()  ,
	v10->as_VMReg()->next(2) ,
	v10->as_VMReg()->next(3) ,
	v11->as_VMReg()          ,
	v11->as_VMReg()->next()  ,
	v11->as_VMReg()->next(2) ,
	v11->as_VMReg()->next(3) ,
	v12->as_VMReg()          ,
	v12->as_VMReg()->next()  ,
	v12->as_VMReg()->next(2) ,
	v12->as_VMReg()->next(3) ,
	v13->as_VMReg()          ,
	v13->as_VMReg()->next()  ,
	v13->as_VMReg()->next(2) ,
	v13->as_VMReg()->next(3) ,
	v14->as_VMReg()          ,
	v14->as_VMReg()->next()  ,
	v14->as_VMReg()->next(2) ,
	v14->as_VMReg()->next(3) ,
	v15->as_VMReg()          ,
	v15->as_VMReg()->next()  ,
	v15->as_VMReg()->next(2) ,
	v15->as_VMReg()->next(3) ,
	p0->as_VMReg(),
	p1->as_VMReg(),
	p2->as_VMReg(),
	p3->as_VMReg(),
	p4->as_VMReg(),
	p5->as_VMReg(),
	p6->as_VMReg(),
	p8->as_VMReg(),
	p9->as_VMReg(),
	p10->as_VMReg(),
	p11->as_VMReg(),
	p12->as_VMReg(),
	p13->as_VMReg(),
	p14->as_VMReg(),
	p15->as_VMReg(),
	p7->as_VMReg(),
	VMRegImpl::Bad() // no trailing comma
	};

 OptoReg::Name OptoReg::vm2opto[ConcreteRegisterImpl::number_of_registers];

// An array of the machine register encode values
const unsigned char Matcher::_regEncode[REG_COUNT] = {
  (unsigned char)'\xA',  // R10
  (unsigned char)'\xA',  // R10_H
  (unsigned char)'\xB',  // R11
  (unsigned char)'\xB',  // R11_H
  (unsigned char)'\xC',  // R12
  (unsigned char)'\xC',  // R12_H
  (unsigned char)'\xD',  // R13
  (unsigned char)'\xD',  // R13_H
  (unsigned char)'\xE',  // R14
  (unsigned char)'\xE',  // R14_H
  (unsigned char)'\xF',  // R15
  (unsigned char)'\xF',  // R15_H
  (unsigned char)'\x10',  // R16
  (unsigned char)'\x10',  // R16_H
  (unsigned char)'\x11',  // R17
  (unsigned char)'\x11',  // R17_H
  (unsigned char)'\x12',  // R18
  (unsigned char)'\x12',  // R18_H
  (unsigned char)'\x0',  // R0
  (unsigned char)'\x0',  // R0_H
  (unsigned char)'\x1',  // R1
  (unsigned char)'\x1',  // R1_H
  (unsigned char)'\x2',  // R2
  (unsigned char)'\x2',  // R2_H
  (unsigned char)'\x3',  // R3
  (unsigned char)'\x3',  // R3_H
  (unsigned char)'\x4',  // R4
  (unsigned char)'\x4',  // R4_H
  (unsigned char)'\x5',  // R5
  (unsigned char)'\x5',  // R5_H
  (unsigned char)'\x6',  // R6
  (unsigned char)'\x6',  // R6_H
  (unsigned char)'\x7',  // R7
  (unsigned char)'\x7',  // R7_H
  (unsigned char)'\x13',  // R19
  (unsigned char)'\x13',  // R19_H
  (unsigned char)'\x14',  // R20
  (unsigned char)'\x14',  // R20_H
  (unsigned char)'\x15',  // R21
  (unsigned char)'\x15',  // R21_H
  (unsigned char)'\x16',  // R22
  (unsigned char)'\x16',  // R22_H
  (unsigned char)'\x17',  // R23
  (unsigned char)'\x17',  // R23_H
  (unsigned char)'\x18',  // R24
  (unsigned char)'\x18',  // R24_H
  (unsigned char)'\x19',  // R25
  (unsigned char)'\x19',  // R25_H
  (unsigned char)'\x1A',  // R26
  (unsigned char)'\x1A',  // R26_H
  (unsigned char)'\x1B',  // R27
  (unsigned char)'\x1B',  // R27_H
  (unsigned char)'\x1C',  // R28
  (unsigned char)'\x1C',  // R28_H
  (unsigned char)'\x1D',  // R29
  (unsigned char)'\x1D',  // R29_H
  (unsigned char)'\x1E',  // R30
  (unsigned char)'\x1E',  // R30_H
  (unsigned char)'\x1F',  // R31
  (unsigned char)'\x1F',  // R31_H
  (unsigned char)'\x8',  // R8
  (unsigned char)'\x8',  // R8_H
  (unsigned char)'\x9',  // R9
  (unsigned char)'\x9',  // R9_H
  (unsigned char)'\x10',  // V16
  (unsigned char)'\x10',  // V16_H
  (unsigned char)'\x10',  // V16_J
  (unsigned char)'\x10',  // V16_K
  (unsigned char)'\x11',  // V17
  (unsigned char)'\x11',  // V17_H
  (unsigned char)'\x11',  // V17_J
  (unsigned char)'\x11',  // V17_K
  (unsigned char)'\x12',  // V18
  (unsigned char)'\x12',  // V18_H
  (unsigned char)'\x12',  // V18_J
  (unsigned char)'\x12',  // V18_K
  (unsigned char)'\x13',  // V19
  (unsigned char)'\x13',  // V19_H
  (unsigned char)'\x13',  // V19_J
  (unsigned char)'\x13',  // V19_K
  (unsigned char)'\x14',  // V20
  (unsigned char)'\x14',  // V20_H
  (unsigned char)'\x14',  // V20_J
  (unsigned char)'\x14',  // V20_K
  (unsigned char)'\x15',  // V21
  (unsigned char)'\x15',  // V21_H
  (unsigned char)'\x15',  // V21_J
  (unsigned char)'\x15',  // V21_K
  (unsigned char)'\x16',  // V22
  (unsigned char)'\x16',  // V22_H
  (unsigned char)'\x16',  // V22_J
  (unsigned char)'\x16',  // V22_K
  (unsigned char)'\x17',  // V23
  (unsigned char)'\x17',  // V23_H
  (unsigned char)'\x17',  // V23_J
  (unsigned char)'\x17',  // V23_K
  (unsigned char)'\x18',  // V24
  (unsigned char)'\x18',  // V24_H
  (unsigned char)'\x18',  // V24_J
  (unsigned char)'\x18',  // V24_K
  (unsigned char)'\x19',  // V25
  (unsigned char)'\x19',  // V25_H
  (unsigned char)'\x19',  // V25_J
  (unsigned char)'\x19',  // V25_K
  (unsigned char)'\x1A',  // V26
  (unsigned char)'\x1A',  // V26_H
  (unsigned char)'\x1A',  // V26_J
  (unsigned char)'\x1A',  // V26_K
  (unsigned char)'\x1B',  // V27
  (unsigned char)'\x1B',  // V27_H
  (unsigned char)'\x1B',  // V27_J
  (unsigned char)'\x1B',  // V27_K
  (unsigned char)'\x1C',  // V28
  (unsigned char)'\x1C',  // V28_H
  (unsigned char)'\x1C',  // V28_J
  (unsigned char)'\x1C',  // V28_K
  (unsigned char)'\x1D',  // V29
  (unsigned char)'\x1D',  // V29_H
  (unsigned char)'\x1D',  // V29_J
  (unsigned char)'\x1D',  // V29_K
  (unsigned char)'\x1E',  // V30
  (unsigned char)'\x1E',  // V30_H
  (unsigned char)'\x1E',  // V30_J
  (unsigned char)'\x1E',  // V30_K
  (unsigned char)'\x1F',  // V31
  (unsigned char)'\x1F',  // V31_H
  (unsigned char)'\x1F',  // V31_J
  (unsigned char)'\x1F',  // V31_K
  (unsigned char)'\x0',  // V0
  (unsigned char)'\x0',  // V0_H
  (unsigned char)'\x0',  // V0_J
  (unsigned char)'\x0',  // V0_K
  (unsigned char)'\x1',  // V1
  (unsigned char)'\x1',  // V1_H
  (unsigned char)'\x1',  // V1_J
  (unsigned char)'\x1',  // V1_K
  (unsigned char)'\x2',  // V2
  (unsigned char)'\x2',  // V2_H
  (unsigned char)'\x2',  // V2_J
  (unsigned char)'\x2',  // V2_K
  (unsigned char)'\x3',  // V3
  (unsigned char)'\x3',  // V3_H
  (unsigned char)'\x3',  // V3_J
  (unsigned char)'\x3',  // V3_K
  (unsigned char)'\x4',  // V4
  (unsigned char)'\x4',  // V4_H
  (unsigned char)'\x4',  // V4_J
  (unsigned char)'\x4',  // V4_K
  (unsigned char)'\x5',  // V5
  (unsigned char)'\x5',  // V5_H
  (unsigned char)'\x5',  // V5_J
  (unsigned char)'\x5',  // V5_K
  (unsigned char)'\x6',  // V6
  (unsigned char)'\x6',  // V6_H
  (unsigned char)'\x6',  // V6_J
  (unsigned char)'\x6',  // V6_K
  (unsigned char)'\x7',  // V7
  (unsigned char)'\x7',  // V7_H
  (unsigned char)'\x7',  // V7_J
  (unsigned char)'\x7',  // V7_K
  (unsigned char)'\x8',  // V8
  (unsigned char)'\x8',  // V8_H
  (unsigned char)'\x8',  // V8_J
  (unsigned char)'\x8',  // V8_K
  (unsigned char)'\x9',  // V9
  (unsigned char)'\x9',  // V9_H
  (unsigned char)'\x9',  // V9_J
  (unsigned char)'\x9',  // V9_K
  (unsigned char)'\xA',  // V10
  (unsigned char)'\xA',  // V10_H
  (unsigned char)'\xA',  // V10_J
  (unsigned char)'\xA',  // V10_K
  (unsigned char)'\xB',  // V11
  (unsigned char)'\xB',  // V11_H
  (unsigned char)'\xB',  // V11_J
  (unsigned char)'\xB',  // V11_K
  (unsigned char)'\xC',  // V12
  (unsigned char)'\xC',  // V12_H
  (unsigned char)'\xC',  // V12_J
  (unsigned char)'\xC',  // V12_K
  (unsigned char)'\xD',  // V13
  (unsigned char)'\xD',  // V13_H
  (unsigned char)'\xD',  // V13_J
  (unsigned char)'\xD',  // V13_K
  (unsigned char)'\xE',  // V14
  (unsigned char)'\xE',  // V14_H
  (unsigned char)'\xE',  // V14_J
  (unsigned char)'\xE',  // V14_K
  (unsigned char)'\xF',  // V15
  (unsigned char)'\xF',  // V15_H
  (unsigned char)'\xF',  // V15_J
  (unsigned char)'\xF',  // V15_K
  (unsigned char)'\x0',  // P0
  (unsigned char)'\x1',  // P1
  (unsigned char)'\x2',  // P2
  (unsigned char)'\x3',  // P3
  (unsigned char)'\x4',  // P4
  (unsigned char)'\x5',  // P5
  (unsigned char)'\x6',  // P6
  (unsigned char)'\x8',  // P8
  (unsigned char)'\x9',  // P9
  (unsigned char)'\xA',  // P10
  (unsigned char)'\xB',  // P11
  (unsigned char)'\xC',  // P12
  (unsigned char)'\xD',  // P13
  (unsigned char)'\xE',  // P14
  (unsigned char)'\xF',  // P15
  (unsigned char)'\x7',  // P7
  (unsigned char)'\x20' // no trailing comma  // RFLAGS
};


//------------------Define classes derived from MachOper---------------------
MachOper  *labelOper::clone() const {
  return  new labelOper(_label, _block_num);
}
uint labelOper::opcode() const { return LABEL; }

const RegMask *sRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

MachOper  *methodOper::clone() const {
  return  new methodOper(_method);
}
uint methodOper::opcode() const { return METHOD; }

const RegMask *iRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *iRegINoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_REG32_mask();
}

const RegMask *iRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG_mask();
}

const RegMask *iRegLNoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_REG_mask();
}

const RegMask *iRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *iRegPNoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_PTR_REG_mask();
}

const RegMask *iRegP_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0_REG_mask();
}

const RegMask *iRegP_R1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R1_REG_mask();
}

const RegMask *iRegP_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2_REG_mask();
}

const RegMask *iRegP_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R3_REG_mask();
}

const RegMask *iRegP_R4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R4_REG_mask();
}

const RegMask *iRegP_R5Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R5_REG_mask();
}

const RegMask *iRegP_R10Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R10_REG_mask();
}

const RegMask *iRegL_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0_REG_mask();
}

const RegMask *iRegL_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2_REG_mask();
}

const RegMask *iRegL_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R3_REG_mask();
}

const RegMask *iRegL_R11Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R11_REG_mask();
}

const RegMask *iRegP_FPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FP_REG_mask();
}

const RegMask *iRegI_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R0_REG_mask();
}

const RegMask *iRegI_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R2_REG_mask();
}

const RegMask *iRegI_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R3_REG_mask();
}

const RegMask *iRegI_R4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R4_REG_mask();
}

const RegMask *iRegNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *iRegN_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0_REG_mask();
}

const RegMask *iRegN_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2_REG_mask();
}

const RegMask *iRegN_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R3_REG_mask();
}

const RegMask *iRegNNoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_REG32_mask();
}

const RegMask *iRegIHeapbaseOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &HEAPBASE_REG_mask();
}

const RegMask *vRegFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FLOAT_REG_mask();
}

const RegMask *vRegDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &DOUBLE_REG_mask();
}

const RegMask *vRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RegMask::Empty;
}

const RegMask *vecAOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORA_REG_mask();
}

const RegMask *vecDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORD_REG_mask();
}

const RegMask *vecXOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORX_REG_mask();
}

const RegMask *vRegD_V0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V0_REG_mask();
}

const RegMask *vRegD_V1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V1_REG_mask();
}

const RegMask *vRegD_V2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V2_REG_mask();
}

const RegMask *vRegD_V3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V3_REG_mask();
}

const RegMask *vRegD_V4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V4_REG_mask();
}

const RegMask *vRegD_V5Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V5_REG_mask();
}

const RegMask *vRegD_V6Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V6_REG_mask();
}

const RegMask *vRegD_V7Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V7_REG_mask();
}

const RegMask *vRegD_V8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V8_REG_mask();
}

const RegMask *vRegD_V9Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V9_REG_mask();
}

const RegMask *vRegD_V10Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V10_REG_mask();
}

const RegMask *vRegD_V11Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V11_REG_mask();
}

const RegMask *vRegD_V12Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V12_REG_mask();
}

const RegMask *vRegD_V13Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V13_REG_mask();
}

const RegMask *vRegD_V14Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V14_REG_mask();
}

const RegMask *vRegD_V15Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V15_REG_mask();
}

const RegMask *vRegD_V16Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V16_REG_mask();
}

const RegMask *vRegD_V17Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V17_REG_mask();
}

const RegMask *vRegD_V18Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V18_REG_mask();
}

const RegMask *vRegD_V19Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V19_REG_mask();
}

const RegMask *vRegD_V20Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V20_REG_mask();
}

const RegMask *vRegD_V21Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V21_REG_mask();
}

const RegMask *vRegD_V22Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V22_REG_mask();
}

const RegMask *vRegD_V23Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V23_REG_mask();
}

const RegMask *vRegD_V24Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V24_REG_mask();
}

const RegMask *vRegD_V25Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V25_REG_mask();
}

const RegMask *vRegD_V26Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V26_REG_mask();
}

const RegMask *vRegD_V27Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V27_REG_mask();
}

const RegMask *vRegD_V28Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V28_REG_mask();
}

const RegMask *vRegD_V29Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V29_REG_mask();
}

const RegMask *vRegD_V30Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V30_REG_mask();
}

const RegMask *vRegD_V31Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V31_REG_mask();
}

const RegMask *pRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PR_REG_mask();
}

const RegMask *pRegGovOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &GOV_PR_mask();
}

const RegMask *pRegGov_P0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &P0_REG_mask();
}

const RegMask *pRegGov_P1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &P1_REG_mask();
}

const RegMask *rFlagsRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *rFlagsRegUOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *inline_cache_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &METHOD_REG_mask();
}

const RegMask *thread_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &THREAD_REG_mask();
}

const RegMask *lr_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &LR_REG_mask();
}

const RegMask *indirectOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indIndexScaledI2LOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG32_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexScaledOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexI2LOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG32_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indOffIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI16Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL16Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indirectNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexScaledI2LNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexScaledNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG32_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexI2LNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG32_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indOffINOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indOffLNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *thread_anchor_pcOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *stackSlotPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *iRegL2IOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG_mask();
}

const RegMask *vmemA_indOffI4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *vmemA_indOffL4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

//------------------Define members for classes derived from MachNode----------
// Build short branch version of this instruction
MachNode *far_cmpL_branch_signNode::short_branch_version() {
  cmpL_branch_signNode *node = new cmpL_branch_signNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}

// Build short branch version of this instruction
MachNode *far_cmpI_branch_signNode::short_branch_version() {
  cmpI_branch_signNode *node = new cmpI_branch_signNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}

// Build short branch version of this instruction
MachNode *far_cmpL_branch_bitNode::short_branch_version() {
  cmpL_branch_bitNode *node = new cmpL_branch_bitNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}

// Build short branch version of this instruction
MachNode *far_cmpI_branch_bitNode::short_branch_version() {
  cmpI_branch_bitNode *node = new cmpI_branch_bitNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}


// Copy _idx, inputs and operands to new node
void MachNode::fill_new_machnode(MachNode* node) const {
  // New node must use same node index
  node->set_idx( _idx );
  // Copy machine-independent inputs
  for( uint j = 0; j < req(); j++ ) {
    node->add_req(in(j));
  }
  // Copy my operands, except for cisc position
  int nopnds = num_opnds();
  assert( node->num_opnds() == (uint)nopnds, "Must have same number of operands");
  MachOper **to = node->_opnds;
  for( int i = 0; i < nopnds; i++ ) {
    if( i != cisc_operand() ) 
      to[i] = _opnds[i]->clone();
  }
}

void overflowMulI_reg_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void overflowMulI_reg_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void overflowMulL_reg_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void overflowMulL_reg_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpI_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpI_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpP_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpP_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpN_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpN_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpP_narrowOop_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpP_narrowOop_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpUI_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpUI_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpUL_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpUL_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpI_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpI_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpI_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpI_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpL_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpL_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpI_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpI_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpL_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpL_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpI_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpI_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchLoopEndNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchLoopEndNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchLoopEndUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchLoopEndUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void CallStaticJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallDynamicJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallRuntimeDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafNoFPDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

int loadBNode::reloc() const {
  return 1;
}

int loadB2LNode::reloc() const {
  return 1;
}

int loadUBNode::reloc() const {
  return 1;
}

int loadUB2LNode::reloc() const {
  return 1;
}

int loadSNode::reloc() const {
  return 1;
}

int loadS2LNode::reloc() const {
  return 1;
}

int loadUSNode::reloc() const {
  return 1;
}

int loadUS2LNode::reloc() const {
  return 1;
}

int loadINode::reloc() const {
  return 1;
}

int loadI2LNode::reloc() const {
  return 1;
}

int loadUI2LNode::reloc() const {
  return 1;
}

int loadLNode::reloc() const {
  return 1;
}

int loadRangeNode::reloc() const {
  return 1;
}

int loadPNode::reloc() const {
  return 1;
}

int loadNNode::reloc() const {
  return 1;
}

int loadKlassNode::reloc() const {
  return 1;
}

int loadNKlassNode::reloc() const {
  return 1;
}

int loadFNode::reloc() const {
  return 1;
}

int loadDNode::reloc() const {
  return 1;
}

int loadConPNode::reloc() const {
  return 1;
}

int loadConP0Node::reloc() const {
  return 1;
}

int loadConP1Node::reloc() const {
  return 1;
}

int loadByteMapBaseNode::reloc() const {
  return 1;
}

int loadConF_packedNode::reloc() const {
  return 2;
}

int loadConFNode::reloc() const {
  return 2;
}

int loadConD_packedNode::reloc() const {
  return 2;
}

int loadConDNode::reloc() const {
  return 2;
}

int storeimmCM0Node::reloc() const {
  return 2;
}

int storeimmCM0_orderedNode::reloc() const {
  return 2;
}

int storeBNode::reloc() const {
  return 3;
}

int storeimmB0Node::reloc() const {
  return 2;
}

int storeCNode::reloc() const {
  return 3;
}

int storeimmC0Node::reloc() const {
  return 2;
}

int storeINode::reloc() const {
  return 3;
}

int storeimmI0Node::reloc() const {
  return 2;
}

int storeLNode::reloc() const {
  return 2;
}

int storeimmL0Node::reloc() const {
  return 2;
}

int storePNode::reloc() const {
  return 2;
}

int storeimmP0Node::reloc() const {
  return 3;
}

int storeNNode::reloc() const {
  return 2;
}

int storeImmN0Node::reloc() const {
  return 2;
}

int storeFNode::reloc() const {
  return 2;
}

int storeDNode::reloc() const {
  return 2;
}

int storeNKlassNode::reloc() const {
  return 2;
}

int prefetchallocNode::reloc() const {
  return 1;
}

int storeB_volatileNode::reloc() const {
  return 1;
}

int storeC_volatileNode::reloc() const {
  return 1;
}

int storeI_volatileNode::reloc() const {
  return 1;
}

int storeimmP0_volatileNode::reloc() const {
  return 1;
}

int bytes_reverse_intNode::reloc() const {
  return 1;
}

int bytes_reverse_unsigned_shortNode::reloc() const {
  return 1;
}

int bytes_reverse_shortNode::reloc() const {
  return 1;
}

int countLeadingZerosINode::reloc() const {
  return 1;
}

int countTrailingZerosINode::reloc() const {
  return 1;
}

int popCountINode::reloc() const {
  return 1;
}

int popCountI_memNode::reloc() const {
  return 1;
}

int popCountL_memNode::reloc() const {
  return 1;
}

int get_and_addINode::reloc() const {
  return 1;
}

int get_and_addI_no_resNode::reloc() const {
  return 1;
}

int get_and_addIAcqNode::reloc() const {
  return 1;
}

int get_and_addI_no_resAcqNode::reloc() const {
  return 1;
}

int cmovI_reg_regNode::reloc() const {
  return 2;
}

int cmovUI_reg_regNode::reloc() const {
  return 2;
}

int cmovI_zero_regNode::reloc() const {
  return 1;
}

int cmovUI_zero_regNode::reloc() const {
  return 1;
}

int cmovI_reg_zeroNode::reloc() const {
  return 1;
}

int cmovUI_reg_zeroNode::reloc() const {
  return 1;
}

int cmovP_reg_zeroNode::reloc() const {
  return 1;
}

int cmovUP_reg_zeroNode::reloc() const {
  return 1;
}

int cmovP_zero_regNode::reloc() const {
  return 1;
}

int cmovUP_zero_regNode::reloc() const {
  return 1;
}

int addI_reg_regNode::reloc() const {
  return 2;
}

int addI_reg_immNode::reloc() const {
  return 1;
}

int addP_reg_reg_extNode::reloc() const {
  return 1;
}

int addP_reg_reg_ext_shiftNode::reloc() const {
  return 1;
}

int lshift_extNode::reloc() const {
  return 1;
}

int subI_reg_regNode::reloc() const {
  return 2;
}

int subI_reg_immNode::reloc() const {
  return 1;
}

int negI_regNode::reloc() const {
  return 1;
}

int mulINode::reloc() const {
  return 2;
}

int smulINode::reloc() const {
  return 2;
}

int smulI_0Node::reloc() const {
  return 2;
}

int maddINode::reloc() const {
  return 3;
}

int maddI_0Node::reloc() const {
  return 3;
}

int msubINode::reloc() const {
  return 3;
}

int mnegINode::reloc() const {
  return 2;
}

int mnegI_0Node::reloc() const {
  return 2;
}

int smaddLNode::reloc() const {
  return 2;
}

int smaddL_1Node::reloc() const {
  return 2;
}

int smaddL_0Node::reloc() const {
  return 2;
}

int smaddL_2Node::reloc() const {
  return 2;
}

int smsubLNode::reloc() const {
  return 2;
}

int smsubL_0Node::reloc() const {
  return 2;
}

int smnegLNode::reloc() const {
  return 2;
}

int smnegL_0Node::reloc() const {
  return 2;
}

int muladdS2INode::reloc() const {
  return 4;
}

int divINode::reloc() const {
  return 2;
}

int modINode::reloc() const {
  return 2;
}

int UdivI_reg_regNode::reloc() const {
  return 2;
}

int UmodI_reg_regNode::reloc() const {
  return 2;
}

int lShiftI_reg_regNode::reloc() const {
  return 2;
}

int lShiftI_reg_immNode::reloc() const {
  return 1;
}

int urShiftI_reg_regNode::reloc() const {
  return 2;
}

int urShiftI_reg_immNode::reloc() const {
  return 1;
}

int rShiftI_reg_regNode::reloc() const {
  return 2;
}

int rShiftI_reg_immNode::reloc() const {
  return 1;
}

int lShiftL_reg_regNode::reloc() const {
  return 1;
}

int urShiftL_reg_regNode::reloc() const {
  return 1;
}

int rShiftL_reg_regNode::reloc() const {
  return 1;
}

int regI_not_regNode::reloc() const {
  return 1;
}

int NegI_reg_URShift_regNode::reloc() const {
  return 1;
}

int NegI_reg_RShift_regNode::reloc() const {
  return 1;
}

int NegI_reg_LShift_regNode::reloc() const {
  return 1;
}

int AndI_reg_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_URShift_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_URShift_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RShift_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_RShift_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RotateRight_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_RotateRight_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_LShift_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_LShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_reg_2Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_reg_2Node::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_not_reg_2Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_reg_2Node::reloc() const {
  return 2;
}

int OrI_reg_URShift_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_URShift_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RShift_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_RShift_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RotateRight_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_RotateRight_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_LShift_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_LShift_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_URShift_regNode::reloc() const {
  return 2;
}

int AndI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RShift_regNode::reloc() const {
  return 2;
}

int AndI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_LShift_regNode::reloc() const {
  return 2;
}

int AndI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RotateRight_regNode::reloc() const {
  return 2;
}

int AndI_reg_RotateRight_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_regNode::reloc() const {
  return 2;
}

int XorI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_regNode::reloc() const {
  return 2;
}

int XorI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_regNode::reloc() const {
  return 2;
}

int XorI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_regNode::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_URShift_regNode::reloc() const {
  return 2;
}

int OrI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RShift_regNode::reloc() const {
  return 2;
}

int OrI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_LShift_regNode::reloc() const {
  return 2;
}

int OrI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RotateRight_regNode::reloc() const {
  return 2;
}

int OrI_reg_RotateRight_reg_0Node::reloc() const {
  return 2;
}

int AddI_reg_URShift_regNode::reloc() const {
  return 2;
}

int AddI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int AddI_reg_RShift_regNode::reloc() const {
  return 2;
}

int AddI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int AddI_reg_LShift_regNode::reloc() const {
  return 2;
}

int AddI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int SubI_reg_URShift_regNode::reloc() const {
  return 2;
}

int SubI_reg_RShift_regNode::reloc() const {
  return 2;
}

int SubI_reg_LShift_regNode::reloc() const {
  return 2;
}

int sbfmwINode::reloc() const {
  return 1;
}

int ubfmwINode::reloc() const {
  return 1;
}

int ubfxwINode::reloc() const {
  return 1;
}

int ubfxIConvI2LNode::reloc() const {
  return 1;
}

int ubfizwINode::reloc() const {
  return 1;
}

int ubfizwIConvI2LNode::reloc() const {
  return 1;
}

int ubfizIConvI2LNode::reloc() const {
  return 1;
}

int extrOrINode::reloc() const {
  return 2;
}

int extrOrI_0Node::reloc() const {
  return 2;
}

int extrAddINode::reloc() const {
  return 2;
}

int extrAddI_0Node::reloc() const {
  return 2;
}

int AddExtINode::reloc() const {
  return 1;
}

int AddExtI_0Node::reloc() const {
  return 1;
}

int SubExtINode::reloc() const {
  return 1;
}

int AddExtI_sxthNode::reloc() const {
  return 2;
}

int AddExtI_sxth_0Node::reloc() const {
  return 2;
}

int AddExtI_sxtbNode::reloc() const {
  return 2;
}

int AddExtI_sxtb_0Node::reloc() const {
  return 2;
}

int AddExtI_uxtbNode::reloc() const {
  return 2;
}

int AddExtI_uxtb_0Node::reloc() const {
  return 2;
}

int AddExtI_uxtb_andNode::reloc() const {
  return 2;
}

int AddExtI_uxtb_and_0Node::reloc() const {
  return 2;
}

int AddExtI_uxth_andNode::reloc() const {
  return 2;
}

int AddExtI_uxth_and_0Node::reloc() const {
  return 2;
}

int SubExtI_uxtb_andNode::reloc() const {
  return 2;
}

int SubExtI_uxth_andNode::reloc() const {
  return 2;
}

int AddExtI_sxtb_shiftNode::reloc() const {
  return 2;
}

int AddExtI_sxtb_shift_0Node::reloc() const {
  return 2;
}

int AddExtI_sxth_shiftNode::reloc() const {
  return 2;
}

int AddExtI_sxth_shift_0Node::reloc() const {
  return 2;
}

int SubExtI_sxtb_shiftNode::reloc() const {
  return 2;
}

int SubExtI_sxth_shiftNode::reloc() const {
  return 2;
}

int AddExtI_shiftNode::reloc() const {
  return 1;
}

int AddExtI_shift_0Node::reloc() const {
  return 1;
}

int SubExtI_shiftNode::reloc() const {
  return 1;
}

int AddExtI_uxtb_and_shiftNode::reloc() const {
  return 2;
}

int AddExtI_uxtb_and_shift_0Node::reloc() const {
  return 2;
}

int AddExtI_uxth_and_shiftNode::reloc() const {
  return 2;
}

int AddExtI_uxth_and_shift_0Node::reloc() const {
  return 2;
}

int SubExtI_uxtb_and_shiftNode::reloc() const {
  return 2;
}

int SubExtI_uxth_and_shiftNode::reloc() const {
  return 2;
}

int mnsubF_reg_regNode::reloc() const {
  return 1;
}

int mnsubD_reg_regNode::reloc() const {
  return 1;
}

int absI_regNode::reloc() const {
  return 1;
}

int andI_reg_regNode::reloc() const {
  return 2;
}

int andI_reg_immNode::reloc() const {
  return 1;
}

int orI_reg_regNode::reloc() const {
  return 2;
}

int orI_reg_immNode::reloc() const {
  return 1;
}

int xorI_reg_regNode::reloc() const {
  return 2;
}

int xorI_reg_immNode::reloc() const {
  return 1;
}

int convI2L_reg_regNode::reloc() const {
  return 1;
}

int convUI2L_reg_regNode::reloc() const {
  return 1;
}

int convI2BNode::reloc() const {
  return 1;
}

int convI2F_reg_regNode::reloc() const {
  return 1;
}

int convI2D_reg_regNode::reloc() const {
  return 1;
}

int overflowAddI_reg_regNode::reloc() const {
  return 2;
}

int overflowAddI_reg_immNode::reloc() const {
  return 1;
}

int overflowSubI_reg_regNode::reloc() const {
  return 2;
}

int overflowSubI_reg_immNode::reloc() const {
  return 1;
}

int overflowNegI_regNode::reloc() const {
  return 1;
}

int overflowMulI_regNode::reloc() const {
  return 2;
}

int overflowMulI_reg_branchNode::reloc() const {
  return 2;
}

int testP_regNode::reloc() const {
  return 1;
}

int compF_reg_zeroNode::reloc() const {
  return 1;
}

int compD_reg_zeroNode::reloc() const {
  return 1;
}

int compF3_reg_immF0Node::reloc() const {
  return 1;
}

int compD3_reg_immD0Node::reloc() const {
  return 1;
}

int cmpLTMask_reg_regNode::reloc() const {
  return 2;
}

int cmpLTMask_reg_zeroNode::reloc() const {
  return 1;
}

int cmpI_imm0_branchNode::reloc() const {
  return 1;
}

int cmpP_imm0_branchNode::reloc() const {
  return 1;
}

int cmpP_narrowOop_imm0_branchNode::reloc() const {
  return 1;
}

int cmpUI_imm0_branchNode::reloc() const {
  return 1;
}

int cmpI_branch_signNode::reloc() const {
  return 1;
}

int cmpI_branch_bitNode::reloc() const {
  return 1;
}

int far_cmpI_branch_signNode::reloc() const {
  return 1;
}

int far_cmpI_branch_bitNode::reloc() const {
  return 1;
}

int cmpI_andNode::reloc() const {
  return 1;
}

int cmpI_and_regNode::reloc() const {
  return 2;
}

int safePointNode::reloc() const {
  return 1;
}

int CallStaticJavaDirectNode::reloc() const {
  return 1;
}

int CallDynamicJavaDirectNode::reloc() const {
  return 1;
}

int CallRuntimeDirectNode::reloc() const {
  return 1;
}

int CallLeafDirectNode::reloc() const {
  return 1;
}

int CallLeafNoFPDirectNode::reloc() const {
  return 1;
}

int TailCalljmpIndNode::reloc() const {
  return 1;
}

int TailjmpIndNode::reloc() const {
  return 1;
}

int RethrowExceptionNode::reloc() const {
  return 1;
}

int RetNode::reloc() const {
  return 1;
}

int partialSubtypeCheckVsZeroNode::reloc() const {
  return 1;
}

int loadV2Node::reloc() const {
  return 1;
}

int storeV2Node::reloc() const {
  return 2;
}

int loadV4Node::reloc() const {
  return 1;
}

int storeV4Node::reloc() const {
  return 2;
}

int loadV8Node::reloc() const {
  return 1;
}

int storeV8Node::reloc() const {
  return 2;
}

int loadV16Node::reloc() const {
  return 1;
}

int storeV16Node::reloc() const {
  return 2;
}

int loadVNode::reloc() const {
  return 1;
}

int storeVNode::reloc() const {
  return 2;
}

int loadV_maskedNode::reloc() const {
  return 1;
}

int storeV_maskedNode::reloc() const {
  return 2;
}

int vshiftcntLNode::reloc() const {
  return 1;
}

int vshiftcntRNode::reloc() const {
  return 1;
}

int reduce_addI_neonNode::reloc() const {
  return 1;
}

int reduce_addI_sveNode::reloc() const {
  return 1;
}

int reduce_addI_maskedNode::reloc() const {
  return 1;
}

int reduce_mulINode::reloc() const {
  return 1;
}

int reduce_andI_neonNode::reloc() const {
  return 1;
}

int reduce_andI_sveNode::reloc() const {
  return 1;
}

int reduce_andI_maskedNode::reloc() const {
  return 1;
}

int reduce_orI_neonNode::reloc() const {
  return 1;
}

int reduce_orI_sveNode::reloc() const {
  return 1;
}

int reduce_orI_maskedNode::reloc() const {
  return 1;
}

int reduce_xorI_neonNode::reloc() const {
  return 1;
}

int reduce_xorI_sveNode::reloc() const {
  return 1;
}

int reduce_xorI_maskedNode::reloc() const {
  return 1;
}

int reduce_maxI_neonNode::reloc() const {
  return 1;
}

int reduce_maxI_sveNode::reloc() const {
  return 1;
}

int reduce_maxI_maskedNode::reloc() const {
  return 1;
}

int reduce_minI_neonNode::reloc() const {
  return 1;
}

int reduce_minI_sveNode::reloc() const {
  return 1;
}

int reduce_minI_maskedNode::reloc() const {
  return 1;
}

int replicateBNode::reloc() const {
  return 1;
}

int replicateSNode::reloc() const {
  return 1;
}

int replicateINode::reloc() const {
  return 1;
}

int insertI_le128bNode::reloc() const {
  return 1;
}

int insertI_index_lt32Node::reloc() const {
  return 1;
}

int insertI_index_ge32Node::reloc() const {
  return 1;
}

int vloadmask_loadVMaskedNode::reloc() const {
  return 1;
}

int vloadmask_loadVMasked_maskedNode::reloc() const {
  return 1;
}

int storeVMasked_vstoremaskNode::reloc() const {
  return 2;
}

int storeVMasked_vstoremask_maskedNode::reloc() const {
  return 2;
}

int vmaskAllINode::reloc() const {
  return 1;
}

int vmaskAllI_maskedNode::reloc() const {
  return 1;
}

int vmask_gen_INode::reloc() const {
  return 1;
}

int populateindexNode::reloc() const {
  return 1;
}

int zLoadPNode::reloc() const {
  return 1;
}


void loadBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2780 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrsbw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 14454 "ad_aarch64.cpp"
  }
}

void loadB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2788 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrsb, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 14471 "ad_aarch64.cpp"
  }
}

void loadUBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2804 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrb, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 14488 "ad_aarch64.cpp"
  }
}

void loadUB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2804 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrb, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 14505 "ad_aarch64.cpp"
  }
}

void loadSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2812 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrshw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 14522 "ad_aarch64.cpp"
  }
}

void loadS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2820 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrsh, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 14539 "ad_aarch64.cpp"
  }
}

void loadUSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2836 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrh, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 14556 "ad_aarch64.cpp"
  }
}

void loadUS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2836 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrh, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 14573 "ad_aarch64.cpp"
  }
}

void loadINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2852 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 14590 "ad_aarch64.cpp"
  }
}

void loadI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2860 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrsw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 14607 "ad_aarch64.cpp"
  }
}

void loadUI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {

#line 2852 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 14625 "ad_aarch64.cpp"
  }
}

void loadLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2868 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 14642 "ad_aarch64.cpp"
  }
}

void loadRangeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2852 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 14659 "ad_aarch64.cpp"
  }
}

void loadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2868 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 14676 "ad_aarch64.cpp"
  }
}

void loadNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2852 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 14693 "ad_aarch64.cpp"
  }
}

void loadKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2868 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 14710 "ad_aarch64.cpp"
  }
}

void loadNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2852 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 14727 "ad_aarch64.cpp"
  }
}

void loadFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2876 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrs, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 14744 "ad_aarch64.cpp"
  }
}

void loadDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2884 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrd, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 14761 "ad_aarch64.cpp"
  }
}

void loadConINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 3344 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    uint32_t con = (uint32_t)opnd_array(1)->constant();
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    if (con == 0) {
      __ movw(dst_reg, zr);
    } else {
      __ movw(dst_reg, con);
    }
  
#line 14783 "ad_aarch64.cpp"
  }
}

void loadConLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 3355 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    uint64_t con = (uint64_t)opnd_array(1)->constantL();
    if (con == 0) {
      __ mov(dst_reg, zr);
    } else {
      __ mov(dst_reg, con);
    }
  
#line 14805 "ad_aarch64.cpp"
  }
}

void loadConPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3366 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    address con = (address)opnd_array(1)->constant();
    if (con == NULL || con == (address)1) {
      ShouldNotReachHere();
    } else {
      relocInfo::relocType rtype = opnd_array(1)->constant_reloc();
      if (rtype == relocInfo::oop_type) {
        __ movoop(dst_reg, (jobject)con);
      } else if (rtype == relocInfo::metadata_type) {
        __ mov_metadata(dst_reg, (Metadata*)con);
      } else {
        assert(rtype == relocInfo::none, "unexpected reloc type");
        if (! __ is_valid_AArch64_address(con) ||
            con < (address)(uintptr_t)os::vm_page_size()) {
          __ mov(dst_reg, con);
        } else {
          uint64_t offset;
          __ adrp(dst_reg, con, offset);
          __ add(dst_reg, dst_reg, offset);
        }
      }
    }
  
#line 14842 "ad_aarch64.cpp"
  }
}

void loadConP0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3392 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ mov(dst_reg, zr);
  
#line 14859 "ad_aarch64.cpp"
  }
}

void loadConP1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3398 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ mov(dst_reg, (uint64_t)1);
  
#line 14876 "ad_aarch64.cpp"
  }
}

void loadByteMapBaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3404 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    __ load_byte_map_base(opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 14892 "ad_aarch64.cpp"
  }
}

void loadConNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3409 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    address con = (address)opnd_array(1)->constant();
    if (con == NULL) {
      ShouldNotReachHere();
    } else {
      relocInfo::relocType rtype = opnd_array(1)->constant_reloc();
      assert(rtype == relocInfo::oop_type, "unexpected reloc type");
      __ set_narrow_oop(dst_reg, (jobject)con);
    }
  
#line 14916 "ad_aarch64.cpp"
  }
}

void loadConN0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3422 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ mov(dst_reg, zr);
  
#line 14933 "ad_aarch64.cpp"
  }
}

void loadConNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3428 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    address con = (address)opnd_array(1)->constant();
    if (con == NULL) {
      ShouldNotReachHere();
    } else {
      relocInfo::relocType rtype = opnd_array(1)->constant_reloc();
      assert(rtype == relocInfo::metadata_type, "unexpected reloc type");
      __ set_narrow_klass(dst_reg, (Klass *)con);
    }
  
#line 14957 "ad_aarch64.cpp"
  }
}

void loadConF_packedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7356 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), (double)opnd_array(1)->constantF());
  
#line 14973 "ad_aarch64.cpp"
  }
}

void loadConFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7374 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 14989 "ad_aarch64.cpp"
  }
}

void loadConFNode::eval_constant(Compile* C) {
  {

#line 7375 "src/hotspot/cpu/aarch64/aarch64.ad"
    _constant = C->output()->constant_table().add(this, opnd_array(1));
#line 14998 "ad_aarch64.cpp"
  }
}
void loadConD_packedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7387 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->constantD());
  
#line 15013 "ad_aarch64.cpp"
  }
}

void loadConDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7404 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 15029 "ad_aarch64.cpp"
  }
}

void loadConDNode::eval_constant(Compile* C) {
  {

#line 7405 "src/hotspot/cpu/aarch64/aarch64.ad"
    _constant = C->output()->constant_table().add(this, opnd_array(1));
#line 15038 "ad_aarch64.cpp"
  }
}
void storeimmCM0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2900 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strb, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 15055 "ad_aarch64.cpp"
  }
}

void storeimmCM0_orderedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2980 "src/hotspot/cpu/aarch64/aarch64.ad"

      C2_MacroAssembler _masm(&cbuf);
      __ membar(Assembler::StoreStore);
      loadStore(_masm, &MacroAssembler::strb, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 15074 "ad_aarch64.cpp"
  }
}

void storeBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2892 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strb, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 15092 "ad_aarch64.cpp"
  }
}

void storeimmB0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2900 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strb, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 15110 "ad_aarch64.cpp"
  }
}

void storeCNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2908 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strh, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 15128 "ad_aarch64.cpp"
  }
}

void storeimmC0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2916 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strh, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 15146 "ad_aarch64.cpp"
  }
}

void storeINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2924 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15164 "ad_aarch64.cpp"
  }
}

void storeimmI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2932 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strw, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15182 "ad_aarch64.cpp"
  }
}

void storeLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2940 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      C2_MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 15208 "ad_aarch64.cpp"
  }
}

void storeimmL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2956 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::str, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 15226 "ad_aarch64.cpp"
  }
}

void storePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2940 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      C2_MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 15252 "ad_aarch64.cpp"
  }
}

void storeimmP0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2956 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::str, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 15270 "ad_aarch64.cpp"
  }
}

void storeNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2924 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15288 "ad_aarch64.cpp"
  }
}

void storeImmN0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2932 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strw, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15306 "ad_aarch64.cpp"
  }
}

void storeFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2964 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strs, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15324 "ad_aarch64.cpp"
  }
}

void storeDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2972 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strd, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 15342 "ad_aarch64.cpp"
  }
}

void storeNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2924 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15360 "ad_aarch64.cpp"
  }
}

void prefetchallocNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {

#line 3323 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    if (index == -1) {
      __ prfm(Address(base, disp), PSTL1KEEP);
    } else {
      Register index_reg = as_Register(index);
      if (disp == 0) {
        __ prfm(Address(base, index_reg, Address::lsl(scale)), PSTL1KEEP);
      } else {
        __ lea(rscratch1, Address(base, disp));
	__ prfm(Address(rscratch1, index_reg, Address::lsl(scale)), PSTL1KEEP);
      }
    }
  
#line 15390 "ad_aarch64.cpp"
  }
}

void loadB_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3077 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
    __ sxtb(dst_reg, dst_reg);
  
#line 15408 "ad_aarch64.cpp"
  }
}

void loadB2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3077 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
    __ sxtb(dst_reg, dst_reg);
  
#line 15426 "ad_aarch64.cpp"
  }
}

void loadUB_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3089 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
  
#line 15442 "ad_aarch64.cpp"
  }
}

void loadUB2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3089 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
  
#line 15458 "ad_aarch64.cpp"
  }
}

void loadS_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3094 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
    __ sxthw(dst_reg, dst_reg);
  
#line 15476 "ad_aarch64.cpp"
  }
}

void loadUS_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3108 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
  
#line 15492 "ad_aarch64.cpp"
  }
}

void loadUS2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3113 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
  
#line 15508 "ad_aarch64.cpp"
  }
}

void loadS2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3101 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
    __ sxth(dst_reg, dst_reg);
  
#line 15526 "ad_aarch64.cpp"
  }
}

void loadI_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3123 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
  
#line 15542 "ad_aarch64.cpp"
  }
}

void loadUI2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {

#line 3123 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
  
#line 15559 "ad_aarch64.cpp"
  }
}

void loadL_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3128 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldar);
  
#line 15575 "ad_aarch64.cpp"
  }
}

void loadP_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3128 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldar);
  
#line 15591 "ad_aarch64.cpp"
  }
}

void loadN_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3123 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
  
#line 15607 "ad_aarch64.cpp"
  }
}

void loadF_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3133 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(rscratch1, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
    __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), rscratch1);
  
#line 15624 "ad_aarch64.cpp"
  }
}

void loadD_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3139 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(rscratch1, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldar);
    __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), rscratch1);
  
#line 15641 "ad_aarch64.cpp"
  }
}

void storeB_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3040 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrb);
  
#line 15658 "ad_aarch64.cpp"
  }
}

void storeimmB0_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3045 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(zr, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrb);
  
#line 15675 "ad_aarch64.cpp"
  }
}

void storeC_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3050 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrh);
  
#line 15692 "ad_aarch64.cpp"
  }
}

void storeimmC0_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3055 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(zr, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrh);
  
#line 15709 "ad_aarch64.cpp"
  }
}

void storeI_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3060 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 15726 "ad_aarch64.cpp"
  }
}

void storeimmI0_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3065 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(zr, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 15743 "ad_aarch64.cpp"
  }
}

void storeL_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3145 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      C2_MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    MOV_VOLATILE(src_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 15769 "ad_aarch64.cpp"
  }
}

void storeimmL0_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3159 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(zr, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 15786 "ad_aarch64.cpp"
  }
}

void storeP_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3145 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      C2_MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    MOV_VOLATILE(src_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 15812 "ad_aarch64.cpp"
  }
}

void storeimmP0_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3159 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(zr, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 15829 "ad_aarch64.cpp"
  }
}

void storeN_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3060 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 15846 "ad_aarch64.cpp"
  }
}

void storeimmN0_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3065 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(zr, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 15863 "ad_aarch64.cpp"
  }
}

void storeF_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3164 "src/hotspot/cpu/aarch64/aarch64.ad"

    {
      C2_MacroAssembler _masm(&cbuf);
      FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
      __ fmovs(rscratch2, src_reg);
    }
    MOV_VOLATILE(rscratch2, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 15885 "ad_aarch64.cpp"
  }
}

void storeD_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3174 "src/hotspot/cpu/aarch64/aarch64.ad"

    {
      C2_MacroAssembler _masm(&cbuf);
      FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
      __ fmovd(rscratch2, src_reg);
    }
    MOV_VOLATILE(rscratch2, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 15907 "ad_aarch64.cpp"
  }
}

void cacheWBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8057 "src/hotspot/cpu/aarch64/aarch64.ad"

    assert(opnd_array(1)->index_position() < 0, "should be");
    assert(opnd_array(1)->disp(ra_,this,idx1)== 0, "should be");
    __ cache_wb(Address(as_Register(opnd_array(1)->base(ra_,this,idx1)), 0));
  
#line 15925 "ad_aarch64.cpp"
  }
}

void cacheWBPreSyncNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8072 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cache_wbsync(true);
  
#line 15941 "ad_aarch64.cpp"
  }
}

void cacheWBPostSyncNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8085 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cache_wbsync(false);
  
#line 15957 "ad_aarch64.cpp"
  }
}

void bytes_reverse_intNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8100 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ revw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 15973 "ad_aarch64.cpp"
  }
}

void bytes_reverse_longNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8113 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rev(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 15989 "ad_aarch64.cpp"
  }
}

void bytes_reverse_unsigned_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8126 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rev16w(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 16005 "ad_aarch64.cpp"
  }
}

void bytes_reverse_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8140 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rev16w(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sbfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */), 0U, 15U);
  
#line 16022 "ad_aarch64.cpp"
  }
}

void countLeadingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8156 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ clzw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 16038 "ad_aarch64.cpp"
  }
}

void countLeadingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8168 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ clz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 16054 "ad_aarch64.cpp"
  }
}

void countTrailingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8181 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rbitw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ clzw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 16071 "ad_aarch64.cpp"
  }
}

void countTrailingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8195 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rbit(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ clz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 16088 "ad_aarch64.cpp"
  }
}

void popCountINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8216 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */); // ensure top 32 bits 0
    __ mov(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ D, 0, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ D, 0);
  
#line 16109 "ad_aarch64.cpp"
  }
}

void popCountI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8236 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister tmp_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrs, tmp_reg, opnd_array(1)->opcode(),
              as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ D, 0);
  
#line 16131 "ad_aarch64.cpp"
  }
}

void popCountLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8258 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mov(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ D, 0, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ D, 0);
  
#line 16151 "ad_aarch64.cpp"
  }
}

void popCountL_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8277 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister tmp_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrd, tmp_reg, opnd_array(1)->opcode(),
              as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ D, 0);
  
#line 16173 "ad_aarch64.cpp"
  }
}

void load_fenceNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8298 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ membar(Assembler::LoadLoad|Assembler::LoadStore);
  
#line 16189 "ad_aarch64.cpp"
  }
}

void unnecessary_membar_acquireNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8311 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_acquire (elided)");
  
#line 16205 "ad_aarch64.cpp"
  }
}

void membar_acquireNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8325 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_acquire");
    __ membar(Assembler::LoadLoad|Assembler::LoadStore);
  
#line 16222 "ad_aarch64.cpp"
  }
}

void membar_acquire_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8340 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_acquire_lock (elided)");
  
#line 16238 "ad_aarch64.cpp"
  }
}

void store_fenceNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8353 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ membar(Assembler::LoadStore|Assembler::StoreStore);
  
#line 16254 "ad_aarch64.cpp"
  }
}

void unnecessary_membar_releaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8366 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_release (elided)");
  
#line 16270 "ad_aarch64.cpp"
  }
}

void membar_releaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8379 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_release");
    __ membar(Assembler::LoadStore|Assembler::StoreStore);
  
#line 16287 "ad_aarch64.cpp"
  }
}

void membar_storestoreNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8393 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ membar(Assembler::StoreStore);
  
#line 16303 "ad_aarch64.cpp"
  }
}

void membar_storestore_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8393 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ membar(Assembler::StoreStore);
  
#line 16319 "ad_aarch64.cpp"
  }
}

void membar_release_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8405 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_release_lock (elided)");
  
#line 16335 "ad_aarch64.cpp"
  }
}

void unnecessary_membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8419 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_volatile (elided)");
  
#line 16351 "ad_aarch64.cpp"
  }
}

void membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8433 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_volatile");
    __ membar(Assembler::StoreLoad);
  
#line 16368 "ad_aarch64.cpp"
  }
}

void castX2PNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8450 "src/hotspot/cpu/aarch64/aarch64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */!= opnd_array(1)->reg(ra_,this,idx1)/* src */) {
      __ mov(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
  
#line 16386 "ad_aarch64.cpp"
  }
}

void castP2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8465 "src/hotspot/cpu/aarch64/aarch64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */!= opnd_array(1)->reg(ra_,this,idx1)/* src */) {
      __ mov(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
  
#line 16404 "ad_aarch64.cpp"
  }
}

void convP2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8480 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16420 "ad_aarch64.cpp"
  }
}

void convN2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8496 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16436 "ad_aarch64.cpp"
  }
}

void encodeHeapOopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8511 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ encode_heap_oop(d, s);
  
#line 16454 "ad_aarch64.cpp"
  }
}

void encodeHeapOop_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8524 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ encode_heap_oop_not_null(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16470 "ad_aarch64.cpp"
  }
}

void decodeHeapOopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8536 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ decode_heap_oop(d, s);
  
#line 16488 "ad_aarch64.cpp"
  }
}

void decodeHeapOop_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8550 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ decode_heap_oop_not_null(d, s);
  
#line 16506 "ad_aarch64.cpp"
  }
}

void encodeKlass_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8568 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ encode_klass_not_null(dst_reg, src_reg);
  
#line 16524 "ad_aarch64.cpp"
  }
}

void decodeKlass_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8583 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    if (dst_reg != src_reg) {
      __ decode_klass_not_null(dst_reg, src_reg);
    } else {
      __ decode_klass_not_null(dst_reg);
    }
  
#line 16546 "ad_aarch64.cpp"
  }
}

void checkCastPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint checkCastPPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castPPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castIINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castIINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castLLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castLLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castFFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castFFNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castDDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castDDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castVVNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castVVNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castVVMaskNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castVVMaskNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void compareAndSwapBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3269 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 16671 "ad_aarch64.cpp"
  }
  {

#line 3315 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 16681 "ad_aarch64.cpp"
  }
}

void compareAndSwapSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3261 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 16702 "ad_aarch64.cpp"
  }
  {

#line 3315 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 16712 "ad_aarch64.cpp"
  }
}

void compareAndSwapINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3253 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 16733 "ad_aarch64.cpp"
  }
  {

#line 3315 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 16743 "ad_aarch64.cpp"
  }
}

void compareAndSwapLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3245 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 16764 "ad_aarch64.cpp"
  }
  {

#line 3315 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 16774 "ad_aarch64.cpp"
  }
}

void compareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3245 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 16795 "ad_aarch64.cpp"
  }
  {

#line 3315 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 16805 "ad_aarch64.cpp"
  }
}

void compareAndSwapNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3253 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 16826 "ad_aarch64.cpp"
  }
  {

#line 3315 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 16836 "ad_aarch64.cpp"
  }
}

void compareAndSwapBAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3306 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 16857 "ad_aarch64.cpp"
  }
  {

#line 3315 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 16867 "ad_aarch64.cpp"
  }
}

void compareAndSwapSAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3298 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 16888 "ad_aarch64.cpp"
  }
  {

#line 3315 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 16898 "ad_aarch64.cpp"
  }
}

void compareAndSwapIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3290 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 16919 "ad_aarch64.cpp"
  }
  {

#line 3315 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 16929 "ad_aarch64.cpp"
  }
}

void compareAndSwapLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3282 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 16950 "ad_aarch64.cpp"
  }
  {

#line 3315 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 16960 "ad_aarch64.cpp"
  }
}

void compareAndSwapPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3282 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 16981 "ad_aarch64.cpp"
  }
  {

#line 3315 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 16991 "ad_aarch64.cpp"
  }
}

void compareAndSwapNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3290 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 17012 "ad_aarch64.cpp"
  }
  {

#line 3315 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 17022 "ad_aarch64.cpp"
  }
}

void compareAndExchangeBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8943 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxtbw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17044 "ad_aarch64.cpp"
  }
}

void compareAndExchangeSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8962 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxthw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17066 "ad_aarch64.cpp"
  }
}

void compareAndExchangeINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8981 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17087 "ad_aarch64.cpp"
  }
}

void compareAndExchangeLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8999 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17108 "ad_aarch64.cpp"
  }
}

void compareAndExchangeNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9017 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17129 "ad_aarch64.cpp"
  }
}

void compareAndExchangePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9035 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17150 "ad_aarch64.cpp"
  }
}

void compareAndExchangeBAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9053 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxtbw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17172 "ad_aarch64.cpp"
  }
}

void compareAndExchangeSAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9072 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxthw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17194 "ad_aarch64.cpp"
  }
}

void compareAndExchangeIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9091 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17215 "ad_aarch64.cpp"
  }
}

void compareAndExchangeLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9109 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17236 "ad_aarch64.cpp"
  }
}

void compareAndExchangeNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9127 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17257 "ad_aarch64.cpp"
  }
}

void compareAndExchangePAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9145 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17278 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9164 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 17299 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9184 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 17320 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9204 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 17341 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9224 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 17362 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9244 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 17383 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9264 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 17404 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapBAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9284 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 17425 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapSAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9304 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 17446 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9324 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 17467 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9344 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 17488 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9364 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 17509 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9384 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 17530 "ad_aarch64.cpp"
  }
}

void get_and_setINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9400 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17547 "ad_aarch64.cpp"
  }
}

void get_and_setLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9410 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchg(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17564 "ad_aarch64.cpp"
  }
}

void get_and_setNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9420 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17581 "ad_aarch64.cpp"
  }
}

void get_and_setPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9431 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchg(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17598 "ad_aarch64.cpp"
  }
}

void get_and_setIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9442 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgalw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17615 "ad_aarch64.cpp"
  }
}

void get_and_setLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9453 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgal(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17632 "ad_aarch64.cpp"
  }
}

void get_and_setNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9464 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgalw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17649 "ad_aarch64.cpp"
  }
}

void get_and_setPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9475 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgal(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17666 "ad_aarch64.cpp"
  }
}

void get_and_addLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9486 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17683 "ad_aarch64.cpp"
  }
}

void get_and_addL_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9497 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17700 "ad_aarch64.cpp"
  }
}

void get_and_addLiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9507 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17717 "ad_aarch64.cpp"
  }
}

void get_and_addLi_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9518 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(noreg, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17734 "ad_aarch64.cpp"
  }
}

void get_and_addINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9528 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17751 "ad_aarch64.cpp"
  }
}

void get_and_addI_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9539 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17768 "ad_aarch64.cpp"
  }
}

void get_and_addIiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9549 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17785 "ad_aarch64.cpp"
  }
}

void get_and_addIi_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9560 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(noreg, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17802 "ad_aarch64.cpp"
  }
}

void get_and_addLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9571 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17819 "ad_aarch64.cpp"
  }
}

void get_and_addL_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9582 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17836 "ad_aarch64.cpp"
  }
}

void get_and_addLiAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9593 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17853 "ad_aarch64.cpp"
  }
}

void get_and_addLi_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9604 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(noreg, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17870 "ad_aarch64.cpp"
  }
}

void get_and_addIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9615 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17887 "ad_aarch64.cpp"
  }
}

void get_and_addI_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9626 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17904 "ad_aarch64.cpp"
  }
}

void get_and_addIiAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9637 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17921 "ad_aarch64.cpp"
  }
}

void get_and_addIi_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9648 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(noreg, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 17938 "ad_aarch64.cpp"
  }
}

void cmpL3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9668 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
    __ cnegw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LT);
  
#line 17957 "ad_aarch64.cpp"
  }
}

void cmpL3_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9688 "src/hotspot/cpu/aarch64/aarch64.ad"

    int32_t con = (int32_t)opnd_array(2)->constantL();
     if (con < 0) {
      __ adds(zr, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, -con);
    } else {
      __ subs(zr, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, con);
    }
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
    __ cnegw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LT);
  
#line 17981 "ad_aarch64.cpp"
  }
}

void cmovI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9721 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18003 "ad_aarch64.cpp"
  }
}

void cmovUI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9737 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18025 "ad_aarch64.cpp"
  }
}

void cmovI_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9762 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18047 "ad_aarch64.cpp"
  }
}

void cmovUI_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9778 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18069 "ad_aarch64.cpp"
  }
}

void cmovI_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9794 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18091 "ad_aarch64.cpp"
  }
}

void cmovUI_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9810 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18113 "ad_aarch64.cpp"
  }
}

void cmovI_reg_zero_oneNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9831 "src/hotspot/cpu/aarch64/aarch64.ad"

    // equivalently
    // cset(as_Register($dst$$reg),
    //      negate_condition((Assembler::Condition)$cmp$$cmpcode));
    __ csincw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18138 "ad_aarch64.cpp"
  }
}

void cmovUI_reg_zero_oneNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9850 "src/hotspot/cpu/aarch64/aarch64.ad"

    // equivalently
    // cset(as_Register($dst$$reg),
    //      negate_condition((Assembler::Condition)$cmp$$cmpcode));
    __ csincw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18163 "ad_aarch64.cpp"
  }
}

void cmovL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9869 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18185 "ad_aarch64.cpp"
  }
}

void cmovUL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9885 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18207 "ad_aarch64.cpp"
  }
}

void cmovL_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9903 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18229 "ad_aarch64.cpp"
  }
}

void cmovUL_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9919 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18251 "ad_aarch64.cpp"
  }
}

void cmovL_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9935 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18273 "ad_aarch64.cpp"
  }
}

void cmovUL_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9951 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18295 "ad_aarch64.cpp"
  }
}

void cmovP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9967 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18317 "ad_aarch64.cpp"
  }
}

void cmovUP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9983 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18339 "ad_aarch64.cpp"
  }
}

void cmovP_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10001 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18361 "ad_aarch64.cpp"
  }
}

void cmovUP_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10017 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18383 "ad_aarch64.cpp"
  }
}

void cmovP_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10033 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18405 "ad_aarch64.cpp"
  }
}

void cmovUP_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10049 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18427 "ad_aarch64.cpp"
  }
}

void cmovN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10065 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18449 "ad_aarch64.cpp"
  }
}

void cmovUN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10081 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18471 "ad_aarch64.cpp"
  }
}

void cmovN_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10099 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18493 "ad_aarch64.cpp"
  }
}

void cmovUN_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10115 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18515 "ad_aarch64.cpp"
  }
}

void cmovN_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10131 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18537 "ad_aarch64.cpp"
  }
}

void cmovUN_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10147 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18559 "ad_aarch64.cpp"
  }
}

void cmovF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10164 "src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcsels(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 18582 "ad_aarch64.cpp"
  }
}

void cmovUF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10182 "src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcsels(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 18605 "ad_aarch64.cpp"
  }
}

void cmovD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10200 "src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcseld(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 18628 "ad_aarch64.cpp"
  }
}

void cmovUD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10218 "src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcseld(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 18651 "ad_aarch64.cpp"
  }
}

void addI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10247 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 18670 "ad_aarch64.cpp"
  }
}

void addI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3443 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constant();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ subw(dst_reg, src_reg, -con);
    } else {
      __ addw(dst_reg, src_reg, con);
    }
  
#line 18696 "ad_aarch64.cpp"
  }
}

void addI_reg_imm_i2lNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3443 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constant();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ subw(dst_reg, src_reg, -con);
    } else {
      __ addw(dst_reg, src_reg, con);
    }
  
#line 18722 "ad_aarch64.cpp"
  }
}

void addP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10291 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 18741 "ad_aarch64.cpp"
  }
}

void addP_reg_reg_extNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10306 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
  
#line 18760 "ad_aarch64.cpp"
  }
}

void addP_reg_reg_lslNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// scale
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10321 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lea(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           Address(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                   Address::lsl(opnd_array(3)->constant())));
  
#line 18780 "ad_aarch64.cpp"
  }
}

void addP_reg_reg_ext_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// scale
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10336 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lea(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           Address(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                   Address::sxtw(opnd_array(3)->constant())));
  
#line 18800 "ad_aarch64.cpp"
  }
}

void lshift_extNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// scale
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10351 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sbfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
          opnd_array(2)->constant()& 63, MIN2(32, (int)((-opnd_array(2)->constant()) & 63)));
  
#line 18819 "ad_aarch64.cpp"
  }
}

void addP_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3457 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constantL();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ sub(dst_reg, src_reg, -con);
    } else {
      __ add(dst_reg, src_reg, con);
    }
  
#line 18845 "ad_aarch64.cpp"
  }
}

void addL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10385 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 18864 "ad_aarch64.cpp"
  }
}

void addL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3457 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constantL();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ sub(dst_reg, src_reg, -con);
    } else {
      __ add(dst_reg, src_reg, con);
    }
  
#line 18890 "ad_aarch64.cpp"
  }
}

void subI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10416 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 18909 "ad_aarch64.cpp"
  }
}

void subI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3443 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constant();
    // add has primary == 0, subtract has primary == 1
    if ((0x1 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ subw(dst_reg, src_reg, -con);
    } else {
      __ addw(dst_reg, src_reg, con);
    }
  
#line 18935 "ad_aarch64.cpp"
  }
}

void subL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10448 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 18954 "ad_aarch64.cpp"
  }
}

void subL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3457 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constantL();
    // add has primary == 0, subtract has primary == 1
    if ((0x1 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ sub(dst_reg, src_reg, -con);
    } else {
      __ add(dst_reg, src_reg, con);
    }
  
#line 18980 "ad_aarch64.cpp"
  }
}

void negI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10480 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 18998 "ad_aarch64.cpp"
  }
}

void negL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10496 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ neg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 19016 "ad_aarch64.cpp"
  }
}

void mulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10512 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mulw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19035 "ad_aarch64.cpp"
  }
}

void smulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10527 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smull(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19054 "ad_aarch64.cpp"
  }
}

void smulI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10527 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smull(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 19073 "ad_aarch64.cpp"
  }
}

void mulLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10544 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mul(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19092 "ad_aarch64.cpp"
  }
}

void mulHiL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10560 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smulh(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19111 "ad_aarch64.cpp"
  }
}

void umulHiL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10576 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ umulh(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19130 "ad_aarch64.cpp"
  }
}

void maddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10593 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ maddw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 19151 "ad_aarch64.cpp"
  }
}

void maddI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10593 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ maddw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 19172 "ad_aarch64.cpp"
  }
}

void msubINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10609 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ msubw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 19193 "ad_aarch64.cpp"
  }
}

void mnegINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10627 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mnegw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 19213 "ad_aarch64.cpp"
  }
}

void mnegI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10627 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mnegw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 19233 "ad_aarch64.cpp"
  }
}

void maddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10644 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ madd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 19254 "ad_aarch64.cpp"
  }
}

void maddL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10644 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ madd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 19275 "ad_aarch64.cpp"
  }
}

void msubLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10660 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ msub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 19296 "ad_aarch64.cpp"
  }
}

void mnegLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10678 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mneg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 19316 "ad_aarch64.cpp"
  }
}

void mnegL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10678 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mneg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 19336 "ad_aarch64.cpp"
  }
}

void smaddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10695 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 19357 "ad_aarch64.cpp"
  }
}

void smaddL_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10695 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 19378 "ad_aarch64.cpp"
  }
}

void smaddL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10695 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 19399 "ad_aarch64.cpp"
  }
}

void smaddL_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10695 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 19420 "ad_aarch64.cpp"
  }
}

void smsubLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10711 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smsubl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 19441 "ad_aarch64.cpp"
  }
}

void smsubL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10711 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smsubl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 19462 "ad_aarch64.cpp"
  }
}

void smnegLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10727 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smnegl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 19482 "ad_aarch64.cpp"
  }
}

void smnegL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10727 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smnegl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 19502 "ad_aarch64.cpp"
  }
}

void muladdS2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10745 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mulw(rscratch1, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ maddw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src4 */), rscratch1); 
#line 19521 "ad_aarch64.cpp"
  }
}

void divINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3471 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivl(dst_reg, src1_reg, src2_reg, false, rscratch1);
  
#line 19541 "ad_aarch64.cpp"
  }
}

void divLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3479 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivq(dst_reg, src1_reg, src2_reg, false, rscratch1);
  
#line 19561 "ad_aarch64.cpp"
  }
}

void modINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3487 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivl(dst_reg, src1_reg, src2_reg, true, rscratch1);
  
#line 19581 "ad_aarch64.cpp"
  }
}

void modLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3495 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivq(dst_reg, src1_reg, src2_reg, true, rscratch1);
  
#line 19601 "ad_aarch64.cpp"
  }
}

void UdivI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10810 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ udivw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 19618 "ad_aarch64.cpp"
  }
}

void UdivL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10825 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ udiv(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 19635 "ad_aarch64.cpp"
  }
}

void UmodI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10841 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ udivw(rscratch1, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
    __ msubw(opnd_array(0)->as_Register(ra_,this)/* dst */, rscratch1, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
  
#line 19653 "ad_aarch64.cpp"
  }
}

void UModL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10858 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ udiv(rscratch1, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
    __ msub(opnd_array(0)->as_Register(ra_,this)/* dst */, rscratch1, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
  
#line 19671 "ad_aarch64.cpp"
  }
}

void lShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10875 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lslvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19690 "ad_aarch64.cpp"
  }
}

void lShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10891 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lslw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x1f);
  
#line 19709 "ad_aarch64.cpp"
  }
}

void urShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10907 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsrvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19728 "ad_aarch64.cpp"
  }
}

void urShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10923 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x1f);
  
#line 19747 "ad_aarch64.cpp"
  }
}

void rShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10939 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19766 "ad_aarch64.cpp"
  }
}

void rShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10955 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x1f);
  
#line 19785 "ad_aarch64.cpp"
  }
}

void lShiftL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10976 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lslv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19804 "ad_aarch64.cpp"
  }
}

void lShiftL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10992 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x3f);
  
#line 19823 "ad_aarch64.cpp"
  }
}

void urShiftL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11008 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsrv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19842 "ad_aarch64.cpp"
  }
}

void urShiftL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11024 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           opnd_array(2)->constant()& 0x3f);
  
#line 19861 "ad_aarch64.cpp"
  }
}

void urShiftP_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11040 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           opnd_array(2)->constant()& 0x3f);
  
#line 19880 "ad_aarch64.cpp"
  }
}

void rShiftL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11056 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19899 "ad_aarch64.cpp"
  }
}

void rShiftL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11072 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           opnd_array(2)->constant()& 0x3f);
  
#line 19918 "ad_aarch64.cpp"
  }
}

void regL_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11094 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              zr,
              Assembler::LSL, 0);
  
#line 19938 "ad_aarch64.cpp"
  }
}

void regI_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11113 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              zr,
              Assembler::LSL, 0);
  
#line 19958 "ad_aarch64.cpp"
  }
}

void NegI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11132 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            Assembler::LSR, opnd_array(3)->constant()& 0x1f);
  
#line 19977 "ad_aarch64.cpp"
  }
}

void NegI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11149 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            Assembler::ASR, opnd_array(3)->constant()& 0x1f);
  
#line 19996 "ad_aarch64.cpp"
  }
}

void NegI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11166 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            Assembler::LSL, opnd_array(3)->constant()& 0x1f);
  
#line 20015 "ad_aarch64.cpp"
  }
}

void NegL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11183 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ neg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            Assembler::LSR, opnd_array(3)->constant()& 0x3f);
  
#line 20034 "ad_aarch64.cpp"
  }
}

void NegL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11200 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ neg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            Assembler::ASR, opnd_array(3)->constant()& 0x3f);
  
#line 20053 "ad_aarch64.cpp"
  }
}

void NegL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11217 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ neg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            Assembler::LSL, opnd_array(3)->constant()& 0x3f);
  
#line 20072 "ad_aarch64.cpp"
  }
}

void AndI_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11233 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 20093 "ad_aarch64.cpp"
  }
}

void AndI_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11233 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 20114 "ad_aarch64.cpp"
  }
}

void AndL_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11251 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 20135 "ad_aarch64.cpp"
  }
}

void AndL_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11251 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 20156 "ad_aarch64.cpp"
  }
}

void OrI_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11269 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 20177 "ad_aarch64.cpp"
  }
}

void OrI_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11269 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 20198 "ad_aarch64.cpp"
  }
}

void OrL_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11287 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 20219 "ad_aarch64.cpp"
  }
}

void OrL_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11287 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 20240 "ad_aarch64.cpp"
  }
}

void XorI_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11305 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 20261 "ad_aarch64.cpp"
  }
}

void XorI_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11305 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 20282 "ad_aarch64.cpp"
  }
}

void XorL_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11323 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 20303 "ad_aarch64.cpp"
  }
}

void XorL_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11323 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 20324 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11343 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 20347 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11343 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 20370 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11364 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 20393 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11364 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 20416 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11385 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 20439 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11385 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 20462 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11406 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 20485 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11406 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 20508 "ad_aarch64.cpp"
  }
}

void AndI_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11427 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 20531 "ad_aarch64.cpp"
  }
}

void AndI_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11427 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 20554 "ad_aarch64.cpp"
  }
}

void AndL_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11448 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 20577 "ad_aarch64.cpp"
  }
}

void AndL_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11448 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 20600 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11469 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 20623 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11469 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 20646 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11490 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 20669 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11490 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 20692 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11511 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 20715 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11511 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 20738 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11511 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSR,
              opnd_array(4)->constant()& 0x1f);
  
#line 20761 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11511 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 20784 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11532 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 20807 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11532 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 20830 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11532 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSR,
              opnd_array(4)->constant()& 0x3f);
  
#line 20853 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11532 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 20876 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11553 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 20899 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11553 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 20922 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11553 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ASR,
              opnd_array(4)->constant()& 0x1f);
  
#line 20945 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11553 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 20968 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11574 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 20991 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11574 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 21014 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11574 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ASR,
              opnd_array(4)->constant()& 0x3f);
  
#line 21037 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11574 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 21060 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11595 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 21083 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11595 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 21106 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11595 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ROR,
              opnd_array(4)->constant()& 0x1f);
  
#line 21129 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11595 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 21152 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11616 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 21175 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11616 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 21198 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11616 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ROR,
              opnd_array(4)->constant()& 0x3f);
  
#line 21221 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11616 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 21244 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11637 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 21267 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11637 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 21290 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11637 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSL,
              opnd_array(4)->constant()& 0x1f);
  
#line 21313 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11637 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 21336 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11658 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 21359 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11658 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 21382 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11658 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSL,
              opnd_array(4)->constant()& 0x3f);
  
#line 21405 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11658 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 21428 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11679 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 21451 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11679 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 21474 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11700 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 21497 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11700 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 21520 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11721 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 21543 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11721 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 21566 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11742 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 21589 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11742 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 21612 "ad_aarch64.cpp"
  }
}

void OrI_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11763 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 21635 "ad_aarch64.cpp"
  }
}

void OrI_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11763 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 21658 "ad_aarch64.cpp"
  }
}

void OrL_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11784 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 21681 "ad_aarch64.cpp"
  }
}

void OrL_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11784 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 21704 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11805 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 21727 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11805 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 21750 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11826 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 21773 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11826 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 21796 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11847 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 21818 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11847 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 21840 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11868 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 21862 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11868 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 21884 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11889 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 21906 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11889 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 21928 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11910 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 21950 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11910 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 21972 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11931 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 21994 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11931 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 22016 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11952 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 22038 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11952 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 22060 "ad_aarch64.cpp"
  }
}

void AndI_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11973 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22082 "ad_aarch64.cpp"
  }
}

void AndI_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11973 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22104 "ad_aarch64.cpp"
  }
}

void AndL_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11994 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22126 "ad_aarch64.cpp"
  }
}

void AndL_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11994 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22148 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12015 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22170 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12015 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22192 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12036 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22214 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12036 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22236 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12057 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22258 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12057 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22280 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12078 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22302 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12078 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22324 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12099 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 22346 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12099 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 22368 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12120 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 22390 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12120 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 22412 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12141 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22434 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12141 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22456 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12162 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22478 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12162 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22500 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12183 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22522 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12183 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22544 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12204 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22566 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12204 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22588 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12225 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22610 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12225 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22632 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12246 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22654 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12246 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22676 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12267 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 22698 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12267 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 22720 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12288 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 22742 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12288 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 22764 "ad_aarch64.cpp"
  }
}

void OrI_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12309 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22786 "ad_aarch64.cpp"
  }
}

void OrI_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12309 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22808 "ad_aarch64.cpp"
  }
}

void OrL_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12330 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22830 "ad_aarch64.cpp"
  }
}

void OrL_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12330 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22852 "ad_aarch64.cpp"
  }
}

void AddI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12351 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22874 "ad_aarch64.cpp"
  }
}

void AddI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12351 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22896 "ad_aarch64.cpp"
  }
}

void AddL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12372 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22918 "ad_aarch64.cpp"
  }
}

void AddL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12372 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22940 "ad_aarch64.cpp"
  }
}

void AddI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12393 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22962 "ad_aarch64.cpp"
  }
}

void AddI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12393 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22984 "ad_aarch64.cpp"
  }
}

void AddL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12414 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23006 "ad_aarch64.cpp"
  }
}

void AddL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12414 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 23028 "ad_aarch64.cpp"
  }
}

void AddI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12435 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 23050 "ad_aarch64.cpp"
  }
}

void AddI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12435 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 23072 "ad_aarch64.cpp"
  }
}

void AddL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12456 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 23094 "ad_aarch64.cpp"
  }
}

void AddL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12456 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 23116 "ad_aarch64.cpp"
  }
}

void SubI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12477 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23138 "ad_aarch64.cpp"
  }
}

void SubL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12498 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23160 "ad_aarch64.cpp"
  }
}

void SubI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12519 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23182 "ad_aarch64.cpp"
  }
}

void SubL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12540 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23204 "ad_aarch64.cpp"
  }
}

void SubI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12561 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 23226 "ad_aarch64.cpp"
  }
}

void SubL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12582 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 23248 "ad_aarch64.cpp"
  }
}

void sbfmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12603 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 63;
    int rshift = opnd_array(3)->constant()& 63;
    int s = 63 - lshift;
    int r = (rshift - lshift) & 63;
    __ sbfm(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 23272 "ad_aarch64.cpp"
  }
}

void sbfmwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12626 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 31;
    int rshift = opnd_array(3)->constant()& 31;
    int s = 31 - lshift;
    int r = (rshift - lshift) & 31;
    __ sbfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 23296 "ad_aarch64.cpp"
  }
}

void ubfmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12649 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 63;
    int rshift = opnd_array(3)->constant()& 63;
    int s = 63 - lshift;
    int r = (rshift - lshift) & 63;
    __ ubfm(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 23320 "ad_aarch64.cpp"
  }
}

void ubfmwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12672 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 31;
    int rshift = opnd_array(3)->constant()& 31;
    int s = 31 - lshift;
    int r = (rshift - lshift) & 31;
    __ ubfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 23344 "ad_aarch64.cpp"
  }
}

void ubfxwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12697 "src/hotspot/cpu/aarch64/aarch64.ad"

    int rshift = opnd_array(2)->constant()& 31;
    intptr_t mask = opnd_array(3)->constant();
    int width = exact_log2(mask+1);
    __ ubfxw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rshift, width);
  
#line 23366 "ad_aarch64.cpp"
  }
}

void ubfxLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12717 "src/hotspot/cpu/aarch64/aarch64.ad"

    int rshift = opnd_array(2)->constant()& 63;
    intptr_t mask = opnd_array(3)->constantL();
    int width = exact_log2_long(mask+1);
    __ ubfx(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rshift, width);
  
#line 23388 "ad_aarch64.cpp"
  }
}

void ubfxIConvI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12741 "src/hotspot/cpu/aarch64/aarch64.ad"

    int rshift = opnd_array(2)->constant()& 31;
    intptr_t mask = opnd_array(3)->constant();
    int width = exact_log2(mask+1);
    __ ubfx(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rshift, width);
  
#line 23410 "ad_aarch64.cpp"
  }
}

void ubfizwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12764 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 31;
    intptr_t mask = opnd_array(2)->constant();
    int width = exact_log2(mask+1);
    __ ubfizw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 23432 "ad_aarch64.cpp"
  }
}

void ubfizLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12786 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 63;
    intptr_t mask = opnd_array(2)->constantL();
    int width = exact_log2_long(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 23454 "ad_aarch64.cpp"
  }
}

void ubfizwIConvI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12808 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 31;
    intptr_t mask = opnd_array(2)->constant();
    int width = exact_log2(mask+1);
    __ ubfizw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 23476 "ad_aarch64.cpp"
  }
}

void ubfizLConvL2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12830 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 63;
    intptr_t mask = opnd_array(2)->constantL();
    int width = exact_log2_long(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 23498 "ad_aarch64.cpp"
  }
}

void ubfizIConvI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12852 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 63;
    intptr_t mask = opnd_array(2)->constant();
    int width = exact_log2(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 23520 "ad_aarch64.cpp"
  }
}

void ubfizLConvL2IxNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12873 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 31;
    intptr_t mask = opnd_array(2)->constantL();
    int width = exact_log2(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 23542 "ad_aarch64.cpp"
  }
}

void ubfizIConvI2LAndINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// msk
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12892 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0, exact_log2(opnd_array(2)->constant()+ 1));
  
#line 23559 "ad_aarch64.cpp"
  }
}

void extrOrLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12910 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 63);
  
#line 23579 "ad_aarch64.cpp"
  }
}

void extrOrL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12910 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 63);
  
#line 23599 "ad_aarch64.cpp"
  }
}

void extrOrINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12928 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 31);
  
#line 23619 "ad_aarch64.cpp"
  }
}

void extrOrI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12928 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 31);
  
#line 23639 "ad_aarch64.cpp"
  }
}

void extrAddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12946 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 63);
  
#line 23659 "ad_aarch64.cpp"
  }
}

void extrAddL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12946 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 63);
  
#line 23679 "ad_aarch64.cpp"
  }
}

void extrAddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12964 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 31);
  
#line 23699 "ad_aarch64.cpp"
  }
}

void extrAddI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12964 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 31);
  
#line 23719 "ad_aarch64.cpp"
  }
}

void rorI_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12981 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
               opnd_array(2)->constant()& 0x1f);
  
#line 23737 "ad_aarch64.cpp"
  }
}

void rorL_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12997 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
               opnd_array(2)->constant()& 0x3f);
  
#line 23755 "ad_aarch64.cpp"
  }
}

void rorI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13013 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ rorvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 23772 "ad_aarch64.cpp"
  }
}

void rorL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13028 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ rorv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 23789 "ad_aarch64.cpp"
  }
}

void rolI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13043 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(rscratch1, zr, as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
     __ rorvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rscratch1);
  
#line 23807 "ad_aarch64.cpp"
  }
}

void rolL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13059 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(rscratch1, zr, as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
     __ rorv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rscratch1);
  
#line 23825 "ad_aarch64.cpp"
  }
}

void AddExtINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13077 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
   
#line 23843 "ad_aarch64.cpp"
  }
}

void AddExtI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13077 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw);
   
#line 23861 "ad_aarch64.cpp"
  }
}

void SubExtINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13092 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
   
#line 23879 "ad_aarch64.cpp"
  }
}

void AddExtI_sxthNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13107 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth);
   
#line 23899 "ad_aarch64.cpp"
  }
}

void AddExtI_sxth_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13107 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth);
   
#line 23919 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13122 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb);
   
#line 23939 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13122 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb);
   
#line 23959 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13137 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 23979 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13137 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 23999 "ad_aarch64.cpp"
  }
}

void AddExtL_sxthNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13152 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth);
   
#line 24019 "ad_aarch64.cpp"
  }
}

void AddExtL_sxth_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13152 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth);
   
#line 24039 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtwNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13167 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
   
#line 24059 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtw_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13167 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw);
   
#line 24079 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13182 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb);
   
#line 24099 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13182 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb);
   
#line 24119 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13197 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 24139 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13197 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 24159 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13212 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 24178 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13212 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 24197 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13227 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 24216 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13227 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth);
   
#line 24235 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13242 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 24254 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13242 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 24273 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13257 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 24292 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13257 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth);
   
#line 24311 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13272 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw);
   
#line 24330 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13272 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtw);
   
#line 24349 "ad_aarch64.cpp"
  }
}

void SubExtI_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13287 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 24368 "ad_aarch64.cpp"
  }
}

void SubExtI_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13302 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 24387 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13317 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 24406 "ad_aarch64.cpp"
  }
}

void SubExtL_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13332 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 24425 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtw_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13347 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw);
   
#line 24444 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13363 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 24465 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtb_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13363 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb, (opnd_array(4)->constant()));
   
#line 24486 "ad_aarch64.cpp"
  }
}

void AddExtL_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13378 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 24507 "ad_aarch64.cpp"
  }
}

void AddExtL_sxth_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13378 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth, (opnd_array(4)->constant()));
   
#line 24528 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtw_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13393 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(5)->constant()));
   
#line 24549 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtw_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13393 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw, (opnd_array(4)->constant()));
   
#line 24570 "ad_aarch64.cpp"
  }
}

void SubExtL_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13408 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 24591 "ad_aarch64.cpp"
  }
}

void SubExtL_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13423 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 24612 "ad_aarch64.cpp"
  }
}

void SubExtL_sxtw_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13438 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(5)->constant()));
   
#line 24633 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13453 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 24654 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtb_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13453 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb, (opnd_array(4)->constant()));
   
#line 24675 "ad_aarch64.cpp"
  }
}

void AddExtI_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13468 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 24696 "ad_aarch64.cpp"
  }
}

void AddExtI_sxth_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13468 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth, (opnd_array(4)->constant()));
   
#line 24717 "ad_aarch64.cpp"
  }
}

void SubExtI_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13483 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 24738 "ad_aarch64.cpp"
  }
}

void SubExtI_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13498 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 24759 "ad_aarch64.cpp"
  }
}

void AddExtI_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13513 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(3)->constant()));
   
#line 24778 "ad_aarch64.cpp"
  }
}

void AddExtI_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13513 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw, (opnd_array(2)->constant()));
   
#line 24797 "ad_aarch64.cpp"
  }
}

void SubExtI_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13528 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(3)->constant()));
   
#line 24816 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13543 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 24836 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13543 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb, (opnd_array(3)->constant()));
   
#line 24856 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13558 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 24876 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13558 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth, (opnd_array(3)->constant()));
   
#line 24896 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13573 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw, (opnd_array(4)->constant()));
   
#line 24916 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13573 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtw, (opnd_array(3)->constant()));
   
#line 24936 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13588 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 24956 "ad_aarch64.cpp"
  }
}

void SubExtL_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13603 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 24976 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtw_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13618 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw, (opnd_array(4)->constant()));
   
#line 24996 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13633 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 25016 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13633 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb, (opnd_array(3)->constant()));
   
#line 25036 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13648 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 25056 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13648 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth, (opnd_array(3)->constant()));
   
#line 25076 "ad_aarch64.cpp"
  }
}

void SubExtI_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13663 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 25096 "ad_aarch64.cpp"
  }
}

void SubExtI_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13678 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 25116 "ad_aarch64.cpp"
  }
}

void addF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13699 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25135 "ad_aarch64.cpp"
  }
}

void addD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13714 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ faddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25154 "ad_aarch64.cpp"
  }
}

void subF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13729 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25173 "ad_aarch64.cpp"
  }
}

void subD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13744 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsubd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25192 "ad_aarch64.cpp"
  }
}

void mulF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13759 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmuls(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25211 "ad_aarch64.cpp"
  }
}

void mulD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13774 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmuld(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25230 "ad_aarch64.cpp"
  }
}

void maddF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13790 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25251 "ad_aarch64.cpp"
  }
}

void maddD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13807 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmaddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25272 "ad_aarch64.cpp"
  }
}

void msubF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13825 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25293 "ad_aarch64.cpp"
  }
}

void msubF_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13825 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25314 "ad_aarch64.cpp"
  }
}

void msubD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13843 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25335 "ad_aarch64.cpp"
  }
}

void msubD_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13843 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25356 "ad_aarch64.cpp"
  }
}

void mnaddF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13861 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25377 "ad_aarch64.cpp"
  }
}

void mnaddF_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13861 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25398 "ad_aarch64.cpp"
  }
}

void mnaddD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13879 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmaddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25419 "ad_aarch64.cpp"
  }
}

void mnaddD_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13879 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmaddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25440 "ad_aarch64.cpp"
  }
}

void mnsubF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13896 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25461 "ad_aarch64.cpp"
  }
}

void mnsubD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13913 "src/hotspot/cpu/aarch64/aarch64.ad"

  // n.b. insn name should be fnmsubd
    __ fnmsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25483 "ad_aarch64.cpp"
  }
}

void maxF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13930 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmaxs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25502 "ad_aarch64.cpp"
  }
}

void minF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13944 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmins(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25521 "ad_aarch64.cpp"
  }
}

void maxD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13958 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmaxd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25540 "ad_aarch64.cpp"
  }
}

void minD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13972 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmind(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25559 "ad_aarch64.cpp"
  }
}

void divF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13988 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fdivs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25578 "ad_aarch64.cpp"
  }
}

void divD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14003 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fdivd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25597 "ad_aarch64.cpp"
  }
}

void negF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14018 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnegs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 25614 "ad_aarch64.cpp"
  }
}

void negD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14032 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnegd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 25631 "ad_aarch64.cpp"
  }
}

void absI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14050 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cnegw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), Assembler::LT);
  
#line 25648 "ad_aarch64.cpp"
  }
}

void absL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14067 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cneg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), Assembler::LT);
  
#line 25665 "ad_aarch64.cpp"
  }
}

void absF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14079 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabss(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 25682 "ad_aarch64.cpp"
  }
}

void absD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14092 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabsd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 25699 "ad_aarch64.cpp"
  }
}

void absdF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14105 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25718 "ad_aarch64.cpp"
  }
}

void absdD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14119 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabdd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25737 "ad_aarch64.cpp"
  }
}

void sqrtD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14133 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsqrtd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 25754 "ad_aarch64.cpp"
  }
}

void sqrtF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14146 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsqrts(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 25771 "ad_aarch64.cpp"
  }
}

void roundD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rmode
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14158 "src/hotspot/cpu/aarch64/aarch64.ad"

    switch (opnd_array(2)->constant()) {
      case RoundDoubleModeNode::rmode_rint:
        __ frintnd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_floor:
        __ frintmd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_ceil:
        __ frintpd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
    }
  
#line 25801 "ad_aarch64.cpp"
  }
}

void copySignD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14181 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst = as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */),
                  src1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                  src2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                  zero = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* zero */);
    __ fnegd(dst, zero);
    __ bsl(dst, __ T8B, src2, src1);
  
#line 25825 "ad_aarch64.cpp"
  }
}

void copySignF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14196 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
                  src1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                  src2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ movi(dst, __ T2S, 0x80, 24);
    __ bsl(dst, __ T8B, src2, src1);
  
#line 25847 "ad_aarch64.cpp"
  }
}

void signumD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14210 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                  dst = as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */),
                  zero = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* zero */),
                  one = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* one */);
    __ facgtd(dst, src, zero); // dst=0 for +-0.0 and NaN. 0xFFF..F otherwise
    __ ushrd(dst, dst, 1);     // dst=0 for +-0.0 and NaN. 0x7FF..F otherwise
    // Bit selection instruction gets bit from "one" for each enabled bit in
    // "dst", otherwise gets a bit from "src". For "src" that contains +-0.0 or
    // NaN the whole "src" will be copied because "dst" is zero. For all other
    // "src" values dst is 0x7FF..F, which means only the sign bit is copied
    // from "src", and all other bits are copied from 1.0.
    __ bsl(dst, __ T8B, one, src);
  
#line 25877 "ad_aarch64.cpp"
  }
}

void signumF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14231 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                  dst = as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */),
                  zero = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* zero */),
                  one = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* one */);
    __ facgts(dst, src, zero);    // dst=0 for +-0.0 and NaN. 0xFFF..F otherwise
    __ ushr(dst, __ T2S, dst, 1); // dst=0 for +-0.0 and NaN. 0x7FF..F otherwise
    // Bit selection instruction gets bit from "one" for each enabled bit in
    // "dst", otherwise gets a bit from "src". For "src" that contains +-0.0 or
    // NaN the whole "src" will be copied because "dst" is zero. For all other
    // "src" values dst is 0x7FF..F, which means only the sign bit is copied
    // from "src", and all other bits are copied from 1.0.
    __ bsl(dst, __ T8B, one, src);
  
#line 25907 "ad_aarch64.cpp"
  }
}

void onspinwaitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14254 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ spin_wait();
  
#line 25923 "ad_aarch64.cpp"
  }
}

void andI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14274 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25942 "ad_aarch64.cpp"
  }
}

void andI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14289 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constant()));
  
#line 25961 "ad_aarch64.cpp"
  }
}

void orI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14306 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25980 "ad_aarch64.cpp"
  }
}

void orI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14321 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constant()));
  
#line 25999 "ad_aarch64.cpp"
  }
}

void xorI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14338 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 26018 "ad_aarch64.cpp"
  }
}

void xorI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14353 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constant()));
  
#line 26037 "ad_aarch64.cpp"
  }
}

void andL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14371 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 26056 "ad_aarch64.cpp"
  }
}

void andL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14386 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constantL()));
  
#line 26075 "ad_aarch64.cpp"
  }
}

void orL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14403 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 26094 "ad_aarch64.cpp"
  }
}

void orL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14418 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           (uint64_t)(opnd_array(2)->constantL()));
  
#line 26113 "ad_aarch64.cpp"
  }
}

void xorL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14435 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 26132 "ad_aarch64.cpp"
  }
}

void xorL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14450 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           (uint64_t)(opnd_array(2)->constantL()));
  
#line 26151 "ad_aarch64.cpp"
  }
}

void convI2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14465 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sbfm(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0, 31);
  
#line 26167 "ad_aarch64.cpp"
  }
}

void convUI2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14478 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ubfm(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0, 31);
  
#line 26184 "ad_aarch64.cpp"
  }
}

void convL2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14491 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26200 "ad_aarch64.cpp"
  }
}

void convI2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14508 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cset(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::NE);
  
#line 26217 "ad_aarch64.cpp"
  }
}

void convP2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14526 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cset(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::NE);
  
#line 26234 "ad_aarch64.cpp"
  }
}

void convD2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14540 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26250 "ad_aarch64.cpp"
  }
}

void convF2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14553 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvts(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26266 "ad_aarch64.cpp"
  }
}

void convF2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14566 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzsw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26282 "ad_aarch64.cpp"
  }
}

void convF2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14579 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzs(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26298 "ad_aarch64.cpp"
  }
}

void convF2HF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14592 "src/hotspot/cpu/aarch64/aarch64.ad"

      __ fcvtsh(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      __ smov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ H, 0);
  
#line 26316 "ad_aarch64.cpp"
  }
}

void convHF2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14605 "src/hotspot/cpu/aarch64/aarch64.ad"

      __ mov(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ H, 0, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
      __ fcvths(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
  
#line 26334 "ad_aarch64.cpp"
  }
}

void convI2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14618 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfws(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26350 "ad_aarch64.cpp"
  }
}

void convL2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14631 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26366 "ad_aarch64.cpp"
  }
}

void convD2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14644 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzdw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26382 "ad_aarch64.cpp"
  }
}

void convD2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14657 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26398 "ad_aarch64.cpp"
  }
}

void convI2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14670 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfwd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26414 "ad_aarch64.cpp"
  }
}

void convL2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14683 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26430 "ad_aarch64.cpp"
  }
}

void round_double_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ftmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14695 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ java_round_double(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                         as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* ftmp */));
  
#line 26449 "ad_aarch64.cpp"
  }
}

void round_float_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ftmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14707 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ java_round_float(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                        as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* ftmp */));
  
#line 26468 "ad_aarch64.cpp"
  }
}

void MoveF2I_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14726 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrw(opnd_array(0)->as_Register(ra_,this)/* dst */, Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 26484 "ad_aarch64.cpp"
  }
}

void MoveI2F_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14744 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 26500 "ad_aarch64.cpp"
  }
}

void MoveD2L_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14762 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */, Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 26516 "ad_aarch64.cpp"
  }
}

void MoveL2D_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14780 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 26532 "ad_aarch64.cpp"
  }
}

void MoveF2I_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14798 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ strs(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 26548 "ad_aarch64.cpp"
  }
}

void MoveI2F_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14816 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ strw(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 26564 "ad_aarch64.cpp"
  }
}

void MoveD2L_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14834 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ strd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 26580 "ad_aarch64.cpp"
  }
}

void MoveL2D_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14852 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ str(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 26596 "ad_aarch64.cpp"
  }
}

void MoveF2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14870 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovs(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26612 "ad_aarch64.cpp"
  }
}

void MoveI2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14888 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 26628 "ad_aarch64.cpp"
  }
}

void MoveD2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14906 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26644 "ad_aarch64.cpp"
  }
}

void MoveL2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14924 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 26660 "ad_aarch64.cpp"
  }
}

void clearArray_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cnt
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14943 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ zero_words(opnd_array(2)->as_Register(ra_,this,idx2)/* base */, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 26681 "ad_aarch64.cpp"
  }
}

void clearArray_imm_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cnt
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// temp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14964 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ zero_words(opnd_array(2)->as_Register(ra_,this,idx2)/* base */, (uint64_t)opnd_array(1)->constantL());
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 26703 "ad_aarch64.cpp"
  }
}

void overflowAddI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14984 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmnw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 26720 "ad_aarch64.cpp"
  }
}

void overflowAddI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14997 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmnw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 26737 "ad_aarch64.cpp"
  }
}

void overflowAddL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15010 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmn(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 26754 "ad_aarch64.cpp"
  }
}

void overflowAddL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15023 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ adds(zr, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 26771 "ad_aarch64.cpp"
  }
}

void overflowSubI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15036 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 26788 "ad_aarch64.cpp"
  }
}

void overflowSubI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15049 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 26805 "ad_aarch64.cpp"
  }
}

void overflowSubL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15062 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 26822 "ad_aarch64.cpp"
  }
}

void overflowSubL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15075 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subs(zr, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 26839 "ad_aarch64.cpp"
  }
}

void overflowNegI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15088 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(zr, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */);
  
#line 26856 "ad_aarch64.cpp"
  }
}

void overflowNegL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15101 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(zr, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */);
  
#line 26873 "ad_aarch64.cpp"
  }
}

void overflowMulI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15118 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smull(rscratch1, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
    __ subs(zr, rscratch1, rscratch1, ext::sxtw);      // NE => overflow
    __ movw(rscratch1, 0x80000000);                    // Develop 0 (EQ),
    __ cselw(rscratch1, rscratch1, zr, Assembler::NE); // or 0x80000000 (NE)
    __ cmpw(rscratch1, 1);                             // 0x80000000 - 1 => VS
  
#line 26894 "ad_aarch64.cpp"
  }
}

void overflowMulI_reg_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15140 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ smull(rscratch1, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* op2 */);
    __ subs(zr, rscratch1, rscratch1, ext::sxtw);      // NE => overflow
    __ br(cond == Assembler::VS ? Assembler::NE : Assembler::EQ, *L);
  
#line 26917 "ad_aarch64.cpp"
  }
}

void overflowMulL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15162 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mul(rscratch1, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);   // Result bits 0..63
    __ smulh(rscratch2, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */); // Result bits 64..127
    __ cmp(rscratch2, rscratch1, Assembler::ASR, 63);    // Top is pure sign ext
    __ movw(rscratch1, 0x80000000);                    // Develop 0 (EQ),
    __ cselw(rscratch1, rscratch1, zr, Assembler::NE); // or 0x80000000 (NE)
    __ cmpw(rscratch1, 1);                             // 0x80000000 - 1 => VS
  
#line 26939 "ad_aarch64.cpp"
  }
}

void overflowMulL_reg_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15186 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ mul(rscratch1, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* op2 */);   // Result bits 0..63
    __ smulh(rscratch2, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* op2 */); // Result bits 64..127
    __ cmp(rscratch2, rscratch1, Assembler::ASR, 63);    // Top is pure sign ext
    __ br(cond == Assembler::VS ? Assembler::NE : Assembler::EQ, *L);
  
#line 26963 "ad_aarch64.cpp"
  }
}

void compI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3505 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmpw(reg1, reg2);
  
#line 26982 "ad_aarch64.cpp"
  }
}

void compI_reg_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3512 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 27005 "ad_aarch64.cpp"
  }
}

void compI_reg_immIAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3512 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 27028 "ad_aarch64.cpp"
  }
}

void compI_reg_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3523 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint32_t val = (uint32_t)opnd_array(2)->constant();
    __ movw(rscratch1, val);
    __ cmpw(reg1, rscratch1);
  
#line 27048 "ad_aarch64.cpp"
  }
}

void compU_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3505 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmpw(reg1, reg2);
  
#line 27067 "ad_aarch64.cpp"
  }
}

void compU_reg_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3512 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 27090 "ad_aarch64.cpp"
  }
}

void compU_reg_immIAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3512 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 27113 "ad_aarch64.cpp"
  }
}

void compU_reg_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3523 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint32_t val = (uint32_t)opnd_array(2)->constant();
    __ movw(rscratch1, val);
    __ cmpw(reg1, rscratch1);
  
#line 27133 "ad_aarch64.cpp"
  }
}

void compL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3531 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmp(reg1, reg2);
  
#line 27152 "ad_aarch64.cpp"
  }
}

void compL_reg_immL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3538 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 27179 "ad_aarch64.cpp"
  }
}

void compL_reg_immLAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3538 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 27206 "ad_aarch64.cpp"
  }
}

void compL_reg_immLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3553 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint64_t val = (uint64_t)opnd_array(2)->constantL();
    __ mov(rscratch1, val);
    __ cmp(reg1, rscratch1);
  
#line 27226 "ad_aarch64.cpp"
  }
}

void compUL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3531 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmp(reg1, reg2);
  
#line 27245 "ad_aarch64.cpp"
  }
}

void compUL_reg_immL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3538 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 27272 "ad_aarch64.cpp"
  }
}

void compUL_reg_immLAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3538 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 27299 "ad_aarch64.cpp"
  }
}

void compUL_reg_immLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3553 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint64_t val = (uint64_t)opnd_array(2)->constantL();
    __ mov(rscratch1, val);
    __ cmp(reg1, rscratch1);
  
#line 27319 "ad_aarch64.cpp"
  }
}

void compP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3561 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmp(reg1, reg2);
  
#line 27338 "ad_aarch64.cpp"
  }
}

void compN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3568 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmpw(reg1, reg2);
  
#line 27357 "ad_aarch64.cpp"
  }
}

void testP_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3575 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    __ cmp(reg, zr);
  
#line 27375 "ad_aarch64.cpp"
  }
}

void testN_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3581 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    __ cmpw(reg, zr);
  
#line 27393 "ad_aarch64.cpp"
  }
}

void compF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15497 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmps(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27410 "ad_aarch64.cpp"
  }
}

void compF_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15511 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmps(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), 0.0);
  
#line 27427 "ad_aarch64.cpp"
  }
}

void compD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15526 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmpd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27444 "ad_aarch64.cpp"
  }
}

void compD_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15540 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmpd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), 0.0);
  
#line 27461 "ad_aarch64.cpp"
  }
}

void compF3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15558 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    FloatRegister s2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmps(s1, s2);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 27487 "ad_aarch64.cpp"
  }
}

void compD3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15586 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    FloatRegister s2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmpd(s1, s2);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 27513 "ad_aarch64.cpp"
  }
}

void compF3_reg_immF0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15613 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmps(s1, 0.0);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 27538 "ad_aarch64.cpp"
  }
}

void compD3_reg_immD0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15640 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmpd(s1, 0.0);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 27563 "ad_aarch64.cpp"
  }
}

void cmpLTMask_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15667 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* p */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* q */));
    __ csetw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::LT);
    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), zr, as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 27582 "ad_aarch64.cpp"
  }
}

void cmpLTMask_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15685 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), 31);
  
#line 27599 "ad_aarch64.cpp"
  }
}

void cmovI_reg_reg_ltNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15702 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
             Assembler::LT);
  
#line 27620 "ad_aarch64.cpp"
  }
}

void cmovI_reg_reg_gtNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15733 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
             Assembler::GT);
  
#line 27641 "ad_aarch64.cpp"
  }
}

void branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3587 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(1)->label();
    __ b(*L);
  
#line 27658 "ad_aarch64.cpp"
  }
}

void branchConNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3593 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 27677 "ad_aarch64.cpp"
  }
}

void branchConUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3599 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 27696 "ad_aarch64.cpp"
  }
}

void cmpI_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15824 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 27720 "ad_aarch64.cpp"
  }
}

void cmpL_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15841 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 27744 "ad_aarch64.cpp"
  }
}

void cmpP_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15858 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 27768 "ad_aarch64.cpp"
  }
}

void cmpN_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15875 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 27792 "ad_aarch64.cpp"
  }
}

void cmpP_narrowOop_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15892 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* oop */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* oop */, *L);
  
#line 27816 "ad_aarch64.cpp"
  }
}

void cmpUI_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15909 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ || cond == Assembler::LS)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 27840 "ad_aarch64.cpp"
  }
}

void cmpUL_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15926 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ || cond == Assembler::LS)
      __ cbz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 27864 "ad_aarch64.cpp"
  }
}

void cmpL_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15946 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 63, *L);
  
#line 27886 "ad_aarch64.cpp"
  }
}

void cmpI_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15962 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 31, *L);
  
#line 27908 "ad_aarch64.cpp"
  }
}

void cmpL_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15979 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2_long(opnd_array(3)->constantL());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L);
  
#line 27931 "ad_aarch64.cpp"
  }
}

void cmpI_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15996 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2((juint)opnd_array(3)->constant());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L);
  
#line 27954 "ad_aarch64.cpp"
  }
}

void far_cmpL_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16013 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 63, *L, /*far*/true);
  
#line 27976 "ad_aarch64.cpp"
  }
}

void far_cmpI_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16028 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 31, *L, /*far*/true);
  
#line 27998 "ad_aarch64.cpp"
  }
}

void far_cmpL_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16044 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2_long(opnd_array(3)->constantL());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L, /*far*/true);
  
#line 28021 "ad_aarch64.cpp"
  }
}

void far_cmpI_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16060 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2((juint)opnd_array(3)->constant());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L, /*far*/true);
  
#line 28044 "ad_aarch64.cpp"
  }
}

void cmpL_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16078 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ tst(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 28062 "ad_aarch64.cpp"
  }
}

void cmpI_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16091 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ tstw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 28080 "ad_aarch64.cpp"
  }
}

void cmpL_and_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16102 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ tst(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 28098 "ad_aarch64.cpp"
  }
}

void cmpI_and_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16113 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ tstw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 28116 "ad_aarch64.cpp"
  }
}

void branchLoopEndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3593 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 28135 "ad_aarch64.cpp"
  }
}

void branchLoopEndUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3599 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 28154 "ad_aarch64.cpp"
  }
}

void cmpFastLockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {

#line 3756 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register oop = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* object */);
    Register box = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* box */);
    Register disp_hdr = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp */);
    Register tmp = as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */);
    Label cont;
    Label object_has_monitor;
    Label no_count;

    assert_different_registers(oop, box, tmp, disp_hdr);

    // Load markWord from object into displaced_header.
    __ ldr(disp_hdr, Address(oop, oopDesc::mark_offset_in_bytes()));

    if (DiagnoseSyncOnValueBasedClasses != 0) {
      __ load_klass(tmp, oop);
      __ ldrw(tmp, Address(tmp, Klass::access_flags_offset()));
      __ tstw(tmp, JVM_ACC_IS_VALUE_BASED_CLASS);
      __ br(Assembler::NE, cont);
    }

    // Check for existing monitor
    __ tbnz(disp_hdr, exact_log2(markWord::monitor_value), object_has_monitor);

    if (!UseHeavyMonitors) {
      // Set tmp to be (markWord of object | UNLOCK_VALUE).
      __ orr(tmp, disp_hdr, markWord::unlocked_value);

      // Initialize the box. (Must happen before we update the object mark!)
      __ str(tmp, Address(box, BasicLock::displaced_header_offset_in_bytes()));

      // Compare object markWord with an unlocked value (tmp) and if
      // equal exchange the stack address of our box with object markWord.
      // On failure disp_hdr contains the possibly locked markWord.
      __ cmpxchg(oop, tmp, box, Assembler::xword, /*acquire*/ true,
                 /*release*/ true, /*weak*/ false, disp_hdr);
      __ br(Assembler::EQ, cont);

      assert(oopDesc::mark_offset_in_bytes() == 0, "offset of _mark is not 0");

      // If the compare-and-exchange succeeded, then we found an unlocked
      // object, will have now locked it will continue at label cont

      // Check if the owner is self by comparing the value in the
      // markWord of object (disp_hdr) with the stack pointer.
      __ mov(rscratch1, sp);
      __ sub(disp_hdr, disp_hdr, rscratch1);
      __ mov(tmp, (address) (~(os::vm_page_size()-1) | markWord::lock_mask_in_place));
      // If condition is true we are cont and hence we can store 0 as the
      // displaced header in the box, which indicates that it is a recursive lock.
      __ ands(tmp/*==0?*/, disp_hdr, tmp);   // Sets flags for result
      __ str(tmp/*==0, perhaps*/, Address(box, BasicLock::displaced_header_offset_in_bytes()));
    } else {
      __ tst(oop, oop); // Set NE to indicate 'failure' -> take slow-path. We know that oop != 0.
    }
    __ b(cont);

    // Handle existing monitor.
    __ bind(object_has_monitor);

    // The object's monitor m is unlocked iff m->owner == NULL,
    // otherwise m->owner may contain a thread or a stack address.
    //
    // Try to CAS m->owner from NULL to current thread.
    __ add(tmp, disp_hdr, (ObjectMonitor::owner_offset_in_bytes()-markWord::monitor_value));
    __ cmpxchg(tmp, zr, rthread, Assembler::xword, /*acquire*/ true,
               /*release*/ true, /*weak*/ false, rscratch1); // Sets flags for result

    // Store a non-null value into the box to avoid looking like a re-entrant
    // lock. The fast-path monitor unlock code checks for
    // markWord::monitor_value so use markWord::unused_mark which has the
    // relevant bit set, and also matches ObjectSynchronizer::enter.
    __ mov(tmp, (address)markWord::unused_mark().value());
    __ str(tmp, Address(box, BasicLock::displaced_header_offset_in_bytes()));

    __ br(Assembler::EQ, cont); // CAS success means locking succeeded

    __ cmp(rscratch1, rthread);
    __ br(Assembler::NE, cont); // Check for recursive locking

    // Recursive lock case
    __ increment(Address(disp_hdr, ObjectMonitor::recursions_offset_in_bytes() - markWord::monitor_value), 1);
    // flag == EQ still from the cmp above, checking if this is a reentrant lock

    __ bind(cont);
    // flag == EQ indicates success
    // flag == NE indicates failure
    __ br(Assembler::NE, no_count);

    __ increment(Address(rthread, JavaThread::held_monitor_count_offset()));

    __ bind(no_count);
  
#line 28263 "ad_aarch64.cpp"
  }
}

void cmpFastUnlockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {

#line 3851 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register oop = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* object */);
    Register box = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* box */);
    Register disp_hdr = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp */);
    Register tmp = as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */);
    Label cont;
    Label object_has_monitor;
    Label no_count;

    assert_different_registers(oop, box, tmp, disp_hdr);

    if (!UseHeavyMonitors) {
      // Find the lock address and load the displaced header from the stack.
      __ ldr(disp_hdr, Address(box, BasicLock::displaced_header_offset_in_bytes()));

      // If the displaced header is 0, we have a recursive unlock.
      __ cmp(disp_hdr, zr);
      __ br(Assembler::EQ, cont);
    }

    // Handle existing monitor.
    __ ldr(tmp, Address(oop, oopDesc::mark_offset_in_bytes()));
    __ tbnz(tmp, exact_log2(markWord::monitor_value), object_has_monitor);

    if (!UseHeavyMonitors) {
      // Check if it is still a light weight lock, this is is true if we
      // see the stack address of the basicLock in the markWord of the
      // object.

      __ cmpxchg(oop, box, disp_hdr, Assembler::xword, /*acquire*/ false,
                 /*release*/ true, /*weak*/ false, tmp);
    } else {
      __ tst(oop, oop); // Set NE to indicate 'failure' -> take slow-path. We know that oop != 0.
    }
    __ b(cont);

    assert(oopDesc::mark_offset_in_bytes() == 0, "offset of _mark is not 0");

    // Handle existing monitor.
    __ bind(object_has_monitor);
    STATIC_ASSERT(markWord::monitor_value <= INT_MAX);
    __ add(tmp, tmp, -(int)markWord::monitor_value); // monitor
    __ ldr(disp_hdr, Address(tmp, ObjectMonitor::recursions_offset_in_bytes()));

    Label notRecursive;
    __ cbz(disp_hdr, notRecursive);

    // Recursive lock
    __ sub(disp_hdr, disp_hdr, 1u);
    __ str(disp_hdr, Address(tmp, ObjectMonitor::recursions_offset_in_bytes()));
    __ cmp(disp_hdr, disp_hdr); // Sets flags for result
    __ b(cont);

    __ bind(notRecursive);
    __ ldr(rscratch1, Address(tmp, ObjectMonitor::EntryList_offset_in_bytes()));
    __ ldr(disp_hdr, Address(tmp, ObjectMonitor::cxq_offset_in_bytes()));
    __ orr(rscratch1, rscratch1, disp_hdr); // Will be 0 if both are 0.
    __ cmp(rscratch1, zr); // Sets flags for result
    __ cbnz(rscratch1, cont);
    // need a release store here
    __ lea(tmp, Address(tmp, ObjectMonitor::owner_offset_in_bytes()));
    __ stlr(zr, tmp); // set unowned

    __ bind(cont);
    // flag == EQ indicates success
    // flag == NE indicates failure
    __ br(Assembler::NE, no_count);

    __ decrement(Address(rthread, JavaThread::held_monitor_count_offset()));

    __ bind(no_count);
  
#line 28351 "ad_aarch64.cpp"
  }
}

void safePointNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16208 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ read_polling_page(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* poll */), relocInfo::poll_type);
  
#line 28367 "ad_aarch64.cpp"
  }
}

void CallStaticJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3623 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);

    address addr = (address)opnd_array(1)->method();
    address call;
    if (!_method) {
      // A call to a runtime wrapper, e.g. new, new_typeArray_Java, uncommon_trap.
      call = __ trampoline_call(Address(addr, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    } else if (_method->intrinsic_id() == vmIntrinsicID::_ensureMaterializedForStackWalk) {
      // The NOP here is purely to ensure that eliding a call to
      // JVM_EnsureMaterializedForStackWalk doesn't change the code size.
      __ nop();
      __ block_comment("call JVM_EnsureMaterializedForStackWalk (elided)");
    } else {
      int method_index = resolved_method_index(cbuf);
      RelocationHolder rspec = _optimized_virtual ? opt_virtual_call_Relocation::spec(method_index)
                                                  : static_call_Relocation::spec(method_index);
      call = __ trampoline_call(Address(addr, rspec));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
      if (CodeBuffer::supports_shared_stubs() && _method->can_be_statically_bound()) {
        // Calls of the same statically bound method can share
        // a stub to the interpreter.
        cbuf.shared_stub_to_interp_for(_method, call - cbuf.insts_begin());
      } else {
        // Emit stub for static call
        address stub = CompiledStaticCall::emit_to_interp_stub(cbuf, call);
        if (stub == NULL) {
          ciEnv::current()->record_failure("CodeCache is full");
          return;
        }
      }
    }

    __ post_call_nop();

    // Only non uncommon_trap calls need to reinitialize ptrue.
    if (Compile::current()->max_vector_size() > 0 && uncommon_trap_request() == 0) {
      __ reinitialize_ptrue();
    }
  
#line 28426 "ad_aarch64.cpp"
  }
  {

#line 3685 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      __ call_Unimplemented();
    }
  
#line 28438 "ad_aarch64.cpp"
  }
}

void CallDynamicJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3671 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    int method_index = resolved_method_index(cbuf);
    address call = __ ic_call((address)opnd_array(1)->method(), method_index);
    if (call == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
    __ post_call_nop();
    if (Compile::current()->max_vector_size() > 0) {
      __ reinitialize_ptrue();
    }
  
#line 28463 "ad_aarch64.cpp"
  }
  {

#line 3685 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      __ call_Unimplemented();
    }
  
#line 28475 "ad_aarch64.cpp"
  }
}

void CallRuntimeDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3693 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
      __ post_call_nop();
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ post_call_nop();
      __ add(sp, sp, 2 * wordSize);
    }
    if (Compile::current()->max_vector_size() > 0) {
      __ reinitialize_ptrue();
    }
  
#line 28518 "ad_aarch64.cpp"
  }
}

void CallLeafDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3693 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
      __ post_call_nop();
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ post_call_nop();
      __ add(sp, sp, 2 * wordSize);
    }
    if (Compile::current()->max_vector_size() > 0) {
      __ reinitialize_ptrue();
    }
  
#line 28561 "ad_aarch64.cpp"
  }
}

void CallLeafNoFPDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3693 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
      __ post_call_nop();
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ post_call_nop();
      __ add(sp, sp, 2 * wordSize);
    }
    if (Compile::current()->max_vector_size() > 0) {
      __ reinitialize_ptrue();
    }
  
#line 28604 "ad_aarch64.cpp"
  }
}

void TailCalljmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// method_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {

#line 3740 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register target_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* jump_target */);
    __ br(target_reg);
  
#line 28622 "ad_aarch64.cpp"
  }
}

void TailjmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// ex_oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {

#line 3746 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register target_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* jump_target */);
    // exception oop should be in r0
    // ret addr has been popped into lr
    // callee expects it in r3
    __ mov(r3, lr);
    __ br(target_reg);
  
#line 28644 "ad_aarch64.cpp"
  }
}

void CreateExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint CreateExceptionNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void RethrowExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 3725 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    __ far_jump(RuntimeAddress(OptoRuntime::rethrow_stub()));
  
#line 28673 "ad_aarch64.cpp"
  }
}

void RetNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 3730 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
#ifdef ASSERT
    if (Compile::current()->max_vector_size() > 0) {
      __ verify_ptrue();
    }
#endif
    __ ret(lr);
  
#line 28694 "ad_aarch64.cpp"
  }
}

void ShouldNotReachHereNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16388 "src/hotspot/cpu/aarch64/aarch64.ad"

    if (is_reachable()) {
      __ stop(_halt_reason);
    }
  
#line 28712 "ad_aarch64.cpp"
  }
}

void partialSubtypeCheckNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// sub
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// super
  {

#line 3606 "src/hotspot/cpu/aarch64/aarch64.ad"

     Register sub_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* sub */);
     Register super_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* super */);
     Register temp_reg = as_Register(R2_enc);
     Register result_reg = as_Register(opnd_array(0)->reg(ra_,this)/* result */);

     Label miss;
     C2_MacroAssembler _masm(&cbuf);
     __ check_klass_subtype_slow_path(sub_reg, super_reg, temp_reg, result_reg,
                                     NULL, &miss,
                                     /*set_cond_codes:*/ true);
     if ((0x1 /*primary()*/)) {
       __ mov(result_reg, zr);
     }
     __ bind(miss);
  
#line 28741 "ad_aarch64.cpp"
  }
}

void partialSubtypeCheckVsZeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// sub
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// super
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {

#line 3606 "src/hotspot/cpu/aarch64/aarch64.ad"

     Register sub_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* sub */);
     Register super_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* super */);
     Register temp_reg = as_Register(R2_enc);
     Register result_reg = as_Register(R5_enc);

     Label miss;
     C2_MacroAssembler _masm(&cbuf);
     __ check_klass_subtype_slow_path(sub_reg, super_reg, temp_reg, result_reg,
                                     NULL, &miss,
                                     /*set_cond_codes:*/ true);
     if ((0x0 /*primary()*/)) {
       __ mov(result_reg, zr);
     }
     __ bind(miss);
  
#line 28771 "ad_aarch64.cpp"
  }
}

void string_compareUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16445 "src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      fnoreg, fnoreg, fnoreg, pnoreg, pnoreg, StrIntrinsicNode::UU);
  
#line 28794 "ad_aarch64.cpp"
  }
}

void string_compareLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16463 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      fnoreg, fnoreg, fnoreg, pnoreg, pnoreg, StrIntrinsicNode::LL);
  
#line 28816 "ad_aarch64.cpp"
  }
}

void string_compareULNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16482 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      as_FloatRegister(V0_enc), as_FloatRegister(V1_enc),
                      as_FloatRegister(V2_enc), pnoreg, pnoreg, StrIntrinsicNode::UL);
  
#line 28839 "ad_aarch64.cpp"
  }
}

void string_compareLUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16502 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      as_FloatRegister(V0_enc), as_FloatRegister(V1_enc),
                      as_FloatRegister(V2_enc), pnoreg, pnoreg, StrIntrinsicNode::LU);
  
#line 28862 "ad_aarch64.cpp"
  }
}

void string_compareLL_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// vtmp1
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// vtmp2
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// pgtmp1
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// pgtmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16527 "src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_FloatRegister(ra_,this,idx7)/* vtmp1 */, opnd_array(8)->as_FloatRegister(ra_,this,idx8)/* vtmp2 */, fnoreg,
                      as_PRegister(opnd_array(9)->reg(ra_,this,idx9)/* pgtmp1 */), as_PRegister(opnd_array(10)->reg(ra_,this,idx10)/* pgtmp2 */),
                      StrIntrinsicNode::LL);
  
#line 28893 "ad_aarch64.cpp"
  }
}

void string_compareLU_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// vtmp1
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// vtmp2
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// pgtmp1
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// pgtmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16550 "src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_FloatRegister(ra_,this,idx7)/* vtmp1 */, opnd_array(8)->as_FloatRegister(ra_,this,idx8)/* vtmp2 */, fnoreg,
                      as_PRegister(opnd_array(9)->reg(ra_,this,idx9)/* pgtmp1 */), as_PRegister(opnd_array(10)->reg(ra_,this,idx10)/* pgtmp2 */),
                      StrIntrinsicNode::LU);
  
#line 28924 "ad_aarch64.cpp"
  }
}

void string_compareUL_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// vtmp1
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// vtmp2
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// pgtmp1
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// pgtmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16573 "src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_FloatRegister(ra_,this,idx7)/* vtmp1 */, opnd_array(8)->as_FloatRegister(ra_,this,idx8)/* vtmp2 */, fnoreg,
                      as_PRegister(opnd_array(9)->reg(ra_,this,idx9)/* pgtmp1 */), as_PRegister(opnd_array(10)->reg(ra_,this,idx10)/* pgtmp2 */),
                      StrIntrinsicNode::UL);
  
#line 28955 "ad_aarch64.cpp"
  }
}

void string_compareUU_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// vtmp1
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// vtmp2
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// pgtmp1
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// pgtmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16596 "src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_FloatRegister(ra_,this,idx7)/* vtmp1 */, opnd_array(8)->as_FloatRegister(ra_,this,idx8)/* vtmp2 */, fnoreg,
                      as_PRegister(opnd_array(9)->reg(ra_,this,idx9)/* pgtmp1 */), as_PRegister(opnd_array(10)->reg(ra_,this,idx10)/* pgtmp2 */),
                      StrIntrinsicNode::UU);
  
#line 28986 "ad_aarch64.cpp"
  }
}

void string_indexofUUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// tmp5
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// tmp6
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16618 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */,
                      opnd_array(9)->as_Register(ra_,this,idx9)/* tmp5 */, opnd_array(10)->as_Register(ra_,this,idx10)/* tmp6 */,
                      -1, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UU);
  
#line 29016 "ad_aarch64.cpp"
  }
}

void string_indexofLLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// tmp5
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// tmp6
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16639 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */,
                      opnd_array(9)->as_Register(ra_,this,idx9)/* tmp5 */, opnd_array(10)->as_Register(ra_,this,idx10)/* tmp6 */,
                      -1, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::LL);
  
#line 29046 "ad_aarch64.cpp"
  }
}

void string_indexofULNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// tmp5
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// tmp6
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16660 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */,
                      opnd_array(9)->as_Register(ra_,this,idx9)/* tmp5 */, opnd_array(10)->as_Register(ra_,this,idx10)/* tmp6 */,
                      -1, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UL);
  
#line 29076 "ad_aarch64.cpp"
  }
}

void string_indexof_conUUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// int_cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16681 "src/hotspot/cpu/aarch64/aarch64.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, zr,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */, zr, zr,
                      icnt2, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UU);
  
#line 29104 "ad_aarch64.cpp"
  }
}

void string_indexof_conLLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// int_cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16702 "src/hotspot/cpu/aarch64/aarch64.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, zr,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */, zr, zr,
                      icnt2, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::LL);
  
#line 29132 "ad_aarch64.cpp"
  }
}

void string_indexof_conULNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// int_cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16723 "src/hotspot/cpu/aarch64/aarch64.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, zr,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */, zr, zr,
                      icnt2, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UL);
  
#line 29160 "ad_aarch64.cpp"
  }
}

void string_indexof_charNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ch
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16745 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof_char(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* ch */,
                           opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */,
                           opnd_array(6)->as_Register(ra_,this,idx6)/* tmp3 */);
  
#line 29183 "ad_aarch64.cpp"
  }
}

void stringL_indexof_charNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ch
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16764 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ stringL_indexof_char(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* ch */,
                            opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */,
                            opnd_array(6)->as_Register(ra_,this,idx6)/* tmp3 */);
  
#line 29206 "ad_aarch64.cpp"
  }
}

void stringL_indexof_char_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ch
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ztmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ztmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// pgtmp
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16779 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof_char_sve(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* ch */,
                               opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* ztmp1 */,
                               opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* ztmp2 */, opnd_array(6)->as_PRegister(ra_,this,idx6)/* pgtmp */,
                               opnd_array(7)->as_PRegister(ra_,this,idx7)/* ptmp */, true /* isL */);
  
#line 29231 "ad_aarch64.cpp"
  }
}

void stringU_indexof_char_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ch
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ztmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ztmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// pgtmp
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16795 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof_char_sve(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* ch */,
                               opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* ztmp1 */,
                               opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* ztmp2 */, opnd_array(6)->as_PRegister(ra_,this,idx6)/* pgtmp */,
                               opnd_array(7)->as_PRegister(ra_,this,idx7)/* ptmp */, false /* isL */);
  
#line 29256 "ad_aarch64.cpp"
  }
}

void string_equalsLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// str2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16812 "src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* str2 */,
                     opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(3)->as_Register(ra_,this,idx3)/* cnt */, 1);
  
#line 29276 "ad_aarch64.cpp"
  }
}

void string_equalsUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// str2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16828 "src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* str2 */,
                     opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(3)->as_Register(ra_,this,idx3)/* cnt */, 2);
  
#line 29296 "ad_aarch64.cpp"
  }
}

void array_equalsBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// ary1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ary2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16845 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ arrays_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* ary1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* ary2 */,
                                   opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp3 */,
                                   opnd_array(0)->as_Register(ra_,this)/* result */, as_Register(R10_enc), 1);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 29322 "ad_aarch64.cpp"
  }
}

void array_equalsCNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// ary1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ary2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16866 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ arrays_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* ary1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* ary2 */,
                                   opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp3 */,
                                   opnd_array(0)->as_Register(ra_,this)/* result */, as_Register(R10_enc), 2);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 29348 "ad_aarch64.cpp"
  }
}

void count_positivesNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// ary1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// len
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16883 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ count_positives(opnd_array(1)->as_Register(ra_,this,idx1)/* ary1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* len */, opnd_array(0)->as_Register(ra_,this)/* result */);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 29369 "ad_aarch64.cpp"
  }
}

void string_compressNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16904 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ char_array_compress(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
                           opnd_array(0)->as_Register(ra_,this)/* result */,
                           opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp2 */,
                           opnd_array(6)->as_FloatRegister(ra_,this,idx6)/* tmp3 */, opnd_array(7)->as_FloatRegister(ra_,this,idx7)/* tmp4 */);
  
#line 29394 "ad_aarch64.cpp"
  }
}

void string_inflateNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16921 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ byte_array_inflate(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
                                        opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp2 */,
                                        opnd_array(6)->as_FloatRegister(ra_,this,idx6)/* tmp3 */, opnd_array(7)->as_Register(ra_,this,idx7)/* tmp4 */);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 29422 "ad_aarch64.cpp"
  }
}

void encode_iso_arrayNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16945 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ encode_iso_array(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
                        opnd_array(0)->as_Register(ra_,this)/* result */, false,
                        as_FloatRegister(V0_enc), as_FloatRegister(V1_enc),
                        as_FloatRegister(V2_enc), as_FloatRegister(V3_enc));
  
#line 29443 "ad_aarch64.cpp"
  }
}

void encode_ascii_arrayNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16965 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ encode_iso_array(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
                        opnd_array(0)->as_Register(ra_,this)/* result */, true,
                        as_FloatRegister(V0_enc), as_FloatRegister(V1_enc),
                        as_FloatRegister(V2_enc), as_FloatRegister(V3_enc));
  
#line 29464 "ad_aarch64.cpp"
  }
}

void tlsLoadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint tlsLoadPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void loadV2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2990 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::H,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29494 "ad_aarch64.cpp"
  }
}

void storeV2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3014 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::H,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29512 "ad_aarch64.cpp"
  }
}

void loadV4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2996 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::S,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29529 "ad_aarch64.cpp"
  }
}

void storeV4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3020 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::S,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29547 "ad_aarch64.cpp"
  }
}

void loadV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3002 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::D,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29564 "ad_aarch64.cpp"
  }
}

void storeV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3026 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::D,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29582 "ad_aarch64.cpp"
  }
}

void loadV16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3008 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::Q,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29599 "ad_aarch64.cpp"
  }
}

void storeV16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3032 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::Q,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29617 "ad_aarch64.cpp"
  }
}

void loadVNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 403 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), /* is_store */ false,
                          opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, ptrue, bt, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29639 "ad_aarch64.cpp"
  }
}

void storeVNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 420 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), /* is_store */ true,
                          opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, ptrue, bt, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29662 "ad_aarch64.cpp"
  }
}

void loadV_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 438 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), /* is_store */ false, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */,
                          opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, bt, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29682 "ad_aarch64.cpp"
  }
}

void storeV_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 451 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), /* is_store */ true, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */,
                          opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, bt, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29703 "ad_aarch64.cpp"
  }
}

void vloadconNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 465 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    if (UseSVE == 0) {
      uint length_in_bytes = Matcher::vector_length_in_bytes(this);
      assert(length_in_bytes <= 16, "must be");
      // The iota indices are ordered by type B/S/I/L/F/D, and the offset between two types is 16.
      int offset = exact_log2(type2aelembytes(bt)) << 4;
      if (is_floating_point_type(bt)) {
        offset += 32;
      }
      __ lea(rscratch1, ExternalAddress(StubRoutines::aarch64::vector_iota_indices() + offset));
      if (length_in_bytes == 16) {
        __ ldrq(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, rscratch1);
      } else {
        __ ldrd(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, rscratch1);
      }
    } else {
      Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
      __ sve_index(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, size, 0, 1);
      if (is_floating_point_type(bt)) {
        __ sve_scvtf(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, size, ptrue, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, size);
      }
    }
  
#line 29740 "ad_aarch64.cpp"
  }
}

void vaddBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 499 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ addv(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_add(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ B, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 29764 "ad_aarch64.cpp"
  }
}

void vaddSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 515 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ addv(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_add(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ H, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 29788 "ad_aarch64.cpp"
  }
}

void vaddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 531 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ addv(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_add(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ S, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 29812 "ad_aarch64.cpp"
  }
}

void vaddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 547 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ addv(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_add(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 29836 "ad_aarch64.cpp"
  }
}

void vaddFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 563 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fadd(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_fadd(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ S, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 29860 "ad_aarch64.cpp"
  }
}

void vaddDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 579 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fadd(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_fadd(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 29884 "ad_aarch64.cpp"
  }
}

void vaddB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 598 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_add(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ B, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 29902 "ad_aarch64.cpp"
  }
}

void vaddS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 608 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_add(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ H, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 29920 "ad_aarch64.cpp"
  }
}

void vaddI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 618 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_add(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ S, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 29938 "ad_aarch64.cpp"
  }
}

void vaddL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 628 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_add(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ D, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 29956 "ad_aarch64.cpp"
  }
}

void vaddF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 638 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fadd(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ S, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 29974 "ad_aarch64.cpp"
  }
}

void vaddD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 648 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fadd(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ D, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 29992 "ad_aarch64.cpp"
  }
}

void vaddImmBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 660 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    int val = (int)opnd_array(2)->constant();
    if (val > 0) {
      __ sve_add(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ B, val);
    } else {
      __ sve_sub(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ B, -val);
    }
  
#line 30014 "ad_aarch64.cpp"
  }
}

void vaddImmB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 660 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    int val = (int)opnd_array(1)->constant();
    if (val > 0) {
      __ sve_add(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ B, val);
    } else {
      __ sve_sub(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ B, -val);
    }
  
#line 30036 "ad_aarch64.cpp"
  }
}

void vaddImmSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 675 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    int val = (int)opnd_array(2)->constant();
    if (val > 0) {
      __ sve_add(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ H, val);
    } else {
      __ sve_sub(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ H, -val);
    }
  
#line 30058 "ad_aarch64.cpp"
  }
}

void vaddImmS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 675 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    int val = (int)opnd_array(1)->constant();
    if (val > 0) {
      __ sve_add(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ H, val);
    } else {
      __ sve_sub(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ H, -val);
    }
  
#line 30080 "ad_aarch64.cpp"
  }
}

void vaddImmINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 690 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    int val = (int)opnd_array(2)->constant();
    if (val > 0) {
      __ sve_add(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ S, val);
    } else {
      __ sve_sub(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ S, -val);
    }
  
#line 30102 "ad_aarch64.cpp"
  }
}

void vaddImmI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 690 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    int val = (int)opnd_array(1)->constant();
    if (val > 0) {
      __ sve_add(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ S, val);
    } else {
      __ sve_sub(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ S, -val);
    }
  
#line 30124 "ad_aarch64.cpp"
  }
}

void vaddImmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 705 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    int val = (int)opnd_array(2)->constantL();
    if (val > 0) {
      __ sve_add(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ D, val);
    } else {
      __ sve_sub(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ D, -val);
    }
  
#line 30146 "ad_aarch64.cpp"
  }
}

void vaddImmL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 705 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    int val = (int)opnd_array(1)->constantL();
    if (val > 0) {
      __ sve_add(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ D, val);
    } else {
      __ sve_sub(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ D, -val);
    }
  
#line 30168 "ad_aarch64.cpp"
  }
}

void vsubBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 723 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ subv(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_sub(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ B, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 30192 "ad_aarch64.cpp"
  }
}

void vsubSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 739 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ subv(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_sub(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ H, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 30216 "ad_aarch64.cpp"
  }
}

void vsubINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 755 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ subv(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_sub(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ S, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 30240 "ad_aarch64.cpp"
  }
}

void vsubLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 771 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ subv(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_sub(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 30264 "ad_aarch64.cpp"
  }
}

void vsubFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 787 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fsub(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_fsub(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ S, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 30288 "ad_aarch64.cpp"
  }
}

void vsubDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 803 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fsub(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_fsub(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 30312 "ad_aarch64.cpp"
  }
}

void vsubB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 822 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_sub(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ B, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30330 "ad_aarch64.cpp"
  }
}

void vsubS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 832 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_sub(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ H, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30348 "ad_aarch64.cpp"
  }
}

void vsubI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 842 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_sub(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ S, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30366 "ad_aarch64.cpp"
  }
}

void vsubL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 852 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_sub(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ D, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30384 "ad_aarch64.cpp"
  }
}

void vsubF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 862 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fsub(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ S, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30402 "ad_aarch64.cpp"
  }
}

void vsubD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 872 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fsub(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ D, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30420 "ad_aarch64.cpp"
  }
}

void vmulB_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 886 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ mulv(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30438 "ad_aarch64.cpp"
  }
}

void vmulB_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 897 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_mul(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ B, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30456 "ad_aarch64.cpp"
  }
}

void vmulS_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 908 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ mulv(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30474 "ad_aarch64.cpp"
  }
}

void vmulS_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 919 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_mul(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ H, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30492 "ad_aarch64.cpp"
  }
}

void vmulI_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 930 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ mulv(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30510 "ad_aarch64.cpp"
  }
}

void vmulI_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 941 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_mul(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ S, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30528 "ad_aarch64.cpp"
  }
}

void vmulL_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 954 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    assert(length_in_bytes == 16, "must be");
    __ umov(rscratch1, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, __ D, 0);
    __ umov(rscratch2, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, __ D, 0);
    __ mul(rscratch2, rscratch2, rscratch1);
    __ mov(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, 0, rscratch2);
    __ umov(rscratch1, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, __ D, 1);
    __ umov(rscratch2, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, __ D, 1);
    __ mul(rscratch2, rscratch2, rscratch1);
    __ mov(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, 1, rscratch2);
  
#line 30554 "ad_aarch64.cpp"
  }
}

void vmulL_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 973 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_mul(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ D, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30571 "ad_aarch64.cpp"
  }
}

void vmulFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 984 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fmul(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_fmul(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ S, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 30595 "ad_aarch64.cpp"
  }
}

void vmulDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1000 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fmul(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_fmul(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 30619 "ad_aarch64.cpp"
  }
}

void vmulB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1019 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_mul(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ B, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30637 "ad_aarch64.cpp"
  }
}

void vmulS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1029 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_mul(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ H, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30655 "ad_aarch64.cpp"
  }
}

void vmulI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1039 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_mul(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ S, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30673 "ad_aarch64.cpp"
  }
}

void vmulL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1049 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_mul(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ D, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30691 "ad_aarch64.cpp"
  }
}

void vmulF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1059 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fmul(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ S, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30709 "ad_aarch64.cpp"
  }
}

void vmulD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1069 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fmul(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ D, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30727 "ad_aarch64.cpp"
  }
}

void vdivF_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1083 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ fdiv(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30745 "ad_aarch64.cpp"
  }
}

void vdivF_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1094 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_fdiv(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ S, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30763 "ad_aarch64.cpp"
  }
}

void vdivD_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1105 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ fdiv(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30781 "ad_aarch64.cpp"
  }
}

void vdivD_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1116 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_fdiv(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ D, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30799 "ad_aarch64.cpp"
  }
}

void vdivF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1129 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fdiv(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ S, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30817 "ad_aarch64.cpp"
  }
}

void vdivD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1139 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fdiv(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ D, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30835 "ad_aarch64.cpp"
  }
}

void vandNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1152 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ andr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_and(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 30859 "ad_aarch64.cpp"
  }
}

void vand_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1171 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_and(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 30879 "ad_aarch64.cpp"
  }
}

void vandImmBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1185 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_and(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ B, (uint64_t)(opnd_array(2)->constant()));
  
#line 30896 "ad_aarch64.cpp"
  }
}

void vandImmB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1185 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_and(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ B, (uint64_t)(opnd_array(1)->constant()));
  
#line 30913 "ad_aarch64.cpp"
  }
}

void vandImmSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1195 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_and(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ H, (uint64_t)(opnd_array(2)->constant()));
  
#line 30930 "ad_aarch64.cpp"
  }
}

void vandImmS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1195 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_and(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ H, (uint64_t)(opnd_array(1)->constant()));
  
#line 30947 "ad_aarch64.cpp"
  }
}

void vandImmINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1205 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_and(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ S, (uint64_t)(opnd_array(2)->constant()));
  
#line 30964 "ad_aarch64.cpp"
  }
}

void vandImmI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1205 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_and(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ S, (uint64_t)(opnd_array(1)->constant()));
  
#line 30981 "ad_aarch64.cpp"
  }
}

void vandImmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1215 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_and(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ D, (uint64_t)(opnd_array(2)->constantL()));
  
#line 30998 "ad_aarch64.cpp"
  }
}

void vandImmL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1215 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_and(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ D, (uint64_t)(opnd_array(1)->constantL()));
  
#line 31015 "ad_aarch64.cpp"
  }
}

void vorNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1228 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ orr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_orr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 31039 "ad_aarch64.cpp"
  }
}

void vor_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1247 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_orr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 31059 "ad_aarch64.cpp"
  }
}

void vorImmBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1261 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_orr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ B, (uint64_t)(opnd_array(2)->constant()));
  
#line 31076 "ad_aarch64.cpp"
  }
}

void vorImmB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1261 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_orr(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ B, (uint64_t)(opnd_array(1)->constant()));
  
#line 31093 "ad_aarch64.cpp"
  }
}

void vorImmSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1271 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_orr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ H, (uint64_t)(opnd_array(2)->constant()));
  
#line 31110 "ad_aarch64.cpp"
  }
}

void vorImmS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1271 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_orr(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ H, (uint64_t)(opnd_array(1)->constant()));
  
#line 31127 "ad_aarch64.cpp"
  }
}

void vorImmINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1281 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_orr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ S, (uint64_t)(opnd_array(2)->constant()));
  
#line 31144 "ad_aarch64.cpp"
  }
}

void vorImmI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1281 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_orr(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ S, (uint64_t)(opnd_array(1)->constant()));
  
#line 31161 "ad_aarch64.cpp"
  }
}

void vorImmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1291 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_orr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ D, (uint64_t)(opnd_array(2)->constantL()));
  
#line 31178 "ad_aarch64.cpp"
  }
}

void vorImmL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1291 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_orr(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ D, (uint64_t)(opnd_array(1)->constantL()));
  
#line 31195 "ad_aarch64.cpp"
  }
}

void vxorNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1304 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ eor(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_eor(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 31219 "ad_aarch64.cpp"
  }
}

void vxor_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1323 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_eor(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 31239 "ad_aarch64.cpp"
  }
}

void vxorImmBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1337 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_eor(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ B, (uint64_t)(opnd_array(2)->constant()));
  
#line 31256 "ad_aarch64.cpp"
  }
}

void vxorImmB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1337 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_eor(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ B, (uint64_t)(opnd_array(1)->constant()));
  
#line 31273 "ad_aarch64.cpp"
  }
}

void vxorImmSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1347 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_eor(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ H, (uint64_t)(opnd_array(2)->constant()));
  
#line 31290 "ad_aarch64.cpp"
  }
}

void vxorImmS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1347 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_eor(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ H, (uint64_t)(opnd_array(1)->constant()));
  
#line 31307 "ad_aarch64.cpp"
  }
}

void vxorImmINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1357 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_eor(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ S, (uint64_t)(opnd_array(2)->constant()));
  
#line 31324 "ad_aarch64.cpp"
  }
}

void vxorImmI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1357 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_eor(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ S, (uint64_t)(opnd_array(1)->constant()));
  
#line 31341 "ad_aarch64.cpp"
  }
}

void vxorImmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1367 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_eor(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ D, (uint64_t)(opnd_array(2)->constantL()));
  
#line 31358 "ad_aarch64.cpp"
  }
}

void vxorImmL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1367 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_eor(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst_src */, __ D, (uint64_t)(opnd_array(1)->constantL()));
  
#line 31375 "ad_aarch64.cpp"
  }
}

void veor3_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1380 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ eor3(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T16B, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */,
            opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 31394 "ad_aarch64.cpp"
  }
}

void veor3_neon_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1380 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ eor3(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T16B, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */,
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src2 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src3 */);
  
#line 31413 "ad_aarch64.cpp"
  }
}

void veor3_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1391 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_eor3(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 31431 "ad_aarch64.cpp"
  }
}

void veor3_sve_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1391 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_eor3(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst_src1 */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src2 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src3 */);
  
#line 31449 "ad_aarch64.cpp"
  }
}

void vnotINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1406 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ notr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_not(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 31473 "ad_aarch64.cpp"
  }
}

void vnotI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1406 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ notr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
              opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_not(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */);
    }
  
#line 31497 "ad_aarch64.cpp"
  }
}

void vnotI_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1406 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ notr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_not(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 31521 "ad_aarch64.cpp"
  }
}

void vnotI_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1406 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ notr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
              opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_not(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */);
    }
  
#line 31545 "ad_aarch64.cpp"
  }
}

void vnotI_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1406 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ notr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_not(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 31569 "ad_aarch64.cpp"
  }
}

void vnotI_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1406 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ notr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
              opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_not(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */);
    }
  
#line 31593 "ad_aarch64.cpp"
  }
}

void vnotLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1422 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ notr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_not(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 31617 "ad_aarch64.cpp"
  }
}

void vnotL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1422 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ notr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
              opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_not(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */);
    }
  
#line 31641 "ad_aarch64.cpp"
  }
}

void vnotI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1443 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_not(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 31661 "ad_aarch64.cpp"
  }
}

void vnotI_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1443 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_not(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 31681 "ad_aarch64.cpp"
  }
}

void vnotI_masked_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1443 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_not(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 31701 "ad_aarch64.cpp"
  }
}

void vnotL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1455 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_not(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 31721 "ad_aarch64.cpp"
  }
}

void vand_notINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1472 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 31746 "ad_aarch64.cpp"
  }
}

void vand_notI_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1472 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src2 */);
    }
  
#line 31771 "ad_aarch64.cpp"
  }
}

void vand_notI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1472 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src2 */);
    }
  
#line 31796 "ad_aarch64.cpp"
  }
}

void vand_notI_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1472 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 31821 "ad_aarch64.cpp"
  }
}

void vand_notI_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1472 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 31846 "ad_aarch64.cpp"
  }
}

void vand_notI_5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1472 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src2 */);
    }
  
#line 31871 "ad_aarch64.cpp"
  }
}

void vand_notI_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1472 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src2 */);
    }
  
#line 31896 "ad_aarch64.cpp"
  }
}

void vand_notI_6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1472 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 31921 "ad_aarch64.cpp"
  }
}

void vand_notI_7Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1472 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 31946 "ad_aarch64.cpp"
  }
}

void vand_notI_9Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1472 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src2 */);
    }
  
#line 31971 "ad_aarch64.cpp"
  }
}

void vand_notI_8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1472 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src2 */);
    }
  
#line 31996 "ad_aarch64.cpp"
  }
}

void vand_notI_10Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1472 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 32021 "ad_aarch64.cpp"
  }
}

void vand_notLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1488 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 32046 "ad_aarch64.cpp"
  }
}

void vand_notL_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1488 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src2 */);
    }
  
#line 32071 "ad_aarch64.cpp"
  }
}

void vand_notL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1488 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src2 */);
    }
  
#line 32096 "ad_aarch64.cpp"
  }
}

void vand_notL_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1488 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_bic(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 32121 "ad_aarch64.cpp"
  }
}

void vand_notI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1509 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_bic(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 32142 "ad_aarch64.cpp"
  }
}

void vand_notI_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1509 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_bic(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src2 */);
  
#line 32163 "ad_aarch64.cpp"
  }
}

void vand_notI_masked_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1509 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_bic(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 32184 "ad_aarch64.cpp"
  }
}

void vand_notI_masked_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1509 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_bic(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src2 */);
  
#line 32205 "ad_aarch64.cpp"
  }
}

void vand_notI_masked_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1509 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_bic(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 32226 "ad_aarch64.cpp"
  }
}

void vand_notI_masked_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1509 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_bic(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src2 */);
  
#line 32247 "ad_aarch64.cpp"
  }
}

void vand_notL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1521 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_bic(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 32268 "ad_aarch64.cpp"
  }
}

void vand_notL_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1521 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_bic(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src2 */);
  
#line 32289 "ad_aarch64.cpp"
  }
}

void vabsBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1536 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ absr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_abs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ B, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 32311 "ad_aarch64.cpp"
  }
}

void vabsSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1551 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ absr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_abs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ H, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 32333 "ad_aarch64.cpp"
  }
}

void vabsINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1566 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ absr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_abs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ S, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 32355 "ad_aarch64.cpp"
  }
}

void vabsLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1581 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ absr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_abs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 32377 "ad_aarch64.cpp"
  }
}

void vabsFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1596 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fabs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_fabs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ S, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 32399 "ad_aarch64.cpp"
  }
}

void vabsDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1611 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fabs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_fabs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 32421 "ad_aarch64.cpp"
  }
}

void vabsB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1629 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_abs(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ B, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 32438 "ad_aarch64.cpp"
  }
}

void vabsS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1639 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_abs(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ H, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 32455 "ad_aarch64.cpp"
  }
}

void vabsI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1649 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_abs(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ S, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 32472 "ad_aarch64.cpp"
  }
}

void vabsL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1659 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_abs(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ D, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 32489 "ad_aarch64.cpp"
  }
}

void vabsF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1669 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fabs(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ S, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 32506 "ad_aarch64.cpp"
  }
}

void vabsD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1679 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fabs(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ D, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 32523 "ad_aarch64.cpp"
  }
}

void vfabd_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1694 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ fabd(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 32541 "ad_aarch64.cpp"
  }
}

void vfabd_neon_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1694 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ fabd(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 32559 "ad_aarch64.cpp"
  }
}

void vfabd_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1706 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fabd(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 32579 "ad_aarch64.cpp"
  }
}

void vfabd_sve_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1706 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fabd(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 32599 "ad_aarch64.cpp"
  }
}

void vfabd_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1722 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fabd(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 32619 "ad_aarch64.cpp"
  }
}

void vfabd_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1722 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fabd(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 32639 "ad_aarch64.cpp"
  }
}

void vnegINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1737 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ negr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      BasicType bt = Matcher::vector_element_basic_type(this);
      __ sve_neg(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt),
                 ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 32663 "ad_aarch64.cpp"
  }
}

void vnegLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1754 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ negr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_neg(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 32685 "ad_aarch64.cpp"
  }
}

void vnegFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1769 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fneg(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_fneg(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ S, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 32707 "ad_aarch64.cpp"
  }
}

void vnegDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1784 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fneg(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_fneg(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 32729 "ad_aarch64.cpp"
  }
}

void vnegI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1802 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_neg(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 32748 "ad_aarch64.cpp"
  }
}

void vnegL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1814 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_neg(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ D, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 32765 "ad_aarch64.cpp"
  }
}

void vnegF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1824 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fneg(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ S, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 32782 "ad_aarch64.cpp"
  }
}

void vnegD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1834 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fneg(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ D, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 32799 "ad_aarch64.cpp"
  }
}

void vsqrtFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1847 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fsqrt(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_fsqrt(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ S, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 32821 "ad_aarch64.cpp"
  }
}

void vsqrtDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1862 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fsqrt(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_fsqrt(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 32843 "ad_aarch64.cpp"
  }
}

void vsqrtF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1880 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fsqrt(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ S, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 32860 "ad_aarch64.cpp"
  }
}

void vsqrtD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1890 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fsqrt(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ D, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 32877 "ad_aarch64.cpp"
  }
}

void vminL_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1905 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ cmgt(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, __ T2D, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    __ bsl(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, __ T16B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */);
  
#line 32896 "ad_aarch64.cpp"
  }
}

void vminL_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1916 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_smin(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ D, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 32913 "ad_aarch64.cpp"
  }
}

void vmin_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1929 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    if (is_floating_point_type(bt)) {
      __ fmin(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(is_integral_type(bt) && bt != T_LONG, "unsupported type");
      __ minv(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 32938 "ad_aarch64.cpp"
  }
}

void vmin_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1948 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this);
    if (is_floating_point_type(bt)) {
      __ sve_fmin(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                  ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(is_integral_type(bt) && bt != T_LONG, "unsupported type");
      __ sve_smin(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                  ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 32964 "ad_aarch64.cpp"
  }
}

void vmin_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1969 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    if (is_floating_point_type(bt)) {
      __ sve_fmin(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                  opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(is_integral_type(bt), "unsupported type");
      __ sve_smin(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                  opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 32990 "ad_aarch64.cpp"
  }
}

void vmaxL_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1992 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ cmgt(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, __ T2D, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    __ bsl(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, __ T16B, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 33009 "ad_aarch64.cpp"
  }
}

void vmaxL_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2003 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_smax(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ D, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 33026 "ad_aarch64.cpp"
  }
}

void vmax_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2016 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    if (is_floating_point_type(bt)) {
      __ fmax(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(is_integral_type(bt) && bt != T_LONG, "unsupported type");
      __ maxv(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 33051 "ad_aarch64.cpp"
  }
}

void vmax_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2035 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this);
    if (is_floating_point_type(bt)) {
      __ sve_fmax(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                  ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(is_integral_type(bt) && bt != T_LONG, "unsupported type");
      __ sve_smax(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                  ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 33077 "ad_aarch64.cpp"
  }
}

void vmax_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2056 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    if (is_floating_point_type(bt)) {
      __ sve_fmax(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                  opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    } else {
      assert(is_integral_type(bt), "unsupported type");
      __ sve_smax(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                  opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    }
  
#line 33103 "ad_aarch64.cpp"
  }
}

void vmlaNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2080 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ mlav(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, get_arrangement(this),
              opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_mla(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    }
  
#line 33130 "ad_aarch64.cpp"
  }
}

void vmla_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2080 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ mlav(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst_src1 */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src2 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src3 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_mla(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src2 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src3 */);
    }
  
#line 33157 "ad_aarch64.cpp"
  }
}

void vmla_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2080 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ mlav(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, get_arrangement(this),
              opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_mla(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    }
  
#line 33184 "ad_aarch64.cpp"
  }
}

void vmla_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2080 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ mlav(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst_src1 */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src2 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src3 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_mla(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src2 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src3 */);
    }
  
#line 33211 "ad_aarch64.cpp"
  }
}

void vmla_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2080 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ mlav(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, get_arrangement(this),
              opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_mla(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    }
  
#line 33238 "ad_aarch64.cpp"
  }
}

void vmla_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2080 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ mlav(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst_src1 */, get_arrangement(this),
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src2 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src3 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_mla(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src2 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src3 */);
    }
  
#line 33265 "ad_aarch64.cpp"
  }
}

void vmlaLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2099 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_mla(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33285 "ad_aarch64.cpp"
  }
}

void vmlaL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2099 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_mla(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst_src1 */, __ elemType_to_regVariant(bt),
               ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src2 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src3 */);
  
#line 33305 "ad_aarch64.cpp"
  }
}

void vmla_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2114 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_mla(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33326 "ad_aarch64.cpp"
  }
}

void vmla_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2114 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_mla(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33347 "ad_aarch64.cpp"
  }
}

void vmla_masked_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2114 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_mla(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33368 "ad_aarch64.cpp"
  }
}

void vmla_masked_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2114 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_mla(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33389 "ad_aarch64.cpp"
  }
}

void vfmlaNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2130 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fmla(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, get_arrangement(this),
              opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      BasicType bt = Matcher::vector_element_basic_type(this);
      __ sve_fmla(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                  ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    }
  
#line 33416 "ad_aarch64.cpp"
  }
}

void vfmla_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2130 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fmla(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, get_arrangement(this),
              opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      BasicType bt = Matcher::vector_element_basic_type(this);
      __ sve_fmla(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                  ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    }
  
#line 33443 "ad_aarch64.cpp"
  }
}

void vfmad_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2153 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fmad(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33464 "ad_aarch64.cpp"
  }
}

void vfmad_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2153 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fmad(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33485 "ad_aarch64.cpp"
  }
}

void vmlsNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2169 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ mlsv(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, get_arrangement(this),
              opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_mls(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    }
  
#line 33512 "ad_aarch64.cpp"
  }
}

void vmls_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2169 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ mlsv(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, get_arrangement(this),
              opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_mls(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    }
  
#line 33539 "ad_aarch64.cpp"
  }
}

void vmls_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2169 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ mlsv(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, get_arrangement(this),
              opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_mls(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    }
  
#line 33566 "ad_aarch64.cpp"
  }
}

void vmlsLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2188 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_mls(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33586 "ad_aarch64.cpp"
  }
}

void vmls_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2203 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_mls(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33607 "ad_aarch64.cpp"
  }
}

void vmls_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2203 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_mls(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33628 "ad_aarch64.cpp"
  }
}

void vmls_masked_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2203 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_mls(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33649 "ad_aarch64.cpp"
  }
}

void vmls_masked_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2203 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_mls(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33670 "ad_aarch64.cpp"
  }
}

void vfmls1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2219 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fmls(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, get_arrangement(this),
              opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      BasicType bt = Matcher::vector_element_basic_type(this);
      __ sve_fmls(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                  ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    }
  
#line 33697 "ad_aarch64.cpp"
  }
}

void vfmls1_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2219 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fmls(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, get_arrangement(this),
              opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      BasicType bt = Matcher::vector_element_basic_type(this);
      __ sve_fmls(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                  ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    }
  
#line 33724 "ad_aarch64.cpp"
  }
}

void vfmls2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2240 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fmls(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, get_arrangement(this),
              opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      BasicType bt = Matcher::vector_element_basic_type(this);
      __ sve_fmls(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                  ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    }
  
#line 33751 "ad_aarch64.cpp"
  }
}

void vfmls2_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2240 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fmls(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, get_arrangement(this),
              opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    } else {
      assert(UseSVE > 0, "must be sve");
      BasicType bt = Matcher::vector_element_basic_type(this);
      __ sve_fmls(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                  ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
    }
  
#line 33778 "ad_aarch64.cpp"
  }
}

void vfmsb_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2263 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fmsb(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33799 "ad_aarch64.cpp"
  }
}

void vfmsb_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2263 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fmsb(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33820 "ad_aarch64.cpp"
  }
}

void vfnmla1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2279 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fnmla(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33840 "ad_aarch64.cpp"
  }
}

void vfnmla1_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2279 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fnmla(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33860 "ad_aarch64.cpp"
  }
}

void vfnmla2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2293 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fnmla(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33880 "ad_aarch64.cpp"
  }
}

void vfnmla2_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2293 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fnmla(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33900 "ad_aarch64.cpp"
  }
}

void vfnmad_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2309 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fnmad(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33921 "ad_aarch64.cpp"
  }
}

void vfnmad_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2309 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fnmad(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33942 "ad_aarch64.cpp"
  }
}

void vfnmlsNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2325 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fnmls(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33962 "ad_aarch64.cpp"
  }
}

void vfnmls_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2325 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fnmls(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 33982 "ad_aarch64.cpp"
  }
}

void vfnmsb_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2341 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fnmsb(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 34003 "ad_aarch64.cpp"
  }
}

void vfnmsb_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2341 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fnmsb(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
                 opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src3 */);
  
#line 34024 "ad_aarch64.cpp"
  }
}

void vmuladdS2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2358 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ smullv(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */, __ T4H, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    __ smullv(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, __ T8H, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    __ addpv(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, __ T4S, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */);
  
#line 34045 "ad_aarch64.cpp"
  }
}

void vshiftcntLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2402 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */);
    } else {
      assert(UseSVE > 0, "must be sve");
      BasicType bt = Matcher::vector_element_basic_type(this);
      __ sve_dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt), opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */);
    }
  
#line 34068 "ad_aarch64.cpp"
  }
}

void vshiftcntRNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2418 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    if (UseSVE == 0) {
      uint length_in_bytes = Matcher::vector_length_in_bytes(this);
      assert(length_in_bytes <= 16, "must be");
      __ negw(rscratch1, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */);
      __ dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), rscratch1);
    } else {
      BasicType bt = Matcher::vector_element_basic_type(this);
      __ sve_dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt), opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */);
    }
  
#line 34092 "ad_aarch64.cpp"
  }
}

void vlsl_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2441 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sshl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34110 "ad_aarch64.cpp"
  }
}

void vlsl_neon_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2441 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sshl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34128 "ad_aarch64.cpp"
  }
}

void vlsl_neon_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2441 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sshl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34146 "ad_aarch64.cpp"
  }
}

void vlsl_neon_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2441 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sshl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34164 "ad_aarch64.cpp"
  }
}

void vlsl_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2455 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_lsl(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34184 "ad_aarch64.cpp"
  }
}

void vlsl_sve_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2455 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_lsl(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34204 "ad_aarch64.cpp"
  }
}

void vlsl_sve_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2455 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_lsl(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34224 "ad_aarch64.cpp"
  }
}

void vlsl_sve_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2455 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_lsl(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34244 "ad_aarch64.cpp"
  }
}

void vasr_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2473 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sshl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34262 "ad_aarch64.cpp"
  }
}

void vasr_neon_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2473 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sshl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34280 "ad_aarch64.cpp"
  }
}

void vasr_neon_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2473 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sshl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34298 "ad_aarch64.cpp"
  }
}

void vasr_neon_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2473 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sshl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34316 "ad_aarch64.cpp"
  }
}

void vasr_neon_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2488 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    __ negr(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
            opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
    __ sshl(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */);
  
#line 34338 "ad_aarch64.cpp"
  }
}

void vasr_neon_var_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2488 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    __ negr(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
            opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
    __ sshl(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */);
  
#line 34360 "ad_aarch64.cpp"
  }
}

void vasr_neon_var_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2488 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    __ negr(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
            opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
    __ sshl(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */);
  
#line 34382 "ad_aarch64.cpp"
  }
}

void vasr_neon_var_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2488 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    __ negr(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
            opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
    __ sshl(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */);
  
#line 34404 "ad_aarch64.cpp"
  }
}

void vasr_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2505 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_asr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34423 "ad_aarch64.cpp"
  }
}

void vasr_sve_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2505 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_asr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34442 "ad_aarch64.cpp"
  }
}

void vasr_sve_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2505 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_asr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34461 "ad_aarch64.cpp"
  }
}

void vasr_sve_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2505 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_asr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34480 "ad_aarch64.cpp"
  }
}

void vlsr_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2522 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ ushl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34498 "ad_aarch64.cpp"
  }
}

void vlsr_neon_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2522 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ ushl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34516 "ad_aarch64.cpp"
  }
}

void vlsr_neon_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2522 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ ushl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34534 "ad_aarch64.cpp"
  }
}

void vlsr_neon_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2522 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ ushl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34552 "ad_aarch64.cpp"
  }
}

void vlsr_neon_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2537 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    __ negr(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
            opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
    __ ushl(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */);
  
#line 34574 "ad_aarch64.cpp"
  }
}

void vlsr_neon_var_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2537 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    __ negr(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
            opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
    __ ushl(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */);
  
#line 34596 "ad_aarch64.cpp"
  }
}

void vlsr_neon_var_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2537 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    __ negr(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
            opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
    __ ushl(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */);
  
#line 34618 "ad_aarch64.cpp"
  }
}

void vlsr_neon_var_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2537 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    __ negr(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
            opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
    __ ushl(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this),
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */);
  
#line 34640 "ad_aarch64.cpp"
  }
}

void vlsr_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2554 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_lsr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34659 "ad_aarch64.cpp"
  }
}

void vlsr_sve_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2554 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_lsr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34678 "ad_aarch64.cpp"
  }
}

void vlsr_sve_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2554 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_lsr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34697 "ad_aarch64.cpp"
  }
}

void vlsr_sve_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2554 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_lsr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */);
  
#line 34716 "ad_aarch64.cpp"
  }
}

void vlsl_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2571 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) {
      // Optimize for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) {
        if (VM_Version::use_neon_for_vector(length_in_bytes)) {
          __ eor(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
                 opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        } else {
          assert(UseSVE > 0, "must be sve");
          __ sve_eor(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        }
        return;
      }
    }
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ shl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_lsl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    }
  
#line 34755 "ad_aarch64.cpp"
  }
}

void vlsl_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2571 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) {
      // Optimize for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) {
        if (VM_Version::use_neon_for_vector(length_in_bytes)) {
          __ eor(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
                 opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        } else {
          assert(UseSVE > 0, "must be sve");
          __ sve_eor(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        }
        return;
      }
    }
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ shl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_lsl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    }
  
#line 34794 "ad_aarch64.cpp"
  }
}

void vlsl_imm_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2571 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) {
      // Optimize for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) {
        if (VM_Version::use_neon_for_vector(length_in_bytes)) {
          __ eor(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
                 opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        } else {
          assert(UseSVE > 0, "must be sve");
          __ sve_eor(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        }
        return;
      }
    }
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ shl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_lsl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    }
  
#line 34833 "ad_aarch64.cpp"
  }
}

void vlsl_imm_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2571 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) {
      // Optimize for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) {
        if (VM_Version::use_neon_for_vector(length_in_bytes)) {
          __ eor(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
                 opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        } else {
          assert(UseSVE > 0, "must be sve");
          __ sve_eor(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        }
        return;
      }
    }
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ shl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_lsl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    }
  
#line 34872 "ad_aarch64.cpp"
  }
}

void vasr_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2606 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) {
      // Refine con for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) con = esize_in_bits - 1;
    }
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ sshr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_asr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    }
  
#line 34902 "ad_aarch64.cpp"
  }
}

void vasr_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2606 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) {
      // Refine con for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) con = esize_in_bits - 1;
    }
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ sshr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_asr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    }
  
#line 34932 "ad_aarch64.cpp"
  }
}

void vasr_imm_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2606 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) {
      // Refine con for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) con = esize_in_bits - 1;
    }
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ sshr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_asr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    }
  
#line 34962 "ad_aarch64.cpp"
  }
}

void vasr_imm_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2606 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) {
      // Refine con for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) con = esize_in_bits - 1;
    }
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ sshr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_asr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    }
  
#line 34992 "ad_aarch64.cpp"
  }
}

void vlsr_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2632 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) {
      // Optimize for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) {
        if (VM_Version::use_neon_for_vector(length_in_bytes)) {
          __ eor(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
                 opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        } else {
          assert(UseSVE > 0, "must be sve");
          __ sve_eor(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        }
        return;
      }
    }
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ ushr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_lsr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    }
  
#line 35031 "ad_aarch64.cpp"
  }
}

void vlsr_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2632 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) {
      // Optimize for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) {
        if (VM_Version::use_neon_for_vector(length_in_bytes)) {
          __ eor(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
                 opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        } else {
          assert(UseSVE > 0, "must be sve");
          __ sve_eor(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        }
        return;
      }
    }
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ ushr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_lsr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    }
  
#line 35070 "ad_aarch64.cpp"
  }
}

void vlsr_imm_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2632 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) {
      // Optimize for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) {
        if (VM_Version::use_neon_for_vector(length_in_bytes)) {
          __ eor(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
                 opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        } else {
          assert(UseSVE > 0, "must be sve");
          __ sve_eor(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        }
        return;
      }
    }
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ ushr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_lsr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    }
  
#line 35109 "ad_aarch64.cpp"
  }
}

void vlsr_imm_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2632 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) {
      // Optimize for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) {
        if (VM_Version::use_neon_for_vector(length_in_bytes)) {
          __ eor(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
                 opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        } else {
          assert(UseSVE > 0, "must be sve");
          __ sve_eor(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        }
        return;
      }
    }
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ ushr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_lsr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    }
  
#line 35148 "ad_aarch64.cpp"
  }
}

void vasra_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2669 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int con = (int)opnd_array(3)->constant();
    if (is_subword_type(bt)) {
      // Refine con for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) con = esize_in_bits - 1;
    }
    __ ssra(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst */, get_arrangement(this), opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, con);
  
#line 35173 "ad_aarch64.cpp"
  }
}

void vasra_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2669 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) {
      // Refine con for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) con = esize_in_bits - 1;
    }
    __ ssra(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
  
#line 35198 "ad_aarch64.cpp"
  }
}

void vasra_imm_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2669 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int con = (int)opnd_array(3)->constant();
    if (is_subword_type(bt)) {
      // Refine con for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) con = esize_in_bits - 1;
    }
    __ ssra(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst */, get_arrangement(this), opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, con);
  
#line 35223 "ad_aarch64.cpp"
  }
}

void vasra_imm_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2669 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) {
      // Refine con for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) con = esize_in_bits - 1;
    }
    __ ssra(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
  
#line 35248 "ad_aarch64.cpp"
  }
}

void vasra_imm_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2669 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int con = (int)opnd_array(3)->constant();
    if (is_subword_type(bt)) {
      // Refine con for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) con = esize_in_bits - 1;
    }
    __ ssra(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst */, get_arrangement(this), opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, con);
  
#line 35273 "ad_aarch64.cpp"
  }
}

void vasra_imm_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2669 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) {
      // Refine con for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) con = esize_in_bits - 1;
    }
    __ ssra(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
  
#line 35298 "ad_aarch64.cpp"
  }
}

void vasra_imm_5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2669 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int con = (int)opnd_array(3)->constant();
    if (is_subword_type(bt)) {
      // Refine con for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) con = esize_in_bits - 1;
    }
    __ ssra(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst */, get_arrangement(this), opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, con);
  
#line 35323 "ad_aarch64.cpp"
  }
}

void vasra_imm_6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2669 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) {
      // Refine con for B/S
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con >= esize_in_bits) con = esize_in_bits - 1;
    }
    __ ssra(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
  
#line 35348 "ad_aarch64.cpp"
  }
}

void vlsra_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2689 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int con = (int)opnd_array(3)->constant();
    if (is_subword_type(bt)) { // for B/H
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con < esize_in_bits) {
        __ usra(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst */, get_arrangement(this), opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, con);
      }
    } else { // for S/D
      assert(type2aelembytes(bt) == 4 || type2aelembytes(bt) == 8, "unsupported type");
      __ usra(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst */, get_arrangement(this), opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, con);
    }
  
#line 35376 "ad_aarch64.cpp"
  }
}

void vlsra_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2689 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) { // for B/H
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con < esize_in_bits) {
        __ usra(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
      }
    } else { // for S/D
      assert(type2aelembytes(bt) == 4 || type2aelembytes(bt) == 8, "unsupported type");
      __ usra(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    }
  
#line 35404 "ad_aarch64.cpp"
  }
}

void vlsra_imm_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2689 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int con = (int)opnd_array(3)->constant();
    if (is_subword_type(bt)) { // for B/H
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con < esize_in_bits) {
        __ usra(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst */, get_arrangement(this), opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, con);
      }
    } else { // for S/D
      assert(type2aelembytes(bt) == 4 || type2aelembytes(bt) == 8, "unsupported type");
      __ usra(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst */, get_arrangement(this), opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, con);
    }
  
#line 35432 "ad_aarch64.cpp"
  }
}

void vlsra_imm_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2689 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) { // for B/H
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con < esize_in_bits) {
        __ usra(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
      }
    } else { // for S/D
      assert(type2aelembytes(bt) == 4 || type2aelembytes(bt) == 8, "unsupported type");
      __ usra(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    }
  
#line 35460 "ad_aarch64.cpp"
  }
}

void vlsra_imm_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2689 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int con = (int)opnd_array(3)->constant();
    if (is_subword_type(bt)) { // for B/H
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con < esize_in_bits) {
        __ usra(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst */, get_arrangement(this), opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, con);
      }
    } else { // for S/D
      assert(type2aelembytes(bt) == 4 || type2aelembytes(bt) == 8, "unsupported type");
      __ usra(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst */, get_arrangement(this), opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, con);
    }
  
#line 35488 "ad_aarch64.cpp"
  }
}

void vlsra_imm_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2689 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) { // for B/H
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con < esize_in_bits) {
        __ usra(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
      }
    } else { // for S/D
      assert(type2aelembytes(bt) == 4 || type2aelembytes(bt) == 8, "unsupported type");
      __ usra(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    }
  
#line 35516 "ad_aarch64.cpp"
  }
}

void vlsra_imm_5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2689 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int con = (int)opnd_array(3)->constant();
    if (is_subword_type(bt)) { // for B/H
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con < esize_in_bits) {
        __ usra(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst */, get_arrangement(this), opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, con);
      }
    } else { // for S/D
      assert(type2aelembytes(bt) == 4 || type2aelembytes(bt) == 8, "unsupported type");
      __ usra(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst */, get_arrangement(this), opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, con);
    }
  
#line 35544 "ad_aarch64.cpp"
  }
}

void vlsra_imm_6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2689 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int con = (int)opnd_array(2)->constant();
    if (is_subword_type(bt)) { // for B/H
      int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
      if (con < esize_in_bits) {
        __ usra(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
      }
    } else { // for S/D
      assert(type2aelembytes(bt) == 4 || type2aelembytes(bt) == 8, "unsupported type");
      __ usra(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, con);
    }
  
#line 35572 "ad_aarch64.cpp"
  }
}

void vlsl_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2714 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_lsl(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 35592 "ad_aarch64.cpp"
  }
}

void vlsl_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2714 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_lsl(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 35612 "ad_aarch64.cpp"
  }
}

void vlsl_masked_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2714 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_lsl(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 35632 "ad_aarch64.cpp"
  }
}

void vlsl_masked_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2714 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_lsl(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 35652 "ad_aarch64.cpp"
  }
}

void vasr_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2729 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_asr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 35672 "ad_aarch64.cpp"
  }
}

void vasr_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2729 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_asr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 35692 "ad_aarch64.cpp"
  }
}

void vasr_masked_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2729 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_asr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 35712 "ad_aarch64.cpp"
  }
}

void vasr_masked_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2729 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_asr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 35732 "ad_aarch64.cpp"
  }
}

void vlsr_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2744 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_lsr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 35752 "ad_aarch64.cpp"
  }
}

void vlsr_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2744 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_lsr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 35772 "ad_aarch64.cpp"
  }
}

void vlsr_masked_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2744 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_lsr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 35792 "ad_aarch64.cpp"
  }
}

void vlsr_masked_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2744 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_lsr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 35812 "ad_aarch64.cpp"
  }
}

void vlsl_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2761 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
    int con = (int)opnd_array(2)->constant();
    assert(con >= 0 && con < esize_in_bits, "invalid shift immediate");
    __ sve_lsl(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, con);
  
#line 35835 "ad_aarch64.cpp"
  }
}

void vlsl_imm_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2761 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
    int con = (int)opnd_array(2)->constant();
    assert(con >= 0 && con < esize_in_bits, "invalid shift immediate");
    __ sve_lsl(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, con);
  
#line 35858 "ad_aarch64.cpp"
  }
}

void vlsl_imm_masked_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2761 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
    int con = (int)opnd_array(2)->constant();
    assert(con >= 0 && con < esize_in_bits, "invalid shift immediate");
    __ sve_lsl(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, con);
  
#line 35881 "ad_aarch64.cpp"
  }
}

void vlsl_imm_masked_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2761 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
    int con = (int)opnd_array(2)->constant();
    assert(con >= 0 && con < esize_in_bits, "invalid shift immediate");
    __ sve_lsl(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, con);
  
#line 35904 "ad_aarch64.cpp"
  }
}

void vasr_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2779 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < esize_in_bits, "invalid shift immediate");
    __ sve_asr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, con);
  
#line 35927 "ad_aarch64.cpp"
  }
}

void vasr_imm_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2779 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < esize_in_bits, "invalid shift immediate");
    __ sve_asr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, con);
  
#line 35950 "ad_aarch64.cpp"
  }
}

void vasr_imm_masked_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2779 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < esize_in_bits, "invalid shift immediate");
    __ sve_asr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, con);
  
#line 35973 "ad_aarch64.cpp"
  }
}

void vasr_imm_masked_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2779 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < esize_in_bits, "invalid shift immediate");
    __ sve_asr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, con);
  
#line 35996 "ad_aarch64.cpp"
  }
}

void vlsr_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2797 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < esize_in_bits, "invalid shift immediate");
    __ sve_lsr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, con);
  
#line 36019 "ad_aarch64.cpp"
  }
}

void vlsr_imm_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2797 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < esize_in_bits, "invalid shift immediate");
    __ sve_lsr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, con);
  
#line 36042 "ad_aarch64.cpp"
  }
}

void vlsr_imm_masked_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2797 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < esize_in_bits, "invalid shift immediate");
    __ sve_lsr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, con);
  
#line 36065 "ad_aarch64.cpp"
  }
}

void vlsr_imm_masked_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2797 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int esize_in_bits = type2aelembytes(bt) * BitsPerByte;
    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < esize_in_bits, "invalid shift immediate");
    __ sve_lsr(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, con);
  
#line 36088 "ad_aarch64.cpp"
  }
}

void reduce_addI_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2817 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    __ neon_reduce_add_integral(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                                opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                                length_in_bytes, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 36111 "ad_aarch64.cpp"
  }
}

void reduce_addI_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2832 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           ptrue, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 36136 "ad_aarch64.cpp"
  }
}

void reduce_addL_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2851 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    __ neon_reduce_add_integral(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                                opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                                length_in_bytes, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 36159 "ad_aarch64.cpp"
  }
}

void reduce_addL_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2866 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           ptrue, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 36184 "ad_aarch64.cpp"
  }
}

void reduce_addF_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2885 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    __ fadds(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* fsrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */);
    __ ins(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */, __ S, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */, 0, 1);
    __ fadds(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
    if (length_in_bytes == 16) {
      __ ins(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */, __ S, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */, 0, 2);
      __ fadds(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
      __ ins(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */, __ S, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */, 0, 3);
      __ fadds(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
    }
  
#line 36212 "ad_aarch64.cpp"
  }
}

void reduce_addF_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2904 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_fadda(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ S, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 36231 "ad_aarch64.cpp"
  }
}

void reduce_addD_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2919 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ faddd(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dsrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */);
    __ ins(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */, __ D, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */, 0, 1);
    __ faddd(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 36252 "ad_aarch64.cpp"
  }
}

void reduce_addD_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2931 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_fadda(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ D, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 36271 "ad_aarch64.cpp"
  }
}

void reduce_addI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2946 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */);
  
#line 36294 "ad_aarch64.cpp"
  }
}

void reduce_addL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2960 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */);
  
#line 36317 "ad_aarch64.cpp"
  }
}

void reduce_addF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2973 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fadda(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ S,
                 opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 36336 "ad_aarch64.cpp"
  }
}

void reduce_addD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2984 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fadda(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src1 */, __ D,
                 opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 36355 "ad_aarch64.cpp"
  }
}

void reduce_mulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3000 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    __ neon_reduce_mul_integral(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */,
                                opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */, length_in_bytes,
                                opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp2 */);
  
#line 36379 "ad_aarch64.cpp"
  }
}

void reduce_mulLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3015 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ neon_reduce_mul_integral(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */,
                                opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */, 16, fnoreg, fnoreg);
  
#line 36398 "ad_aarch64.cpp"
  }
}

void reduce_mulFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3027 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    __ neon_reduce_mul_fp(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, T_FLOAT, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* fsrc */,
                          opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */, length_in_bytes, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 36419 "ad_aarch64.cpp"
  }
}

void reduce_mulDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3040 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ neon_reduce_mul_fp(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, T_DOUBLE, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dsrc */,
                          opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */, 16, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 36439 "ad_aarch64.cpp"
  }
}

void reduce_andI_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3056 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    __ neon_reduce_logical(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */, length_in_bytes);
  
#line 36460 "ad_aarch64.cpp"
  }
}

void reduce_andI_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3070 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           ptrue, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 36484 "ad_aarch64.cpp"
  }
}

void reduce_andL_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3088 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    __ neon_reduce_logical(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */, length_in_bytes);
  
#line 36505 "ad_aarch64.cpp"
  }
}

void reduce_andL_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3102 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           ptrue, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 36529 "ad_aarch64.cpp"
  }
}

void reduce_andI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3120 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */);
  
#line 36552 "ad_aarch64.cpp"
  }
}

void reduce_andL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3134 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */);
  
#line 36575 "ad_aarch64.cpp"
  }
}

void reduce_orI_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3152 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    __ neon_reduce_logical(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */, length_in_bytes);
  
#line 36596 "ad_aarch64.cpp"
  }
}

void reduce_orI_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3166 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           ptrue, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 36620 "ad_aarch64.cpp"
  }
}

void reduce_orL_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3184 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    __ neon_reduce_logical(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */, length_in_bytes);
  
#line 36641 "ad_aarch64.cpp"
  }
}

void reduce_orL_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3198 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           ptrue, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 36665 "ad_aarch64.cpp"
  }
}

void reduce_orI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3216 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */);
  
#line 36688 "ad_aarch64.cpp"
  }
}

void reduce_orL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3230 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */);
  
#line 36711 "ad_aarch64.cpp"
  }
}

void reduce_xorI_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3248 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    __ neon_reduce_logical(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */, length_in_bytes);
  
#line 36732 "ad_aarch64.cpp"
  }
}

void reduce_xorI_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3262 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           ptrue, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 36756 "ad_aarch64.cpp"
  }
}

void reduce_xorL_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3280 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    __ neon_reduce_logical(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */, length_in_bytes);
  
#line 36777 "ad_aarch64.cpp"
  }
}

void reduce_xorL_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3294 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           ptrue, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 36801 "ad_aarch64.cpp"
  }
}

void reduce_xorI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3312 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */);
  
#line 36824 "ad_aarch64.cpp"
  }
}

void reduce_xorL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3326 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */);
  
#line 36847 "ad_aarch64.cpp"
  }
}

void reduce_maxI_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3348 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    __ neon_reduce_minmax_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                                   opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                                   length_in_bytes, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 36870 "ad_aarch64.cpp"
  }
}

void reduce_maxI_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3367 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           ptrue, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 36895 "ad_aarch64.cpp"
  }
}

void reduce_maxL_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3386 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ neon_reduce_minmax_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                                   opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                                   /* vector_length_in_bytes */ 16, fnoreg);
  
#line 36915 "ad_aarch64.cpp"
  }
}

void reduce_maxL_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3400 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           ptrue, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 36938 "ad_aarch64.cpp"
  }
}

void reduce_maxFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3417 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      if (length_in_bytes == 8) {
        __ fmaxp(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */, __ S);
      } else {
        __ fmaxv(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, __ T4S, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */);
      }
    } else {
      assert(UseSVE > 0, "must be sve");
      assert(length_in_bytes == MaxVectorSize, "invalid vector length");
      __ sve_fmaxv(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, __ S, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */);
    }
    __ fmaxs(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* fsrc */);
  
#line 36968 "ad_aarch64.cpp"
  }
}

void reduce_maxDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3442 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fmaxp(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */, __ D);
    } else {
      assert(UseSVE > 0, "must be sve");
      assert(length_in_bytes == MaxVectorSize, "invalid vector length");
      __ sve_fmaxv(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, __ D, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */);
    }
    __ fmaxd(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dsrc */);
  
#line 36994 "ad_aarch64.cpp"
  }
}

void reduce_maxI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3467 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */);
  
#line 37017 "ad_aarch64.cpp"
  }
}

void reduce_maxL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3482 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */);
  
#line 37040 "ad_aarch64.cpp"
  }
}

void reduce_maxF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3496 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fmaxv(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, __ S, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */);
    __ fmaxs(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* fsrc */);
  
#line 37060 "ad_aarch64.cpp"
  }
}

void reduce_maxD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3508 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fmaxv(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, __ D, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */);
    __ fmaxd(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dsrc */);
  
#line 37080 "ad_aarch64.cpp"
  }
}

void reduce_minI_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3528 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    __ neon_reduce_minmax_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                                   opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                                   length_in_bytes, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 37103 "ad_aarch64.cpp"
  }
}

void reduce_minI_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3547 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           ptrue, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 37128 "ad_aarch64.cpp"
  }
}

void reduce_minL_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3566 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ neon_reduce_minmax_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                                   opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                                   /* vector_length_in_bytes */ 16, fnoreg);
  
#line 37148 "ad_aarch64.cpp"
  }
}

void reduce_minL_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3580 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           ptrue, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 37171 "ad_aarch64.cpp"
  }
}

void reduce_minFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3597 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      if (length_in_bytes == 8) {
        __ fminp(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */, __ S);
      } else {
        __ fminv(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, __ T4S, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */);
      }
    } else {
      assert(UseSVE > 0, "must be sve");
      assert(length_in_bytes == MaxVectorSize, "invalid vector length");
      __ sve_fminv(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, __ S, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */);
    }
    __ fmins(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* fsrc */);
  
#line 37201 "ad_aarch64.cpp"
  }
}

void reduce_minDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3622 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ fminp(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */, __ D);
    } else {
      assert(UseSVE > 0, "must be sve");
      assert(length_in_bytes == MaxVectorSize, "invalid vector length");
      __ sve_fminv(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, __ D, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */);
    }
    __ fmind(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dsrc */);
  
#line 37227 "ad_aarch64.cpp"
  }
}

void reduce_minI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3647 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */);
  
#line 37250 "ad_aarch64.cpp"
  }
}

void reduce_minL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3662 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */,
                           opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */);
  
#line 37273 "ad_aarch64.cpp"
  }
}

void reduce_minF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3676 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fminv(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, __ S, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */);
    __ fmins(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* fsrc */);
  
#line 37293 "ad_aarch64.cpp"
  }
}

void reduce_minD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3688 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_fminv(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, __ D, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* vsrc */);
    __ fmind(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dsrc */);
  
#line 37313 "ad_aarch64.cpp"
  }
}

void reinterpret_same_sizeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  // User did not define which encode class to use.
}

void reinterpret_resize_le128bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3712 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes_src = Matcher::vector_length_in_bytes(this, opnd_array(1));
    uint length_in_bytes_dst = Matcher::vector_length_in_bytes(this);
    // The higher bits in "dst" register must be cleared to zero.
    if ((length_in_bytes_src == 4 && length_in_bytes_dst == 8) ||
        (length_in_bytes_src == 8 && length_in_bytes_dst == 4)) {
      // Reinterpret between 32 bits and 64 bits
      __ dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ S, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else if ((length_in_bytes_src == 4 && length_in_bytes_dst == 16) ||
               (length_in_bytes_src == 16 && length_in_bytes_dst == 4)) {
      // Reinterpret between 32 bits and 128 bits
      __ dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ S, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else if ((length_in_bytes_src == 8 && length_in_bytes_dst == 16) ||
               (length_in_bytes_src == 16 && length_in_bytes_dst == 8)) {
      // Reinterpret between 64 bits and 128 bits
      __ orr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T8B, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(false, "invalid vector length");
      ShouldNotReachHere();
    }
  
#line 37355 "ad_aarch64.cpp"
  }
}

void reinterpret_resize_gt128bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3743 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    uint length_in_bytes_src = Matcher::vector_length_in_bytes(this, opnd_array(1));
    uint length_in_bytes_dst = Matcher::vector_length_in_bytes(this);
    uint length_in_bytes_resize = length_in_bytes_src < length_in_bytes_dst ?
                                  length_in_bytes_src : length_in_bytes_dst;
    assert(length_in_bytes_src <= MaxVectorSize && length_in_bytes_dst <= MaxVectorSize,
           "invalid vector length");
    __ sve_gen_mask_imm(opnd_array(3)->as_PRegister(ra_,this,idx3)/* ptmp */, T_BYTE, length_in_bytes_resize);
    __ sve_dup(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ B, 0);
    __ sve_sel(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ B, opnd_array(3)->as_PRegister(ra_,this,idx3)/* ptmp */,
               opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */);
  
#line 37383 "ad_aarch64.cpp"
  }
}

void vcvtBtoXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3766 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      // 4B to 4S/4I/4F, 8B to 8S
      __ neon_vector_extend(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, bt == T_FLOAT ? T_INT : bt,
                            length_in_bytes, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, T_BYTE);
      if (bt == T_FLOAT) {
        __ scvtfv(__ T4S, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
      }
    } else {
      assert(UseSVE > 0, "must be sve");
      Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
      __ sve_vector_extend(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, size, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ B);
      if (is_floating_point_type(bt)) {
        __ sve_scvtf(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, size, ptrue, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, size);
      }
    }
  
#line 37415 "ad_aarch64.cpp"
  }
}

void vcvtStoB_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3795 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // 4S/8S to 4B/8B
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(1));
    __ neon_vector_narrow(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, T_BYTE,
                          opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, T_SHORT, length_in_bytes);
  
#line 37434 "ad_aarch64.cpp"
  }
}

void vcvtStoB_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3810 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_vector_narrow(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ B,
                         opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ H, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
  
#line 37453 "ad_aarch64.cpp"
  }
}

void vcvtStoX_extendNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3822 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      // 4S to 4I/4F
      __ neon_vector_extend(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, T_INT, length_in_bytes,
                            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, T_SHORT);
      if (bt == T_FLOAT) {
        __ scvtfv(__ T4S, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
      }
    } else {
      assert(UseSVE > 0, "must be sve");
      Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
      __ sve_vector_extend(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, size, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ H);
      if (is_floating_point_type(bt)) {
        __ sve_scvtf(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, size, ptrue, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, size);
      }
    }
  
#line 37485 "ad_aarch64.cpp"
  }
}

void vcvtItoX_narrow_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3853 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // 4I to 4B/4S
    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(1));
    __ neon_vector_narrow(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, bt,
                          opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, T_INT, length_in_bytes);
  
#line 37506 "ad_aarch64.cpp"
  }
}

void vcvtItoX_narrow_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3870 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_vector_narrow(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ elemType_to_regVariant(bt),
                         opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ S, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */);
  
#line 37527 "ad_aarch64.cpp"
  }
}

void vcvtItoXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3883 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes =  Matcher::vector_length_in_bytes(this);
    if (bt == T_FLOAT) {
      if (VM_Version::use_neon_for_vector(length_in_bytes)) {
        // 2I/4I to 2F/4F
        __ scvtfv(get_arrangement(this), opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      } else {
        assert(UseSVE > 0, "must be sve");
        __ sve_scvtf(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ S, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ S);
      }
    } else {
      assert(type2aelembytes(bt) == 8, "unsupported type");
      if (VM_Version::use_neon_for_vector(length_in_bytes)) {
        // 2I to 2L/2D
        __ neon_vector_extend(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, T_LONG, length_in_bytes,
                              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, T_INT);
        if (bt == T_DOUBLE) {
          __ scvtfv(__ T2D, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
        }
      } else {
        assert(UseSVE > 0, "must be sve");
        __ sve_vector_extend(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ S);
        if (bt == T_DOUBLE) {
          __ sve_scvtf(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D);
        }
      }
    }
  
#line 37569 "ad_aarch64.cpp"
  }
}

void vcvtLtoI_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3922 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // 2L to 2I
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(1));
    __ neon_vector_narrow(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, T_INT,
                          opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, T_LONG, length_in_bytes);
  
#line 37588 "ad_aarch64.cpp"
  }
}

void vcvtLtoI_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3939 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_vector_narrow(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ elemType_to_regVariant(bt),
                         opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ D, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */);
  
#line 37609 "ad_aarch64.cpp"
  }
}

void vcvtLtoF_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3953 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // 2L to 2F
    __ umov(rscratch1, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ D, 0);
    __ scvtfs(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, rscratch1);
    __ umov(rscratch1, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ D, 1);
    __ scvtfs(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, rscratch1);
    __ ins(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ S, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, 1, 0);
  
#line 37632 "ad_aarch64.cpp"
  }
}

void vcvtLtoF_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3969 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_scvtf(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ S, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ D);
    __ sve_vector_narrow(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ S,
                         opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ D, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */);
  
#line 37652 "ad_aarch64.cpp"
  }
}

void vcvtLtoDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3981 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      // 2L to 2D
      __ scvtfv(__ T2D, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_scvtf(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ D);
    }
  
#line 37675 "ad_aarch64.cpp"
  }
}

void vcvtFtoX_narrow_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4003 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // 4F to 4B/4S
    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(1));
    __ fcvtzs(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ T4S, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    __ neon_vector_narrow(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, bt,
                          opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, T_INT, length_in_bytes);
  
#line 37697 "ad_aarch64.cpp"
  }
}

void vcvtFtoX_narrow_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4021 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fcvtzs(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ S, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ S);
    __ sve_vector_narrow(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ elemType_to_regVariant(bt),
                         opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ S, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */);
  
#line 37719 "ad_aarch64.cpp"
  }
}

void vcvtFtoXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4035 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes =  Matcher::vector_length_in_bytes(this);
    if (bt == T_INT) {
      if (VM_Version::use_neon_for_vector(length_in_bytes)) {
        // 2F/4F to 2I/4I
        __ fcvtzs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      } else {
        assert(UseSVE > 0, "must be sve");
        __ sve_fcvtzs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ S, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ S);
      }
    } else if (bt == T_LONG) {
      if (UseSVE == 0) {
        // 2F to 2L
        __ fcvtl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T2D, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ T2S);
        __ fcvtzs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T2D, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
      } else {
        __ sve_vector_extend(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ S);
        __ sve_fcvtzs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ S);
      }
    } else {
      assert(bt == T_DOUBLE, "unsupported type");
      if (length_in_bytes == 16) {
        // 2F to 2D
        __ fcvtl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T2D, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ T2S);
      } else {
        assert(UseSVE > 0 && length_in_bytes > 16, "must be");
        __ sve_vector_extend(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ S);
        __ sve_fcvt(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ S);
      }
    }
  
#line 37764 "ad_aarch64.cpp"
  }
}

void vcvtDtoI_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4077 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // 2D to 2I
    __ ins(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ D, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 0, 1);
    // We can't use fcvtzs(vector, integer) instruction here because we need
    // saturation arithmetic. See JDK-8276151.
    __ fcvtzdw(rscratch1, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    __ fcvtzdw(rscratch2, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */);
    __ fmovs(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, rscratch1);
    __ mov(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ S, 1, rscratch2);
  
#line 37788 "ad_aarch64.cpp"
  }
}

void vcvtDtoI_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4098 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_fcvtzs(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ S, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ D);
    __ sve_vector_narrow(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ elemType_to_regVariant(bt),
                         opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ D, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */);
  
#line 37809 "ad_aarch64.cpp"
  }
}

void vcvtDtoLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4111 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes =  Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      // 2D to 2L
      __ fcvtzs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T2D, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_fcvtzs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ D);
    }
  
#line 37832 "ad_aarch64.cpp"
  }
}

void vcvtDtoF_64bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4129 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // 2D to 2F
    __ fcvtn(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T2S, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ T2D);
  
#line 37849 "ad_aarch64.cpp"
  }
}

void vcvtDtoF_gt64bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4142 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_fcvt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ S, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ D);
    __ sve_vector_narrow(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ S,
                         opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, __ D, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */);
  
#line 37870 "ad_aarch64.cpp"
  }
}

void replicateBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4158 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ B, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    }
  
#line 37892 "ad_aarch64.cpp"
  }
}

void replicateSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4173 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ H, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    }
  
#line 37914 "ad_aarch64.cpp"
  }
}

void replicateINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4188 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ S, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    }
  
#line 37936 "ad_aarch64.cpp"
  }
}

void replicateLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4203 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    }
  
#line 37958 "ad_aarch64.cpp"
  }
}

void replicateFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4218 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_cpy(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ S, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 37980 "ad_aarch64.cpp"
  }
}

void replicateDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4233 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_cpy(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 38002 "ad_aarch64.cpp"
  }
}

void replicateI_imm_le128bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4253 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int imm = (int)opnd_array(1)->constant();
    if (type2aelembytes(bt) == 1) {
      // Refine imm for B
      imm = imm & 0xff;
    } else if (type2aelembytes(bt) == 2) {
      // Refine imm for S
      imm = imm & 0xffff;
    }
    __ mov(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), imm);
  
#line 38027 "ad_aarch64.cpp"
  }
}

void replicateI_imm_le128b_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4253 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int imm = (int)opnd_array(1)->constant();
    if (type2aelembytes(bt) == 1) {
      // Refine imm for B
      imm = imm & 0xff;
    } else if (type2aelembytes(bt) == 2) {
      // Refine imm for S
      imm = imm & 0xffff;
    }
    __ mov(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), imm);
  
#line 38052 "ad_aarch64.cpp"
  }
}

void replicateI_imm_le128b_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4253 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int imm = (int)opnd_array(1)->constant();
    if (type2aelembytes(bt) == 1) {
      // Refine imm for B
      imm = imm & 0xff;
    } else if (type2aelembytes(bt) == 2) {
      // Refine imm for S
      imm = imm & 0xffff;
    }
    __ mov(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), imm);
  
#line 38077 "ad_aarch64.cpp"
  }
}

void replicateB_imm8_gt128bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4272 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ B, (int)(opnd_array(1)->constant()));
  
#line 38094 "ad_aarch64.cpp"
  }
}

void replicateS_imm8_gt128bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4283 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ H, (int)(opnd_array(1)->constant()));
  
#line 38111 "ad_aarch64.cpp"
  }
}

void replicateI_imm8_gt128bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4294 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ S, (int)(opnd_array(1)->constant()));
  
#line 38128 "ad_aarch64.cpp"
  }
}

void replicateL_imm_128bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4305 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ mov(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T2D, (uint64_t)(opnd_array(1)->constantL()));
  
#line 38144 "ad_aarch64.cpp"
  }
}

void replicateL_imm8_gt128bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4315 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_dup(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, (int)(opnd_array(1)->constantL()));
  
#line 38161 "ad_aarch64.cpp"
  }
}

void insertI_le128bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4333 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (opnd_array(0)->as_FloatRegister(ra_,this)/* dst */!= opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */) {
      __ orr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
    __ mov(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt),
           (int)(opnd_array(3)->constant()), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 38186 "ad_aarch64.cpp"
  }
}

void insertI_index_lt32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4356 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_index(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */, size, -16, 1);
    __ sve_cmp(Assembler::EQ, opnd_array(5)->as_PRegister(ra_,this,idx5)/* pgtmp */, size, ptrue,
               opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */, (int)(opnd_array(3)->constant()) - 16);
    if (opnd_array(0)->as_FloatRegister(ra_,this)/* dst */!= opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */) {
      __ sve_orr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
    __ sve_cpy(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, size, opnd_array(5)->as_PRegister(ra_,this,idx5)/* pgtmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 38215 "ad_aarch64.cpp"
  }
}

void insertI_index_ge32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4380 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_index(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp1 */, size, 0, 1);
    __ sve_dup(opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp2 */, size, (int)(opnd_array(3)->constant()));
    __ sve_cmp(Assembler::EQ, opnd_array(6)->as_PRegister(ra_,this,idx6)/* pgtmp */, size, ptrue,
               opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp2 */);
    if (opnd_array(0)->as_FloatRegister(ra_,this)/* dst */!= opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */) {
      __ sve_orr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
    __ sve_cpy(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, size, opnd_array(6)->as_PRegister(ra_,this,idx6)/* pgtmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 38246 "ad_aarch64.cpp"
  }
}

void insertL_128bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4403 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    if (opnd_array(0)->as_FloatRegister(ra_,this)/* dst */!= opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */) {
      __ orr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T16B, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
    __ mov(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, (int)(opnd_array(3)->constant()), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 38267 "ad_aarch64.cpp"
  }
}

void insertL_gt128bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4419 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_index(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */, __ D, -16, 1);
    __ sve_cmp(Assembler::EQ, opnd_array(5)->as_PRegister(ra_,this,idx5)/* pgtmp */, __ D, ptrue,
               opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */, (int)(opnd_array(3)->constant()) - 16);
    if (opnd_array(0)->as_FloatRegister(ra_,this)/* dst */!= opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */) {
      __ sve_orr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
    __ sve_cpy(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, opnd_array(5)->as_PRegister(ra_,this,idx5)/* pgtmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 38294 "ad_aarch64.cpp"
  }
}

void insertF_le128bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4440 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */!= opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */) {
      __ orr(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
    __ ins(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, __ S, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* val */, (int)(opnd_array(3)->constant()), 0);
  
#line 38318 "ad_aarch64.cpp"
  }
}

void insertF_index_lt32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4459 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_index(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, __ S, -16, 1);
    __ sve_cmp(Assembler::EQ, opnd_array(5)->as_PRegister(ra_,this,idx5)/* pgtmp */, __ S, ptrue,
               opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, (int)(opnd_array(3)->constant()) - 16);
    __ sve_orr(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    __ sve_cpy(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, __ S, opnd_array(5)->as_PRegister(ra_,this,idx5)/* pgtmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* val */);
  
#line 38343 "ad_aarch64.cpp"
  }
}

void insertF_index_ge32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4477 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_index(opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */, __ S, 0, 1);
    __ sve_dup(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, __ S, (int)(opnd_array(3)->constant()));
    __ sve_cmp(Assembler::EQ, opnd_array(6)->as_PRegister(ra_,this,idx6)/* pgtmp */, __ S, ptrue,
               opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */);
    __ sve_orr(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    __ sve_cpy(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, __ S, opnd_array(6)->as_PRegister(ra_,this,idx6)/* pgtmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* val */);
  
#line 38370 "ad_aarch64.cpp"
  }
}

void insertD_128bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4497 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    if (opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */!= opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */) {
      __ orr(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, __ T16B, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
    __ ins(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, __ D, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* val */, (int)(opnd_array(3)->constant()), 0);
  
#line 38392 "ad_aarch64.cpp"
  }
}

void insertD_gt128bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4513 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_index(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, __ D, -16, 1);
    __ sve_cmp(Assembler::EQ, opnd_array(5)->as_PRegister(ra_,this,idx5)/* pgtmp */, __ D, ptrue,
               opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, (int)(opnd_array(3)->constant()) - 16);
    __ sve_orr(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    __ sve_cpy(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, __ D, opnd_array(5)->as_PRegister(ra_,this,idx5)/* pgtmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* val */);
  
#line 38417 "ad_aarch64.cpp"
  }
}

void extractB_index_lt16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4531 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ smov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ B, (int)(opnd_array(2)->constant()));
  
#line 38434 "ad_aarch64.cpp"
  }
}

void extractB_index_ge16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4542 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_extract_integral(opnd_array(0)->as_Register(ra_,this)/* dst */, T_BYTE, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
                            (int)(opnd_array(2)->constant()), opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */);
  
#line 38454 "ad_aarch64.cpp"
  }
}

void extractS_index_lt8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4556 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ smov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ H, (int)(opnd_array(2)->constant()));
  
#line 38471 "ad_aarch64.cpp"
  }
}

void extractS_index_ge8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4567 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_extract_integral(opnd_array(0)->as_Register(ra_,this)/* dst */, T_SHORT, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
                            (int)(opnd_array(2)->constant()), opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */);
  
#line 38491 "ad_aarch64.cpp"
  }
}

void extractI_index_lt4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4581 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ S, (int)(opnd_array(2)->constant()));
  
#line 38508 "ad_aarch64.cpp"
  }
}

void extractI_index_ge4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4592 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_extract_integral(opnd_array(0)->as_Register(ra_,this)/* dst */, T_INT, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
                            (int)(opnd_array(2)->constant()), opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */);
  
#line 38528 "ad_aarch64.cpp"
  }
}

void extractL_index_lt2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4606 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ D, (int)(opnd_array(2)->constant()));
  
#line 38545 "ad_aarch64.cpp"
  }
}

void extractL_index_ge2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4617 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    __ sve_extract_integral(opnd_array(0)->as_Register(ra_,this)/* dst */, T_LONG, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
                            (int)(opnd_array(2)->constant()), opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */);
  
#line 38565 "ad_aarch64.cpp"
  }
}

void extractFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4631 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    int index = (int)opnd_array(2)->constant();
    if (index == 0) {
      __ fmovs(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else if (index < 4) {
      __ ins(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, __ S, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 0, index);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_orr(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      __ sve_ext(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, index << 2);
    }
  
#line 38592 "ad_aarch64.cpp"
  }
}

void extractDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4652 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    int index = (int)opnd_array(2)->constant();
    if (index == 0) {
      __ fmovd(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else if (index < 2) {
      __ ins(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, __ D, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 0, index);
    } else {
      assert(UseSVE > 0, "must be sve");
      __ sve_orr(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      __ sve_ext(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, index << 3);
    }
  
#line 38619 "ad_aarch64.cpp"
  }
}

void vloadmask_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4677 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    if (bt == T_BYTE) {
      uint length_in_bytes = Matcher::vector_length_in_bytes(this);
      __ negr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
              opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    } else {
      __ uxtl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T8H, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ T8B);
      if (type2aelembytes(bt) >= 4) {
        __ uxtl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T4S, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T4H);
      }
      if (type2aelembytes(bt) == 8) {
        __ uxtl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T2D, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T2S);
      }
      __ negr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
    }
  
#line 38649 "ad_aarch64.cpp"
  }
}

void vloadmaskB_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4702 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_cmp(Assembler::NE, opnd_array(0)->as_PRegister(ra_,this)/* dst */, __ B,
               ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 0);
  
#line 38666 "ad_aarch64.cpp"
  }
}

void vloadmask_extend_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4714 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_vector_extend(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, size, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ B);
    __ sve_cmp(Assembler::NE, opnd_array(0)->as_PRegister(ra_,this)/* dst */, size, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, 0);
  
#line 38686 "ad_aarch64.cpp"
  }
}

void vloadmaskB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4728 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_cmp(Assembler::NE, opnd_array(0)->as_PRegister(ra_,this)/* dst */, __ B,
               opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 0);
  
#line 38704 "ad_aarch64.cpp"
  }
}

void vloadmask_extend_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4740 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_vector_extend(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, size, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ B);
    __ sve_cmp(Assembler::NE, opnd_array(0)->as_PRegister(ra_,this)/* dst */, size,
               opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, 0);
  
#line 38726 "ad_aarch64.cpp"
  }
}

void vstoremaskB_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4756 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    assert(length_in_bytes == 8 || length_in_bytes == 16, "must be");
    __ negr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 38746 "ad_aarch64.cpp"
  }
}

void vstoremask_narrow_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4769 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    int esize = (int)opnd_array(2)->constant();
    if (esize == 2) {
      __ xtn(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T8B, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ T8H);
    } else if (esize == 4) {
      __ xtn(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T4H, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ T4S);
      __ xtn(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T8B, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T8H);
    } else {
      assert(esize == 8, "must be");
      __ xtn(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T2S, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ T2D);
      __ xtn(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T4H, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T4S);
      __ xtn(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T8B, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T8H);
    }
    __ negr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T8B, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
  
#line 38775 "ad_aarch64.cpp"
  }
}

void vstoremaskB_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4793 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_cpy(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ B, opnd_array(1)->as_PRegister(ra_,this,idx1)/* src */, 1, false);
  
#line 38792 "ad_aarch64.cpp"
  }
}

void vstoremask_narrow_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4804 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    Assembler::SIMD_RegVariant size = __ elemBytes_to_regVariant((int)opnd_array(2)->constant());
    __ sve_cpy(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, size, opnd_array(1)->as_PRegister(ra_,this,idx1)/* src */, 1, false);
    __ sve_vector_narrow(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, __ B,
                         opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, size, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 38814 "ad_aarch64.cpp"
  }
}

void vloadmask_loadVNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4822 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // Load mask values which are boolean type, and extend them to the
    // defined vector element type. Convert the vector to predicate.
    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), false, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */,
                          ptrue, T_BOOLEAN, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
    __ sve_cmp(Assembler::NE, opnd_array(0)->as_PRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt),
               ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, 0);
  
#line 38840 "ad_aarch64.cpp"
  }
}

void vloadmask_loadV_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4845 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // Load valid mask values which are boolean type, and extend them to the
    // defined vector element type. Convert the vector to predicate.
    BasicType bt = Matcher::vector_element_basic_type(this);
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), false, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */,
                          opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, T_BOOLEAN, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
    __ sve_cmp(Assembler::NE, opnd_array(0)->as_PRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt),
               opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, 0);
  
#line 38865 "ad_aarch64.cpp"
  }
}

void vloadmask_loadVMaskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4865 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // Load mask values which are boolean type, and extend them to the
    // defined vector element type. Convert the vector to predicate.
    //
    // Note that we cannot use "pg" here, since it is the predicate used
    // for the vector load with boolean type. But the predicate used in
    // the extending "sve_ld1b" is based on the final extended vector type,
    // which is the full-sized predicate (ptrue) used in VectorLoadMask.
    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), false, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */,
                          ptrue, T_BOOLEAN, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
    __ sve_cmp(Assembler::NE, opnd_array(0)->as_PRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt),
               ptrue, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, 0);
  
#line 38897 "ad_aarch64.cpp"
  }
}

void vloadmask_loadVMasked_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4893 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // Load valid mask values which are boolean type, and extend them to the
    // defined vector element type. Convert the vector to predicate.
    //
    // Note that we cannot use "pg1" here, since it is the predicate used
    // for the vector load with boolean type. But the predicate used in
    // the extending "sve_ld1b" is based on the final extended vector type,
    // which is the "pg2" used in VectorLoadMask.
    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), false, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */,
                          opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg2 */, T_BOOLEAN, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
    __ sve_cmp(Assembler::NE, opnd_array(0)->as_PRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg2 */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */, 0);
  
#line 38930 "ad_aarch64.cpp"
  }
}

void storeV_vstoremaskNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// esize
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4922 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // Convert the valid src predicate to vector, and store the vector elements
    // as boolean values.
    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    assert(type2aelembytes(bt) == (int)opnd_array(3)->constant(), "unsupported type");
    Assembler::SIMD_RegVariant size = __ elemBytes_to_regVariant(opnd_array(3)->constant());
    __ sve_cpy(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */, size, opnd_array(2)->as_PRegister(ra_,this,idx2)/* src */, 1, false);
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), true, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */,
                          ptrue, T_BOOLEAN, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 38957 "ad_aarch64.cpp"
  }
}

void storeV_vstoremask_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// esize
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4944 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // Convert the valid src predicate to vector, and store the vector elements
    // as boolean values.
    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_cpy(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */, size, opnd_array(2)->as_PRegister(ra_,this,idx2)/* src */, 1, false);
    __ sve_gen_mask_imm(opnd_array(5)->as_PRegister(ra_,this,idx5)/* pgtmp */, bt, Matcher::vector_length(this, opnd_array(2)));
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), true, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */,
                          opnd_array(5)->as_PRegister(ra_,this,idx5)/* pgtmp */, T_BOOLEAN, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 38985 "ad_aarch64.cpp"
  }
}

void storeVMasked_vstoremaskNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// esize
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4965 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // Convert the valid src predicate to vector, and store the vector elements
    // as boolean values.
    //
    // Note that we cannot use "pg" here, since it is the predicate used
    // for the vector store with boolean type. But the predicate used in
    // the narrowing "sve_st1b" is based on the "src" vector type, which
    // is the full-sized predicate (ptrue) here.
    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    assert(type2aelembytes(bt) == (int)opnd_array(3)->constant(), "unsupported type.");
    Assembler::SIMD_RegVariant size = __ elemBytes_to_regVariant(opnd_array(3)->constant());
    __ sve_cpy(opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */, size, opnd_array(2)->as_PRegister(ra_,this,idx2)/* src */, 1, false);
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), true, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */,
                          ptrue, T_BOOLEAN, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 39018 "ad_aarch64.cpp"
  }
}

void storeVMasked_vstoremask_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// esize
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4992 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // Convert the valid src predicate to vector, and store the vector elements
    // as boolean values.
    //
    // Note that we cannot use "pg" here, since it is the predicate used for the
    // vector store with boolean type. But the predicate used in the narrowing
    // "sve_st1b" is based on the "src" vector type, which needed to be generated
    // here.
    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_cpy(opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */, size, opnd_array(2)->as_PRegister(ra_,this,idx2)/* src */, 1, false);
    __ sve_gen_mask_imm(opnd_array(6)->as_PRegister(ra_,this,idx6)/* pgtmp */, bt, Matcher::vector_length(this, opnd_array(2)));
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), true, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */,
                          opnd_array(6)->as_PRegister(ra_,this,idx6)/* pgtmp */, T_BOOLEAN, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 39052 "ad_aarch64.cpp"
  }
}

void vmask_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// pn
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pm
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5019 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_and(opnd_array(0)->as_PRegister(ra_,this)/* pd */, ptrue, opnd_array(1)->as_PRegister(ra_,this,idx1)/* pn */, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pm */);
  
#line 39069 "ad_aarch64.cpp"
  }
}

void vmask_orNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// pn
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pm
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5029 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_orr(opnd_array(0)->as_PRegister(ra_,this)/* pd */, ptrue, opnd_array(1)->as_PRegister(ra_,this,idx1)/* pn */, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pm */);
  
#line 39086 "ad_aarch64.cpp"
  }
}

void vmask_xorNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// pn
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pm
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5039 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_eor(opnd_array(0)->as_PRegister(ra_,this)/* pd */, ptrue, opnd_array(1)->as_PRegister(ra_,this,idx1)/* pn */, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pm */);
  
#line 39103 "ad_aarch64.cpp"
  }
}

void vmask_and_notINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// pn
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pm
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5049 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_bic(opnd_array(0)->as_PRegister(ra_,this)/* pd */, ptrue, opnd_array(1)->as_PRegister(ra_,this,idx1)/* pn */, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pm */);
  
#line 39121 "ad_aarch64.cpp"
  }
}

void vmask_and_notLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// pn
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pm
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5059 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_bic(opnd_array(0)->as_PRegister(ra_,this)/* pd */, ptrue, opnd_array(1)->as_PRegister(ra_,this,idx1)/* pn */, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pm */);
  
#line 39139 "ad_aarch64.cpp"
  }
}

void vmaskcmp_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cond
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5073 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    __ neon_compare(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, bt, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */,
                    opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, (int)(opnd_array(3)->constant()),
                    /* isQ */ length_in_bytes == 16);
  
#line 39161 "ad_aarch64.cpp"
  }
}

void vmaskcmp_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cond
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5088 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_compare(opnd_array(0)->as_PRegister(ra_,this)/* dst */, bt, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */,
                   opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, (int)(opnd_array(3)->constant()));
  
#line 39183 "ad_aarch64.cpp"
  }
}

void vmaskcmp_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cond
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5104 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_compare(opnd_array(0)->as_PRegister(ra_,this)/* dst */, bt, opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */,
                   opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, (int)(opnd_array(3)->constant()));
  
#line 39204 "ad_aarch64.cpp"
  }
}

void vmaskcast_same_esize_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  // User did not define which encode class to use.
}

void vmaskcast_extend_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5130 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType dst_bt = Matcher::vector_element_basic_type(this);
    if (is_floating_point_type(dst_bt)) {
      dst_bt = (dst_bt == T_FLOAT) ? T_INT : T_LONG;
    }
    uint length_in_bytes_dst = Matcher::vector_length_in_bytes(this);
    BasicType src_bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    if (is_floating_point_type(src_bt)) {
      src_bt = (src_bt == T_FLOAT) ? T_INT : T_LONG;
    }
    __ neon_vector_extend(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, dst_bt, length_in_bytes_dst,
                          opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, src_bt);
  
#line 39238 "ad_aarch64.cpp"
  }
}

void vmaskcast_narrow_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5151 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType dst_bt = Matcher::vector_element_basic_type(this);
    if (is_floating_point_type(dst_bt)) {
      dst_bt = (dst_bt == T_FLOAT) ? T_INT : T_LONG;
    }
    BasicType src_bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    if (is_floating_point_type(src_bt)) {
      src_bt = (src_bt == T_FLOAT) ? T_INT : T_LONG;
    }
    uint length_in_bytes_src = Matcher::vector_length_in_bytes(this, opnd_array(1));
    __ neon_vector_narrow(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, dst_bt,
                          opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, src_bt, length_in_bytes_src);
  
#line 39264 "ad_aarch64.cpp"
  }
}

void vmaskcast_same_esize_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  // User did not define which encode class to use.
}

void vmaskcast_extend_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5182 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes_dst = Matcher::vector_length_in_bytes(this);
    uint length_in_bytes_src = Matcher::vector_length_in_bytes(this, opnd_array(1));
    assert(length_in_bytes_dst == 2 * length_in_bytes_src ||
           length_in_bytes_dst == 4 * length_in_bytes_src ||
           length_in_bytes_dst == 8 * length_in_bytes_src, "invalid vector length");
    __ sve_vmaskcast_extend(opnd_array(0)->as_PRegister(ra_,this)/* dst */, opnd_array(1)->as_PRegister(ra_,this,idx1)/* src */,
                            length_in_bytes_dst, length_in_bytes_src);
  
#line 39294 "ad_aarch64.cpp"
  }
}

void vmaskcast_narrow_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5199 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes_dst = Matcher::vector_length_in_bytes(this);
    uint length_in_bytes_src = Matcher::vector_length_in_bytes(this, opnd_array(1));
    assert(length_in_bytes_dst * 2 == length_in_bytes_src ||
           length_in_bytes_dst * 4 == length_in_bytes_src ||
           length_in_bytes_dst * 8 == length_in_bytes_src, "invalid vector length");
    __ sve_vmaskcast_narrow(opnd_array(0)->as_PRegister(ra_,this)/* dst */, opnd_array(1)->as_PRegister(ra_,this,idx1)/* src */,
                            length_in_bytes_dst, length_in_bytes_src);
  
#line 39316 "ad_aarch64.cpp"
  }
}

void vmask_reinterpret_same_esizeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  // User did not define which encode class to use.
}

void vmask_reinterpret_diff_esizeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5231 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType from_bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant from_size = __ elemType_to_regVariant(from_bt);
    BasicType to_bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant to_size = __ elemType_to_regVariant(to_bt);
    __ sve_cpy(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, from_size, opnd_array(1)->as_PRegister(ra_,this,idx1)/* src */, -1, false);
    __ sve_cmp(Assembler::EQ, opnd_array(0)->as_PRegister(ra_,this)/* dst */, to_size, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, -1);
  
#line 39346 "ad_aarch64.cpp"
  }
}

void vmask_truecount_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5251 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // Input "src" is a vector of boolean represented as bytes with
    // 0x00/0x01 as element values.
    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    assert(bt == T_BOOLEAN, "unsupported type");
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(1));
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, length_in_bytes == 16 ? __ T16B : __ T8B,
            opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ B, 0);
  
#line 39370 "ad_aarch64.cpp"
  }
}

void vmask_truecount_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5268 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    __ sve_cntp(opnd_array(0)->as_Register(ra_,this)/* dst */, __ elemType_to_regVariant(bt),
                ptrue, opnd_array(1)->as_PRegister(ra_,this,idx1)/* src */);
  
#line 39388 "ad_aarch64.cpp"
  }
}

void vmask_firsttrue_lt8eNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5284 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // Returns the index of the first active lane of the
    // vector mask, or VLENGTH if no lane is active.
    //
    // Input "src" is a vector of boolean represented as
    // bytes with 0x00/0x01 as element values.
    //
    // Computed by reversing the bits and counting the leading
    // zero bytes.
    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    assert(bt == T_BOOLEAN, "unsupported type");
    __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    __ rbit(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ clz(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ lsrw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, 3);
    __ movw(rscratch1, Matcher::vector_length(this, opnd_array(1)));
    __ cmpw(opnd_array(0)->as_Register(ra_,this)/* dst */, rscratch1);
    __ cselw(opnd_array(0)->as_Register(ra_,this)/* dst */, rscratch1, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::GE);
  
#line 39420 "ad_aarch64.cpp"
  }
}

void vmask_firsttrue_8or16eNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5311 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // Returns the index of the first active lane of the
    // vector mask, or VLENGTH if no lane is active.
    //
    // Input "src" is a vector of boolean represented as
    // bytes with 0x00/0x01 as element values.
    //
    // Computed by reversing the bits and counting the leading
    // zero bytes.

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    assert(bt == T_BOOLEAN, "unsupported type");
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(1));
    if (length_in_bytes == 8) {
      __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      __ rbit(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
      __ clz(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
      __ lsrw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, 3);
    } else {
      assert(length_in_bytes == 16, "must be");
      Label FIRST_TRUE_INDEX;

      // Try to compute the result from lower 64 bits.
      __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      __ movw(rscratch1, zr);
      __ cbnz(opnd_array(0)->as_Register(ra_,this)/* dst */, FIRST_TRUE_INDEX);

      // Compute the result from the higher 64 bits.
      __ fmovhid(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      __ movw(rscratch1, 8);

      // Reverse the bits and count the leading zero bytes.
      __ bind(FIRST_TRUE_INDEX);
      __ rbit(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
      __ clz(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
      __ addw(opnd_array(0)->as_Register(ra_,this)/* dst */, rscratch1, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LSR, 3);
    }
  
#line 39471 "ad_aarch64.cpp"
  }
}

void vmask_firsttrue_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5360 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(1));
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_brkb(opnd_array(2)->as_PRegister(ra_,this,idx2)/* ptmp */, ptrue, opnd_array(1)->as_PRegister(ra_,this,idx1)/* src */, false);
    __ sve_cntp(opnd_array(0)->as_Register(ra_,this)/* dst */, __ elemType_to_regVariant(bt), ptrue, opnd_array(2)->as_PRegister(ra_,this,idx2)/* ptmp */);
  
#line 39492 "ad_aarch64.cpp"
  }
}

void vmask_firsttrue_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5375 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    __ sve_brkb(opnd_array(3)->as_PRegister(ra_,this,idx3)/* ptmp */, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_PRegister(ra_,this,idx1)/* src */, false);
    __ sve_cntp(opnd_array(0)->as_Register(ra_,this)/* dst */, __ elemType_to_regVariant(bt), ptrue, opnd_array(3)->as_PRegister(ra_,this,idx3)/* ptmp */);
  
#line 39512 "ad_aarch64.cpp"
  }
}

void vmask_lasttrue_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5389 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // Returns the index of the last active lane of the
    // vector mask, or -1 if no lane is active.
    //
    // Input "src" is a vector of boolean represented as
    // bytes with 0x00/0x01 as element values.

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    assert(bt == T_BOOLEAN, "unsupported type");
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(1));
    if (length_in_bytes <= 8) {
      // Computed by counting the leading zero bytes and
      // subtracting it by 7 (VLENGTH - 1).
      __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      __ clz(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
      __ movw(rscratch1, 7);
      __ subw(opnd_array(0)->as_Register(ra_,this)/* dst */, rscratch1, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LSR, 3);
    } else {
      assert(length_in_bytes == 16, "must be");
      Label LAST_TRUE_INDEX;

      // Try to compute the result from higher 64 bits.
      __ fmovhid(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      __ movw(rscratch1, 16 - 1);
      __ cbnz(opnd_array(0)->as_Register(ra_,this)/* dst */, LAST_TRUE_INDEX);

      // Compute the result from the lower 64 bits.
      __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      __ movw(rscratch1, 8 - 1);

      // Count the leading zero bytes and subtract it by 15 (VLENGTH - 1).
      __ bind(LAST_TRUE_INDEX);
      __ clz(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
      __ subw(opnd_array(0)->as_Register(ra_,this)/* dst */, rscratch1, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LSR, 3);
    }
  
#line 39561 "ad_aarch64.cpp"
  }
}

void vmask_lasttrue_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5433 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    __ sve_vmask_lasttrue(opnd_array(0)->as_Register(ra_,this)/* dst */, bt, opnd_array(1)->as_PRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_PRegister(ra_,this,idx2)/* ptmp */);
  
#line 39579 "ad_aarch64.cpp"
  }
}

void vmask_tolong_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5446 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // Input "src" is a vector of boolean represented as
    // bytes with 0x00/0x01 as element values.

    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(1));
    if (length_in_bytes <= 8) {
      __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      __ bytemask_compress(opnd_array(0)->as_Register(ra_,this)/* dst */);
    } else {
      assert(length_in_bytes == 16, "must be");
      __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ D, 0);
      __ umov(rscratch1, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ D, 1);
      __ bytemask_compress(opnd_array(0)->as_Register(ra_,this)/* dst */);
      __ bytemask_compress(rscratch1);
      __ orr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, rscratch1, Assembler::LSL, 8);
    }
  
#line 39609 "ad_aarch64.cpp"
  }
}

void vmask_tolong_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5471 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_vmask_tolong(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_PRegister(ra_,this,idx1)/* src */,
                        Matcher::vector_element_basic_type(this, opnd_array(1)),
                        Matcher::vector_length(this, opnd_array(1)),
                        opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp1 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp2 */);
  
#line 39630 "ad_aarch64.cpp"
  }
}

void vmask_fromlongNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5486 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_vmask_fromlong(opnd_array(0)->as_PRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */,
                          Matcher::vector_element_basic_type(this),
                          Matcher::vector_length(this),
                          opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp1 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp2 */);
  
#line 39651 "ad_aarch64.cpp"
  }
}

void vmaskAll_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5504 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    int con = (int)opnd_array(1)->constant();
    if (con == 0) {
      __ sve_pfalse(opnd_array(0)->as_PRegister(ra_,this)/* dst */);
    } else {
      assert(con == -1, "invalid constant value for mask");
      BasicType bt = Matcher::vector_element_basic_type(this);
      __ sve_gen_mask_imm(opnd_array(0)->as_PRegister(ra_,this)/* dst */, bt, Matcher::vector_length(this));
    }
  
#line 39674 "ad_aarch64.cpp"
  }
}

void vmaskAllINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5522 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_dup(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, size, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ sve_cmp(Assembler::NE, opnd_array(0)->as_PRegister(ra_,this)/* dst */, size, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, 0);
  
#line 39696 "ad_aarch64.cpp"
  }
}

void vmaskAllI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5538 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_dup(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, size, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ sve_cmp(Assembler::NE, opnd_array(0)->as_PRegister(ra_,this)/* dst */, size,
               opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, 0);
  
#line 39718 "ad_aarch64.cpp"
  }
}

void vmaskAll_immLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5553 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    long con = (long)opnd_array(1)->constantL();
    if (con == 0) {
      __ sve_pfalse(opnd_array(0)->as_PRegister(ra_,this)/* dst */);
    } else {
      assert(con == -1, "invalid constant value for mask");
      BasicType bt = Matcher::vector_element_basic_type(this);
      __ sve_gen_mask_imm(opnd_array(0)->as_PRegister(ra_,this)/* dst */, bt, Matcher::vector_length(this));
    }
  
#line 39741 "ad_aarch64.cpp"
  }
}

void vmaskAllLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5571 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_dup(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, size, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ sve_cmp(Assembler::NE, opnd_array(0)->as_PRegister(ra_,this)/* dst */, size, ptrue, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, 0);
  
#line 39763 "ad_aarch64.cpp"
  }
}

void vmaskAllL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5587 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_dup(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, size, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ sve_cmp(Assembler::NE, opnd_array(0)->as_PRegister(ra_,this)/* dst */, size,
               opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, 0);
  
#line 39785 "ad_aarch64.cpp"
  }
}

void vmask_gen_INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5604 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_whilelow(opnd_array(0)->as_PRegister(ra_,this)/* pd */, __ elemType_to_regVariant(bt), zr, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 39802 "ad_aarch64.cpp"
  }
}

void vmask_gen_LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5616 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_whilelo(opnd_array(0)->as_PRegister(ra_,this)/* pd */, __ elemType_to_regVariant(bt), zr, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 39819 "ad_aarch64.cpp"
  }
}

void vmask_gen_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5628 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_gen_mask_imm(opnd_array(0)->as_PRegister(ra_,this)/* pd */, bt, (uint)(opnd_array(1)->constantL()));
  
#line 39836 "ad_aarch64.cpp"
  }
}

void vpopcountINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5642 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (bt == T_BYTE) {
      if (VM_Version::use_neon_for_vector(length_in_bytes)) {
        __ cnt(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
               opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      } else {
        assert(UseSVE > 0, "must be sve");
        __ sve_cnt(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ B, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      }
    } else {
      assert(bt == T_SHORT || bt == T_INT, "unsupported");
      if (UseSVE == 0) {
        assert(length_in_bytes == 8 || length_in_bytes == 16, "unsupported");
        __ cnt(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
               opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        __ uaddlp(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
                  opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
        if (bt == T_INT) {
          __ uaddlp(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T8H : __ T4H,
                    opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
        }
      } else {
        __ sve_cnt(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt),
                   ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      }
    }
  
#line 39878 "ad_aarch64.cpp"
  }
}

void vpopcountLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5679 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    if (UseSVE == 0) {
      __ cnt(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T16B, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      __ uaddlp(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T16B, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
      __ uaddlp(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T8H, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
      __ uaddlp(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T4S, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
    } else {
      __ sve_cnt(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
  
#line 39901 "ad_aarch64.cpp"
  }
}

void vpopcountI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5698 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_cnt(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 39920 "ad_aarch64.cpp"
  }
}

void vpopcountL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5710 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_cnt(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ D,
               opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 39938 "ad_aarch64.cpp"
  }
}

void vblend_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5723 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    assert(length_in_bytes == 8 || length_in_bytes == 16, "must be");
    __ bsl(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
           opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */);
  
#line 39959 "ad_aarch64.cpp"
  }
}

void vblend_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5736 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_sel(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt),
               opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */);
  
#line 39979 "ad_aarch64.cpp"
  }
}

void vcmove_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// copnd
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cond
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5754 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    assert(length_in_bytes == 8 || length_in_bytes == 16, "must be");
    __ neon_compare(opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* dst */, bt, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */,
                    opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src2 */, (int)(opnd_array(2)->constant()),
                    /* isQ */ length_in_bytes == 16);
    __ bsl(opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
           opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */);
  
#line 40006 "ad_aarch64.cpp"
  }
}

void vcmove_neon_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// copnd
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cond
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5754 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    assert(length_in_bytes == 8 || length_in_bytes == 16, "must be");
    __ neon_compare(opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* dst */, bt, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */,
                    opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src2 */, (int)(opnd_array(2)->constant()),
                    /* isQ */ length_in_bytes == 16);
    __ bsl(opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
           opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */);
  
#line 40033 "ad_aarch64.cpp"
  }
}

void vcmove_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// copnd
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cond
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5774 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    __ sve_compare(opnd_array(5)->as_PRegister(ra_,this,idx5)/* pgtmp */, bt, ptrue, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */,
                   opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src2 */, (int)(opnd_array(2)->constant()));
    __ sve_sel(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt),
               opnd_array(5)->as_PRegister(ra_,this,idx5)/* pgtmp */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */);
  
#line 40059 "ad_aarch64.cpp"
  }
}

void vcmove_sve_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// copnd
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cond
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5774 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    __ sve_compare(opnd_array(5)->as_PRegister(ra_,this,idx5)/* pgtmp */, bt, ptrue, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */,
                   opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src2 */, (int)(opnd_array(2)->constant()));
    __ sve_sel(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt),
               opnd_array(5)->as_PRegister(ra_,this,idx5)/* pgtmp */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src2 */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* src1 */);
  
#line 40085 "ad_aarch64.cpp"
  }
}

void vround_le128bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5797 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ vector_round_neon(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
                         opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp1 */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp2 */,
                         opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp3 */, get_arrangement(this));
  
#line 40107 "ad_aarch64.cpp"
  }
}

void vround_le128b_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5797 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ vector_round_neon(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
                         opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp1 */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp2 */,
                         opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp3 */, get_arrangement(this));
  
#line 40129 "ad_aarch64.cpp"
  }
}

void vround_gt128bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5812 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this);
    __ vector_round_sve(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
                        opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp1 */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp2 */,
                        opnd_array(5)->as_PRegister(ra_,this,idx5)/* pgtmp */, __ elemType_to_regVariant(bt));
  
#line 40153 "ad_aarch64.cpp"
  }
}

void vround_gt128b_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5812 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this);
    __ vector_round_sve(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
                        opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp1 */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp2 */,
                        opnd_array(5)->as_PRegister(ra_,this,idx5)/* pgtmp */, __ elemType_to_regVariant(bt));
  
#line 40177 "ad_aarch64.cpp"
  }
}

void vroundDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rmode
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5830 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      switch (opnd_array(2)->constant()) {
        case RoundDoubleModeNode::rmode_rint:
          __ frintn(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T2D, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
          break;
        case RoundDoubleModeNode::rmode_floor:
          __ frintm(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T2D, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
          break;
        case RoundDoubleModeNode::rmode_ceil:
          __ frintp(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T2D, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
          break;
        default:
          assert(false, "unsupported");
          ShouldNotReachHere();
      }
    } else {
      assert(UseSVE > 0, "must be sve");
      switch (opnd_array(2)->constant()) {
        case RoundDoubleModeNode::rmode_rint:
          __ sve_frintn(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
          break;
        case RoundDoubleModeNode::rmode_floor:
          __ sve_frintm(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
          break;
        case RoundDoubleModeNode::rmode_ceil:
          __ sve_frintp(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
          break;
        default:
          assert(false, "unsupported");
          ShouldNotReachHere();
      }
    }
  
#line 40226 "ad_aarch64.cpp"
  }
}

void vtest_anytrue_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5878 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // No need to use src2.
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(1));
    assert(length_in_bytes == 8 || length_in_bytes == 16, "must be");
    __ addv(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, length_in_bytes == 16 ? __ T16B : __ T8B, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */);
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, __ B, 0);
    __ cmpw(opnd_array(0)->as_Register(ra_,this)/* dst */, zr);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
  
#line 40250 "ad_aarch64.cpp"
  }
}

void vtest_anytrue_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5896 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // "src2" is not used for sve.
    __ sve_ptest(ptrue, opnd_array(1)->as_PRegister(ra_,this,idx1)/* src1 */);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
  
#line 40269 "ad_aarch64.cpp"
  }
}

void vtest_alltrue_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5912 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // No need to use src2.
    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(1));
    assert(length_in_bytes == 8 || length_in_bytes == 16, "must be");
    __ uminv(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, length_in_bytes == 16 ? __ T16B : __ T8B, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */);
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, __ B, 0);
    __ cmpw(opnd_array(0)->as_Register(ra_,this)/* dst */, 0xff);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::EQ);
  
#line 40293 "ad_aarch64.cpp"
  }
}

void vtest_alltrue_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5930 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_eors(opnd_array(3)->as_PRegister(ra_,this,idx3)/* ptmp */, ptrue, opnd_array(1)->as_PRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_PRegister(ra_,this,idx2)/* src2 */);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::EQ);
  
#line 40312 "ad_aarch64.cpp"
  }
}

void loadshuffleNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5942 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (bt == T_BYTE) {
      if (opnd_array(0)->as_FloatRegister(ra_,this)/* dst */!= opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */) {
        if (VM_Version::use_neon_for_vector(length_in_bytes)) {
          __ orr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
                 opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        } else {
          assert(UseSVE > 0, "must be sve");
          __ sve_orr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        }
      }
    } else {
      if (VM_Version::use_neon_for_vector(length_in_bytes)) {
        // 4S/8S, 4I, 4F
        __ uxtl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T8H, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ T8B);
        if (type2aelembytes(bt) == 4) {
          __ uxtl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T4S, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ T4H);
        }
      } else {
        assert(UseSVE > 0, "must be sve");
        __ sve_vector_extend(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */,  __ elemType_to_regVariant(bt),
                             opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ B);
      }
    }
  
#line 40352 "ad_aarch64.cpp"
  }
}

void rearrange_HS_neonNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6002 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    if (bt == T_SHORT) {
      uint length_in_bytes = Matcher::vector_length_in_bytes(this);
      assert(length_in_bytes == 8 || length_in_bytes == 16, "must be");
      Assembler::SIMD_Arrangement size1 = length_in_bytes == 16 ? __ T16B : __ T8B;
      Assembler::SIMD_Arrangement size2 = length_in_bytes == 16 ? __ T8H : __ T4H;
      __ mov(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp1 */, size1, 0x02);
      __ mov(opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp2 */, size2, 0x0100);
      __ mulv(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, size2, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shuffle */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp1 */);
      __ addv(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, size1, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp2 */);
      __ tbl(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, size1, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 1, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */);
    } else {
      assert(bt == T_INT || bt == T_FLOAT, "unsupported type");
      __ mov(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp1 */, __ T16B, 0x04);
      __ mov(opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp2 */, __ T4S, 0x03020100);
      __ mulv(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, __ T4S, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shuffle */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp1 */);
      __ addv(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, __ T16B, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp2 */);
      __ tbl(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, __ T16B, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 1, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */);
    }
  
#line 40390 "ad_aarch64.cpp"
  }
}

void rearrangeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6030 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt_dst = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (bt_dst == T_BYTE && VM_Version::use_neon_for_vector(length_in_bytes)) {
      __ tbl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
             opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 1, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shuffle */);
    } else {
      assert(UseSVE > 0, "must be sve");
      BasicType bt_src = Matcher::vector_element_basic_type(this, opnd_array(1));
      __ sve_tbl(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt_src),
                 opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shuffle */);
    }
  
#line 40417 "ad_aarch64.cpp"
  }
}

void gather_loadSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6053 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_ld1w_gather(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, ptrue,
                       as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* idx */);
 
#line 40437 "ad_aarch64.cpp"
  }
}

void gather_loadDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6068 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_uunpklo(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, __ D, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* idx */);
    __ sve_ld1d_gather(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, ptrue, as_Register(opnd_array(1)->base(ra_,this,idx1)),
                       opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */);
  
#line 40459 "ad_aarch64.cpp"
  }
}

void gather_loadS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6083 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_ld1w_gather(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */,
                       as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* idx */);
  
#line 40478 "ad_aarch64.cpp"
  }
}

void gather_loadD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6096 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_uunpklo(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */, __ D, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* idx */);
    __ sve_ld1d_gather(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_PRegister(ra_,this,idx3)/* pg */,
                       as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 40499 "ad_aarch64.cpp"
  }
}

void scatter_storeSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6111 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_st1w_scatter(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, ptrue,
                        as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* idx */);
  
#line 40520 "ad_aarch64.cpp"
  }
}

void scatter_storeDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6126 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(2));
    assert(length_in_bytes == MaxVectorSize, "invalid vector length");
    __ sve_uunpklo(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */, __ D, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* idx */);
    __ sve_st1d_scatter(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, ptrue,
                        as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp */);
  
#line 40543 "ad_aarch64.cpp"
  }
}

void scatter_storeS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6141 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_st1w_scatter(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */,
                        as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* idx */);
  
#line 40563 "ad_aarch64.cpp"
  }
}

void scatter_storeD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6154 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_uunpklo(opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */, __ D, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* idx */);
    __ sve_st1d_scatter(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, opnd_array(4)->as_PRegister(ra_,this,idx4)/* pg */,
                        as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */);
  
#line 40585 "ad_aarch64.cpp"
  }
}

void vcountLeadingZerosNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6167 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (bt == T_LONG) {
      if (UseSVE == 0) {
        __ umov(rscratch1, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ D, 0);
        __ clz(rscratch1, rscratch1);
        __ mov(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, 0, rscratch1);
        __ umov(rscratch1, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, __ D, 1);
        __ clz(rscratch1, rscratch1);
        __ mov(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, 1, rscratch1);
      } else {
        __ sve_clz(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      }
    } else {
      if (VM_Version::use_neon_for_vector(length_in_bytes)) {
        __ clz(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      } else {
        assert(UseSVE > 0, "must be sve");
        __ sve_clz(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt),
                   ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      }
    }
  
#line 40622 "ad_aarch64.cpp"
  }
}

void vcountLeadingZeros_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6201 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_clz(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 40641 "ad_aarch64.cpp"
  }
}

void vcountTrailingZerosNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6214 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (bt == T_BYTE) {
      if (VM_Version::use_neon_for_vector(length_in_bytes)) {
        __ rbit(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
                opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        __ clz(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
      } else {
        assert(UseSVE > 0, "must be sve");
        __ sve_rbit(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ B, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        __ sve_clz(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ B, ptrue, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
      }
    } else {
      assert(bt == T_SHORT || bt == T_INT || bt == T_LONG, "unsupported type");
      if (UseSVE == 0) {
        assert(length_in_bytes == 8 || length_in_bytes == 16, "unsupported");
        __ neon_reverse_bits(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
                             bt, /* isQ */ length_in_bytes == 16);
        if (bt != T_LONG) {
          __ clz(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, get_arrangement(this), opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
        } else {
          __ umov(rscratch1, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, 0);
          __ clz(rscratch1, rscratch1);
          __ mov(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, 0, rscratch1);
          __ umov(rscratch1, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, 1);
          __ clz(rscratch1, rscratch1);
          __ mov(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ D, 1, rscratch1);
        }
      } else {
        Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
        __ sve_rbit(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, size, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        __ sve_clz(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, size, ptrue, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
      }
    }
  
#line 40690 "ad_aarch64.cpp"
  }
}

void vcountTrailingZeros_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6259 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_rbit(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, size,
                opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
    __ sve_clz(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, size,
               opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 40712 "ad_aarch64.cpp"
  }
}

void vreverseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6275 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (bt == T_BYTE) {
      if (VM_Version::use_neon_for_vector(length_in_bytes)) {
        __ rbit(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
                opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      } else {
        assert(UseSVE > 0, "must be sve");
        __ sve_rbit(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ B, ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      }
    } else {
      assert(bt == T_SHORT || bt == T_INT || bt == T_LONG, "unsupported type");
      if (UseSVE == 0) {
        assert(length_in_bytes == 8 || length_in_bytes == 16, "unsupported");
        __ neon_reverse_bits(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
                             bt, /* isQ */ length_in_bytes == 16);
      } else {
        __ sve_rbit(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt),
                    ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      }
    }
  
#line 40748 "ad_aarch64.cpp"
  }
}

void vreverse_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6308 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_rbit(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
               opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
  
#line 40767 "ad_aarch64.cpp"
  }
}

void vreverseBytesNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6321 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    if (VM_Version::use_neon_for_vector(length_in_bytes)) {
      assert(length_in_bytes == 8 || length_in_bytes == 16, "unsupported");
      if (bt == T_BYTE) {
        if (opnd_array(0)->as_FloatRegister(ra_,this)/* dst */!= opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */) {
          __ orr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, length_in_bytes == 16 ? __ T16B : __ T8B,
                 opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        }
      } else {
        __ neon_reverse_bytes(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
                              bt, /* isQ */ length_in_bytes == 16);
      }
    } else {
      assert(UseSVE > 0, "must be sve");
      if (bt == T_BYTE) {
        if (opnd_array(0)->as_FloatRegister(ra_,this)/* dst */!= opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */) {
          __ sve_orr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
        }
      } else {
        __ sve_revb(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt),
                    ptrue, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
      }
    }
  
#line 40806 "ad_aarch64.cpp"
  }
}

void vreverseBytes_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6356 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    if (bt == T_BYTE) {
      // do nothing
    } else {
      __ sve_revb(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */, __ elemType_to_regVariant(bt),
                  opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* dst_src */);
    }
  
#line 40829 "ad_aarch64.cpp"
  }
}

void populateindexNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6374 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_index(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt),
                 opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (int)(opnd_array(2)->constant()));
  
#line 40848 "ad_aarch64.cpp"
  }
}

void mcompressNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6389 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_cntp(rscratch1, size, ptrue, opnd_array(1)->as_PRegister(ra_,this,idx1)/* pg */);
    __ sve_whilelo(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, zr, rscratch1);
  
#line 40867 "ad_aarch64.cpp"
  }
}

void vcompressNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6403 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_compact(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ elemType_to_regVariant(bt),
                   opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */);
  
#line 40886 "ad_aarch64.cpp"
  }
}

void vcompressBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp4
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// ptmp
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6417 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_compress_byte(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */,
                         opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp1 */,opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp2 */,
                         opnd_array(6)->as_FloatRegister(ra_,this,idx6)/* tmp3 */,opnd_array(7)->as_FloatRegister(ra_,this,idx7)/* tmp4 */,
                         opnd_array(8)->as_PRegister(ra_,this,idx8)/* ptmp */, opnd_array(9)->as_PRegister(ra_,this,idx9)/* pgtmp */);
  
#line 40913 "ad_aarch64.cpp"
  }
}

void vcompressSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6432 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ sve_compress_short(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */,
                          opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp1 */,opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp2 */, opnd_array(6)->as_PRegister(ra_,this,idx6)/* pgtmp */);
  
#line 40935 "ad_aarch64.cpp"
  }
}

void vexpandNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6443 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    // Example input:   src   = 1 2 3 4 5 6 7 8
    //                  pg    = 1 0 0 1 1 0 1 1
    // Expected result: dst   = 4 0 0 5 6 0 7 8

    // The basic idea is to use TBL which can shuffle the elements in the given
    // vector flexibly. HISTCNT + SUB is used to generate the second source input
    // for TBL whose value is used to select the indexed element from src vector.

    BasicType bt = Matcher::vector_element_basic_type(this);
    assert(UseSVE == 2 && !is_subword_type(bt), "unsupported");
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    // dst = 0 0 0 0 0 0 0 0
    __ sve_dup(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, size, 0);
    // dst = 5 0 0 4 3 0 2 1
    __ sve_histcnt(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, size, opnd_array(2)->as_PRegister(ra_,this,idx2)/* pg */,
                   opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */);
    // dst = 4 -1 -1 3 2 -1 1 0
    __ sve_sub(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, size, 1);
    // dst = 4 0 0 5 6 0 7 8
    __ sve_tbl(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, size, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */);
  
#line 40972 "ad_aarch64.cpp"
  }
}

void vsignum_le128bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6478 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ vector_signum_neon(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* zero */,
                          opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* one */, get_arrangement(this));
  
#line 40992 "ad_aarch64.cpp"
  }
}

void vsignum_le128b_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6478 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    __ vector_signum_neon(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* zero */,
                          opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* one */, get_arrangement(this));
  
#line 41012 "ad_aarch64.cpp"
  }
}

void vsignum_gt128bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6491 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this);
    __ vector_signum_sve(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* zero */,
                         opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* one */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */, opnd_array(6)->as_PRegister(ra_,this,idx6)/* pgtmp */,
                         __ elemType_to_regVariant(bt));
  
#line 41037 "ad_aarch64.cpp"
  }
}

void vsignum_gt128b_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6491 "src/hotspot/cpu/aarch64/aarch64_vector.ad"

    assert(UseSVE > 0, "must be sve");
    BasicType bt = Matcher::vector_element_basic_type(this);
    __ vector_signum_sve(opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* zero */,
                         opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* one */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp */, opnd_array(6)->as_PRegister(ra_,this,idx6)/* pgtmp */,
                         __ elemType_to_regVariant(bt));
  
#line 41062 "ad_aarch64.cpp"
  }
}

void compareAndSwapP_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {

#line 31 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 41085 "ad_aarch64.cpp"
  }
}

void compareAndSwapN_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 77 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, /*acquire*/ false, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 41106 "ad_aarch64.cpp"
  }
}

void compareAndSwapPAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {

#line 40 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 41129 "ad_aarch64.cpp"
  }
}

void compareAndSwapNAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 115 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, /*acquire*/ true, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 41150 "ad_aarch64.cpp"
  }
}

void compareAndExchangeN_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 131 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ true, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 41173 "ad_aarch64.cpp"
  }
}

void compareAndExchangeP_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 147 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ true, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 41196 "ad_aarch64.cpp"
  }
}

void compareAndExchangeNAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 164 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ true, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 41219 "ad_aarch64.cpp"
  }
}

void compareAndExchangePAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 181 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ true, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 41242 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapN_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 198 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    // Weak is not currently supported by ShenandoahBarrierSet::cmpxchg_oop
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 41265 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapP_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 215 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    // Weak is not currently supported by ShenandoahBarrierSet::cmpxchg_oop
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 41288 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapNAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 234 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    // Weak is not currently supported by ShenandoahBarrierSet::cmpxchg_oop
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 41311 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapPAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 253 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    // Weak is not currently supported by ShenandoahBarrierSet::cmpxchg_oop
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 41334 "ad_aarch64.cpp"
  }
}

void zLoadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 64 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    const Address ref_addr = mem2address(opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
    __ ldr(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, ref_addr);
    z_load_barrier(_masm, this, ref_addr, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, rscratch2 /* tmp */, barrier_data());
  
#line 41353 "ad_aarch64.cpp"
  }
}

void zLoadPVolatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 84 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    __ ldar(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */);
    z_load_barrier(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, rscratch2 /* tmp */, barrier_data());
  
#line 41371 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 103 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               false /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 false /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 41404 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapP_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 103 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               false /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 false /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 41437 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 135 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               true /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */ );
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 true /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 41470 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapPAcq_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 135 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               true /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */ );
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 true /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 41503 "ad_aarch64.cpp"
  }
}

void zCompareAndExchangePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 165 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               false /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), opnd_array(4)->as_Register(ra_,this,idx4)/* res */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 false /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ bind(good);
    }
  
#line 41534 "ad_aarch64.cpp"
  }
}

void zCompareAndExchangePAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 193 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               true /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), opnd_array(4)->as_Register(ra_,this,idx4)/* res */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 true /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ bind(good);
    }
  
#line 41565 "ad_aarch64.cpp"
  }
}

void zGetAndSetPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// prev
  {
    C2_MacroAssembler _masm(&cbuf);

#line 221 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    __ atomic_xchg(opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */);
    z_load_barrier(_masm, this, Address(noreg, 0), opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, rscratch2 /* tmp */, barrier_data());
  
#line 41584 "ad_aarch64.cpp"
  }
}

void zGetAndSetPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// prev
  {
    C2_MacroAssembler _masm(&cbuf);

#line 238 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    __ atomic_xchgal(opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */);
    z_load_barrier(_masm, this, Address(noreg, 0), opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, rscratch2 /* tmp */, barrier_data());
  
#line 41603 "ad_aarch64.cpp"
  }
}

const MachOper* loadBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadINode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadLNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadRangeNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadNNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadNKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadFNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadDNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmCM0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmCM0_orderedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeBNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmB0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeCNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmC0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeINode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmI0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeLNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmL0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storePNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmP0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeNNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmN0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeFNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeDNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeNKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchallocNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUI2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadL_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadP_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadN_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadF_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadD_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeB_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmB0_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeC_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmC0_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeI_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmI0_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeL_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmL0_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeP_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmP0_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeN_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmN0_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeF_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeD_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* cacheWBNode::memory_operand() const { return _opnds[1]; }
const MachOper* popCountI_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* popCountL_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapBNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapSNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapINode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapLNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapPNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapNNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapBAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapSAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeBNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeSNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeINode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeLNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeNNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangePNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeBAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeSAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangePAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapBNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapSNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapINode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapLNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapNNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapPNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapBAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapSAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setINode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setLNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setNNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setPNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addL_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLiNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLi_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addINode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addI_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIiNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIi_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addL_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLiAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLi_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addI_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIiAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIi_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV2Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV2Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV4Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV4Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV16Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV16Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadVNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeVNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* vloadmask_loadVNode::memory_operand() const { return _opnds[1]; }
const MachOper* vloadmask_loadV_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* vloadmask_loadVMaskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* vloadmask_loadVMasked_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV_vstoremaskNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV_vstoremask_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeVMasked_vstoremaskNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeVMasked_vstoremask_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* gather_loadSNode::memory_operand() const { return _opnds[1]; }
const MachOper* gather_loadDNode::memory_operand() const { return _opnds[1]; }
const MachOper* gather_loadS_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* gather_loadD_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* scatter_storeSNode::memory_operand() const { return _opnds[1]; }
const MachOper* scatter_storeDNode::memory_operand() const { return _opnds[1]; }
const MachOper* scatter_storeS_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* scatter_storeD_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapP_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapN_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapPAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapNAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeN_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeP_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeNAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangePAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapN_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapP_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapNAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapPAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* zLoadPNode::memory_operand() const { return _opnds[1]; }
const MachOper* zLoadPVolatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapPNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapP_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapPAcq_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndExchangePNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndExchangePAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* zGetAndSetPNode::memory_operand() const { return _opnds[1]; }
const MachOper* zGetAndSetPAcqNode::memory_operand() const { return _opnds[1]; }


const bool Matcher::has_match_rule(int opcode) {
  assert(_last_machine_leaf < opcode && opcode < _last_opcode, "opcode in range");
  return _hasMatchRule[opcode];
}

const bool Matcher::_hasMatchRule[_last_opcode] = {
    false,  // Node
    false,  // Set
    false,  // RegN
    false,  // RegI
    false,  // RegP
    false,  // RegF
    false,  // RegD
    false,  // RegL
    false,  // VecA
    false,  // VecS
    false,  // VecD
    false,  // VecX
    false,  // VecY
    false,  // VecZ
    false,  // RegVectMask
    false,  // RegFlags
    false,  // _last_machine_leaf
    true ,  // AbsD
    true ,  // AbsF
    true ,  // AbsI
    true ,  // AbsL
    true ,  // AddD
    true ,  // AddF
    true ,  // AddI
    true ,  // AddL
    true ,  // AddP
    false,  // Allocate
    false,  // AllocateArray
    true ,  // AndI
    true ,  // AndL
    false,  // ArrayCopy
    true ,  // AryEq
    false,  // AtanD
    true ,  // Binary
    false,  // Blackhole
    true ,  // Bool
    false,  // BoxLock
    true ,  // ReverseBytesI
    true ,  // ReverseBytesL
    true ,  // ReverseBytesUS
    true ,  // ReverseBytesS
    true ,  // ReverseBytesV
    false,  // CProj
    true ,  // CacheWB
    true ,  // CacheWBPreSync
    true ,  // CacheWBPostSync
    true ,  // CallDynamicJava
    false,  // CallJava
    true ,  // CallLeaf
    true ,  // CallLeafNoFP
    false,  // CallLeafVector
    true ,  // CallRuntime
    true ,  // CallStaticJava
    true ,  // CastDD
    true ,  // CastFF
    true ,  // CastII
    true ,  // CastLL
    true ,  // CastVV
    true ,  // CastX2P
    true ,  // CastP2X
    true ,  // CastPP
    false,  // Catch
    false,  // CatchProj
    true ,  // CheckCastPP
    true ,  // ClearArray
    false,  // CompressBits
    false,  // ExpandBits
    false,  // ConstraintCast
    true ,  // CMoveD
    true ,  // CMoveVD
    true ,  // CMoveF
    true ,  // CMoveVF
    true ,  // CMoveI
    true ,  // CMoveL
    true ,  // CMoveP
    true ,  // CMoveN
    true ,  // CmpN
    true ,  // CmpD
    true ,  // CmpD3
    true ,  // CmpF
    true ,  // CmpF3
    true ,  // CmpI
    true ,  // CmpL
    true ,  // CmpL3
    true ,  // CmpLTMask
    true ,  // CmpP
    true ,  // CmpU
    false,  // CmpU3
    true ,  // CmpUL
    false,  // CmpUL3
    true ,  // CompareAndSwapB
    true ,  // CompareAndSwapS
    true ,  // CompareAndSwapI
    true ,  // CompareAndSwapL
    true ,  // CompareAndSwapP
    true ,  // CompareAndSwapN
    true ,  // WeakCompareAndSwapB
    true ,  // WeakCompareAndSwapS
    true ,  // WeakCompareAndSwapI
    true ,  // WeakCompareAndSwapL
    true ,  // WeakCompareAndSwapP
    true ,  // WeakCompareAndSwapN
    true ,  // CompareAndExchangeB
    true ,  // CompareAndExchangeS
    true ,  // CompareAndExchangeI
    true ,  // CompareAndExchangeL
    true ,  // CompareAndExchangeP
    true ,  // CompareAndExchangeN
    false,  // GetAndAddB
    false,  // GetAndAddS
    true ,  // GetAndAddI
    true ,  // GetAndAddL
    false,  // GetAndSetB
    false,  // GetAndSetS
    true ,  // GetAndSetI
    true ,  // GetAndSetL
    true ,  // GetAndSetP
    true ,  // GetAndSetN
    false,  // Con
    true ,  // ConN
    true ,  // ConNKlass
    true ,  // ConD
    true ,  // ConF
    true ,  // ConI
    true ,  // ConL
    true ,  // ConP
    true ,  // Conv2B
    true ,  // ConvD2F
    true ,  // ConvD2I
    true ,  // ConvD2L
    true ,  // ConvF2D
    true ,  // ConvF2I
    true ,  // ConvF2L
    true ,  // ConvI2D
    true ,  // ConvI2F
    true ,  // ConvI2L
    true ,  // ConvL2D
    true ,  // ConvL2F
    true ,  // ConvL2I
    true ,  // ConvF2HF
    true ,  // ConvHF2F
    false,  // CountedLoop
    true ,  // CountedLoopEnd
    false,  // OuterStripMinedLoop
    false,  // OuterStripMinedLoopEnd
    false,  // LongCountedLoop
    false,  // LongCountedLoopEnd
    true ,  // CountLeadingZerosI
    true ,  // CountLeadingZerosL
    true ,  // CountLeadingZerosV
    true ,  // CountTrailingZerosI
    true ,  // CountTrailingZerosL
    true ,  // CountTrailingZerosV
    true ,  // CreateEx
    true ,  // DecodeN
    true ,  // DecodeNKlass
    true ,  // DivD
    true ,  // DivF
    true ,  // DivI
    true ,  // DivL
    true ,  // UDivI
    true ,  // UDivL
    false,  // DivMod
    false,  // DivModI
    false,  // DivModL
    false,  // UDivModI
    false,  // UDivModL
    true ,  // EncodeISOArray
    true ,  // EncodeP
    true ,  // EncodePKlass
    true ,  // FastLock
    true ,  // FastUnlock
    true ,  // FmaD
    true ,  // FmaF
    true ,  // Goto
    true ,  // Halt
    true ,  // CountPositives
    true ,  // If
    false,  // RangeCheck
    false,  // IfFalse
    false,  // IfTrue
    false,  // Initialize
    false,  // JProj
    false,  // Jump
    false,  // JumpProj
    true ,  // LShiftI
    true ,  // LShiftL
    true ,  // LoadB
    true ,  // LoadUB
    true ,  // LoadUS
    true ,  // LoadD
    false,  // LoadD_unaligned
    true ,  // LoadF
    true ,  // LoadI
    true ,  // LoadKlass
    true ,  // LoadNKlass
    true ,  // LoadL
    false,  // LoadL_unaligned
    true ,  // LoadP
    true ,  // LoadN
    true ,  // LoadRange
    true ,  // LoadS
    false,  // Lock
    false,  // Loop
    false,  // LoopLimit
    false,  // Mach
    false,  // MachNullCheck
    false,  // MachProj
    true ,  // MulAddS2I
    true ,  // MaxI
    false,  // MaxL
    true ,  // MaxD
    true ,  // MaxF
    true ,  // MemBarAcquire
    true ,  // LoadFence
    true ,  // MemBarAcquireLock
    false,  // MemBarCPUOrder
    true ,  // MemBarRelease
    true ,  // StoreFence
    true ,  // StoreStoreFence
    true ,  // MemBarReleaseLock
    true ,  // MemBarVolatile
    true ,  // MemBarStoreStore
    false,  // MergeMem
    true ,  // MinI
    false,  // MinL
    true ,  // MinF
    true ,  // MinD
    false,  // ModD
    false,  // ModF
    true ,  // ModI
    true ,  // ModL
    true ,  // UModI
    true ,  // UModL
    true ,  // MoveI2F
    true ,  // MoveF2I
    true ,  // MoveL2D
    true ,  // MoveD2L
    false,  // IsInfiniteF
    false,  // IsFiniteF
    false,  // IsInfiniteD
    false,  // IsFiniteD
    true ,  // MulD
    true ,  // MulF
    true ,  // MulHiL
    true ,  // UMulHiL
    true ,  // MulI
    true ,  // MulL
    false,  // Multi
    false,  // NegI
    false,  // NegL
    true ,  // NegD
    true ,  // NegF
    false,  // NeverBranch
    true ,  // OnSpinWait
    false,  // Opaque1
    false,  // OpaqueLoopInit
    false,  // OpaqueLoopStride
    false,  // OpaqueZeroTripGuard
    false,  // Opaque3
    false,  // Opaque4
    false,  // ProfileBoolean
    true ,  // OrI
    true ,  // OrL
    true ,  // OverflowAddI
    true ,  // OverflowSubI
    true ,  // OverflowMulI
    true ,  // OverflowAddL
    true ,  // OverflowSubL
    true ,  // OverflowMulL
    false,  // PCTable
    false,  // Parm
    true ,  // PartialSubtypeCheck
    false,  // SubTypeCheck
    false,  // Phi
    true ,  // PopCountI
    true ,  // PopCountL
    true ,  // PopCountVI
    true ,  // PopCountVL
    true ,  // PopulateIndex
    true ,  // PrefetchAllocation
    false,  // Proj
    true ,  // RShiftI
    true ,  // RShiftL
    false,  // Region
    true ,  // Rethrow
    true ,  // Return
    false,  // ReverseI
    false,  // ReverseL
    true ,  // ReverseV
    false,  // Root
    false,  // RoundDouble
    true ,  // RoundDoubleMode
    true ,  // RoundDoubleModeV
    false,  // RoundFloat
    true ,  // RotateLeft
    false,  // RotateLeftV
    true ,  // RotateRight
    false,  // RotateRightV
    true ,  // SafePoint
    false,  // SafePointScalarObject
    true ,  // ShenandoahCompareAndExchangeP
    true ,  // ShenandoahCompareAndExchangeN
    true ,  // ShenandoahCompareAndSwapN
    true ,  // ShenandoahCompareAndSwapP
    true ,  // ShenandoahWeakCompareAndSwapN
    true ,  // ShenandoahWeakCompareAndSwapP
    false,  // ShenandoahIUBarrier
    false,  // ShenandoahLoadReferenceBarrier
    false,  // SCMemProj
    true ,  // CopySignD
    true ,  // CopySignF
    true ,  // SignumD
    true ,  // SignumF
    true ,  // SignumVF
    true ,  // SignumVD
    true ,  // SqrtD
    true ,  // SqrtF
    true ,  // RoundF
    true ,  // RoundD
    false,  // Start
    false,  // StartOSR
    true ,  // StoreB
    true ,  // StoreC
    true ,  // StoreCM
    true ,  // StoreD
    true ,  // StoreF
    true ,  // StoreI
    true ,  // StoreL
    true ,  // StoreP
    true ,  // StoreN
    true ,  // StoreNKlass
    true ,  // StrComp
    true ,  // StrCompressedCopy
    true ,  // StrEquals
    true ,  // StrIndexOf
    true ,  // StrIndexOfChar
    true ,  // StrInflatedCopy
    true ,  // SubD
    true ,  // SubF
    true ,  // SubI
    true ,  // SubL
    true ,  // TailCall
    true ,  // TailJump
    false,  // MacroLogicV
    true ,  // ThreadLocal
    false,  // Unlock
    false,  // URShiftB
    false,  // URShiftS
    true ,  // URShiftI
    true ,  // URShiftL
    true ,  // XorI
    true ,  // XorL
    false,  // Vector
    true ,  // AddVB
    true ,  // AddVS
    true ,  // AddVI
    true ,  // AddReductionVI
    true ,  // AddVL
    true ,  // AddReductionVL
    true ,  // AddVF
    true ,  // AddReductionVF
    true ,  // AddVD
    true ,  // AddReductionVD
    true ,  // SubVB
    true ,  // SubVS
    true ,  // SubVI
    true ,  // SubVL
    true ,  // SubVF
    true ,  // SubVD
    true ,  // MulVB
    true ,  // MulVS
    true ,  // MulVI
    true ,  // MulReductionVI
    true ,  // MulVL
    true ,  // MulReductionVL
    true ,  // MulVF
    true ,  // MulReductionVF
    true ,  // MulVD
    true ,  // MulReductionVD
    true ,  // MulAddVS2VI
    true ,  // FmaVD
    true ,  // FmaVF
    true ,  // DivVF
    true ,  // DivVD
    true ,  // AbsVB
    true ,  // AbsVS
    true ,  // AbsVI
    true ,  // AbsVL
    true ,  // AbsVF
    true ,  // AbsVD
    true ,  // NegVI
    true ,  // NegVL
    true ,  // NegVF
    true ,  // NegVD
    true ,  // SqrtVD
    true ,  // SqrtVF
    true ,  // LShiftCntV
    true ,  // RShiftCntV
    true ,  // LShiftVB
    true ,  // LShiftVS
    true ,  // LShiftVI
    true ,  // LShiftVL
    true ,  // RShiftVB
    true ,  // RShiftVS
    true ,  // RShiftVI
    true ,  // RShiftVL
    true ,  // URShiftVB
    true ,  // URShiftVS
    true ,  // URShiftVI
    true ,  // URShiftVL
    true ,  // AndV
    true ,  // AndReductionV
    true ,  // OrV
    true ,  // OrReductionV
    true ,  // XorV
    true ,  // XorReductionV
    true ,  // MinV
    true ,  // MaxV
    true ,  // MinReductionV
    true ,  // MaxReductionV
    true ,  // CompressV
    true ,  // CompressM
    true ,  // ExpandV
    true ,  // LoadVector
    true ,  // LoadVectorGather
    true ,  // LoadVectorGatherMasked
    true ,  // StoreVector
    true ,  // StoreVectorScatter
    true ,  // StoreVectorScatterMasked
    true ,  // LoadVectorMasked
    true ,  // StoreVectorMasked
    false,  // VectorCmpMasked
    true ,  // VectorMaskGen
    false,  // VectorMaskOp
    true ,  // VectorMaskTrueCount
    true ,  // VectorMaskFirstTrue
    true ,  // VectorMaskLastTrue
    true ,  // VectorMaskToLong
    true ,  // VectorLongToMask
    false,  // Pack
    false,  // PackB
    false,  // PackS
    false,  // PackI
    false,  // PackL
    false,  // PackF
    false,  // PackD
    false,  // Pack2L
    false,  // Pack2D
    true ,  // ReplicateB
    true ,  // ReplicateS
    true ,  // ReplicateI
    true ,  // ReplicateL
    true ,  // ReplicateF
    true ,  // ReplicateD
    true ,  // RoundVF
    true ,  // RoundVD
    false,  // Extract
    true ,  // ExtractB
    false,  // ExtractUB
    false,  // ExtractC
    true ,  // ExtractS
    true ,  // ExtractI
    true ,  // ExtractL
    true ,  // ExtractF
    true ,  // ExtractD
    false,  // Digit
    false,  // LowerCase
    false,  // UpperCase
    false,  // Whitespace
    false,  // VectorBox
    false,  // VectorBoxAllocate
    false,  // VectorUnbox
    false,  // VectorMaskWrapper
    true ,  // VectorMaskCmp
    true ,  // VectorMaskCast
    true ,  // VectorTest
    true ,  // VectorBlend
    true ,  // VectorRearrange
    true ,  // VectorLoadMask
    true ,  // VectorLoadShuffle
    true ,  // VectorLoadConst
    true ,  // VectorStoreMask
    true ,  // VectorReinterpret
    false,  // VectorCast
    true ,  // VectorCastB2X
    true ,  // VectorCastS2X
    true ,  // VectorCastI2X
    true ,  // VectorCastL2X
    true ,  // VectorCastF2X
    true ,  // VectorCastD2X
    false,  // VectorCastF2HF
    false,  // VectorCastHF2F
    false,  // VectorUCastB2X
    false,  // VectorUCastS2X
    false,  // VectorUCastI2X
    true ,  // VectorInsert
    true ,  // MaskAll
    true ,  // AndVMask
    true ,  // OrVMask
    true    // XorVMask
};


int Compile::sync_stack_slots() const { return 2; }

uint Matcher::stack_alignment_in_bytes() { return StackAlignmentInBytes; }

OptoReg::Name Matcher::return_addr() const { return OptoReg::stack2reg(- 2 +
              align_up((Compile::current()->in_preserve_stack_slots() +
                        Compile::current()->fixed_slots()),
                       stack_alignment_in_slots())); }

uint Compile::varargs_C_out_slots_killed() const { return frame::arg_reg_save_area_bytes/BytesPerInt; }

OptoRegPair Matcher::return_value(uint ideal_reg) {

#line 4026 "src/hotspot/cpu/aarch64/aarch64.ad"

    // TODO do we allow ideal_reg == Op_RegN???
    assert(ideal_reg >= Op_RegI && ideal_reg <= Op_RegL,
           "only return normal values");

    static const int lo[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      R0_num,                            // Op_RegN
      R0_num,                            // Op_RegI
      R0_num,                            // Op_RegP
      V0_num,                            // Op_RegF
      V0_num,                            // Op_RegD
      R0_num                             // Op_RegL
    };

    static const int hi[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      OptoReg::Bad,                      // Op_RegN
      OptoReg::Bad,                      // Op_RegI
      R0_H_num,                          // Op_RegP
      OptoReg::Bad,                      // Op_RegF
      V0_H_num,                          // Op_RegD
      R0_H_num                           // Op_RegL
    };

    return OptoRegPair(hi[ideal_reg], lo[ideal_reg]);
  
#line 42341 "ad_aarch64.cpp"

}

OptoRegPair Matcher::c_return_value(uint ideal_reg) {

#line 4026 "src/hotspot/cpu/aarch64/aarch64.ad"

    // TODO do we allow ideal_reg == Op_RegN???
    assert(ideal_reg >= Op_RegI && ideal_reg <= Op_RegL,
           "only return normal values");

    static const int lo[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      R0_num,                            // Op_RegN
      R0_num,                            // Op_RegI
      R0_num,                            // Op_RegP
      V0_num,                            // Op_RegF
      V0_num,                            // Op_RegD
      R0_num                             // Op_RegL
    };

    static const int hi[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      OptoReg::Bad,                      // Op_RegN
      OptoReg::Bad,                      // Op_RegI
      R0_H_num,                          // Op_RegP
      OptoReg::Bad,                      // Op_RegF
      V0_H_num,                          // Op_RegD
      R0_H_num                           // Op_RegL
    };

    return OptoRegPair(hi[ideal_reg], lo[ideal_reg]);
  
#line 42377 "ad_aarch64.cpp"

}

OptoReg::Name Matcher::inline_cache_reg() { return OptoReg::Name(R12_num); }

int Matcher::inline_cache_reg_encode() { return _regEncode[inline_cache_reg()]; }

OptoReg::Name Matcher::interpreter_frame_pointer_reg() { return OptoReg::Name(R29_num); }

OptoReg::Name Matcher::c_frame_pointer() const { return OptoReg::Name(R31_num); }

// Number of callee-save + always-save registers
int  Matcher::number_of_saved_registers() {
  return 0;
};

bool Compile::needs_deep_clone_jvms() { return false; }

// Check consistency of C++ compilation with ADLC options:
// Check adlc -DLINUX=1
#ifndef LINUX
#  error "LINUX must be defined"
#endif // LINUX
// Check adlc -D_GNU_SOURCE=1
#ifndef _GNU_SOURCE
#  error "_GNU_SOURCE must be defined"
#endif // _GNU_SOURCE
// Check adlc -DAARCH64=1
#ifndef AARCH64
#  error "AARCH64 must be defined"
#endif // AARCH64
// Check adlc -D_LP64=1
#ifndef _LP64
#  error "_LP64 must be defined"
#endif // _LP64
